docs.rs failed to build nominal-api-0.1424.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
nominal-api-0.1379.0
Nominal API
Generated API objects and services for https://nominal.io.
Features
tonic(default): Generate types for gRPC support compatible with Tonic for runtime gRPC client/server functionality
Usage
Use with conjure-runtime and/or tonic to make requests to the Nominal API.