Module attachment_service

Module attachment_service 

Structs

AsyncAttachmentServiceClient
AttachmentServiceClient
LocalAsyncAttachmentServiceClient

Traits

AsyncAttachmentService
The attachment service provides functionality for creating, updating, and archiving attachments uploaded to S3.
AttachmentService
The attachment service provides functionality for creating, updating, and archiving attachments uploaded to S3.
LocalAsyncAttachmentService
The attachment service provides functionality for creating, updating, and archiving attachments uploaded to S3.