Module authentication_service_v2

Module authentication_service_v2 

Structs

AsyncAuthenticationServiceV2Client
AuthenticationServiceV2Client
LocalAsyncAuthenticationServiceV2Client

Traits

AsyncAuthenticationServiceV2
This service provides operations for managing user and org profiles/settings. Its name is a bit of a misnomer.
AuthenticationServiceV2
This service provides operations for managing user and org profiles/settings. Its name is a bit of a misnomer.
LocalAsyncAuthenticationServiceV2
This service provides operations for managing user and org profiles/settings. Its name is a bit of a misnomer.