pub struct AsyncAuthenticationServiceV2Client<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncAuthenticationServiceV2<I> for AsyncAuthenticationServiceV2Client<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncAuthenticationServiceV2<I> for AsyncAuthenticationServiceV2Client<__C>
Sourceasync fn get_my_profile(&self, auth_: &BearerToken) -> Result<UserV2, Error>
async fn get_my_profile(&self, auth_: &BearerToken) -> Result<UserV2, Error>
Gets the profile of the authenticated user.
Sourceasync fn update_my_profile(
&self,
auth_: &BearerToken,
update_my_profile_request: &UpdateMyProfileRequest,
) -> Result<UserV2, Error>
async fn update_my_profile( &self, auth_: &BearerToken, update_my_profile_request: &UpdateMyProfileRequest, ) -> Result<UserV2, Error>
Updates the profile of the authenticated user.
Sourceasync fn get_my_settings(
&self,
auth_: &BearerToken,
) -> Result<UserSettings, Error>
async fn get_my_settings( &self, auth_: &BearerToken, ) -> Result<UserSettings, Error>
Gets the settings of the authenticated user.
Sourceasync fn update_my_settings(
&self,
auth_: &BearerToken,
user_settings: &UserSettings,
) -> Result<UserSettings, Error>
async fn update_my_settings( &self, auth_: &BearerToken, user_settings: &UserSettings, ) -> Result<UserSettings, Error>
Updates the settings of the authenticated user.
Sourceasync fn get_my_org_settings(
&self,
auth_: &BearerToken,
) -> Result<OrgSettings, Error>
async fn get_my_org_settings( &self, auth_: &BearerToken, ) -> Result<OrgSettings, Error>
Gets the settings of the org of the authenticated user.
Sourceasync fn update_my_org_settings(
&self,
auth_: &BearerToken,
org_settings: &OrgSettings,
) -> Result<OrgSettings, Error>
async fn update_my_org_settings( &self, auth_: &BearerToken, org_settings: &OrgSettings, ) -> Result<OrgSettings, Error>
Updates the settings of the org of the authenticated user.
Sourceasync fn search_users_v2(
&self,
auth_: &BearerToken,
request: &SearchUsersRequest,
) -> Result<SearchUsersResponseV2, Error>
async fn search_users_v2( &self, auth_: &BearerToken, request: &SearchUsersRequest, ) -> Result<SearchUsersResponseV2, Error>
Searches for users by email and displayName.
Sourceasync fn get_users(
&self,
auth_: &BearerToken,
user_rids: &BTreeSet<UserRid>,
) -> Result<BTreeSet<UserV2>, Error>
async fn get_users( &self, auth_: &BearerToken, user_rids: &BTreeSet<UserRid>, ) -> Result<BTreeSet<UserV2>, Error>
Get users by RID.
Sourceasync fn get_user(
&self,
auth_: &BearerToken,
user_rid: &UserRid,
) -> Result<UserV2, Error>
async fn get_user( &self, auth_: &BearerToken, user_rid: &UserRid, ) -> Result<UserV2, Error>
Gets a user by RID.
Sourceasync fn get_jwks(&self) -> Result<Jwks, Error>
async fn get_jwks(&self) -> Result<Jwks, Error>
Returns JWKS (JSON Web Key Set) for MediaMTX JWT verification.
Only available if MediaMTX integration is enabled.
Sourceasync fn generate_media_mtx_token(
&self,
auth_: &BearerToken,
request: &GenerateMediaMtxTokenRequest,
) -> Result<GenerateMediaMtxTokenResponse, Error>
async fn generate_media_mtx_token( &self, auth_: &BearerToken, request: &GenerateMediaMtxTokenRequest, ) -> Result<GenerateMediaMtxTokenResponse, Error>
Generates a JWT token for MediaMTX authentication with a 2-hour expiration.
The token is signed with the MediaMTX private key and contains the specified permissions.
Requires authentication with Nominal. This endpoint is intended for internal use only.
Sourceasync fn get_my_coachmark_dismissals(
&self,
auth_: &BearerToken,
request: &GetCoachmarkDismissalsRequest,
) -> Result<GetCoachmarkDismissalsResponse, Error>
async fn get_my_coachmark_dismissals( &self, auth_: &BearerToken, request: &GetCoachmarkDismissalsRequest, ) -> Result<GetCoachmarkDismissalsResponse, Error>
Gets coachmark dismissals for the authenticated user.
Optionally filter by specific coachmark IDs.
Sourceasync fn dismiss_my_coachmark(
&self,
auth_: &BearerToken,
request: &DismissCoachmarkRequest,
) -> Result<CoachmarkDismissal, Error>
async fn dismiss_my_coachmark( &self, auth_: &BearerToken, request: &DismissCoachmarkRequest, ) -> Result<CoachmarkDismissal, Error>
Dismisses a coachmark for the authenticated user.
Records the dismissal timestamp and app version.
Sourceasync fn is_my_coachmark_dismissed(
&self,
auth_: &BearerToken,
coachmark_id: &str,
) -> Result<bool, Error>
async fn is_my_coachmark_dismissed( &self, auth_: &BearerToken, coachmark_id: &str, ) -> Result<bool, Error>
Checks if a specific coachmark has been dismissed by the authenticated user.
Sourceasync fn reset_my_coachmark_dismissal(
&self,
auth_: &BearerToken,
coachmark_id: &str,
) -> Result<(), Error>
async fn reset_my_coachmark_dismissal( &self, auth_: &BearerToken, coachmark_id: &str, ) -> Result<(), Error>
Resets a coachmark dismissal for the authenticated user.
This allows the coachmark to be shown again.
Primarily intended for testing and debugging.
Sourceimpl<C> AsyncService<C> for AsyncAuthenticationServiceV2Client<C>
impl<C> AsyncService<C> for AsyncAuthenticationServiceV2Client<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncAuthenticationServiceV2Client<C>
impl<C: Clone> Clone for AsyncAuthenticationServiceV2Client<C>
Sourcefn clone(&self) -> AsyncAuthenticationServiceV2Client<C>
fn clone(&self) -> AsyncAuthenticationServiceV2Client<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncAuthenticationServiceV2Client<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncAuthenticationServiceV2Client<C>
impl<C> Send for AsyncAuthenticationServiceV2Client<C>where
C: Send,
impl<C> Sync for AsyncAuthenticationServiceV2Client<C>where
C: Sync,
impl<C> Unpin for AsyncAuthenticationServiceV2Client<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncAuthenticationServiceV2Client<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncAuthenticationServiceV2Client<C>