pub struct AuthenticationServiceV2Client<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> AuthenticationServiceV2<I> for AuthenticationServiceV2Client<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> AuthenticationServiceV2<I> for AuthenticationServiceV2Client<__C>where
__C: Client<ResponseBody = I>,
Sourcefn get_my_profile(&self, auth_: &BearerToken) -> Result<UserV2, Error>
fn get_my_profile(&self, auth_: &BearerToken) -> Result<UserV2, Error>
Gets the profile of the authenticated user.
Sourcefn update_my_profile(
&self,
auth_: &BearerToken,
update_my_profile_request: &UpdateMyProfileRequest,
) -> Result<UserV2, Error>
fn update_my_profile( &self, auth_: &BearerToken, update_my_profile_request: &UpdateMyProfileRequest, ) -> Result<UserV2, Error>
Updates the profile of the authenticated user.
Sourcefn get_my_settings(&self, auth_: &BearerToken) -> Result<UserSettings, Error>
fn get_my_settings(&self, auth_: &BearerToken) -> Result<UserSettings, Error>
Gets the settings of the authenticated user.
Sourcefn update_my_settings(
&self,
auth_: &BearerToken,
user_settings: &UserSettings,
) -> Result<UserSettings, Error>
fn update_my_settings( &self, auth_: &BearerToken, user_settings: &UserSettings, ) -> Result<UserSettings, Error>
Updates the settings of the authenticated user.
Sourcefn get_my_org_settings(&self, auth_: &BearerToken) -> Result<OrgSettings, Error>
fn get_my_org_settings(&self, auth_: &BearerToken) -> Result<OrgSettings, Error>
Gets the settings of the org of the authenticated user.
Sourcefn update_my_org_settings(
&self,
auth_: &BearerToken,
org_settings: &OrgSettings,
) -> Result<OrgSettings, Error>
fn update_my_org_settings( &self, auth_: &BearerToken, org_settings: &OrgSettings, ) -> Result<OrgSettings, Error>
Updates the settings of the org of the authenticated user.
Sourcefn search_users_v2(
&self,
auth_: &BearerToken,
request: &SearchUsersRequest,
) -> Result<SearchUsersResponseV2, Error>
fn search_users_v2( &self, auth_: &BearerToken, request: &SearchUsersRequest, ) -> Result<SearchUsersResponseV2, Error>
Searches for users by email and displayName.
Sourcefn get_users(
&self,
auth_: &BearerToken,
user_rids: &BTreeSet<UserRid>,
) -> Result<BTreeSet<UserV2>, Error>
fn get_users( &self, auth_: &BearerToken, user_rids: &BTreeSet<UserRid>, ) -> Result<BTreeSet<UserV2>, Error>
Get users by RID.
Sourcefn get_user(
&self,
auth_: &BearerToken,
user_rid: &UserRid,
) -> Result<UserV2, Error>
fn get_user( &self, auth_: &BearerToken, user_rid: &UserRid, ) -> Result<UserV2, Error>
Gets a user by RID.
Sourcefn get_jwks(&self) -> Result<Jwks, Error>
fn get_jwks(&self) -> Result<Jwks, Error>
Returns JWKS (JSON Web Key Set) for MediaMTX JWT verification.
Only available if MediaMTX integration is enabled.
Sourcefn generate_media_mtx_token(
&self,
auth_: &BearerToken,
request: &GenerateMediaMtxTokenRequest,
) -> Result<GenerateMediaMtxTokenResponse, Error>
fn generate_media_mtx_token( &self, auth_: &BearerToken, request: &GenerateMediaMtxTokenRequest, ) -> Result<GenerateMediaMtxTokenResponse, Error>
Generates a JWT token for MediaMTX authentication with a 2-hour expiration.
The token is signed with the MediaMTX private key and contains the specified permissions.
Requires authentication with Nominal. This endpoint is intended for internal use only.
Sourcefn get_my_coachmark_dismissals(
&self,
auth_: &BearerToken,
request: &GetCoachmarkDismissalsRequest,
) -> Result<GetCoachmarkDismissalsResponse, Error>
fn get_my_coachmark_dismissals( &self, auth_: &BearerToken, request: &GetCoachmarkDismissalsRequest, ) -> Result<GetCoachmarkDismissalsResponse, Error>
Gets coachmark dismissals for the authenticated user.
Optionally filter by specific coachmark IDs.
Sourcefn dismiss_my_coachmark(
&self,
auth_: &BearerToken,
request: &DismissCoachmarkRequest,
) -> Result<CoachmarkDismissal, Error>
fn dismiss_my_coachmark( &self, auth_: &BearerToken, request: &DismissCoachmarkRequest, ) -> Result<CoachmarkDismissal, Error>
Dismisses a coachmark for the authenticated user.
Records the dismissal timestamp and app version.
Sourcefn is_my_coachmark_dismissed(
&self,
auth_: &BearerToken,
coachmark_id: &str,
) -> Result<bool, Error>
fn is_my_coachmark_dismissed( &self, auth_: &BearerToken, coachmark_id: &str, ) -> Result<bool, Error>
Checks if a specific coachmark has been dismissed by the authenticated user.
Sourcefn reset_my_coachmark_dismissal(
&self,
auth_: &BearerToken,
coachmark_id: &str,
) -> Result<(), Error>
fn reset_my_coachmark_dismissal( &self, auth_: &BearerToken, coachmark_id: &str, ) -> Result<(), Error>
Resets a coachmark dismissal for the authenticated user.
This allows the coachmark to be shown again.
Primarily intended for testing and debugging.
Sourceimpl<C: Clone> Clone for AuthenticationServiceV2Client<C>
impl<C: Clone> Clone for AuthenticationServiceV2Client<C>
Sourcefn clone(&self) -> AuthenticationServiceV2Client<C>
fn clone(&self) -> AuthenticationServiceV2Client<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for AuthenticationServiceV2Client<C>
impl<C: Debug> Debug for AuthenticationServiceV2Client<C>
Sourceimpl<C> Service<C> for AuthenticationServiceV2Client<C>
impl<C> Service<C> for AuthenticationServiceV2Client<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.