pub struct AsyncCommentsServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncCommentsService<I> for AsyncCommentsServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncCommentsService<I> for AsyncCommentsServiceClient<__C>
Sourceasync fn get_conversation(
&self,
auth_: &BearerToken,
resource_type: &ResourceType,
resource_rid: &ResourceIdentifier,
) -> Result<Conversation, Error>
async fn get_conversation( &self, auth_: &BearerToken, resource_type: &ResourceType, resource_rid: &ResourceIdentifier, ) -> Result<Conversation, Error>
A conversation is a fully resolved comment tree. It includes all comments for the given resource
and all the nested comments/replies to those comments.
Sourceasync fn get_conversation_count(
&self,
auth_: &BearerToken,
resource_type: &ResourceType,
resource_rid: &ResourceIdentifier,
include_deleted: Option<bool>,
) -> Result<i32, Error>
async fn get_conversation_count( &self, auth_: &BearerToken, resource_type: &ResourceType, resource_rid: &ResourceIdentifier, include_deleted: Option<bool>, ) -> Result<i32, Error>
Returns the number of comments in a conversation.
Sourceasync fn get_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
async fn get_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Get a comment identified by its RID
Sourceasync fn create_comment(
&self,
auth_: &BearerToken,
request: &CreateCommentRequest,
) -> Result<Comment, Error>
async fn create_comment( &self, auth_: &BearerToken, request: &CreateCommentRequest, ) -> Result<Comment, Error>
Create a comment on a resource
Sourceasync fn edit_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
request: &EditCommentRequest,
) -> Result<Comment, Error>
async fn edit_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, request: &EditCommentRequest, ) -> Result<Comment, Error>
Edit an existing comment
Sourceasync fn delete_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
async fn delete_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Delete an existing comment
Sourceasync fn pin_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
async fn pin_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Pin a comment to the top of the conversation
Sourceasync fn unpin_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
async fn unpin_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Unpin a comment from the top of the conversation
Sourceasync fn add_reaction(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
type_: &ReactionType,
) -> Result<Comment, Error>
async fn add_reaction( &self, auth_: &BearerToken, comment_rid: &CommentRid, type_: &ReactionType, ) -> Result<Comment, Error>
Create a reaction on a comment
Sourceasync fn remove_reaction(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
type_: &ReactionType,
) -> Result<Comment, Error>
async fn remove_reaction( &self, auth_: &BearerToken, comment_rid: &CommentRid, type_: &ReactionType, ) -> Result<Comment, Error>
Create a reaction on a comment
Sourceimpl<C> AsyncService<C> for AsyncCommentsServiceClient<C>
impl<C> AsyncService<C> for AsyncCommentsServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncCommentsServiceClient<C>
impl<C: Clone> Clone for AsyncCommentsServiceClient<C>
Sourcefn clone(&self) -> AsyncCommentsServiceClient<C>
fn clone(&self) -> AsyncCommentsServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncCommentsServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncCommentsServiceClient<C>
impl<C> Send for AsyncCommentsServiceClient<C>where
C: Send,
impl<C> Sync for AsyncCommentsServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncCommentsServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncCommentsServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncCommentsServiceClient<C>