pub struct CommentsServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for CommentsServiceClient<C>
impl<C: Clone> Clone for CommentsServiceClient<C>
Sourcefn clone(&self) -> CommentsServiceClient<C>
fn clone(&self) -> CommentsServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> CommentsService<I> for CommentsServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> CommentsService<I> for CommentsServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn get_conversation(
&self,
auth_: &BearerToken,
resource_type: &ResourceType,
resource_rid: &ResourceIdentifier,
) -> Result<Conversation, Error>
fn get_conversation( &self, auth_: &BearerToken, resource_type: &ResourceType, resource_rid: &ResourceIdentifier, ) -> Result<Conversation, Error>
A conversation is a fully resolved comment tree. It includes all comments for the given resource
and all the nested comments/replies to those comments.
Sourcefn get_conversation_count(
&self,
auth_: &BearerToken,
resource_type: &ResourceType,
resource_rid: &ResourceIdentifier,
include_deleted: Option<bool>,
) -> Result<i32, Error>
fn get_conversation_count( &self, auth_: &BearerToken, resource_type: &ResourceType, resource_rid: &ResourceIdentifier, include_deleted: Option<bool>, ) -> Result<i32, Error>
Returns the number of comments in a conversation.
Sourcefn get_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
fn get_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Get a comment identified by its RID
Sourcefn create_comment(
&self,
auth_: &BearerToken,
request: &CreateCommentRequest,
) -> Result<Comment, Error>
fn create_comment( &self, auth_: &BearerToken, request: &CreateCommentRequest, ) -> Result<Comment, Error>
Create a comment on a resource
Sourcefn edit_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
request: &EditCommentRequest,
) -> Result<Comment, Error>
fn edit_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, request: &EditCommentRequest, ) -> Result<Comment, Error>
Edit an existing comment
Sourcefn delete_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
fn delete_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Delete an existing comment
Sourcefn pin_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
fn pin_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Pin a comment to the top of the conversation
Sourcefn unpin_comment(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
) -> Result<Comment, Error>
fn unpin_comment( &self, auth_: &BearerToken, comment_rid: &CommentRid, ) -> Result<Comment, Error>
Unpin a comment from the top of the conversation
Sourcefn add_reaction(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
type_: &ReactionType,
) -> Result<Comment, Error>
fn add_reaction( &self, auth_: &BearerToken, comment_rid: &CommentRid, type_: &ReactionType, ) -> Result<Comment, Error>
Create a reaction on a comment
Sourcefn remove_reaction(
&self,
auth_: &BearerToken,
comment_rid: &CommentRid,
type_: &ReactionType,
) -> Result<Comment, Error>
fn remove_reaction( &self, auth_: &BearerToken, comment_rid: &CommentRid, type_: &ReactionType, ) -> Result<Comment, Error>
Create a reaction on a comment
Sourceimpl<C: Debug> Debug for CommentsServiceClient<C>
impl<C: Debug> Debug for CommentsServiceClient<C>
Sourceimpl<C> Service<C> for CommentsServiceClient<C>
impl<C> Service<C> for CommentsServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.