pub struct LocalAsyncEventServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncEventServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncEventServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncEventServiceClient<C>
impl<C: Clone> Clone for LocalAsyncEventServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncEventServiceClient<C>
fn clone(&self) -> LocalAsyncEventServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncEventServiceClient<C>
impl<C: Debug> Debug for LocalAsyncEventServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncEventService<I> for LocalAsyncEventServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncEventService<I> for LocalAsyncEventServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn create_event(
&self,
auth_: &BearerToken,
request: &CreateEvent,
) -> Result<Event, Error>
async fn create_event( &self, auth_: &BearerToken, request: &CreateEvent, ) -> Result<Event, Error>
Creates an event.
Sourceasync fn get_events(
&self,
auth_: &BearerToken,
request: &GetEvents,
) -> Result<BTreeSet<Event>, Error>
async fn get_events( &self, auth_: &BearerToken, request: &GetEvents, ) -> Result<BTreeSet<Event>, Error>
Gets a set of events by UUIDs
Sourceasync fn batch_get_events(
&self,
auth_: &BearerToken,
request: &BTreeSet<EventRid>,
) -> Result<BTreeSet<Event>, Error>
async fn batch_get_events( &self, auth_: &BearerToken, request: &BTreeSet<EventRid>, ) -> Result<BTreeSet<Event>, Error>
Gets a set of events by RID.
Sourceasync fn batch_filter_events(
&self,
auth_: &BearerToken,
request: &BatchFilterEventsRequest,
) -> Result<BTreeSet<Event>, Error>
async fn batch_filter_events( &self, auth_: &BearerToken, request: &BatchFilterEventsRequest, ) -> Result<BTreeSet<Event>, Error>
Gets a filtered set of events by RID and search filters.
Sourceasync fn update_event(
&self,
auth_: &BearerToken,
request: &UpdateEvent,
) -> Result<Event, Error>
async fn update_event( &self, auth_: &BearerToken, request: &UpdateEvent, ) -> Result<Event, Error>
Updates the fields of an event. Empty fields are left unchanged.
Sourceasync fn batch_update_event(
&self,
auth_: &BearerToken,
request: &BatchUpdateEventRequest,
) -> Result<BatchUpdateEventResponse, Error>
async fn batch_update_event( &self, auth_: &BearerToken, request: &BatchUpdateEventRequest, ) -> Result<BatchUpdateEventResponse, Error>
Updates the fields of an event specified by each request in the batch.
Empty fields in the UpdateEventRequest are left unchanged.
Sourceasync fn batch_update_disposition(
&self,
auth_: &BearerToken,
request: &BatchUpdateDispositionRequest,
) -> Result<BatchUpdateDispositionResponse, Error>
async fn batch_update_disposition( &self, auth_: &BearerToken, request: &BatchUpdateDispositionRequest, ) -> Result<BatchUpdateDispositionResponse, Error>
Updates the disposition of an event.
Sourceasync fn archive_event(
&self,
auth_: &BearerToken,
request: &ArchiveEvent,
) -> Result<(), Error>
async fn archive_event( &self, auth_: &BearerToken, request: &ArchiveEvent, ) -> Result<(), Error>
Archives an event
Sourceasync fn batch_archive_event(
&self,
auth_: &BearerToken,
request: &BTreeSet<EventRid>,
) -> Result<(), Error>
async fn batch_archive_event( &self, auth_: &BearerToken, request: &BTreeSet<EventRid>, ) -> Result<(), Error>
Archives a set of events
Sourceasync fn batch_unarchive_event(
&self,
auth_: &BearerToken,
request: &BTreeSet<EventRid>,
) -> Result<(), Error>
async fn batch_unarchive_event( &self, auth_: &BearerToken, request: &BTreeSet<EventRid>, ) -> Result<(), Error>
Unarchives a set of events
Sourceasync fn search_events(
&self,
auth_: &BearerToken,
request: &SearchEventsRequest,
) -> Result<SearchEventsResponse, Error>
async fn search_events( &self, auth_: &BearerToken, request: &SearchEventsRequest, ) -> Result<SearchEventsResponse, Error>
Searches for events that match the given filters.
Sourceasync fn aggregate_events(
&self,
auth_: &BearerToken,
request: &AggregateEventsRequest,
) -> Result<AggregateEventsResponse, Error>
async fn aggregate_events( &self, auth_: &BearerToken, request: &AggregateEventsRequest, ) -> Result<AggregateEventsResponse, Error>
Searches for events matching the given filter and aggregates them based on the requested functions.
Sourceasync fn batch_aggregate_events(
&self,
auth_: &BearerToken,
request: &BatchAggregateEventsRequest,
) -> Result<BatchAggregateEventsResponse, Error>
async fn batch_aggregate_events( &self, auth_: &BearerToken, request: &BatchAggregateEventsRequest, ) -> Result<BatchAggregateEventsResponse, Error>
Searches for events matching the given filter and aggregates them based on the requested functions.
Returns a list of responses in same order as the batched requests.
Sourceasync fn get_events_histogram(
&self,
auth_: &BearerToken,
request: &EventsHistogramRequest,
) -> Result<EventsHistogramResponse, Error>
async fn get_events_histogram( &self, auth_: &BearerToken, request: &EventsHistogramRequest, ) -> Result<EventsHistogramResponse, Error>
Gets a histogram of events that match the given filters.
Sourceasync fn list_properties_and_labels(
&self,
auth_: &BearerToken,
request: &ListPropertiesAndLabelsRequest,
) -> Result<ListPropertiesAndLabelsResponse, Error>
async fn list_properties_and_labels( &self, auth_: &BearerToken, request: &ListPropertiesAndLabelsRequest, ) -> Result<ListPropertiesAndLabelsResponse, Error>
Lists the properties and labels of all events in the provided workspaces.