pub struct LocalAsyncIngestServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncIngestServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncIngestServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncIngestServiceClient<C>
impl<C: Clone> Clone for LocalAsyncIngestServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncIngestServiceClient<C>
fn clone(&self) -> LocalAsyncIngestServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncIngestServiceClient<C>
impl<C: Debug> Debug for LocalAsyncIngestServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncIngestService<I> for LocalAsyncIngestServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncIngestService<I> for LocalAsyncIngestServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn ingest(
&self,
auth_: &BearerToken,
trigger_ingest: &IngestRequest,
) -> Result<IngestResponse, Error>
async fn ingest( &self, auth_: &BearerToken, trigger_ingest: &IngestRequest, ) -> Result<IngestResponse, Error>
Triggers an ingest job, allowing either creating a new dataset or uploading to an
existing one. This endpoint is meant to supersede all other ingestion endpoints as their functionality
gets migrated to this one.
Sourceasync fn rerun_ingest(
&self,
auth_: &BearerToken,
request: &RerunIngestRequest,
) -> Result<IngestResponse, Error>
async fn rerun_ingest( &self, auth_: &BearerToken, request: &RerunIngestRequest, ) -> Result<IngestResponse, Error>
Triggers an ingest job using an existing ingest job RID.
Returns the same response format as the /ingest endpoint.
Sourceasync fn ingest_run(
&self,
auth_: &BearerToken,
request: &IngestRunRequest,
) -> Result<IngestRunResponse, Error>
async fn ingest_run( &self, auth_: &BearerToken, request: &IngestRunRequest, ) -> Result<IngestRunResponse, Error>
Creates a run and ingests data sources to be added to the run.
Sourceasync fn ingest_video(
&self,
auth_: &BearerToken,
ingest_video: &IngestVideoRequest,
) -> Result<IngestVideoResponse, Error>
async fn ingest_video( &self, auth_: &BearerToken, ingest_video: &IngestVideoRequest, ) -> Result<IngestVideoResponse, Error>
Ingests video data from a S3 Nominal upload bucket.
Sourceasync fn reingest_from_datasets(
&self,
auth_: &BearerToken,
request: &ReingestDatasetsRequest,
) -> Result<ReingestDatasetsResponse, Error>
async fn reingest_from_datasets( &self, auth_: &BearerToken, request: &ReingestDatasetsRequest, ) -> Result<ReingestDatasetsResponse, Error>
Re-ingests data from provided source datasets into either an existing target dataset, or a new one.
Only supported for CSV and Parquet dataset files.
Will only reingest dataset files and will drop streaming data from datasets.
Sourceasync fn delete_file(
&self,
auth_: &BearerToken,
dataset_rid: &DatasetRid,
file_id: Uuid,
) -> Result<(), Error>
async fn delete_file( &self, auth_: &BearerToken, dataset_rid: &DatasetRid, file_id: Uuid, ) -> Result<(), Error>
This is a best effort deletion of the file’s data based on the ingestedAt timestamp. This is an unreversible
action. Only v2 dataset file deletion is supported.
!!!WARNING!!!
It’s possible that the file has overwritten points, in which case, those older points will not be recovered.
Only use this endpoint if this is acceptable, the data across files are disjoint, or you’re willing to
re-ingest files to manually recover older points.