Module api

Module api 

Modules

persistent_compute_service

Structs

AsyncPersistentComputeServiceClient
PersistentComputeServiceClient

Traits

AsyncPersistentComputeService
Exposes a simple endpoints for checking whether or not persistent compute is enabled.
PersistentComputeService
Exposes a simple endpoints for checking whether or not persistent compute is enabled.