PersistentComputeService

Trait PersistentComputeService 

pub trait PersistentComputeService<I: Iterator<Item = Result<Bytes, Error>>> {
    // Required method
    fn is_enabled(
        &self,
        auth_: &BearerToken,
    ) -> Result<IsEnabledResponse, Error>;
}
Exposes a simple endpoints for checking whether or not persistent compute is enabled.

Required Methods

fn is_enabled(&self, auth_: &BearerToken) -> Result<IsEnabledResponse, Error>

Simple “ping” like endpoint to see if the service is enabled (and available).

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I: Iterator<Item = Result<Bytes, Error>>, __C> PersistentComputeService<I> for PersistentComputeServiceClient<__C>
where __C: Client<ResponseBody = I>,