Module api

Module api 

Modules

checklist_service

Structs

AsyncChecklistServiceClient
ChecklistServiceClient

Traits

AsyncChecklistService
The Checklist Service is responsible for managing checklists and checks. A checklist is a collection of checks that can be executed against a set of data sources.
ChecklistService
The Checklist Service is responsible for managing checklists and checks. A checklist is a collection of checks that can be executed against a set of data sources.