pub struct AsyncComputeServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncComputeService<I> for AsyncComputeServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncComputeService<I> for AsyncComputeServiceClient<__C>
Sourceasync fn compute(
&self,
auth_: &BearerToken,
request: &ComputeNodeRequest,
) -> Result<ComputeNodeResponse, Error>
async fn compute( &self, auth_: &BearerToken, request: &ComputeNodeRequest, ) -> Result<ComputeNodeResponse, Error>
Computes the output of the compute graph specified by a ComputeNodeRequest.
Sourceasync fn parameterized_compute(
&self,
auth_: &BearerToken,
request: &ParameterizedComputeNodeRequest,
) -> Result<ParameterizedComputeNodeResponse, Error>
async fn parameterized_compute( &self, auth_: &BearerToken, request: &ParameterizedComputeNodeRequest, ) -> Result<ParameterizedComputeNodeResponse, Error>
Computes the output of the compute graph specified by a ParameterizedComputeNodeRequest. A parameterized
compute request supports multiple values for a single variable, supplied by the ParameterizedContext.
Results are returned in the same order of the request.
Sourceasync fn compute_units(
&self,
auth_: &BearerToken,
request: &ComputeUnitsRequest,
) -> Result<ComputeUnitResult, Error>
async fn compute_units( &self, auth_: &BearerToken, request: &ComputeUnitsRequest, ) -> Result<ComputeUnitResult, Error>
Returns the resulting unit for the output of a compute graph. If the resulting unit is equivalent to exactly
one existing unit in the system, it will be returned (for example, a series in Coulombs divided by a series
in Volts will return an output of Farads). If the output does not have units (for example, a range output,)
the unit result will return noUnitAvailable, and if the computation was not successful, corresponding errors
are returned.
Sourceasync fn batch_compute_with_units(
&self,
auth_: &BearerToken,
request: &BatchComputeWithUnitsRequest,
) -> Result<BatchComputeWithUnitsResponse, Error>
async fn batch_compute_with_units( &self, auth_: &BearerToken, request: &BatchComputeWithUnitsRequest, ) -> Result<BatchComputeWithUnitsResponse, Error>
Computes the output of compute graphs specified by BatchComputeNodeRequest. Results are returned in the same
order as the request.
Sourceasync fn batch_compute_units(
&self,
auth_: &BearerToken,
request: &BatchComputeUnitsRequest,
) -> Result<BatchComputeUnitResult, Error>
async fn batch_compute_units( &self, auth_: &BearerToken, request: &BatchComputeUnitsRequest, ) -> Result<BatchComputeUnitResult, Error>
Same as computeUnits, however this endpoint functions on a batch of requests for wire efficiency purposes. An
extra note is that this method will serialize underlying conjure errors into the BatchComputeUnitResult type,
meaning callers are required to check for errors explicitly (rather than relying on exceptions being thrown).
Sourceasync fn compute_with_units(
&self,
auth_: &BearerToken,
request: &ComputeWithUnitsRequest,
) -> Result<ComputeWithUnitsResponse, Error>
async fn compute_with_units( &self, auth_: &BearerToken, request: &ComputeWithUnitsRequest, ) -> Result<ComputeWithUnitsResponse, Error>
Computes the output of the compute graph specified by a ComputeNodeRequest, as well as providing the resulting
unit for the output of a compute graph. If the resulting unit is equivalent to exactly one existing unit in the
system, it will be returned (for example, a series in Coulombs divided by a series in Volts will return an
output of Farads). If the output does not have units (for example, a range output,) the unit result will return
noUnitAvailable, and if the computation was not successful, corresponding errors are returned.
Sourceimpl<C> AsyncService<C> for AsyncComputeServiceClient<C>
impl<C> AsyncService<C> for AsyncComputeServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncComputeServiceClient<C>
impl<C: Clone> Clone for AsyncComputeServiceClient<C>
Sourcefn clone(&self) -> AsyncComputeServiceClient<C>
fn clone(&self) -> AsyncComputeServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncComputeServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncComputeServiceClient<C>
impl<C> Send for AsyncComputeServiceClient<C>where
C: Send,
impl<C> Sync for AsyncComputeServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncComputeServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncComputeServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncComputeServiceClient<C>