pub struct ConnectionServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for ConnectionServiceClient<C>
impl<C: Clone> Clone for ConnectionServiceClient<C>
Sourcefn clone(&self) -> ConnectionServiceClient<C>
fn clone(&self) -> ConnectionServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> ConnectionService<I> for ConnectionServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> ConnectionService<I> for ConnectionServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn create_connection(
&self,
auth_: &BearerToken,
create_connection: &CreateConnection,
) -> Result<Connection, Error>
fn create_connection( &self, auth_: &BearerToken, create_connection: &CreateConnection, ) -> Result<Connection, Error>
Creates a new connection.
Sourcefn update_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
request: &UpdateConnectionRequest,
) -> Result<Connection, Error>
fn update_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, request: &UpdateConnectionRequest, ) -> Result<Connection, Error>
Updates an existing connection.
Sourcefn update_connection_status(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
request: &ConnectionStatus,
) -> Result<(), Error>
fn update_connection_status( &self, auth_: &BearerToken, rid: &ConnectionRid, request: &ConnectionStatus, ) -> Result<(), Error>
Updates an existing connection status.
Adds available tag key/value pairs to the connection. If a tag name already exists, the values will be merged.
This is primarily an internal endpoint to update tags for external connections as they are periodically
scraped. This endpoint should only be called by clients for Visual crossing connections. Throws if called for
Nominal connections which have their tags automatically indexed in the underlying Database.
Sourcefn get_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
) -> Result<Connection, Error>
fn get_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, ) -> Result<Connection, Error>
Gets a connection by its RID.
Sourcefn get_connections(
&self,
auth_: &BearerToken,
rids: &BTreeSet<ConnectionRid>,
) -> Result<BTreeSet<Connection>, Error>
fn get_connections( &self, auth_: &BearerToken, rids: &BTreeSet<ConnectionRid>, ) -> Result<BTreeSet<Connection>, Error>
Gets a set of connections by their RIDs.
Sourcefn list_connections(
&self,
auth_: &BearerToken,
include_archived: Option<bool>,
workspaces: &BTreeSet<WorkspaceRid>,
) -> Result<BTreeSet<Connection>, Error>
fn list_connections( &self, auth_: &BearerToken, include_archived: Option<bool>, workspaces: &BTreeSet<WorkspaceRid>, ) -> Result<BTreeSet<Connection>, Error>
Lists all connections.
Sourcefn list_connections_v2(
&self,
auth_: &BearerToken,
include_archived: Option<bool>,
workspaces: &BTreeSet<WorkspaceRid>,
page_size: Option<i32>,
next_page_token: Option<&Token>,
) -> Result<ListConnectionsResponse, Error>
fn list_connections_v2( &self, auth_: &BearerToken, include_archived: Option<bool>, workspaces: &BTreeSet<WorkspaceRid>, page_size: Option<i32>, next_page_token: Option<&Token>, ) -> Result<ListConnectionsResponse, Error>
Lists connections with pagination. Returns connections ordered by creation time descending.
Sourcefn list_connections_by_nominal_data_source(
&self,
auth_: &BearerToken,
nominal_data_source_rids: &BTreeSet<NominalDataSourceRid>,
workspaces: &BTreeSet<WorkspaceRid>,
page_size: Option<i32>,
next_page_token: Option<&Token>,
) -> Result<ListConnectionsResponse, Error>
fn list_connections_by_nominal_data_source( &self, auth_: &BearerToken, nominal_data_source_rids: &BTreeSet<NominalDataSourceRid>, workspaces: &BTreeSet<WorkspaceRid>, page_size: Option<i32>, next_page_token: Option<&Token>, ) -> Result<ListConnectionsResponse, Error>
Lists connections that reference the specified Nominal data sources, with pagination.
Only returns connections within the caller’s organization.
Sourcefn archive_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
) -> Result<(), Error>
fn archive_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, ) -> Result<(), Error>
Archives a connection, which simply tags the connection for a client to filter.
Sourcefn unarchive_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
) -> Result<(), Error>
fn unarchive_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, ) -> Result<(), Error>
Undoes the archiving of a connection.
Sourceimpl<C: Debug> Debug for ConnectionServiceClient<C>
impl<C: Debug> Debug for ConnectionServiceClient<C>
Sourceimpl<C> Service<C> for ConnectionServiceClient<C>
impl<C> Service<C> for ConnectionServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.