pub struct AsyncConnectionBootstrapperServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncConnectionBootstrapperService<I> for AsyncConnectionBootstrapperServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncConnectionBootstrapperService<I> for AsyncConnectionBootstrapperServiceClient<__C>
Sourceasync fn populate_series(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
request: &PopulateSeriesRequest,
) -> Result<(), Error>
async fn populate_series( &self, auth_: &BearerToken, rid: &ConnectionRid, request: &PopulateSeriesRequest, ) -> Result<(), Error>
Populates the connection with series, by querying within the requested time range. If start or end are both omitted,
will query the last 7 days by default. If one of start or end is omitted, will query a 7 day range from the provided
start or end. Will throw if the requested range is larger than 30 days.
Sourceimpl<C> AsyncService<C> for AsyncConnectionBootstrapperServiceClient<C>
impl<C> AsyncService<C> for AsyncConnectionBootstrapperServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncConnectionBootstrapperServiceClient<C>
impl<C: Clone> Clone for AsyncConnectionBootstrapperServiceClient<C>
Sourcefn clone(&self) -> AsyncConnectionBootstrapperServiceClient<C>
fn clone(&self) -> AsyncConnectionBootstrapperServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncConnectionBootstrapperServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncConnectionBootstrapperServiceClient<C>
impl<C> Send for AsyncConnectionBootstrapperServiceClient<C>where
C: Send,
impl<C> Sync for AsyncConnectionBootstrapperServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncConnectionBootstrapperServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncConnectionBootstrapperServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncConnectionBootstrapperServiceClient<C>