pub struct AsyncConnectionServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncConnectionService<I> for AsyncConnectionServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncConnectionService<I> for AsyncConnectionServiceClient<__C>
Sourceasync fn create_connection(
&self,
auth_: &BearerToken,
create_connection: &CreateConnection,
) -> Result<Connection, Error>
async fn create_connection( &self, auth_: &BearerToken, create_connection: &CreateConnection, ) -> Result<Connection, Error>
Creates a new connection.
Sourceasync fn update_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
request: &UpdateConnectionRequest,
) -> Result<Connection, Error>
async fn update_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, request: &UpdateConnectionRequest, ) -> Result<Connection, Error>
Updates an existing connection.
Sourceasync fn update_connection_status(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
request: &ConnectionStatus,
) -> Result<(), Error>
async fn update_connection_status( &self, auth_: &BearerToken, rid: &ConnectionRid, request: &ConnectionStatus, ) -> Result<(), Error>
Updates an existing connection status.
Adds available tag key/value pairs to the connection. If a tag name already exists, the values will be merged.
This is primarily an internal endpoint to update tags for external connections as they are periodically
scraped. This endpoint should only be called by clients for Visual crossing connections. Throws if called for
Nominal connections which have their tags automatically indexed in the underlying Database.
Sourceasync fn get_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
) -> Result<Connection, Error>
async fn get_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, ) -> Result<Connection, Error>
Gets a connection by its RID.
Sourceasync fn get_connections(
&self,
auth_: &BearerToken,
rids: &BTreeSet<ConnectionRid>,
) -> Result<BTreeSet<Connection>, Error>
async fn get_connections( &self, auth_: &BearerToken, rids: &BTreeSet<ConnectionRid>, ) -> Result<BTreeSet<Connection>, Error>
Gets a set of connections by their RIDs.
Sourceasync fn list_connections(
&self,
auth_: &BearerToken,
include_archived: Option<bool>,
workspaces: &BTreeSet<WorkspaceRid>,
) -> Result<BTreeSet<Connection>, Error>
async fn list_connections( &self, auth_: &BearerToken, include_archived: Option<bool>, workspaces: &BTreeSet<WorkspaceRid>, ) -> Result<BTreeSet<Connection>, Error>
Lists all connections.
Sourceasync fn list_connections_v2(
&self,
auth_: &BearerToken,
include_archived: Option<bool>,
workspaces: &BTreeSet<WorkspaceRid>,
page_size: Option<i32>,
next_page_token: Option<&Token>,
) -> Result<ListConnectionsResponse, Error>
async fn list_connections_v2( &self, auth_: &BearerToken, include_archived: Option<bool>, workspaces: &BTreeSet<WorkspaceRid>, page_size: Option<i32>, next_page_token: Option<&Token>, ) -> Result<ListConnectionsResponse, Error>
Lists connections with pagination. Returns connections ordered by creation time descending.
Sourceasync fn list_connections_by_nominal_data_source(
&self,
auth_: &BearerToken,
nominal_data_source_rids: &BTreeSet<NominalDataSourceRid>,
workspaces: &BTreeSet<WorkspaceRid>,
page_size: Option<i32>,
next_page_token: Option<&Token>,
) -> Result<ListConnectionsResponse, Error>
async fn list_connections_by_nominal_data_source( &self, auth_: &BearerToken, nominal_data_source_rids: &BTreeSet<NominalDataSourceRid>, workspaces: &BTreeSet<WorkspaceRid>, page_size: Option<i32>, next_page_token: Option<&Token>, ) -> Result<ListConnectionsResponse, Error>
Lists connections that reference the specified Nominal data sources, with pagination.
Only returns connections within the caller’s organization.
Sourceasync fn archive_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
) -> Result<(), Error>
async fn archive_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, ) -> Result<(), Error>
Archives a connection, which simply tags the connection for a client to filter.
Sourceasync fn unarchive_connection(
&self,
auth_: &BearerToken,
rid: &ConnectionRid,
) -> Result<(), Error>
async fn unarchive_connection( &self, auth_: &BearerToken, rid: &ConnectionRid, ) -> Result<(), Error>
Undoes the archiving of a connection.
Sourceimpl<C> AsyncService<C> for AsyncConnectionServiceClient<C>
impl<C> AsyncService<C> for AsyncConnectionServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncConnectionServiceClient<C>
impl<C: Clone> Clone for AsyncConnectionServiceClient<C>
Sourcefn clone(&self) -> AsyncConnectionServiceClient<C>
fn clone(&self) -> AsyncConnectionServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncConnectionServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncConnectionServiceClient<C>
impl<C> Send for AsyncConnectionServiceClient<C>where
C: Send,
impl<C> Sync for AsyncConnectionServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncConnectionServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncConnectionServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncConnectionServiceClient<C>