ConnectionBootstrapperService

Trait ConnectionBootstrapperService 

pub trait ConnectionBootstrapperService<I: Iterator<Item = Result<Bytes, Error>>> {
    // Required method
    fn populate_series(
        &self,
        auth_: &BearerToken,
        rid: &ConnectionRid,
        request: &PopulateSeriesRequest,
    ) -> Result<(), Error>;
}
Nominal periodically scrapes connected databases (Connections) in order to maintain a database of all series that can be read from that database. This service is responsible for executing the scrape, and can be used manually to trigger a rescrape for any reason (for example, when updating a schema).

Required Methods

fn populate_series( &self, auth_: &BearerToken, rid: &ConnectionRid, request: &PopulateSeriesRequest, ) -> Result<(), Error>

Populates the connection with series, by querying within the requested time range. If start or end are both omitted, will query the last 7 days by default. If one of start or end is omitted, will query a 7 day range from the provided start or end. Will throw if the requested range is larger than 30 days.

Implementors

Source

impl<I: Iterator<Item = Result<Bytes, Error>>, __C> ConnectionBootstrapperService<I> for ConnectionBootstrapperServiceClient<__C>
where __C: Client<ResponseBody = I>,