pub struct LocalAsyncDataSourceServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncDataSourceServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncDataSourceServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncDataSourceServiceClient<C>
impl<C: Clone> Clone for LocalAsyncDataSourceServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncDataSourceServiceClient<C>
fn clone(&self) -> LocalAsyncDataSourceServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncDataSourceServiceClient<C>
impl<C: Debug> Debug for LocalAsyncDataSourceServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncDataSourceService<I> for LocalAsyncDataSourceServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncDataSourceService<I> for LocalAsyncDataSourceServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn search_channels(
&self,
auth_: &BearerToken,
query: &SearchChannelsRequest,
) -> Result<SearchChannelsResponse, Error>
async fn search_channels( &self, auth_: &BearerToken, query: &SearchChannelsRequest, ) -> Result<SearchChannelsResponse, Error>
Returns channels that match the search criteria. Results are sorted by similarity score.
Sourceasync fn search_filtered_channels(
&self,
auth_: &BearerToken,
query: &SearchFilteredChannelsRequest,
) -> Result<SearchFilteredChannelsResponse, Error>
async fn search_filtered_channels( &self, auth_: &BearerToken, query: &SearchFilteredChannelsRequest, ) -> Result<SearchFilteredChannelsResponse, Error>
Returns channels that match the search criteria. Results are sorted by similarity score.
Sourceasync fn search_hierarchical_channels(
&self,
auth_: &BearerToken,
query: &SearchHierarchicalChannelsRequest,
) -> Result<SearchHierarchicalChannelsResponse, Error>
async fn search_hierarchical_channels( &self, auth_: &BearerToken, query: &SearchHierarchicalChannelsRequest, ) -> Result<SearchHierarchicalChannelsResponse, Error>
Returns only channels that are direct children of the parent. Returns results sorted alphabetically.
Sourceasync fn index_channel_prefix_tree(
&self,
auth_: &BearerToken,
request: &IndexChannelPrefixTreeRequest,
) -> Result<ChannelPrefixTree, Error>
async fn index_channel_prefix_tree( &self, auth_: &BearerToken, request: &IndexChannelPrefixTreeRequest, ) -> Result<ChannelPrefixTree, Error>
Indexes the channel prefix tree for a specified data source. This operation constructs a prefix tree from the
channels available in the data source.
Sourceasync fn batch_get_channel_prefix_trees(
&self,
auth_: &BearerToken,
request: &BatchGetChannelPrefixTreeRequest,
) -> Result<BatchGetChannelPrefixTreeResponse, Error>
async fn batch_get_channel_prefix_trees( &self, auth_: &BearerToken, request: &BatchGetChannelPrefixTreeRequest, ) -> Result<BatchGetChannelPrefixTreeResponse, Error>
Returns the channel prefix tree for each of the specified data sources. If the tree for a data source has not
been indexed, it will be omitted from the map.
Returns the the set of all tag keys and their values that are available for the specified channel given an
initial set of filters.
Sourceasync fn get_data_scope_bounds(
&self,
auth_: &BearerToken,
request: &BatchGetDataScopeBoundsRequest,
) -> Result<BatchGetDataScopeBoundsResponse, Error>
async fn get_data_scope_bounds( &self, auth_: &BearerToken, request: &BatchGetDataScopeBoundsRequest, ) -> Result<BatchGetDataScopeBoundsResponse, Error>
Returns the maximum data timestamps for the specified data scopes. Responses are returned
in the same order as requests.
Sourceasync fn get_tag_values_for_data_source(
&self,
auth_: &BearerToken,
data_source_rid: &DataSourceRid,
request: &GetTagValuesForDataSourceRequest,
) -> Result<BTreeMap<TagName, BTreeSet<TagValue>>, Error>
async fn get_tag_values_for_data_source( &self, auth_: &BearerToken, data_source_rid: &DataSourceRid, request: &GetTagValuesForDataSourceRequest, ) -> Result<BTreeMap<TagName, BTreeSet<TagValue>>, Error>
Returns available tag values for a given data source for a set of tag keys. For Nominal data sources, a time
range can be provided to filter tag values to those present within the months spanned by the range. If no
time range is provided, this defaults to the last month. For external data sources, the range must not be
specified, as all tag values are returned.
Sourceasync fn get_available_tag_keys(
&self,
auth_: &BearerToken,
data_source_rid: &DataSourceRid,
request: &GetAvailableTagKeysRequest,
) -> Result<GetAvailableTagKeysResponse, Error>
async fn get_available_tag_keys( &self, auth_: &BearerToken, data_source_rid: &DataSourceRid, request: &GetAvailableTagKeysRequest, ) -> Result<GetAvailableTagKeysResponse, Error>
Paged endpoint returning the set of all tag keys that are available for the specified channel given an
initial set of filters.
If any tag filters are supplied, their tag keys are omitted from the result.
Sourceasync fn get_available_tag_values(
&self,
auth_: &BearerToken,
data_source_rid: &DataSourceRid,
request: &GetAvailableTagValuesRequest,
) -> Result<GetAvailableTagValuesResponse, Error>
async fn get_available_tag_values( &self, auth_: &BearerToken, data_source_rid: &DataSourceRid, request: &GetAvailableTagValuesRequest, ) -> Result<GetAvailableTagValuesResponse, Error>
Paged endpoint returning the set of all tag values that are available for the specified tag and datasource
given an initial set of filters.
Sourceasync fn batch_get_series_count(
&self,
auth_: &BearerToken,
request: &BatchGetSeriesCountRequest,
) -> Result<BatchGetSeriesCountResponse, Error>
async fn batch_get_series_count( &self, auth_: &BearerToken, request: &BatchGetSeriesCountRequest, ) -> Result<BatchGetSeriesCountResponse, Error>
Returns the number of distinct series matching each request’s datasource, channel, range,
and tag filters. Each response corresponds positionally to the input request.
Returns empty seriesCount for non-Nominal datasources.
Returns (channel, full-tag-map) entries for a specific channel in a dataset.
If tags are provided, each entry must match all provided key/value pairs; extra tags may still be present.