pub struct DataSourceServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for DataSourceServiceClient<C>
impl<C: Clone> Clone for DataSourceServiceClient<C>
Sourcefn clone(&self) -> DataSourceServiceClient<C>
fn clone(&self) -> DataSourceServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> DataSourceService<I> for DataSourceServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> DataSourceService<I> for DataSourceServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn search_channels(
&self,
auth_: &BearerToken,
query: &SearchChannelsRequest,
) -> Result<SearchChannelsResponse, Error>
fn search_channels( &self, auth_: &BearerToken, query: &SearchChannelsRequest, ) -> Result<SearchChannelsResponse, Error>
Returns channels that match the search criteria. Results are sorted by similarity score.
Sourcefn search_filtered_channels(
&self,
auth_: &BearerToken,
query: &SearchFilteredChannelsRequest,
) -> Result<SearchFilteredChannelsResponse, Error>
fn search_filtered_channels( &self, auth_: &BearerToken, query: &SearchFilteredChannelsRequest, ) -> Result<SearchFilteredChannelsResponse, Error>
Returns channels that match the search criteria. Results are sorted by similarity score.
Sourcefn search_hierarchical_channels(
&self,
auth_: &BearerToken,
query: &SearchHierarchicalChannelsRequest,
) -> Result<SearchHierarchicalChannelsResponse, Error>
fn search_hierarchical_channels( &self, auth_: &BearerToken, query: &SearchHierarchicalChannelsRequest, ) -> Result<SearchHierarchicalChannelsResponse, Error>
Returns only channels that are direct children of the parent. Returns results sorted alphabetically.
Sourcefn index_channel_prefix_tree(
&self,
auth_: &BearerToken,
request: &IndexChannelPrefixTreeRequest,
) -> Result<ChannelPrefixTree, Error>
fn index_channel_prefix_tree( &self, auth_: &BearerToken, request: &IndexChannelPrefixTreeRequest, ) -> Result<ChannelPrefixTree, Error>
Indexes the channel prefix tree for a specified data source. This operation constructs a prefix tree from the
channels available in the data source.
Sourcefn batch_get_channel_prefix_trees(
&self,
auth_: &BearerToken,
request: &BatchGetChannelPrefixTreeRequest,
) -> Result<BatchGetChannelPrefixTreeResponse, Error>
fn batch_get_channel_prefix_trees( &self, auth_: &BearerToken, request: &BatchGetChannelPrefixTreeRequest, ) -> Result<BatchGetChannelPrefixTreeResponse, Error>
Returns the channel prefix tree for each of the specified data sources. If the tree for a data source has not
been indexed, it will be omitted from the map.
Returns the the set of all tag keys and their values that are available for the specified channel given an
initial set of filters.
Sourcefn get_data_scope_bounds(
&self,
auth_: &BearerToken,
request: &BatchGetDataScopeBoundsRequest,
) -> Result<BatchGetDataScopeBoundsResponse, Error>
fn get_data_scope_bounds( &self, auth_: &BearerToken, request: &BatchGetDataScopeBoundsRequest, ) -> Result<BatchGetDataScopeBoundsResponse, Error>
Returns the maximum data timestamps for the specified data scopes. Responses are returned
in the same order as requests.
Sourcefn get_tag_values_for_data_source(
&self,
auth_: &BearerToken,
data_source_rid: &DataSourceRid,
request: &GetTagValuesForDataSourceRequest,
) -> Result<BTreeMap<TagName, BTreeSet<TagValue>>, Error>
fn get_tag_values_for_data_source( &self, auth_: &BearerToken, data_source_rid: &DataSourceRid, request: &GetTagValuesForDataSourceRequest, ) -> Result<BTreeMap<TagName, BTreeSet<TagValue>>, Error>
Returns available tag values for a given data source for a set of tag keys. For Nominal data sources, a time
range can be provided to filter tag values to those present within the months spanned by the range. If no
time range is provided, this defaults to the last month. For external data sources, the range must not be
specified, as all tag values are returned.
Sourcefn get_available_tag_keys(
&self,
auth_: &BearerToken,
data_source_rid: &DataSourceRid,
request: &GetAvailableTagKeysRequest,
) -> Result<GetAvailableTagKeysResponse, Error>
fn get_available_tag_keys( &self, auth_: &BearerToken, data_source_rid: &DataSourceRid, request: &GetAvailableTagKeysRequest, ) -> Result<GetAvailableTagKeysResponse, Error>
Paged endpoint returning the set of all tag keys that are available for the specified channel given an
initial set of filters.
If any tag filters are supplied, their tag keys are omitted from the result.
Sourcefn get_available_tag_values(
&self,
auth_: &BearerToken,
data_source_rid: &DataSourceRid,
request: &GetAvailableTagValuesRequest,
) -> Result<GetAvailableTagValuesResponse, Error>
fn get_available_tag_values( &self, auth_: &BearerToken, data_source_rid: &DataSourceRid, request: &GetAvailableTagValuesRequest, ) -> Result<GetAvailableTagValuesResponse, Error>
Paged endpoint returning the set of all tag values that are available for the specified tag and datasource
given an initial set of filters.
Sourcefn batch_get_series_count(
&self,
auth_: &BearerToken,
request: &BatchGetSeriesCountRequest,
) -> Result<BatchGetSeriesCountResponse, Error>
fn batch_get_series_count( &self, auth_: &BearerToken, request: &BatchGetSeriesCountRequest, ) -> Result<BatchGetSeriesCountResponse, Error>
Returns the number of distinct series matching each request’s datasource, channel, range,
and tag filters. Each response corresponds positionally to the input request.
Returns empty seriesCount for non-Nominal datasources.
Returns (channel, full-tag-map) entries for a specific channel in a dataset.
If tags are provided, each entry must match all provided key/value pairs; extra tags may still be present.
Sourceimpl<C: Debug> Debug for DataSourceServiceClient<C>
impl<C: Debug> Debug for DataSourceServiceClient<C>
Sourceimpl<C> Service<C> for DataSourceServiceClient<C>
impl<C> Service<C> for DataSourceServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.