pub struct LocalAsyncInternalVersioningServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncInternalVersioningServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncInternalVersioningServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncInternalVersioningServiceClient<C>
impl<C: Clone> Clone for LocalAsyncInternalVersioningServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncInternalVersioningServiceClient<C>
fn clone(&self) -> LocalAsyncInternalVersioningServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncInternalVersioningServiceClient<C>
impl<C: Debug> Debug for LocalAsyncInternalVersioningServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncInternalVersioningService<I> for LocalAsyncInternalVersioningServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncInternalVersioningService<I> for LocalAsyncInternalVersioningServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn init_resource_versioning(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &InitResourceVersioningRequest,
) -> Result<BranchAndCommit, Error>
async fn init_resource_versioning( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &InitResourceVersioningRequest, ) -> Result<BranchAndCommit, Error>
Creates a root commit (no parents) and a “main” branch
pointing to that commit, for the given resource.
Throws if the resource already has a commit graph.
Sourceasync fn save_working_state(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
request: &SaveWorkingStateRequest,
) -> Result<BranchAndCommit, Error>
async fn save_working_state( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, request: &SaveWorkingStateRequest, ) -> Result<BranchAndCommit, Error>
Creates a non-permanent commit on the given branch,
Throws if the branch doesn’t exist.
Throws if latestCommit is passed and is not the latest commit.
Sourceasync fn commit(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
request: &CommitRequest,
) -> Result<BranchAndCommit, Error>
async fn commit( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, request: &CommitRequest, ) -> Result<BranchAndCommit, Error>
Creates a new permanent commit on the given branch.
Throws if the branch doesn’t exist.
Throws if latestCommit is passed and is not the latest commit.
Sourceasync fn compact_commits(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &CompactCommitsRequest,
) -> Result<BTreeSet<CommitId>, Error>
async fn compact_commits( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &CompactCommitsRequest, ) -> Result<BTreeSet<CommitId>, Error>
Compacts the commit graph for the resource by deleting
working state commits that match the provided strategy.
Persists commits that are pointed to by branches.
Returns the set of commits that were compacted.
Throws if the resource doesn’t exist.