pub struct AsyncResourceMetadataServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncResourceMetadataService<I> for AsyncResourceMetadataServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncResourceMetadataService<I> for AsyncResourceMetadataServiceClient<__C>
Sourceasync fn list_properties_and_labels(
&self,
auth_: &BearerToken,
request: &ListPropertiesAndLabelsRequest,
) -> Result<ListPropertiesAndLabelsResponse, Error>
async fn list_properties_and_labels( &self, auth_: &BearerToken, request: &ListPropertiesAndLabelsRequest, ) -> Result<ListPropertiesAndLabelsResponse, Error>
Returns all existing properties (key value pairs) and labels, which can be used to organize resources
such as runs and videos.
Sourceasync fn get_metadata_usage_count(
&self,
auth_: &BearerToken,
request: &GetMetadataUsageCountRequest,
) -> Result<GetMetadataUsageCountResponse, Error>
async fn get_metadata_usage_count( &self, auth_: &BearerToken, request: &GetMetadataUsageCountRequest, ) -> Result<GetMetadataUsageCountResponse, Error>
Returns the count of resources that use a given label or property. The query can
match by label, property name (key only), or a full property key+value pair.
Counts are scoped to the caller’s accessible workspaces unless specific workspaces
are provided.
Sourceasync fn find_similar_label_matches(
&self,
auth_: &BearerToken,
request: &FindSimilarLabelMatchesRequest,
) -> Result<FindSimilarLabelMatchesResponse, Error>
async fn find_similar_label_matches( &self, auth_: &BearerToken, request: &FindSimilarLabelMatchesRequest, ) -> Result<FindSimilarLabelMatchesResponse, Error>
Given a set of labels, finds similar labels across the specified workspaces and resource types.
Includes document count. Useful for detecting unintentional duplicate labels.
Sourceasync fn find_similar_property_key_matches(
&self,
auth_: &BearerToken,
request: &FindSimilarPropertyKeyMatchesRequest,
) -> Result<FindSimilarPropertyKeyMatchesResponse, Error>
async fn find_similar_property_key_matches( &self, auth_: &BearerToken, request: &FindSimilarPropertyKeyMatchesRequest, ) -> Result<FindSimilarPropertyKeyMatchesResponse, Error>
Given a set of property keys, finds similar property keys across the specified workspaces and resource types.
Includes document count. Useful for detecting unintentional duplicate property keys.
Sourceasync fn search_labels(
&self,
auth_: &BearerToken,
request: &SearchMetadataRequest,
) -> Result<SearchLabelsResponse, Error>
async fn search_labels( &self, auth_: &BearerToken, request: &SearchMetadataRequest, ) -> Result<SearchLabelsResponse, Error>
Returns a paginated list of labels with document usage counts, filterable by
resource type, workspace, and search text.
Sourceasync fn search_property_keys(
&self,
auth_: &BearerToken,
request: &SearchMetadataRequest,
) -> Result<SearchPropertyKeysResponse, Error>
async fn search_property_keys( &self, auth_: &BearerToken, request: &SearchMetadataRequest, ) -> Result<SearchPropertyKeysResponse, Error>
Returns a paginated list of property keys with document usage counts, filterable
by resource type, workspace, and search text.
Sourceasync fn search_property_values(
&self,
auth_: &BearerToken,
request: &SearchPropertyValuesRequest,
) -> Result<SearchPropertyValuesResponse, Error>
async fn search_property_values( &self, auth_: &BearerToken, request: &SearchPropertyValuesRequest, ) -> Result<SearchPropertyValuesResponse, Error>
Returns a paginated list of property values for a given property key with document
usage counts, filterable by resource type, workspace, and search text.
Sourceimpl<C> AsyncService<C> for AsyncResourceMetadataServiceClient<C>
impl<C> AsyncService<C> for AsyncResourceMetadataServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncResourceMetadataServiceClient<C>
impl<C: Clone> Clone for AsyncResourceMetadataServiceClient<C>
Sourcefn clone(&self) -> AsyncResourceMetadataServiceClient<C>
fn clone(&self) -> AsyncResourceMetadataServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncResourceMetadataServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncResourceMetadataServiceClient<C>
impl<C> Send for AsyncResourceMetadataServiceClient<C>where
C: Send,
impl<C> Sync for AsyncResourceMetadataServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncResourceMetadataServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncResourceMetadataServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncResourceMetadataServiceClient<C>