ResourceMetadataService

Trait ResourceMetadataService 

pub trait ResourceMetadataService<I>
where I: Iterator<Item = Result<Bytes, Error>>,
{ // Required methods fn list_properties_and_labels( &self, auth_: &BearerToken, request: &ListPropertiesAndLabelsRequest, ) -> Result<ListPropertiesAndLabelsResponse, Error>; fn get_metadata_usage_count( &self, auth_: &BearerToken, request: &GetMetadataUsageCountRequest, ) -> Result<GetMetadataUsageCountResponse, Error>; fn find_similar_label_matches( &self, auth_: &BearerToken, request: &FindSimilarLabelMatchesRequest, ) -> Result<FindSimilarLabelMatchesResponse, Error>; fn find_similar_property_key_matches( &self, auth_: &BearerToken, request: &FindSimilarPropertyKeyMatchesRequest, ) -> Result<FindSimilarPropertyKeyMatchesResponse, Error>; fn search_labels( &self, auth_: &BearerToken, request: &SearchMetadataRequest, ) -> Result<SearchLabelsResponse, Error>; fn search_property_keys( &self, auth_: &BearerToken, request: &SearchMetadataRequest, ) -> Result<SearchPropertyKeysResponse, Error>; fn search_property_values( &self, auth_: &BearerToken, request: &SearchPropertyValuesRequest, ) -> Result<SearchPropertyValuesResponse, Error>; }
The Resource Metadata Service provides common metadata about resources.

Required Methods

fn list_properties_and_labels( &self, auth_: &BearerToken, request: &ListPropertiesAndLabelsRequest, ) -> Result<ListPropertiesAndLabelsResponse, Error>

Returns all existing properties (key value pairs) and labels, which can be used to organize resources such as runs and videos. This legacy bulk-list surface returns string property values only. Use searchPropertyKeys for numeric keys.

fn get_metadata_usage_count( &self, auth_: &BearerToken, request: &GetMetadataUsageCountRequest, ) -> Result<GetMetadataUsageCountResponse, Error>

Returns the count of resources that use a given label or property. The query can match by label, property name (key only), or a full property key+value pair. Counts are scoped to the caller’s accessible workspaces unless specific workspaces are provided.

fn find_similar_label_matches( &self, auth_: &BearerToken, request: &FindSimilarLabelMatchesRequest, ) -> Result<FindSimilarLabelMatchesResponse, Error>

Given a set of labels, finds similar labels across the specified workspaces and resource types. Includes document count. Useful for detecting unintentional duplicate labels.

fn find_similar_property_key_matches( &self, auth_: &BearerToken, request: &FindSimilarPropertyKeyMatchesRequest, ) -> Result<FindSimilarPropertyKeyMatchesResponse, Error>

Given a set of property keys, finds similar property keys across the specified workspaces and resource types. Includes document count. Useful for detecting unintentional duplicate property keys.

fn search_labels( &self, auth_: &BearerToken, request: &SearchMetadataRequest, ) -> Result<SearchLabelsResponse, Error>

Returns a paginated list of labels with document usage counts, filterable by resource type, workspace, and search text.

fn search_property_keys( &self, auth_: &BearerToken, request: &SearchMetadataRequest, ) -> Result<SearchPropertyKeysResponse, Error>

Returns a paginated list of string and numeric property keys with typed statistics, filterable by resource type, workspace, and search text.

fn search_property_values( &self, auth_: &BearerToken, request: &SearchPropertyValuesRequest, ) -> Result<SearchPropertyValuesResponse, Error>

Returns a paginated list of string property values for a given property key with document usage counts, filterable by resource type, workspace, and search text. Numeric values are intentionally excluded; their summary is returned by searchPropertyKeys.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, __C> ResourceMetadataService<I> for ResourceMetadataServiceClient<__C>
where I: Iterator<Item = Result<Bytes, Error>>, __C: Client<ResponseBody = I>,