pub struct LocalAsyncNotebookServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncNotebookServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncNotebookServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncNotebookServiceClient<C>
impl<C: Clone> Clone for LocalAsyncNotebookServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncNotebookServiceClient<C>
fn clone(&self) -> LocalAsyncNotebookServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncNotebookServiceClient<C>
impl<C: Debug> Debug for LocalAsyncNotebookServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncNotebookService<I> for LocalAsyncNotebookServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncNotebookService<I> for LocalAsyncNotebookServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn create(
&self,
auth_: &BearerToken,
request: &CreateNotebookRequest,
) -> Result<Notebook, Error>
async fn create( &self, auth_: &BearerToken, request: &CreateNotebookRequest, ) -> Result<Notebook, Error>
Creates a new workbook. The workbook will be associated with the provided run. If the run does not exist,
a RunNotFound error will be thrown.
Sourceasync fn update(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &UpdateNotebookRequest,
) -> Result<Notebook, Error>
async fn update( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookRequest, ) -> Result<Notebook, Error>
Updates the contents of a workbook.
async fn get( &self, auth_: &BearerToken, rid: &NotebookRid, snapshot: Option<&SnapshotRid>, ) -> Result<Notebook, Error>
async fn batch_get( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> Result<BTreeSet<Notebook>, Error>
async fn batch_get_metadata( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> Result<BTreeSet<NotebookMetadataWithRid>, Error>
Sourceasync fn update_metadata(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &UpdateNotebookMetadataRequest,
) -> Result<NotebookMetadata, Error>
async fn update_metadata( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookMetadataRequest, ) -> Result<NotebookMetadata, Error>
Updates metadata about a workbook, but not its contents.
Sourceasync fn get_used_ref_names(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<BTreeSet<DataSourceRefName>, Error>
async fn get_used_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<BTreeSet<DataSourceRefName>, Error>
Returns the set of all ref names used by the workbook.
Sourceasync fn update_ref_names(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &UpdateRefNameRequest,
) -> Result<Notebook, Error>
async fn update_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateRefNameRequest, ) -> Result<Notebook, Error>
Updates the data source ref names for all variables used in the workbook.
Sourceasync fn get_all_labels_and_properties(
&self,
auth_: &BearerToken,
workspaces: &BTreeSet<WorkspaceRid>,
) -> Result<GetAllLabelsAndPropertiesResponse, Error>
async fn get_all_labels_and_properties( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> Result<GetAllLabelsAndPropertiesResponse, Error>
Returns all properties (key value pairs) and labels that have been previously used on workbook. These can
be used to organize workbooks.
async fn search( &self, auth_: &BearerToken, request: &SearchNotebooksRequest, ) -> Result<SearchNotebooksResponse, Error>
Sourceasync fn batch_edit_notebook_metadata(
&self,
auth_: &BearerToken,
request: &BatchEditNotebookMetadataRequest,
) -> Result<BatchEditNotebookMetadataResponse, Error>
async fn batch_edit_notebook_metadata( &self, auth_: &BearerToken, request: &BatchEditNotebookMetadataRequest, ) -> Result<BatchEditNotebookMetadataResponse, Error>
Batch edits metadata across multiple workbooks. Supports rename/merge for labels and properties.
If more than 1000 workbooks are targeted, this endpoint will throw a 400.
Sourceasync fn lock(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<(), Error>
async fn lock( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<(), Error>
Makes a workbook uneditable.
Deprecated: use the isLocked field on updateMetadata instead.
Sourceasync fn unlock(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<(), Error>
async fn unlock( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<(), Error>
Unlocks a workbook for editing.
Deprecated: use the isLocked field on updateMetadata instead.
Sourceasync fn archive(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<(), Error>
async fn archive( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<(), Error>
Archives a workbook, which excludes it from search and hides it from being publicly visible, but does not
permanently delete it. Archived workbooks can be unarchived.
Sourceasync fn unarchive(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<(), Error>
async fn unarchive( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<(), Error>
Makes a previously archived workbook searchable.
Sourceasync fn delete(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<(), Error>
async fn delete( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<(), Error>
The workbook will be deleted and is not recoverable. For soft deletion, use archive.
Sourceasync fn duplicate(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &DuplicateNotebookRequest,
) -> Result<Notebook, Error>
async fn duplicate( &self, auth_: &BearerToken, rid: &NotebookRid, request: &DuplicateNotebookRequest, ) -> Result<Notebook, Error>
Duplicates an existing workbook, copying its content (layout, charts, variables, pinned events)
and optionally overriding metadata fields such as title, description, data scope, labels,
and properties. Returns the newly created workbook.
Sourceasync fn get_snapshot_history(
&self,
auth_: &BearerToken,
request: &GetSnapshotHistoryRequest,
) -> Result<GetSnapshotHistoryResponse, Error>
async fn get_snapshot_history( &self, auth_: &BearerToken, request: &GetSnapshotHistoryRequest, ) -> Result<GetSnapshotHistoryResponse, Error>
Retrieves the snapshot history for a given workbook. These are sorted in reverse chronological order. Results
are limited by page size.