LocalAsyncNotebookService

Trait LocalAsyncNotebookService 

pub trait LocalAsyncNotebookService<I: Stream<Item = Result<Bytes, Error>>> {
Show 17 methods // Required methods fn create( &self, auth_: &BearerToken, request: &CreateNotebookRequest, ) -> impl Future<Output = Result<Notebook, Error>>; fn update( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookRequest, ) -> impl Future<Output = Result<Notebook, Error>>; fn get( &self, auth_: &BearerToken, rid: &NotebookRid, snapshot: Option<&SnapshotRid>, ) -> impl Future<Output = Result<Notebook, Error>>; fn batch_get( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeSet<Notebook>, Error>>; fn batch_get_metadata( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeSet<NotebookMetadataWithRid>, Error>>; fn update_metadata( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookMetadataRequest, ) -> impl Future<Output = Result<NotebookMetadata, Error>>; fn get_used_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<BTreeSet<DataSourceRefName>, Error>>; fn update_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateRefNameRequest, ) -> impl Future<Output = Result<Notebook, Error>>; fn get_all_labels_and_properties( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> impl Future<Output = Result<GetAllLabelsAndPropertiesResponse, Error>>; fn search( &self, auth_: &BearerToken, request: &SearchNotebooksRequest, ) -> impl Future<Output = Result<SearchNotebooksResponse, Error>>; fn batch_edit_notebook_metadata( &self, auth_: &BearerToken, request: &BatchEditNotebookMetadataRequest, ) -> impl Future<Output = Result<BatchEditNotebookMetadataResponse, Error>>; fn lock( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>; fn unlock( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>; fn archive( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>; fn unarchive( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>; fn delete( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>; fn get_snapshot_history( &self, auth_: &BearerToken, request: &GetSnapshotHistoryRequest, ) -> impl Future<Output = Result<GetSnapshotHistoryResponse, Error>>;
}
NotebookService manages workbooks (formerly known as notebooks).

Required Methods

fn create( &self, auth_: &BearerToken, request: &CreateNotebookRequest, ) -> impl Future<Output = Result<Notebook, Error>>

Creates a new workbook. The workbook will be associated with the provided run. If the run does not exist, a RunNotFound error will be thrown.

fn update( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookRequest, ) -> impl Future<Output = Result<Notebook, Error>>

Updates the contents of a workbook.

fn get( &self, auth_: &BearerToken, rid: &NotebookRid, snapshot: Option<&SnapshotRid>, ) -> impl Future<Output = Result<Notebook, Error>>

fn batch_get( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeSet<Notebook>, Error>>

fn batch_get_metadata( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeSet<NotebookMetadataWithRid>, Error>>

fn update_metadata( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookMetadataRequest, ) -> impl Future<Output = Result<NotebookMetadata, Error>>

Updates metadata about a workbook, but not its contents.

fn get_used_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<BTreeSet<DataSourceRefName>, Error>>

Returns the set of all ref names used by the workbook.

fn update_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateRefNameRequest, ) -> impl Future<Output = Result<Notebook, Error>>

Updates the data source ref names for all variables used in the workbook.

fn get_all_labels_and_properties( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> impl Future<Output = Result<GetAllLabelsAndPropertiesResponse, Error>>

Returns all properties (key value pairs) and labels that have been previously used on workbook. These can be used to organize workbooks.

fn search( &self, auth_: &BearerToken, request: &SearchNotebooksRequest, ) -> impl Future<Output = Result<SearchNotebooksResponse, Error>>

fn batch_edit_notebook_metadata( &self, auth_: &BearerToken, request: &BatchEditNotebookMetadataRequest, ) -> impl Future<Output = Result<BatchEditNotebookMetadataResponse, Error>>

Batch edits metadata across multiple workbooks. Supports rename/merge for labels and properties. If more than 1000 workbooks are targeted, this endpoint will throw a 400.

fn lock( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>

Makes a workbook uneditable.

fn unlock( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>

Unlocks a workbook for editing.

fn archive( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>

Archives a workbook, which excludes it from search and hides it from being publicly visible, but does not permanently delete it. Archived workbooks can be unarchived.

fn unarchive( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>

Makes a previously archived workbook searchable.

fn delete( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> impl Future<Output = Result<(), Error>>

The workbook will be deleted and is not recoverable. For soft deletion, use archive.

fn get_snapshot_history( &self, auth_: &BearerToken, request: &GetSnapshotHistoryRequest, ) -> impl Future<Output = Result<GetSnapshotHistoryResponse, Error>>

Retrieves the snapshot history for a given workbook. These are sorted in reverse chronological order. Results are limited by page size.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncNotebookService<I> for LocalAsyncNotebookServiceClient<__C>
where __C: LocalAsyncClient<ResponseBody = I>,