pub struct LocalAsyncSpatialServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncSpatialServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncSpatialServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncSpatialServiceClient<C>
impl<C: Clone> Clone for LocalAsyncSpatialServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncSpatialServiceClient<C>
fn clone(&self) -> LocalAsyncSpatialServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncSpatialServiceClient<C>
impl<C: Debug> Debug for LocalAsyncSpatialServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncSpatialService<I> for LocalAsyncSpatialServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncSpatialService<I> for LocalAsyncSpatialServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn get(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> Result<Spatial, Error>
async fn get( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<Spatial, Error>
Returns spatial asset metadata associated with a spatial asset rid.
Sourceasync fn batch_get(
&self,
auth_: &BearerToken,
request: &GetSpatialsRequest,
) -> Result<GetSpatialsResponse, Error>
async fn batch_get( &self, auth_: &BearerToken, request: &GetSpatialsRequest, ) -> Result<GetSpatialsResponse, Error>
Returns spatial asset metadata for each given spatial asset rid.
Sourceasync fn search(
&self,
auth_: &BearerToken,
request: &SearchSpatialsRequest,
) -> Result<SearchSpatialsResponse, Error>
async fn search( &self, auth_: &BearerToken, request: &SearchSpatialsRequest, ) -> Result<SearchSpatialsResponse, Error>
Returns metadata about spatial assets that match a given query.
Sourceasync fn create(
&self,
auth_: &BearerToken,
request: &CreateSpatialRequest,
) -> Result<Spatial, Error>
async fn create( &self, auth_: &BearerToken, request: &CreateSpatialRequest, ) -> Result<Spatial, Error>
Creates and persists a spatial asset entity with the given metadata.
Sourceasync fn update_metadata(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
request: &UpdateSpatialMetadataRequest,
) -> Result<Spatial, Error>
async fn update_metadata( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, request: &UpdateSpatialMetadataRequest, ) -> Result<Spatial, Error>
Updates the metadata for a spatial asset associated with the given rid.
async fn get_ingest_status( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<SpatialIngestStatus, Error>
async fn batch_get_ingest_status( &self, auth_: &BearerToken, spatial_rids: &BTreeSet<SpatialRid>, ) -> Result<BTreeMap<SpatialRid, SpatialIngestStatus>, Error>
Sourceasync fn archive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> Result<(), Error>
async fn archive( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<(), Error>
Archives a spatial asset, excluding it from search. Can be unarchived.
Sourceasync fn unarchive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> Result<(), Error>
async fn unarchive( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<(), Error>
Unarchives a previously archived spatial asset.
Sourceasync fn import_file(
&self,
auth_: &BearerToken,
request: &ImportFileRequest,
) -> Result<ImportFileResponse, Error>
async fn import_file( &self, auth_: &BearerToken, request: &ImportFileRequest, ) -> Result<ImportFileResponse, Error>
Imports a spatial data file (e.g. LAS, LAZ, PLY, PCAP).
Creates a new spatial asset, processes the file, and uploads the extracted data to Dagger.