LocalAsyncSpatialService

Trait LocalAsyncSpatialService 

pub trait LocalAsyncSpatialService<I>
where I: Stream<Item = Result<Bytes, Error>>,
{ // Required methods fn get( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, ) -> impl Future<Output = Result<Spatial, Error>>; fn batch_get( &self, auth_: &BearerToken, request: &GetSpatialsRequest, ) -> impl Future<Output = Result<GetSpatialsResponse, Error>>; fn search( &self, auth_: &BearerToken, request: &SearchSpatialsRequest, ) -> impl Future<Output = Result<SearchSpatialsResponse, Error>>; fn create( &self, auth_: &BearerToken, request: &CreateSpatialRequest, ) -> impl Future<Output = Result<Spatial, Error>>; fn update_metadata( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, request: &UpdateSpatialMetadataRequest, ) -> impl Future<Output = Result<Spatial, Error>>; fn archive( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, ) -> impl Future<Output = Result<(), Error>>; fn unarchive( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, ) -> impl Future<Output = Result<(), Error>>; }
The spatial asset service manages spatial assets (point clouds, etc.) and their metadata. Spatial asset data is stored in Dagger; Scout tracks metadata and references.

Required Methods

fn get( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, ) -> impl Future<Output = Result<Spatial, Error>>

Returns spatial asset metadata associated with a spatial asset rid.

fn batch_get( &self, auth_: &BearerToken, request: &GetSpatialsRequest, ) -> impl Future<Output = Result<GetSpatialsResponse, Error>>

Returns spatial asset metadata for each given spatial asset rid.

fn search( &self, auth_: &BearerToken, request: &SearchSpatialsRequest, ) -> impl Future<Output = Result<SearchSpatialsResponse, Error>>

Returns metadata about spatial assets that match a given query.

fn create( &self, auth_: &BearerToken, request: &CreateSpatialRequest, ) -> impl Future<Output = Result<Spatial, Error>>

Creates and persists a spatial asset entity with the given metadata.

fn update_metadata( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, request: &UpdateSpatialMetadataRequest, ) -> impl Future<Output = Result<Spatial, Error>>

Updates the metadata for a spatial asset associated with the given rid.

fn archive( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, ) -> impl Future<Output = Result<(), Error>>

Archives a spatial asset, excluding it from search. Can be unarchived.

fn unarchive( &self, auth_: &BearerToken, spatial_rid: &ResourceIdentifier, ) -> impl Future<Output = Result<(), Error>>

Unarchives a previously archived spatial asset.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, __C> LocalAsyncSpatialService<I> for LocalAsyncSpatialServiceClient<__C>
where I: Stream<Item = Result<Bytes, Error>>, __C: LocalAsyncClient<ResponseBody = I>,