pub struct SpatialServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for SpatialServiceClient<C>
impl<C: Clone> Clone for SpatialServiceClient<C>
Sourcefn clone(&self) -> SpatialServiceClient<C>
fn clone(&self) -> SpatialServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for SpatialServiceClient<C>
impl<C: Debug> Debug for SpatialServiceClient<C>
Sourceimpl<C> Service<C> for SpatialServiceClient<C>
impl<C> Service<C> for SpatialServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.
Sourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> SpatialService<I> for SpatialServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> SpatialService<I> for SpatialServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn get(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> Result<Spatial, Error>
fn get( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<Spatial, Error>
Returns spatial asset metadata associated with a spatial asset rid.
Sourcefn batch_get(
&self,
auth_: &BearerToken,
request: &GetSpatialsRequest,
) -> Result<GetSpatialsResponse, Error>
fn batch_get( &self, auth_: &BearerToken, request: &GetSpatialsRequest, ) -> Result<GetSpatialsResponse, Error>
Returns spatial asset metadata for each given spatial asset rid.
Sourcefn search(
&self,
auth_: &BearerToken,
request: &SearchSpatialsRequest,
) -> Result<SearchSpatialsResponse, Error>
fn search( &self, auth_: &BearerToken, request: &SearchSpatialsRequest, ) -> Result<SearchSpatialsResponse, Error>
Returns metadata about spatial assets that match a given query.
Sourcefn create(
&self,
auth_: &BearerToken,
request: &CreateSpatialRequest,
) -> Result<Spatial, Error>
fn create( &self, auth_: &BearerToken, request: &CreateSpatialRequest, ) -> Result<Spatial, Error>
Creates and persists a spatial asset entity with the given metadata.
Sourcefn update_metadata(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
request: &UpdateSpatialMetadataRequest,
) -> Result<Spatial, Error>
fn update_metadata( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, request: &UpdateSpatialMetadataRequest, ) -> Result<Spatial, Error>
Updates the metadata for a spatial asset associated with the given rid.
fn get_ingest_status( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<SpatialIngestStatus, Error>
fn batch_get_ingest_status( &self, auth_: &BearerToken, spatial_rids: &BTreeSet<SpatialRid>, ) -> Result<BTreeMap<SpatialRid, SpatialIngestStatus>, Error>
Sourcefn archive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> Result<(), Error>
fn archive( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<(), Error>
Archives a spatial asset, excluding it from search. Can be unarchived.
Sourcefn unarchive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> Result<(), Error>
fn unarchive( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> Result<(), Error>
Unarchives a previously archived spatial asset.
Sourcefn import_file(
&self,
auth_: &BearerToken,
request: &ImportFileRequest,
) -> Result<ImportFileResponse, Error>
fn import_file( &self, auth_: &BearerToken, request: &ImportFileRequest, ) -> Result<ImportFileResponse, Error>
Imports a spatial data file (e.g. LAS, LAZ, PLY, PCAP).
Creates a new spatial asset, processes the file, and uploads the extracted data to Dagger.