pub struct AsyncTemplateServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for AsyncTemplateServiceClient<C>
impl<C> AsyncService<C> for AsyncTemplateServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncTemplateService<I> for AsyncTemplateServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncTemplateService<I> for AsyncTemplateServiceClient<__C>
Sourceasync fn create(
&self,
auth_: &BearerToken,
request: &CreateTemplateRequest,
) -> Result<Template, Error>
async fn create( &self, auth_: &BearerToken, request: &CreateTemplateRequest, ) -> Result<Template, Error>
Creates a new template.
Sourceasync fn get(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
commit: Option<&CommitId>,
) -> Result<Template, Error>
async fn get( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, commit: Option<&CommitId>, ) -> Result<Template, Error>
Must only pass one of (branch, commit). If neither are passed,
the latest commit on the “main” branch is returned.
Throws if the template, branch, or commit doesn’t exist.
async fn batch_get_metadata( &self, auth_: &BearerToken, rids: &BTreeSet<TemplateRid>, ) -> Result<BTreeSet<TemplateSummary>, Error>
Sourceasync fn save_working_state(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
request: &SaveTemplateRequest,
) -> Result<Template, Error>
async fn save_working_state( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, request: &SaveTemplateRequest, ) -> Result<Template, Error>
Creates a commit that may be compacted, e.g cleaned up and not exist anymore.
Throws if the template or branch doesn’t exist.
Throws if the latest commit doesn’t match the provided id.
Throws if you save to an archived template.
Sourceasync fn get_used_ref_names(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
commit: Option<&CommitId>,
) -> Result<BTreeSet<DataSourceRefName>, Error>
async fn get_used_ref_names( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, commit: Option<&CommitId>, ) -> Result<BTreeSet<DataSourceRefName>, Error>
Returns the set of all ref names used by the template.
Sourceasync fn update_ref_names(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
request: &UpdateRefNameRequest,
) -> Result<Template, Error>
async fn update_ref_names( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, request: &UpdateRefNameRequest, ) -> Result<Template, Error>
Updates the data source ref names for all variables used in the template.
Sourceasync fn commit(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
request: &CommitTemplateRequest,
) -> Result<Template, Error>
async fn commit( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, request: &CommitTemplateRequest, ) -> Result<Template, Error>
Creates a commit with a commit message.
Throws if the template or branch doesn’t exist.
Throws if the latest commit doesn’t match the provided id.
Throws if you commit to an archived template.
Sourceasync fn update_metadata(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
request: &UpdateMetadataRequest,
) -> Result<TemplateMetadata, Error>
async fn update_metadata( &self, auth_: &BearerToken, template_rid: &TemplateRid, request: &UpdateMetadataRequest, ) -> Result<TemplateMetadata, Error>
Throws if the template doesn’t exist.
async fn search_templates( &self, auth_: &BearerToken, request: &SearchTemplatesRequest, ) -> Result<SearchTemplatesResponse, Error>
async fn get_all_labels_and_properties( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> Result<GetAllLabelsAndPropertiesResponse, Error>
Sourceasync fn merge_to_main(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
request: &MergeToMainRequest,
) -> Result<Template, Error>
async fn merge_to_main( &self, auth_: &BearerToken, template_rid: &TemplateRid, request: &MergeToMainRequest, ) -> Result<Template, Error>
Merges the given branch to the “main” branch.
Throws if the template or branch doesn’t exist.
Throws if the latest commit doesn’t match the provided id.
Throws if you merge on an archived template.
Sourceimpl<C: Clone> Clone for AsyncTemplateServiceClient<C>
impl<C: Clone> Clone for AsyncTemplateServiceClient<C>
Sourcefn clone(&self) -> AsyncTemplateServiceClient<C>
fn clone(&self) -> AsyncTemplateServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncTemplateServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncTemplateServiceClient<C>
impl<C> Send for AsyncTemplateServiceClient<C>where
C: Send,
impl<C> Sync for AsyncTemplateServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncTemplateServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncTemplateServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncTemplateServiceClient<C>