pub struct AsyncUnitsServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for AsyncUnitsServiceClient<C>
impl<C> AsyncService<C> for AsyncUnitsServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncUnitsService<I> for AsyncUnitsServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncUnitsService<I> for AsyncUnitsServiceClient<__C>
Sourceasync fn get_all_units(
&self,
auth_: &BearerToken,
) -> Result<GetUnitsResponse, Error>
async fn get_all_units( &self, auth_: &BearerToken, ) -> Result<GetUnitsResponse, Error>
Returns all known units, grouped by the physical property they measure.
Sourceasync fn get_unit(
&self,
auth_: &BearerToken,
unit: &UnitSymbol,
) -> Result<Option<Unit>, Error>
async fn get_unit( &self, auth_: &BearerToken, unit: &UnitSymbol, ) -> Result<Option<Unit>, Error>
Returns information for a unit symbol if available. Returns as empty if the provided symbol cannot be parsed.
Sourceasync fn get_batch_units(
&self,
auth_: &BearerToken,
units: &BTreeSet<UnitSymbol>,
) -> Result<BTreeMap<UnitSymbol, Unit>, Error>
async fn get_batch_units( &self, auth_: &BearerToken, units: &BTreeSet<UnitSymbol>, ) -> Result<BTreeMap<UnitSymbol, Unit>, Error>
Returns information for the unit symbols if available. If the provided symbol cannot be parsed, it will be
omitted from the map.
Sourceasync fn get_commensurable_units(
&self,
auth_: &BearerToken,
unit: &UnitSymbol,
) -> Result<BTreeSet<Unit>, Error>
async fn get_commensurable_units( &self, auth_: &BearerToken, unit: &UnitSymbol, ) -> Result<BTreeSet<Unit>, Error>
Returns the set of cataloged units that can be converted to and from the given unit.
No commensurable units does not imply the unit is invalid. Use /get-unit to check for validity.
Sourceimpl<C: Clone> Clone for AsyncUnitsServiceClient<C>
impl<C: Clone> Clone for AsyncUnitsServiceClient<C>
Sourcefn clone(&self) -> AsyncUnitsServiceClient<C>
fn clone(&self) -> AsyncUnitsServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncUnitsServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncUnitsServiceClient<C>
impl<C> Send for AsyncUnitsServiceClient<C>where
C: Send,
impl<C> Sync for AsyncUnitsServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncUnitsServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncUnitsServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncUnitsServiceClient<C>