pub struct AsyncVersioningServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for AsyncVersioningServiceClient<C>
impl<C> AsyncService<C> for AsyncVersioningServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncVersioningService<I> for AsyncVersioningServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncVersioningService<I> for AsyncVersioningServiceClient<__C>
Sourceasync fn create_branch(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &CreateBranchRequest,
) -> Result<Branch, Error>
async fn create_branch( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &CreateBranchRequest, ) -> Result<Branch, Error>
Creates a mutable pointer to the provided commit.
“Saves”/“commits” can be performed on this pointer.
Throws if the name is already used as a commit
pointer for this resource.
Throws if the provided commit doesn’t exist.
Sourceasync fn create_tag(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &CreateTagRequest,
) -> Result<Tag, Error>
async fn create_tag( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &CreateTagRequest, ) -> Result<Tag, Error>
Creates an immutable pointer to the provided commit.
Throws if the name is already used as a commit
pointer for this resource.
Throws if the provided commit doesn’t exist.
Sourceasync fn get_commit(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
commit_id: &CommitId,
) -> Result<Commit, Error>
async fn get_commit( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, commit_id: &CommitId, ) -> Result<Commit, Error>
Throws if the commit doesn’t exist.
Sourceasync fn batch_get_commits(
&self,
auth_: &BearerToken,
resource_and_commit_ids: &BTreeSet<ResourceAndCommitId>,
) -> Result<BTreeSet<Commit>, Error>
async fn batch_get_commits( &self, auth_: &BearerToken, resource_and_commit_ids: &BTreeSet<ResourceAndCommitId>, ) -> Result<BTreeSet<Commit>, Error>
Filters out resources that are not authorized.
Sourceasync fn get_commit_by_branch(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
) -> Result<Commit, Error>
async fn get_commit_by_branch( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, ) -> Result<Commit, Error>
Returns the commit pointed to by the branch.
Throws if the branch doesn’t exist.
Sourceasync fn get_commit_by_tag(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
tag_name: &TagName,
) -> Result<Commit, Error>
async fn get_commit_by_tag( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, tag_name: &TagName, ) -> Result<Commit, Error>
Returns the commit pointed to by the tag.
Throws if the tag doesn’t exist.
Sourceasync fn get_least_common_ancestor(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &GetLeastCommonAncestorRequest,
) -> Result<CommitId, Error>
async fn get_least_common_ancestor( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &GetLeastCommonAncestorRequest, ) -> Result<CommitId, Error>
Returns the least common ancestor of the two commits.
Throws if either commit doesn’t exist.
Sourceasync fn get_commit_history(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
commit_id: &CommitId,
page_size: Option<i32>,
next_page_token: Option<&Token>,
) -> Result<CommitHistory, Error>
async fn get_commit_history( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, commit_id: &CommitId, page_size: Option<i32>, next_page_token: Option<&Token>, ) -> Result<CommitHistory, Error>
Returns the commit history sorted by creation time descending.
Excludes working state commits.
Throws if the commit doesn’t exist.
Sourceasync fn persist_commits(
&self,
auth_: &BearerToken,
request: &BTreeSet<ResourceAndCommitId>,
) -> Result<(), Error>
async fn persist_commits( &self, auth_: &BearerToken, request: &BTreeSet<ResourceAndCommitId>, ) -> Result<(), Error>
Persists the commits so that they are not compacted.
This operation is atomic - either all commits are persisted
or none are (in the case of an error).
Sourceasync fn get_branch(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
) -> Result<Branch, Error>
async fn get_branch( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, ) -> Result<Branch, Error>
Throws if the branch doesn’t exist.
Sourceasync fn get_branches(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
) -> Result<Vec<Branch>, Error>
async fn get_branches( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, ) -> Result<Vec<Branch>, Error>
Returns all branches for the resource in order of
most recently updated.
Sourceasync fn batch_get_branches(
&self,
auth_: &BearerToken,
resource_and_branches: &BTreeSet<ResourceAndBranchName>,
) -> Result<BTreeSet<Branch>, Error>
async fn batch_get_branches( &self, auth_: &BearerToken, resource_and_branches: &BTreeSet<ResourceAndBranchName>, ) -> Result<BTreeSet<Branch>, Error>
Omits branches that are not authorized.
Sourceasync fn get_tag(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
tag_name: &TagName,
) -> Result<Tag, Error>
async fn get_tag( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, tag_name: &TagName, ) -> Result<Tag, Error>
Throws if the tag doesn’t exist.
Omits tags that are not authorized.
Returns all tags for the resource in order of
most recently created.
Sourceasync fn delete_branch(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
) -> Result<(), Error>
async fn delete_branch( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, ) -> Result<(), Error>
Deletes the branch pointer.
Throws if the branch doesn’t exist.
Throws if you attempt to delete the “main” branch.
Sourceasync fn delete_branches(
&self,
auth_: &BearerToken,
resource_and_branches: &BTreeSet<ResourceAndBranchName>,
) -> Result<(), Error>
async fn delete_branches( &self, auth_: &BearerToken, resource_and_branches: &BTreeSet<ResourceAndBranchName>, ) -> Result<(), Error>
Deletes the branch pointers.
Throws if any resource or branch is non-existent
or unauthorized.
Throws if any attempt is made to delete “main”.
Sourceasync fn delete_tag(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
tag_name: &TagName,
) -> Result<(), Error>
async fn delete_tag( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, tag_name: &TagName, ) -> Result<(), Error>
Deletes the tag pointer.
Throws if the tag doesn’t exist.
Sourceimpl<C: Clone> Clone for AsyncVersioningServiceClient<C>
impl<C: Clone> Clone for AsyncVersioningServiceClient<C>
Sourcefn clone(&self) -> AsyncVersioningServiceClient<C>
fn clone(&self) -> AsyncVersioningServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncVersioningServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncVersioningServiceClient<C>
impl<C> Send for AsyncVersioningServiceClient<C>where
C: Send,
impl<C> Sync for AsyncVersioningServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncVersioningServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncVersioningServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncVersioningServiceClient<C>