pub struct InternalVersioningServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for InternalVersioningServiceClient<C>
impl<C: Clone> Clone for InternalVersioningServiceClient<C>
Sourcefn clone(&self) -> InternalVersioningServiceClient<C>
fn clone(&self) -> InternalVersioningServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for InternalVersioningServiceClient<C>
impl<C: Debug> Debug for InternalVersioningServiceClient<C>
Sourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> InternalVersioningService<I> for InternalVersioningServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> InternalVersioningService<I> for InternalVersioningServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn init_resource_versioning(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &InitResourceVersioningRequest,
) -> Result<BranchAndCommit, Error>
fn init_resource_versioning( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &InitResourceVersioningRequest, ) -> Result<BranchAndCommit, Error>
Creates a root commit (no parents) and a “main” branch
pointing to that commit, for the given resource.
Throws if the resource already has a commit graph.
Sourcefn save_working_state(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
request: &SaveWorkingStateRequest,
) -> Result<BranchAndCommit, Error>
fn save_working_state( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, request: &SaveWorkingStateRequest, ) -> Result<BranchAndCommit, Error>
Creates a non-permanent commit on the given branch,
Throws if the branch doesn’t exist.
Throws if latestCommit is passed and is not the latest commit.
Sourcefn commit(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
branch_name: &BranchName,
request: &CommitRequest,
) -> Result<BranchAndCommit, Error>
fn commit( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, branch_name: &BranchName, request: &CommitRequest, ) -> Result<BranchAndCommit, Error>
Creates a new permanent commit on the given branch.
Throws if the branch doesn’t exist.
Throws if latestCommit is passed and is not the latest commit.
Sourcefn compact_commits(
&self,
auth_: &BearerToken,
resource_rid: &ResourceIdentifier,
request: &CompactCommitsRequest,
) -> Result<BTreeSet<CommitId>, Error>
fn compact_commits( &self, auth_: &BearerToken, resource_rid: &ResourceIdentifier, request: &CompactCommitsRequest, ) -> Result<BTreeSet<CommitId>, Error>
Compacts the commit graph for the resource by deleting
working state commits that match the provided strategy.
Persists commits that are pointed to by branches.
Returns the set of commits that were compacted.
Throws if the resource doesn’t exist.
Sourceimpl<C> Service<C> for InternalVersioningServiceClient<C>
impl<C> Service<C> for InternalVersioningServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.