pub struct NotebookServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for NotebookServiceClient<C>
impl<C: Clone> Clone for NotebookServiceClient<C>
Sourcefn clone(&self) -> NotebookServiceClient<C>
fn clone(&self) -> NotebookServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for NotebookServiceClient<C>
impl<C: Debug> Debug for NotebookServiceClient<C>
Sourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> NotebookService<I> for NotebookServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> NotebookService<I> for NotebookServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn create(
&self,
auth_: &BearerToken,
request: &CreateNotebookRequest,
) -> Result<Notebook, Error>
fn create( &self, auth_: &BearerToken, request: &CreateNotebookRequest, ) -> Result<Notebook, Error>
Creates a new workbook. The workbook will be associated with the provided run. If the run does not exist,
a RunNotFound error will be thrown.
Sourcefn update(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &UpdateNotebookRequest,
) -> Result<Notebook, Error>
fn update( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookRequest, ) -> Result<Notebook, Error>
Updates the contents of a workbook.
fn get( &self, auth_: &BearerToken, rid: &NotebookRid, snapshot: Option<&SnapshotRid>, ) -> Result<Notebook, Error>
fn batch_get( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> Result<BTreeSet<Notebook>, Error>
fn batch_get_metadata( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> Result<BTreeSet<NotebookMetadataWithRid>, Error>
Sourcefn update_metadata(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &UpdateNotebookMetadataRequest,
) -> Result<NotebookMetadata, Error>
fn update_metadata( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateNotebookMetadataRequest, ) -> Result<NotebookMetadata, Error>
Updates metadata about a workbook, but not its contents.
Sourcefn get_used_ref_names(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
) -> Result<BTreeSet<DataSourceRefName>, Error>
fn get_used_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, ) -> Result<BTreeSet<DataSourceRefName>, Error>
Returns the set of all ref names used by the workbook.
Sourcefn update_ref_names(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &UpdateRefNameRequest,
) -> Result<Notebook, Error>
fn update_ref_names( &self, auth_: &BearerToken, rid: &NotebookRid, request: &UpdateRefNameRequest, ) -> Result<Notebook, Error>
Updates the data source ref names for all variables used in the workbook.
Sourcefn get_all_labels_and_properties(
&self,
auth_: &BearerToken,
workspaces: &BTreeSet<WorkspaceRid>,
) -> Result<GetAllLabelsAndPropertiesResponse, Error>
fn get_all_labels_and_properties( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> Result<GetAllLabelsAndPropertiesResponse, Error>
Returns all properties (key value pairs) and labels that have been previously used on workbook. These can
be used to organize workbooks.
fn search( &self, auth_: &BearerToken, request: &SearchNotebooksRequest, ) -> Result<SearchNotebooksResponse, Error>
Sourcefn batch_edit_notebook_metadata(
&self,
auth_: &BearerToken,
request: &BatchEditNotebookMetadataRequest,
) -> Result<BatchEditNotebookMetadataResponse, Error>
fn batch_edit_notebook_metadata( &self, auth_: &BearerToken, request: &BatchEditNotebookMetadataRequest, ) -> Result<BatchEditNotebookMetadataResponse, Error>
Batch edits metadata across multiple workbooks. Supports rename/merge for labels and properties.
If more than 1000 workbooks are targeted, this endpoint will throw a 400.
Sourcefn lock(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
fn lock(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
Makes a workbook uneditable.
Deprecated: use the isLocked field on updateMetadata instead.
Sourcefn unlock(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
fn unlock(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
Unlocks a workbook for editing.
Deprecated: use the isLocked field on updateMetadata instead.
Sourcefn archive(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
fn archive(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
Archives a workbook, which excludes it from search and hides it from being publicly visible, but does not
permanently delete it. Archived workbooks can be unarchived.
Sourcefn unarchive(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
fn unarchive(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
Makes a previously archived workbook searchable.
Sourcefn delete(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
fn delete(&self, auth_: &BearerToken, rid: &NotebookRid) -> Result<(), Error>
The workbook will be deleted and is not recoverable. For soft deletion, use archive.
Sourcefn duplicate(
&self,
auth_: &BearerToken,
rid: &NotebookRid,
request: &DuplicateNotebookRequest,
) -> Result<Notebook, Error>
fn duplicate( &self, auth_: &BearerToken, rid: &NotebookRid, request: &DuplicateNotebookRequest, ) -> Result<Notebook, Error>
Duplicates an existing workbook, copying its content (layout, charts, variables, pinned events)
and optionally overriding metadata fields such as title, description, data scope, labels,
and properties. Returns the newly created workbook.
Sourcefn get_snapshot_history(
&self,
auth_: &BearerToken,
request: &GetSnapshotHistoryRequest,
) -> Result<GetSnapshotHistoryResponse, Error>
fn get_snapshot_history( &self, auth_: &BearerToken, request: &GetSnapshotHistoryRequest, ) -> Result<GetSnapshotHistoryResponse, Error>
Retrieves the snapshot history for a given workbook. These are sorted in reverse chronological order. Results
are limited by page size.
Sourceimpl<C> Service<C> for NotebookServiceClient<C>
impl<C> Service<C> for NotebookServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.