pub struct TemplateServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for TemplateServiceClient<C>
impl<C: Clone> Clone for TemplateServiceClient<C>
Sourcefn clone(&self) -> TemplateServiceClient<C>
fn clone(&self) -> TemplateServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for TemplateServiceClient<C>
impl<C: Debug> Debug for TemplateServiceClient<C>
Sourceimpl<C> Service<C> for TemplateServiceClient<C>
impl<C> Service<C> for TemplateServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.
Sourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> TemplateService<I> for TemplateServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> TemplateService<I> for TemplateServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn create(
&self,
auth_: &BearerToken,
request: &CreateTemplateRequest,
) -> Result<Template, Error>
fn create( &self, auth_: &BearerToken, request: &CreateTemplateRequest, ) -> Result<Template, Error>
Creates a new template.
Sourcefn get(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
commit: Option<&CommitId>,
) -> Result<Template, Error>
fn get( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, commit: Option<&CommitId>, ) -> Result<Template, Error>
Must only pass one of (branch, commit). If neither are passed,
the latest commit on the “main” branch is returned.
Throws if the template, branch, or commit doesn’t exist.
fn batch_get_metadata( &self, auth_: &BearerToken, rids: &BTreeSet<TemplateRid>, ) -> Result<BTreeSet<TemplateSummary>, Error>
Sourcefn save_working_state(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
request: &SaveTemplateRequest,
) -> Result<Template, Error>
fn save_working_state( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, request: &SaveTemplateRequest, ) -> Result<Template, Error>
Creates a commit that may be compacted, e.g cleaned up and not exist anymore.
Throws if the template or branch doesn’t exist.
Throws if the latest commit doesn’t match the provided id.
Throws if you save to an archived template.
Sourcefn get_used_ref_names(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
commit: Option<&CommitId>,
) -> Result<BTreeSet<DataSourceRefName>, Error>
fn get_used_ref_names( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, commit: Option<&CommitId>, ) -> Result<BTreeSet<DataSourceRefName>, Error>
Returns the set of all ref names used by the template.
Sourcefn update_ref_names(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
request: &UpdateRefNameRequest,
) -> Result<Template, Error>
fn update_ref_names( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, request: &UpdateRefNameRequest, ) -> Result<Template, Error>
Updates the data source ref names for all variables used in the template.
Sourcefn commit(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
branch: Option<&BranchName>,
request: &CommitTemplateRequest,
) -> Result<Template, Error>
fn commit( &self, auth_: &BearerToken, template_rid: &TemplateRid, branch: Option<&BranchName>, request: &CommitTemplateRequest, ) -> Result<Template, Error>
Creates a commit with a commit message.
Throws if the template or branch doesn’t exist.
Throws if the latest commit doesn’t match the provided id.
Throws if you commit to an archived template.
Sourcefn update_metadata(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
request: &UpdateMetadataRequest,
) -> Result<TemplateMetadata, Error>
fn update_metadata( &self, auth_: &BearerToken, template_rid: &TemplateRid, request: &UpdateMetadataRequest, ) -> Result<TemplateMetadata, Error>
Throws if the template doesn’t exist.
fn search_templates( &self, auth_: &BearerToken, request: &SearchTemplatesRequest, ) -> Result<SearchTemplatesResponse, Error>
fn get_all_labels_and_properties( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> Result<GetAllLabelsAndPropertiesResponse, Error>
Sourcefn merge_to_main(
&self,
auth_: &BearerToken,
template_rid: &TemplateRid,
request: &MergeToMainRequest,
) -> Result<Template, Error>
fn merge_to_main( &self, auth_: &BearerToken, template_rid: &TemplateRid, request: &MergeToMainRequest, ) -> Result<Template, Error>
Merges the given branch to the “main” branch.
Throws if the template or branch doesn’t exist.
Throws if the latest commit doesn’t match the provided id.
Throws if you merge on an archived template.