pub trait AsyncRunService<I: Stream<Item = Result<Bytes, Error>>> {
Show 22 methods
// Required methods
fn create_run(
&self,
auth_: &BearerToken,
details: &CreateRunRequest,
) -> impl Future<Output = Result<Run, Error>> + Send;
fn update_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
details: &UpdateRunRequest,
) -> impl Future<Output = Result<Run, Error>> + Send;
fn batch_edit_run_metadata(
&self,
auth_: &BearerToken,
request: &BatchEditRunMetadataRequest,
) -> impl Future<Output = Result<BatchEditRunMetadataResponse, Error>> + Send;
fn add_data_sources_to_run(
&self,
auth_: &BearerToken,
run_rid: &RunRid,
request: &BTreeMap<DataSourceRefName, CreateRunDataSource>,
) -> impl Future<Output = Result<Run, Error>> + Send;
fn create_or_update_run(
&self,
auth_: &BearerToken,
details: &CreateOrUpdateRunRequest,
) -> impl Future<Output = Result<Run, Error>> + Send;
fn get_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
) -> impl Future<Output = Result<Run, Error>> + Send;
fn get_run_with_data_review_metrics(
&self,
auth_: &BearerToken,
rid: &RunRid,
) -> impl Future<Output = Result<RunWithDataReviewMetrics, Error>> + Send;
fn get_run_with_data_review_summary(
&self,
auth_: &BearerToken,
rid: &RunRid,
) -> impl Future<Output = Result<RunWithDataReviewSummary, Error>> + Send;
fn get_run_by_id(
&self,
auth_: &BearerToken,
get_run_by_id_request: &GetRunByIdRequest,
) -> impl Future<Output = Result<Run, Error>> + Send;
fn get_runs(
&self,
auth_: &BearerToken,
rids: &BTreeSet<RunRid>,
) -> impl Future<Output = Result<BTreeMap<RunRid, Run>, Error>> + Send;
fn get_runs_by_asset(
&self,
auth_: &BearerToken,
request: &GetRunsByAssetRequest,
) -> impl Future<Output = Result<GetRunsByAssetResponse, Error>> + Send;
fn get_latest_run_for_assets(
&self,
auth_: &BearerToken,
request: &BTreeSet<AssetRid>,
) -> impl Future<Output = Result<BTreeMap<AssetRid, Run>, Error>> + Send;
fn get_all_runs_properties_and_labels(
&self,
auth_: &BearerToken,
workspaces: &BTreeSet<WorkspaceRid>,
) -> impl Future<Output = Result<AllRunsPropertiesAndLabelsResponse, Error>> + Send;
fn search_runs(
&self,
auth_: &BearerToken,
request: &SearchRunsRequest,
) -> impl Future<Output = Result<SearchRunsResponse, Error>> + Send;
fn search_runs_with_data_review_metrics(
&self,
auth_: &BearerToken,
request: &SearchRunsRequest,
) -> impl Future<Output = Result<SearchRunsWithDataReviewMetricsResponse, Error>> + Send;
fn search_runs_with_data_review_summary(
&self,
auth_: &BearerToken,
request: &SearchRunsRequest,
) -> impl Future<Output = Result<SearchRunsWithDataReviewSummaryResponse, Error>> + Send;
fn archive_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
include_linked_workbooks: Option<bool>,
) -> impl Future<Output = Result<bool, Error>> + Send;
fn unarchive_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
include_linked_workbooks: Option<bool>,
) -> impl Future<Output = Result<bool, Error>> + Send;
fn archive_runs(
&self,
auth_: &BearerToken,
request: &ArchiveRunsRequest,
) -> impl Future<Output = Result<(), Error>> + Send;
fn unarchive_runs(
&self,
auth_: &BearerToken,
request: &UnarchiveRunsRequest,
) -> impl Future<Output = Result<(), Error>> + Send;
fn get_data_source_ref_name_and_type_list(
&self,
auth_: &BearerToken,
workspaces: &BTreeSet<WorkspaceRid>,
) -> impl Future<Output = Result<Vec<RefNameAndType>, Error>> + Send;
fn update_run_attachment(
&self,
auth_: &BearerToken,
rid: &RunRid,
request: &UpdateAttachmentsRequest,
) -> impl Future<Output = Result<(), Error>> + Send;
}Expand description
Runs are collections of channels and metadata from one or more data sources, synchronized over a range of real time, which represents a test event or simulation. These API endpoints let you manage runs in the Nominal app.
Required Methods
Sourcefn create_run(
&self,
auth_: &BearerToken,
details: &CreateRunRequest,
) -> impl Future<Output = Result<Run, Error>> + Send
fn create_run( &self, auth_: &BearerToken, details: &CreateRunRequest, ) -> impl Future<Output = Result<Run, Error>> + Send
Create a new run in Nominal.
Throws if start is equal to or after end.
Sourcefn update_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
details: &UpdateRunRequest,
) -> impl Future<Output = Result<Run, Error>> + Send
fn update_run( &self, auth_: &BearerToken, rid: &RunRid, details: &UpdateRunRequest, ) -> impl Future<Output = Result<Run, Error>> + Send
Updates an existing run based on its RID.
Throws if start is equal to or after end.
Sourcefn batch_edit_run_metadata(
&self,
auth_: &BearerToken,
request: &BatchEditRunMetadataRequest,
) -> impl Future<Output = Result<BatchEditRunMetadataResponse, Error>> + Send
fn batch_edit_run_metadata( &self, auth_: &BearerToken, request: &BatchEditRunMetadataRequest, ) -> impl Future<Output = Result<BatchEditRunMetadataResponse, Error>> + Send
Batch edits metadata across multiple runs. Supports rename/merge for labels and properties. If more than 1000 runs are targeted, this endpoint will throw a 400.
Sourcefn add_data_sources_to_run(
&self,
auth_: &BearerToken,
run_rid: &RunRid,
request: &BTreeMap<DataSourceRefName, CreateRunDataSource>,
) -> impl Future<Output = Result<Run, Error>> + Send
fn add_data_sources_to_run( &self, auth_: &BearerToken, run_rid: &RunRid, request: &BTreeMap<DataSourceRefName, CreateRunDataSource>, ) -> impl Future<Output = Result<Run, Error>> + Send
Adds datasources to the run in question.
Throws if any of the ref names conflict with existing data sources or each other.
Sourcefn create_or_update_run(
&self,
auth_: &BearerToken,
details: &CreateOrUpdateRunRequest,
) -> impl Future<Output = Result<Run, Error>> + Send
fn create_or_update_run( &self, auth_: &BearerToken, details: &CreateOrUpdateRunRequest, ) -> impl Future<Output = Result<Run, Error>> + Send
Updates a run if it exists, otherwise it’s created from scratch. Will throw if the workspace of an existing run is different from the workspace of the request.
Sourcefn get_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
) -> impl Future<Output = Result<Run, Error>> + Send
fn get_run( &self, auth_: &BearerToken, rid: &RunRid, ) -> impl Future<Output = Result<Run, Error>> + Send
Fetches details about the run in question based on its RID.
Sourcefn get_run_with_data_review_metrics(
&self,
auth_: &BearerToken,
rid: &RunRid,
) -> impl Future<Output = Result<RunWithDataReviewMetrics, Error>> + Send
fn get_run_with_data_review_metrics( &self, auth_: &BearerToken, rid: &RunRid, ) -> impl Future<Output = Result<RunWithDataReviewMetrics, Error>> + Send
Fetches details about the run in question based on its RID, including metrics for check and violation review status.
Sourcefn get_run_with_data_review_summary(
&self,
auth_: &BearerToken,
rid: &RunRid,
) -> impl Future<Output = Result<RunWithDataReviewSummary, Error>> + Send
fn get_run_with_data_review_summary( &self, auth_: &BearerToken, rid: &RunRid, ) -> impl Future<Output = Result<RunWithDataReviewSummary, Error>> + Send
Fetches details about the run in question based on its RID, including a summary of the data review status.
Sourcefn get_run_by_id(
&self,
auth_: &BearerToken,
get_run_by_id_request: &GetRunByIdRequest,
) -> impl Future<Output = Result<Run, Error>> + Send
fn get_run_by_id( &self, auth_: &BearerToken, get_run_by_id_request: &GetRunByIdRequest, ) -> impl Future<Output = Result<Run, Error>> + Send
Fetches a run based on the run number, rather than RID.
Sourcefn get_runs(
&self,
auth_: &BearerToken,
rids: &BTreeSet<RunRid>,
) -> impl Future<Output = Result<BTreeMap<RunRid, Run>, Error>> + Send
fn get_runs( &self, auth_: &BearerToken, rids: &BTreeSet<RunRid>, ) -> impl Future<Output = Result<BTreeMap<RunRid, Run>, Error>> + Send
Fetches a list of run details based on a list of RIDs.
Sourcefn get_runs_by_asset(
&self,
auth_: &BearerToken,
request: &GetRunsByAssetRequest,
) -> impl Future<Output = Result<GetRunsByAssetResponse, Error>> + Send
fn get_runs_by_asset( &self, auth_: &BearerToken, request: &GetRunsByAssetRequest, ) -> impl Future<Output = Result<GetRunsByAssetResponse, Error>> + Send
Fetches the runs with the given asset.
Sourcefn get_latest_run_for_assets(
&self,
auth_: &BearerToken,
request: &BTreeSet<AssetRid>,
) -> impl Future<Output = Result<BTreeMap<AssetRid, Run>, Error>> + Send
fn get_latest_run_for_assets( &self, auth_: &BearerToken, request: &BTreeSet<AssetRid>, ) -> impl Future<Output = Result<BTreeMap<AssetRid, Run>, Error>> + Send
Fetches the latest run for each requested asset. Assets without associated runs will not be included in response.
fn get_all_runs_properties_and_labels( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> impl Future<Output = Result<AllRunsPropertiesAndLabelsResponse, Error>> + Send
Sourcefn search_runs(
&self,
auth_: &BearerToken,
request: &SearchRunsRequest,
) -> impl Future<Output = Result<SearchRunsResponse, Error>> + Send
fn search_runs( &self, auth_: &BearerToken, request: &SearchRunsRequest, ) -> impl Future<Output = Result<SearchRunsResponse, Error>> + Send
Searches for runs that match the given filters. Defaults to returning un-archived runs, absent an archive filter.
Sourcefn search_runs_with_data_review_metrics(
&self,
auth_: &BearerToken,
request: &SearchRunsRequest,
) -> impl Future<Output = Result<SearchRunsWithDataReviewMetricsResponse, Error>> + Send
fn search_runs_with_data_review_metrics( &self, auth_: &BearerToken, request: &SearchRunsRequest, ) -> impl Future<Output = Result<SearchRunsWithDataReviewMetricsResponse, Error>> + Send
Searches for runs that match the given filters and includes metrics for check and violation review status. Defaults to returning un-archived runs, absent an archive filter.
Sourcefn search_runs_with_data_review_summary(
&self,
auth_: &BearerToken,
request: &SearchRunsRequest,
) -> impl Future<Output = Result<SearchRunsWithDataReviewSummaryResponse, Error>> + Send
fn search_runs_with_data_review_summary( &self, auth_: &BearerToken, request: &SearchRunsRequest, ) -> impl Future<Output = Result<SearchRunsWithDataReviewSummaryResponse, Error>> + Send
Searches for runs that match the given filters and includes a summary of the data review status. Defaults to returning un-archived runs, absent an archive filter.
Sourcefn archive_run(
&self,
auth_: &BearerToken,
rid: &RunRid,
include_linked_workbooks: Option<bool>,
) -> impl Future<Output = Result<bool, Error>> + Send
fn archive_run( &self, auth_: &BearerToken, rid: &RunRid, include_linked_workbooks: Option<bool>, ) -> impl Future<Output = Result<bool, Error>> + Send
Soft-deletes a run. Runs still exist in the database but are no longer visible.
fn unarchive_run( &self, auth_: &BearerToken, rid: &RunRid, include_linked_workbooks: Option<bool>, ) -> impl Future<Output = Result<bool, Error>> + Send
fn archive_runs( &self, auth_: &BearerToken, request: &ArchiveRunsRequest, ) -> impl Future<Output = Result<(), Error>> + Send
fn unarchive_runs( &self, auth_: &BearerToken, request: &UnarchiveRunsRequest, ) -> impl Future<Output = Result<(), Error>> + Send
Sourcefn get_data_source_ref_name_and_type_list(
&self,
auth_: &BearerToken,
workspaces: &BTreeSet<WorkspaceRid>,
) -> impl Future<Output = Result<Vec<RefNameAndType>, Error>> + Send
fn get_data_source_ref_name_and_type_list( &self, auth_: &BearerToken, workspaces: &BTreeSet<WorkspaceRid>, ) -> impl Future<Output = Result<Vec<RefNameAndType>, Error>> + Send
Returns the list of ref names that are in use across specified and authorized workspaces.
Sourcefn update_run_attachment(
&self,
auth_: &BearerToken,
rid: &RunRid,
request: &UpdateAttachmentsRequest,
) -> impl Future<Output = Result<(), Error>> + Send
fn update_run_attachment( &self, auth_: &BearerToken, rid: &RunRid, request: &UpdateAttachmentsRequest, ) -> impl Future<Output = Result<(), Error>> + Send
Updates the attachments associated with a run.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.