UnitsService

Trait UnitsService 

pub trait UnitsService<I>
where I: Iterator<Item = Result<Bytes, Error>>,
{ // Required methods fn get_all_units( &self, auth_: &BearerToken, ) -> Result<GetUnitsResponse, Error>; fn get_unit( &self, auth_: &BearerToken, unit: &UnitSymbol, ) -> Result<Option<Unit>, Error>; fn get_batch_units( &self, auth_: &BearerToken, units: &BTreeSet<UnitSymbol>, ) -> Result<BTreeMap<UnitSymbol, Unit>, Error>; fn get_commensurable_units( &self, auth_: &BearerToken, unit: &UnitSymbol, ) -> Result<BTreeSet<Unit>, Error>; }
The Units Service serves as a comprehensive catalog of the units of measurement supported by scout. Units, by default, follow the UCUM convention for representation.

Required Methods

fn get_all_units(&self, auth_: &BearerToken) -> Result<GetUnitsResponse, Error>

Returns all known units, grouped by the physical property they measure.

fn get_unit( &self, auth_: &BearerToken, unit: &UnitSymbol, ) -> Result<Option<Unit>, Error>

Returns information for a unit symbol if available. Returns as empty if the provided symbol cannot be parsed.

fn get_batch_units( &self, auth_: &BearerToken, units: &BTreeSet<UnitSymbol>, ) -> Result<BTreeMap<UnitSymbol, Unit>, Error>

Returns information for the unit symbols if available. If the provided symbol cannot be parsed, it will be omitted from the map.

fn get_commensurable_units( &self, auth_: &BearerToken, unit: &UnitSymbol, ) -> Result<BTreeSet<Unit>, Error>

Returns the set of cataloged units that can be converted to and from the given unit. No commensurable units does not imply the unit is invalid. Use /get-unit to check for validity.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, __C> UnitsService<I> for UnitsServiceClient<__C>
where I: Iterator<Item = Result<Bytes, Error>>, __C: Client<ResponseBody = I>,