pub struct LocalAsyncVideoFileServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncVideoFileServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncVideoFileServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncVideoFileServiceClient<C>
impl<C: Clone> Clone for LocalAsyncVideoFileServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncVideoFileServiceClient<C>
fn clone(&self) -> LocalAsyncVideoFileServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncVideoFileServiceClient<C>
impl<C: Debug> Debug for LocalAsyncVideoFileServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncVideoFileService<I> for LocalAsyncVideoFileServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncVideoFileService<I> for LocalAsyncVideoFileServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn create(
&self,
auth_: &BearerToken,
request: &CreateVideoFileRequest,
) -> Result<VideoFile, Error>
async fn create( &self, auth_: &BearerToken, request: &CreateVideoFileRequest, ) -> Result<VideoFile, Error>
Create and persist a video file entity with the given metadata
Sourceasync fn get(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
) -> Result<VideoFile, Error>
async fn get( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<VideoFile, Error>
Returns video file metadata associated with a video file RID.
Sourceasync fn batch_get(
&self,
auth_: &BearerToken,
video_file_rids: &BTreeSet<VideoFileRid>,
) -> Result<BTreeSet<VideoFile>, Error>
async fn batch_get( &self, auth_: &BearerToken, video_file_rids: &BTreeSet<VideoFileRid>, ) -> Result<BTreeSet<VideoFile>, Error>
Returns all video files and their metadata associated with the given RIDs
async fn list_files_in_video( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<BTreeSet<VideoFile>, Error>
Sourceasync fn list_files_in_video_paginated(
&self,
auth_: &BearerToken,
video_rid: &ListFilesInVideoRequest,
) -> Result<ListFilesInVideoResponse, Error>
async fn list_files_in_video_paginated( &self, auth_: &BearerToken, video_rid: &ListFilesInVideoRequest, ) -> Result<ListFilesInVideoResponse, Error>
Returns a paginated list of all video files and their metadata associated with the given video RID.
Sourceasync fn update(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
request: &UpdateVideoFileRequest,
) -> Result<VideoFile, Error>
async fn update( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, request: &UpdateVideoFileRequest, ) -> Result<VideoFile, Error>
Updates the metadata for a video file associated with the given RID.
Sourceasync fn delete(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
) -> Result<(), Error>
async fn delete( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<(), Error>
Permanently deletes a video file and all associated segments from the database.
This operation cannot be undone.
async fn archive( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<(), Error>
async fn unarchive( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<(), Error>
Sourceasync fn get_ingest_status(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
) -> Result<GetIngestStatusResponse, Error>
async fn get_ingest_status( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<GetIngestStatusResponse, Error>
Get the latest ingest status for a given video file by RID.
Sourceasync fn batch_get_ingest_status(
&self,
auth_: &BearerToken,
video_file_rids: &BTreeSet<VideoFileRid>,
) -> Result<BTreeMap<VideoFileRid, VideoFileIngestStatus>, Error>
async fn batch_get_ingest_status( &self, auth_: &BearerToken, video_file_rids: &BTreeSet<VideoFileRid>, ) -> Result<BTreeMap<VideoFileRid, VideoFileIngestStatus>, Error>
Get the latest ingest status for a set of given video files by RID.
Sourceasync fn update_ingest_status(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
request: &UpdateIngestStatusRequest,
) -> Result<(), Error>
async fn update_ingest_status( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, request: &UpdateIngestStatusRequest, ) -> Result<(), Error>
Update the latest ingest status for a given video file by RID.
Sourceasync fn get_segment_summaries(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
) -> Result<Vec<SegmentSummary>, Error>
async fn get_segment_summaries( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<Vec<SegmentSummary>, Error>
Returns the min and max absolute and media timestamps for each segment in a video file.
To be used during frame-timestamp mapping when playing back videos.
Sourceasync fn get_playlist(
&self,
auth_: &BearerToken,
video_file_rid: &VideoFileRid,
) -> Result<I, Error>
async fn get_playlist( &self, auth_: &BearerToken, video_file_rid: &VideoFileRid, ) -> Result<I, Error>
Generate an HLS playlist for a video file with the given RID to enable playback.
The HLS playlist will contain links to all of the video segments in the video in sequential order.