LocalAsyncInternalSecretService

Trait LocalAsyncInternalSecretService 

pub trait LocalAsyncInternalSecretService<I>
where I: Stream<Item = Result<Bytes, Error>>,
{ // Required method fn get_decrypted( &self, auth_: &BearerToken, rid: &SecretRid, ) -> impl Future<Output = Result<DecryptedSecret, Error>>; }
The internal secrets service provides functionality for retrieving customer secrets where the “user” is a service.

Required Methods

fn get_decrypted( &self, auth_: &BearerToken, rid: &SecretRid, ) -> impl Future<Output = Result<DecryptedSecret, Error>>

Get decrypted secret by rid. This is a privileged operation that is restricted to services only. This endpoint must be a conjure endpoint in order to support TLS.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors