InternalSecretService

Trait InternalSecretService 

pub trait InternalSecretService<I>
where I: Iterator<Item = Result<Bytes, Error>>,
{ // Required method fn get_decrypted( &self, auth_: &BearerToken, rid: &SecretRid, ) -> Result<DecryptedSecret, Error>; }
The internal secrets service provides functionality for retrieving customer secrets where the “user” is a service.

Required Methods

fn get_decrypted( &self, auth_: &BearerToken, rid: &SecretRid, ) -> Result<DecryptedSecret, Error>

Get decrypted secret by rid. This is a privileged operation that is restricted to services only. This endpoint must be a conjure endpoint in order to support TLS.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<I, __C> InternalSecretService<I> for InternalSecretServiceClient<__C>
where I: Iterator<Item = Result<Bytes, Error>>, __C: Client<ResponseBody = I>,