pub struct AsyncWorkspaceServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for AsyncWorkspaceServiceClient<C>
impl<C> AsyncService<C> for AsyncWorkspaceServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncWorkspaceService<I> for AsyncWorkspaceServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncWorkspaceService<I> for AsyncWorkspaceServiceClient<__C>
Sourceasync fn get_workspaces(
&self,
auth_: &BearerToken,
) -> Result<BTreeSet<Workspace>, Error>
async fn get_workspaces( &self, auth_: &BearerToken, ) -> Result<BTreeSet<Workspace>, Error>
Gets all workspaces that the requesting user belongs to.
Sourceasync fn get_workspace(
&self,
auth_: &BearerToken,
workspace_rid: &WorkspaceRid,
) -> Result<Workspace, Error>
async fn get_workspace( &self, auth_: &BearerToken, workspace_rid: &WorkspaceRid, ) -> Result<Workspace, Error>
Gets the workspace with the specified WorkspaceRid.
Sourceasync fn update_workspace(
&self,
auth_: &BearerToken,
rid: &WorkspaceRid,
request: &UpdateWorkspaceRequest,
) -> Result<Workspace, Error>
async fn update_workspace( &self, auth_: &BearerToken, rid: &WorkspaceRid, request: &UpdateWorkspaceRequest, ) -> Result<Workspace, Error>
Updates the settings of the workspace with the specified WorkspaceRid.
Sourceasync fn get_default_workspace(
&self,
auth_: &BearerToken,
) -> Result<Option<Workspace>, Error>
async fn get_default_workspace( &self, auth_: &BearerToken, ) -> Result<Option<Workspace>, Error>
Gets the default workspace for the requesting user. If the user belongs to a single workspace,
that workspace is returned. Otherwise, if the user’s organization has a default workspace and
the user belongs to it, that will be returned.
Sourceimpl<C: Clone> Clone for AsyncWorkspaceServiceClient<C>
impl<C: Clone> Clone for AsyncWorkspaceServiceClient<C>
Sourcefn clone(&self) -> AsyncWorkspaceServiceClient<C>
fn clone(&self) -> AsyncWorkspaceServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncWorkspaceServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncWorkspaceServiceClient<C>
impl<C> Send for AsyncWorkspaceServiceClient<C>where
C: Send,
impl<C> Sync for AsyncWorkspaceServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncWorkspaceServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncWorkspaceServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncWorkspaceServiceClient<C>