pub struct AsyncDataDeletionServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncDataDeletionService<I> for AsyncDataDeletionServiceClient<__C>
impl<I: Stream<Item = Result<Bytes, Error>>, __C> AsyncDataDeletionService<I> for AsyncDataDeletionServiceClient<__C>
Sourceasync fn delete(
&self,
auth_: &BearerToken,
request: &DeleteDataRequest,
) -> Result<(), Error>
async fn delete( &self, auth_: &BearerToken, request: &DeleteDataRequest, ) -> Result<(), Error>
Deletes stored data. This is an irreversible operation so be careful about specified
time range, channel names, and tag scope. requires the user to be an admin for the organization.
Sourceimpl<C> AsyncService<C> for AsyncDataDeletionServiceClient<C>
impl<C> AsyncService<C> for AsyncDataDeletionServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncDataDeletionServiceClient<C>
impl<C: Clone> Clone for AsyncDataDeletionServiceClient<C>
Sourcefn clone(&self) -> AsyncDataDeletionServiceClient<C>
fn clone(&self) -> AsyncDataDeletionServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncDataDeletionServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncDataDeletionServiceClient<C>
impl<C> Send for AsyncDataDeletionServiceClient<C>where
C: Send,
impl<C> Sync for AsyncDataDeletionServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncDataDeletionServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncDataDeletionServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncDataDeletionServiceClient<C>