pub struct DataDeletionServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for DataDeletionServiceClient<C>
impl<C: Clone> Clone for DataDeletionServiceClient<C>
Sourcefn clone(&self) -> DataDeletionServiceClient<C>
fn clone(&self) -> DataDeletionServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> DataDeletionService<I> for DataDeletionServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> DataDeletionService<I> for DataDeletionServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn delete(
&self,
auth_: &BearerToken,
request: &DeleteDataRequest,
) -> Result<(), Error>
fn delete( &self, auth_: &BearerToken, request: &DeleteDataRequest, ) -> Result<(), Error>
Deletes stored data. This is an irreversible operation so be careful about specified
time range, channel names, and tag scope. requires the user to be an admin for the organization.
Sourceimpl<C: Debug> Debug for DataDeletionServiceClient<C>
impl<C: Debug> Debug for DataDeletionServiceClient<C>
Sourceimpl<C> Service<C> for DataDeletionServiceClient<C>
impl<C> Service<C> for DataDeletionServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.