pub struct LocalAsyncNominalChannelWriterServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncNominalChannelWriterServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncNominalChannelWriterServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncNominalChannelWriterServiceClient<C>
impl<C: Clone> Clone for LocalAsyncNominalChannelWriterServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncNominalChannelWriterServiceClient<C>
fn clone(&self) -> LocalAsyncNominalChannelWriterServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncNominalChannelWriterServiceClient<C>
impl<C: Debug> Debug for LocalAsyncNominalChannelWriterServiceClient<C>
Sourceimpl<O, I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncNominalChannelWriterService<O, I> for LocalAsyncNominalChannelWriterServiceClient<__C>where
__C: LocalAsyncClient<BodyWriter = O, ResponseBody = I>,
impl<O, I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncNominalChannelWriterService<O, I> for LocalAsyncNominalChannelWriterServiceClient<__C>where
__C: LocalAsyncClient<BodyWriter = O, ResponseBody = I>,
Sourceasync fn write_batches(
&self,
auth_: &BearerToken,
request: &WriteBatchesRequestExternal,
) -> Result<(), Error>
async fn write_batches( &self, auth_: &BearerToken, request: &WriteBatchesRequestExternal, ) -> Result<(), Error>
Synchronously writes batches of records to a Nominal data source. Read more
Sourceasync fn write_column_batches(
&self,
auth_: &BearerToken,
request: &WriteColumnBatchesRequest,
) -> Result<(), Error>
async fn write_column_batches( &self, auth_: &BearerToken, request: &WriteColumnBatchesRequest, ) -> Result<(), Error>
Synchronously writes batches of columns of data to a Nominal data source. Read more
Sourceasync fn write_telegraf_batches(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: &WriteTelegrafBatchesRequest,
) -> Result<(), Error>
async fn write_telegraf_batches( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: &WriteTelegrafBatchesRequest, ) -> Result<(), Error>
Synchronously writes batches of records to a Nominal data source. Read more
Sourceasync fn write_prometheus_batches(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: impl LocalAsyncWriteBody<O>,
) -> Result<(), Error>
async fn write_prometheus_batches( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: impl LocalAsyncWriteBody<O>, ) -> Result<(), Error>
Synchronously writes batches of records to a Nominal data source. Read more
Sourceasync fn prometheus_remote_write_health_check(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
) -> Result<bool, Error>
async fn prometheus_remote_write_health_check( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, ) -> Result<bool, Error>
Performs a health check for prometheus remote write Vector sink. All this endpoint does
is verify if the caller is authenticated and the server is online. Once Vector allows the Prometheus
remote write endpoint to configure the healthcheck url, we can remove this endpoint. Read more
Sourceasync fn write_nominal_batches(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: impl LocalAsyncWriteBody<O>,
) -> Result<(), Error>
async fn write_nominal_batches( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: impl LocalAsyncWriteBody<O>, ) -> Result<(), Error>
Synchronously writes a Nominal Write Request to a Nominal data source using the NominalWrite Protobuf schema.
The request must be Protobuf-encoded and accompanied by the appropriate content encoding headers if compressed. Read more
Sourceasync fn write_nominal_columnar_batches(
&self,
auth_: &BearerToken,
request: impl LocalAsyncWriteBody<O>,
) -> Result<(), Error>
async fn write_nominal_columnar_batches( &self, auth_: &BearerToken, request: impl LocalAsyncWriteBody<O>, ) -> Result<(), Error>
Synchronously writes to a Nominal data source using the columnar WriteBatchesRequest Protobuf schema. Read more
Sourceasync fn write_logs(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: &WriteLogsRequest,
) -> Result<(), Error>
async fn write_logs( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: &WriteLogsRequest, ) -> Result<(), Error>
Synchronously writes logs to a Nominal data source.