pub struct AsyncNominalChannelWriterServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<O, I: Stream<Item = Result<Bytes, Error>>, __C> AsyncNominalChannelWriterService<O, I> for AsyncNominalChannelWriterServiceClient<__C>where
__C: AsyncClient<BodyWriter = O, ResponseBody = I> + Sync + Send,
__C::ResponseBody: 'static + Send,
impl<O, I: Stream<Item = Result<Bytes, Error>>, __C> AsyncNominalChannelWriterService<O, I> for AsyncNominalChannelWriterServiceClient<__C>where
__C: AsyncClient<BodyWriter = O, ResponseBody = I> + Sync + Send,
__C::ResponseBody: 'static + Send,
Sourceasync fn write_batches(
&self,
auth_: &BearerToken,
request: &WriteBatchesRequestExternal,
) -> Result<(), Error>
async fn write_batches( &self, auth_: &BearerToken, request: &WriteBatchesRequestExternal, ) -> Result<(), Error>
Synchronously writes batches of records to a Nominal data source. Read more
Sourceasync fn write_column_batches(
&self,
auth_: &BearerToken,
request: &WriteColumnBatchesRequest,
) -> Result<(), Error>
async fn write_column_batches( &self, auth_: &BearerToken, request: &WriteColumnBatchesRequest, ) -> Result<(), Error>
Synchronously writes batches of columns of data to a Nominal data source. Read more
Sourceasync fn write_telegraf_batches(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: &WriteTelegrafBatchesRequest,
) -> Result<(), Error>
async fn write_telegraf_batches( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: &WriteTelegrafBatchesRequest, ) -> Result<(), Error>
Synchronously writes batches of records to a Nominal data source. Read more
Sourceasync fn write_prometheus_batches(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: impl AsyncWriteBody<O> + Sync + Send,
) -> Result<(), Error>
async fn write_prometheus_batches( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: impl AsyncWriteBody<O> + Sync + Send, ) -> Result<(), Error>
Synchronously writes batches of records to a Nominal data source. Read more
Sourceasync fn prometheus_remote_write_health_check(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
) -> Result<bool, Error>
async fn prometheus_remote_write_health_check( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, ) -> Result<bool, Error>
Performs a health check for prometheus remote write Vector sink. All this endpoint does
is verify if the caller is authenticated and the server is online. Once Vector allows the Prometheus
remote write endpoint to configure the healthcheck url, we can remove this endpoint. Read more
Sourceasync fn write_nominal_batches(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: impl AsyncWriteBody<O> + Sync + Send,
) -> Result<(), Error>
async fn write_nominal_batches( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: impl AsyncWriteBody<O> + Sync + Send, ) -> Result<(), Error>
Synchronously writes a Nominal Write Request to a Nominal data source using the NominalWrite Protobuf schema.
The request must be Protobuf-encoded and accompanied by the appropriate content encoding headers if compressed. Read more
Sourceasync fn write_nominal_columnar_batches(
&self,
auth_: &BearerToken,
request: impl AsyncWriteBody<O> + Sync + Send,
) -> Result<(), Error>
async fn write_nominal_columnar_batches( &self, auth_: &BearerToken, request: impl AsyncWriteBody<O> + Sync + Send, ) -> Result<(), Error>
Synchronously writes to a Nominal data source using the columnar WriteBatchesRequest Protobuf schema. Read more
Sourceasync fn write_logs(
&self,
auth_: &BearerToken,
data_source_rid: &NominalDataSourceOrDatasetRid,
request: &WriteLogsRequest,
) -> Result<(), Error>
async fn write_logs( &self, auth_: &BearerToken, data_source_rid: &NominalDataSourceOrDatasetRid, request: &WriteLogsRequest, ) -> Result<(), Error>
Synchronously writes logs to a Nominal data source.
Sourceimpl<C> AsyncService<C> for AsyncNominalChannelWriterServiceClient<C>
impl<C> AsyncService<C> for AsyncNominalChannelWriterServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for AsyncNominalChannelWriterServiceClient<C>
impl<C: Clone> Clone for AsyncNominalChannelWriterServiceClient<C>
Sourcefn clone(&self) -> AsyncNominalChannelWriterServiceClient<C>
fn clone(&self) -> AsyncNominalChannelWriterServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl<C> Freeze for AsyncNominalChannelWriterServiceClient<C>where
C: Freeze,
impl<C> !RefUnwindSafe for AsyncNominalChannelWriterServiceClient<C>
impl<C> Send for AsyncNominalChannelWriterServiceClient<C>where
C: Send,
impl<C> Sync for AsyncNominalChannelWriterServiceClient<C>where
C: Sync,
impl<C> Unpin for AsyncNominalChannelWriterServiceClient<C>where
C: Unpin,
impl<C> UnsafeUnpin for AsyncNominalChannelWriterServiceClient<C>where
C: UnsafeUnpin,
impl<C> !UnwindSafe for AsyncNominalChannelWriterServiceClient<C>