pub struct LocalAsyncSeriesCacheServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncSeriesCacheServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncSeriesCacheServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncSeriesCacheServiceClient<C>
impl<C: Clone> Clone for LocalAsyncSeriesCacheServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncSeriesCacheServiceClient<C>
fn clone(&self) -> LocalAsyncSeriesCacheServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncSeriesCacheServiceClient<C>
impl<C: Debug> Debug for LocalAsyncSeriesCacheServiceClient<C>
Sourceimpl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncSeriesCacheService<I> for LocalAsyncSeriesCacheServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
impl<I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncSeriesCacheService<I> for LocalAsyncSeriesCacheServiceClient<__C>where
__C: LocalAsyncClient<ResponseBody = I>,
Sourceasync fn get_chunks(
&self,
auth_: &BearerToken,
logical_series_rid: &LogicalSeriesRid,
get_chunks_parameters: &GetChunksParameters,
) -> Result<GetChunksResponse, Error>
async fn get_chunks( &self, auth_: &BearerToken, logical_series_rid: &LogicalSeriesRid, get_chunks_parameters: &GetChunksParameters, ) -> Result<GetChunksResponse, Error>
Fetches “chunks” of series that are stored as Arrow files in S3.
This endpoint is being deprecated for new series in favor of batchGetCachedSeries
async fn create_chunks( &self, auth_: &BearerToken, logical_series_rid: &LogicalSeriesRid, create_chunks_parameters: &CreateChunksParameters, ) -> Result<CreateChunksResponse, Error>
async fn batch_create_chunks( &self, auth_: &BearerToken, request: &CreateChunksParameters, ) -> Result<CreateChunksResponse, Error>
Sourceasync fn delete_chunks(
&self,
auth_: &BearerToken,
logical_series_rid: &LogicalSeriesRid,
request: &DeleteChunksParameters,
) -> Result<DeleteChunksResponse, Error>
async fn delete_chunks( &self, auth_: &BearerToken, logical_series_rid: &LogicalSeriesRid, request: &DeleteChunksParameters, ) -> Result<DeleteChunksResponse, Error>
Deletes the chunks that intersect the given time range. Does not delete the corresponding files from S3.