InternalUserCreationService

Trait InternalUserCreationService 

pub trait InternalUserCreationService<I: Iterator<Item = Result<Bytes, Error>>> {
    // Required method
    fn ensure_database_user_exists(
        &self,
        auth_: &BearerToken,
    ) -> Result<(), Error>;
}
Internal service responsible for handling creation of new users.

Required Methods

fn ensure_database_user_exists(&self, auth_: &BearerToken) -> Result<(), Error>

Ensures that the user corresponding to the auth header provided exists in the database. Will do nothing if the user already exists.

Implementors

Source

impl<I: Iterator<Item = Result<Bytes, Error>>, __C> InternalUserCreationService<I> for InternalUserCreationServiceClient<__C>
where __C: Client<ResponseBody = I>,