Module attachment_service

Module attachment_service 

Structs

AsyncAttachmentServiceEndpoints
AttachmentServiceEndpoints
LocalAsyncAttachmentServiceEndpoints

Traits

AsyncAttachmentService
The attachment service provides functionality for creating, updating, and archiving attachments uploaded to S3.
AttachmentService
The attachment service provides functionality for creating, updating, and archiving attachments uploaded to S3.
LocalAsyncAttachmentService
The attachment service provides functionality for creating, updating, and archiving attachments uploaded to S3.