Module event_service

Module event_service 

Structs

AsyncEventServiceEndpoints
EventServiceEndpoints
LocalAsyncEventServiceEndpoints

Traits

AsyncEventService
An Event is an annotated moment or time range. The Event Service is responsible for creating and retrieving events for a particular data source.
EventService
An Event is an annotated moment or time range. The Event Service is responsible for creating and retrieving events for a particular data source.
LocalAsyncEventService
An Event is an annotated moment or time range. The Event Service is responsible for creating and retrieving events for a particular data source.