Modules
Structs
- Async
Containerized Extractor Service Endpoints - Async
Ingest JobService Endpoints - Async
Ingest Service Endpoints - Async
Internal Ingest JobService Endpoints - Containerized
Extractor Service Endpoints - Ingest
JobService Endpoints - Ingest
Service Endpoints - Internal
Ingest JobService Endpoints
Traits
- Async
Containerized Extractor Service - The Containerized Extractor service provides functionality for creating, updating, and archiving containerized extractors.
- Async
Ingest JobService - Public API for querying ingest jobs.
- Async
Ingest Service - The Ingest Service handles the data ingestion into Nominal/Clickhouse.
- Async
Internal Ingest JobService - Internal API for managing ingest jobs. This service is filtered out from public documentation.
- Containerized
Extractor Service - The Containerized Extractor service provides functionality for creating, updating, and archiving containerized extractors.
- Ingest
JobService - Public API for querying ingest jobs.
- Ingest
Service - The Ingest Service handles the data ingestion into Nominal/Clickhouse.
- Internal
Ingest JobService - Internal API for managing ingest jobs. This service is filtered out from public documentation.