LocalAsyncPersistentComputeService

Trait LocalAsyncPersistentComputeService 

pub trait LocalAsyncPersistentComputeService {
    // Required method
    fn is_enabled(
        &self,
        auth_: BearerToken,
    ) -> impl Future<Output = Result<IsEnabledResponse, Error>>;
}
Exposes a simple endpoints for checking whether or not persistent compute is enabled.

Required Methods

fn is_enabled( &self, auth_: BearerToken, ) -> impl Future<Output = Result<IsEnabledResponse, Error>>

Simple “ping” like endpoint to see if the service is enabled (and available).

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors