pub trait PersistentComputeService {
// Required method
fn is_enabled(&self, auth_: BearerToken) -> Result<IsEnabledResponse, Error>;
}Expand description
Exposes a simple endpoints for checking whether or not persistent compute is enabled.
Required Methods
Sourcefn is_enabled(&self, auth_: BearerToken) -> Result<IsEnabledResponse, Error>
fn is_enabled(&self, auth_: BearerToken) -> Result<IsEnabledResponse, Error>
Simple “ping” like endpoint to see if the service is enabled (and available).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".