Module catalog

Module catalog 

Modules

catalog_service

Structs

AsyncCatalogServiceEndpoints
CatalogServiceEndpoints

Traits

AsyncCatalogService
The Catalog Service provides the ability to query for information about Datasets that are stored in the Nominal platform. A Dataset is the Nominal representation of data that has been uploaded to Nominal via a file, primarily CSV.
CatalogService
The Catalog Service provides the ability to query for information about Datasets that are stored in the Nominal platform. A Dataset is the Nominal representation of data that has been uploaded to Nominal via a file, primarily CSV.