pub trait AsyncChannelSearchService {
// Required methods
fn get_locator_delimiters(
&self,
auth_: BearerToken,
request: GetLocatorDelimitersRequest,
) -> impl Future<Output = Result<GetLocatorDelimitersResponse, Error>> + Send;
fn list_channel_children(
&self,
auth_: BearerToken,
request: ListChannelChildrenRequest,
) -> impl Future<Output = Result<ListChannelChildrenResponse, Error>> + Send;
fn search_channels(
&self,
auth_: BearerToken,
request: SearchChannelsRequest,
) -> impl Future<Output = Result<SearchChannelsResponse, Error>> + Send;
fn batch_get_locator_delimiters(
&self,
auth_: BearerToken,
request: BatchGetLocatorDelimitersRequest,
) -> impl Future<Output = Result<BatchGetLocatorDelimitersResponse, Error>> + Send;
fn batch_search_channels(
&self,
auth_: BearerToken,
request: BatchSearchChannelsRequest,
) -> impl Future<Output = Result<BatchSearchChannelsResponse, Error>> + Send;
fn batch_list_channel_children(
&self,
auth_: BearerToken,
request: BatchListChannelChildrenRequest,
) -> impl Future<Output = Result<BatchListChannelChildrenResponse, Error>> + Send;
}Expand description
Channel search over a DataFrame, which can expand to multiple locators.
Required Methods
Sourcefn get_locator_delimiters(
&self,
auth_: BearerToken,
request: GetLocatorDelimitersRequest,
) -> impl Future<Output = Result<GetLocatorDelimitersResponse, Error>> + Send
fn get_locator_delimiters( &self, auth_: BearerToken, request: GetLocatorDelimitersRequest, ) -> impl Future<Output = Result<GetLocatorDelimitersResponse, Error>> + Send
Returns the expanded locator topology for a frame plus per-locator delimiter info.
Sourcefn list_channel_children(
&self,
auth_: BearerToken,
request: ListChannelChildrenRequest,
) -> impl Future<Output = Result<ListChannelChildrenResponse, Error>> + Send
fn list_channel_children( &self, auth_: BearerToken, request: ListChannelChildrenRequest, ) -> impl Future<Output = Result<ListChannelChildrenResponse, Error>> + Send
Lazy one-level hierarchical expansion under parent. Returns a mix of leaf
channels and prefix nodes, each labelled with the set of locators where
they exist.
Sourcefn search_channels(
&self,
auth_: BearerToken,
request: SearchChannelsRequest,
) -> impl Future<Output = Result<SearchChannelsResponse, Error>> + Send
fn search_channels( &self, auth_: BearerToken, request: SearchChannelsRequest, ) -> impl Future<Output = Result<SearchChannelsResponse, Error>> + Send
Flat text search across the frame. Returns matching channels, each labelled with the set of locators in which they exist.
Sourcefn batch_get_locator_delimiters(
&self,
auth_: BearerToken,
request: BatchGetLocatorDelimitersRequest,
) -> impl Future<Output = Result<BatchGetLocatorDelimitersResponse, Error>> + Send
fn batch_get_locator_delimiters( &self, auth_: BearerToken, request: BatchGetLocatorDelimitersRequest, ) -> impl Future<Output = Result<BatchGetLocatorDelimitersResponse, Error>> + Send
Batched form of getLocatorDelimiters.
Sourcefn batch_search_channels(
&self,
auth_: BearerToken,
request: BatchSearchChannelsRequest,
) -> impl Future<Output = Result<BatchSearchChannelsResponse, Error>> + Send
fn batch_search_channels( &self, auth_: BearerToken, request: BatchSearchChannelsRequest, ) -> impl Future<Output = Result<BatchSearchChannelsResponse, Error>> + Send
Batched form of searchChannels. The channel search is performed across the
union of all entry scopes and so is the limit and top-n selection by relevance.
Sourcefn batch_list_channel_children(
&self,
auth_: BearerToken,
request: BatchListChannelChildrenRequest,
) -> impl Future<Output = Result<BatchListChannelChildrenResponse, Error>> + Send
fn batch_list_channel_children( &self, auth_: BearerToken, request: BatchListChannelChildrenRequest, ) -> impl Future<Output = Result<BatchListChannelChildrenResponse, Error>> + Send
Batched form of listChannelChildren. The hierarchical expansion is performed
across the union of all entry scopes for the shared parent path.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.