ChannelSearchService

Trait ChannelSearchService 

pub trait ChannelSearchService {
    // Required methods
    fn get_locator_delimiters(
        &self,
        auth_: BearerToken,
        request: GetLocatorDelimitersRequest,
    ) -> Result<GetLocatorDelimitersResponse, Error>;
    fn list_channel_children(
        &self,
        auth_: BearerToken,
        request: ListChannelChildrenRequest,
    ) -> Result<ListChannelChildrenResponse, Error>;
    fn search_channels(
        &self,
        auth_: BearerToken,
        request: SearchChannelsRequest,
    ) -> Result<SearchChannelsResponse, Error>;
    fn batch_get_locator_delimiters(
        &self,
        auth_: BearerToken,
        request: BatchGetLocatorDelimitersRequest,
    ) -> Result<BatchGetLocatorDelimitersResponse, Error>;
    fn batch_search_channels(
        &self,
        auth_: BearerToken,
        request: BatchSearchChannelsRequest,
    ) -> Result<BatchSearchChannelsResponse, Error>;
    fn batch_list_channel_children(
        &self,
        auth_: BearerToken,
        request: BatchListChannelChildrenRequest,
    ) -> Result<BatchListChannelChildrenResponse, Error>;
}
Channel search over a DataFrame, which can expand to multiple locators.

Required Methods

fn get_locator_delimiters( &self, auth_: BearerToken, request: GetLocatorDelimitersRequest, ) -> Result<GetLocatorDelimitersResponse, Error>

Returns the expanded locator topology for a frame plus per-locator delimiter info.

fn list_channel_children( &self, auth_: BearerToken, request: ListChannelChildrenRequest, ) -> Result<ListChannelChildrenResponse, Error>

Lazy one-level hierarchical expansion under parent. Returns a mix of leaf channels and prefix nodes, each labelled with the set of locators where they exist.

fn search_channels( &self, auth_: BearerToken, request: SearchChannelsRequest, ) -> Result<SearchChannelsResponse, Error>

Flat text search across the frame. Returns matching channels, each labelled with the set of locators in which they exist.

fn batch_get_locator_delimiters( &self, auth_: BearerToken, request: BatchGetLocatorDelimitersRequest, ) -> Result<BatchGetLocatorDelimitersResponse, Error>

Batched form of getLocatorDelimiters.

fn batch_search_channels( &self, auth_: BearerToken, request: BatchSearchChannelsRequest, ) -> Result<BatchSearchChannelsResponse, Error>

Batched form of searchChannels. The channel search is performed across the union of all entry scopes and so is the limit and top-n selection by relevance.

fn batch_list_channel_children( &self, auth_: BearerToken, request: BatchListChannelChildrenRequest, ) -> Result<BatchListChannelChildrenResponse, Error>

Batched form of listChannelChildren. The hierarchical expansion is performed across the union of all entry scopes for the shared parent path.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors