LocalAsyncDataReviewService

Trait LocalAsyncDataReviewService 

pub trait LocalAsyncDataReviewService {
Show 21 methods // Required methods fn batch_initiate( &self, auth_: BearerToken, request: BatchInitiateDataReviewRequest, ) -> impl Future<Output = Result<BatchInitiateDataReviewResponse, Error>>; fn rerun_failed_automatic_checks( &self, auth_: BearerToken, request: RerunFailedAutomaticChecksRequest, ) -> impl Future<Output = Result<(), Error>>; fn find_data_reviews( &self, auth_: BearerToken, request: FindDataReviewsRequest, ) -> impl Future<Output = Result<DataReviewPage, Error>>; fn get( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<DataReview, Error>>; fn get_check_alert( &self, auth_: BearerToken, check_alert_rid: CheckAlertRid, ) -> impl Future<Output = Result<CheckAlert, Error>>; fn get_check_alerts_for_data_review( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<BTreeSet<CheckAlert>, Error>>; fn get_check_alerts_histogram( &self, auth_: BearerToken, request: CheckAlertsHistogramRequest, ) -> impl Future<Output = Result<CheckAlertsHistogramResponse, Error>>; fn search_check_alerts( &self, auth_: BearerToken, request: SearchCheckAlertsRequest, ) -> impl Future<Output = Result<SearchCheckAlertsResponse, Error>>; fn get_check_alert_action_log( &self, auth_: BearerToken, check_alert_rid: CheckAlertRid, ) -> impl Future<Output = Result<CheckAlertActionLog, Error>>; fn get_check_alert_counts_for_notebooks( &self, auth_: BearerToken, rids: BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeMap<NotebookRid, i32>, Error>>; fn get_check_alert_status_for_notebooks( &self, auth_: BearerToken, rids: BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeMap<NotebookRid, Option<CheckAlertStatus>>, Error>>; fn perform_check_alert_action( &self, auth_: BearerToken, check_alert_rid: CheckAlertRid, request: CheckAlertAction, ) -> impl Future<Output = Result<CheckAlert, Error>>; fn batch_perform_check_alert_action( &self, auth_: BearerToken, request: BatchCheckAlertActionRequest, ) -> impl Future<Output = Result<BatchCheckAlertActionResponse, Error>>; fn batch_perform_automatic_check_evaluation_review_action( &self, auth_: BearerToken, request: BatchAutomaticCheckEvaluationActionRequest, ) -> impl Future<Output = Result<BatchAutomaticCheckEvaluationActionResponse, Error>>; fn get_automatic_check_evaluation_action_log( &self, auth_: BearerToken, rid: AutomaticCheckEvaluationRid, ) -> impl Future<Output = Result<AutomaticCheckEvaluationActionLog, Error>>; fn batch_perform_manual_check_alert_action( &self, auth_: BearerToken, request: BatchManualCheckEvaluationActionRequest, ) -> impl Future<Output = Result<(), Error>>; fn get_manual_check_evaluation_action_log( &self, auth_: BearerToken, rid: ManualCheckEvaluationRid, ) -> impl Future<Output = Result<ManualCheckEvaluationActionLog, Error>>; fn archive_data_review( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<bool, Error>>; fn batch_archive_data_review( &self, auth_: BearerToken, rids: BTreeSet<DataReviewRid>, ) -> impl Future<Output = Result<(), Error>>; fn unarchive_data_review( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<(), Error>>; fn get_data_review_check_metrics( &self, auth_: BearerToken, request: GetDataReviewCheckMetricsRequest, ) -> impl Future<Output = Result<GetDataReviewCheckMetricsResponse, Error>>;
}
The data review service manages the evaluation, disposition, and historical record of checks alerts.

Required Methods

fn batch_initiate( &self, auth_: BearerToken, request: BatchInitiateDataReviewRequest, ) -> impl Future<Output = Result<BatchInitiateDataReviewResponse, Error>>

For each request, initiates data review for the requested run and checklist and executes the automatic checks against the run.

fn rerun_failed_automatic_checks( &self, auth_: BearerToken, request: RerunFailedAutomaticChecksRequest, ) -> impl Future<Output = Result<(), Error>>

Re-executes the most recent failed automatic checks for the data review.

fn find_data_reviews( &self, auth_: BearerToken, request: FindDataReviewsRequest, ) -> impl Future<Output = Result<DataReviewPage, Error>>

Returns the data reviews under the provided search parameters.

fn get( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<DataReview, Error>>

Throws if not found.

fn get_check_alert( &self, auth_: BearerToken, check_alert_rid: CheckAlertRid, ) -> impl Future<Output = Result<CheckAlert, Error>>

Throws if not found.

fn get_check_alerts_for_data_review( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<BTreeSet<CheckAlert>, Error>>

Gets all check alerts from the provided data review.

fn get_check_alerts_histogram( &self, auth_: BearerToken, request: CheckAlertsHistogramRequest, ) -> impl Future<Output = Result<CheckAlertsHistogramResponse, Error>>

Returns a histogram of alerts that occur across the provided runs or assets. At least one run or asset must be specified.

fn search_check_alerts( &self, auth_: BearerToken, request: SearchCheckAlertsRequest, ) -> impl Future<Output = Result<SearchCheckAlertsResponse, Error>>

Returns the check alerts under the provided search parameters. At least one run or asset must be specified.

fn get_check_alert_action_log( &self, auth_: BearerToken, check_alert_rid: CheckAlertRid, ) -> impl Future<Output = Result<CheckAlertActionLog, Error>>

Returns a record of the historical actions taken on the provided check alert.

fn get_check_alert_counts_for_notebooks( &self, auth_: BearerToken, rids: BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeMap<NotebookRid, i32>, Error>>

Returns the number of alerts attached to each provided notebook.

fn get_check_alert_status_for_notebooks( &self, auth_: BearerToken, rids: BTreeSet<NotebookRid>, ) -> impl Future<Output = Result<BTreeMap<NotebookRid, Option<CheckAlertStatus>>, Error>>

Returns the check alert status of any linked violations for the provided notebooks. If none exist, an empty optional is returned.

fn perform_check_alert_action( &self, auth_: BearerToken, check_alert_rid: CheckAlertRid, request: CheckAlertAction, ) -> impl Future<Output = Result<CheckAlert, Error>>

Applies a check alert action to the specified check alert RID.

fn batch_perform_check_alert_action( &self, auth_: BearerToken, request: BatchCheckAlertActionRequest, ) -> impl Future<Output = Result<BatchCheckAlertActionResponse, Error>>

Applies a check alert action to the specified check alert RIDs. If any of the check actions fail, then none of the check actions will be applied.

fn batch_perform_automatic_check_evaluation_review_action( &self, auth_: BearerToken, request: BatchAutomaticCheckEvaluationActionRequest, ) -> impl Future<Output = Result<BatchAutomaticCheckEvaluationActionResponse, Error>>

Applies an action to the specified check evaluation RIDs. If any of the check actions fail, then none of the actions will be applied.

fn get_automatic_check_evaluation_action_log( &self, auth_: BearerToken, rid: AutomaticCheckEvaluationRid, ) -> impl Future<Output = Result<AutomaticCheckEvaluationActionLog, Error>>

fn batch_perform_manual_check_alert_action( &self, auth_: BearerToken, request: BatchManualCheckEvaluationActionRequest, ) -> impl Future<Output = Result<(), Error>>

Applies an action to the specified check evaluation RIDs. If any of the check actions fail, then none of the actions will be applied.

fn get_manual_check_evaluation_action_log( &self, auth_: BearerToken, rid: ManualCheckEvaluationRid, ) -> impl Future<Output = Result<ManualCheckEvaluationActionLog, Error>>

Returns a record of the historical manual actions taken on the provided check evaluation.

fn archive_data_review( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<bool, Error>>

Archives the data review with the given rid.

fn batch_archive_data_review( &self, auth_: BearerToken, rids: BTreeSet<DataReviewRid>, ) -> impl Future<Output = Result<(), Error>>

Batch archives the data reviews with the given rids.

fn unarchive_data_review( &self, auth_: BearerToken, data_review_rid: DataReviewRid, ) -> impl Future<Output = Result<(), Error>>

Unarchives the data review with the given rid.

fn get_data_review_check_metrics( &self, auth_: BearerToken, request: GetDataReviewCheckMetricsRequest, ) -> impl Future<Output = Result<GetDataReviewCheckMetricsResponse, Error>>

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors