Module api

Module api 

Modules

sandbox_workspace_service

Structs

AsyncSandboxWorkspaceServiceEndpoints
SandboxWorkspaceServiceEndpoints

Traits

AsyncSandboxWorkspaceService
Service for managing demo workbooks in sandbox workspaces. All endpoints validate that the provided workspace has the human-readable ID “sandbox”.
SandboxWorkspaceService
Service for managing demo workbooks in sandbox workspaces. All endpoints validate that the provided workspace has the human-readable ID “sandbox”.