Module video

Module video 

Modules

video_file_service
video_segment_service
video_service

Structs

AsyncVideoFileServiceEndpoints
AsyncVideoSegmentServiceEndpoints
AsyncVideoServiceEndpoints
VideoFileServiceEndpoints
VideoSegmentServiceEndpoints
VideoServiceEndpoints

Traits

AsyncVideoFileService
The video service manages individual video files and their metadata.
AsyncVideoSegmentService
Upon ingestion, every video is split into smaller segments. The Video Segment Service manages operations on videos at the segment-level.
AsyncVideoService
The video service manages videos and video metadata.
VideoFileService
The video service manages individual video files and their metadata.
VideoSegmentService
Upon ingestion, every video is split into smaller segments. The Video Segment Service manages operations on videos at the segment-level.
VideoService
The video service manages videos and video metadata.