LocalAsyncDataDeletionService

Trait LocalAsyncDataDeletionService 

pub trait LocalAsyncDataDeletionService {
    // Required method
    fn delete(
        &self,
        auth_: BearerToken,
        request: DeleteDataRequest,
    ) -> impl Future<Output = Result<(), Error>>;
}

Required Methods

fn delete( &self, auth_: BearerToken, request: DeleteDataRequest, ) -> impl Future<Output = Result<(), Error>>

Deletes stored data. This is an irreversible operation so be careful about specified time range, channel names, and tag scope. requires the user to be an admin for the organization.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors