pub trait ChannelMetadataService {
// Required methods
fn get_channel_metadata(
&self,
auth_: BearerToken,
request: GetChannelMetadataRequest,
) -> Result<ChannelMetadata, Error>;
fn batch_get_channel_metadata(
&self,
auth_: BearerToken,
request: BatchGetChannelMetadataRequest,
) -> Result<BatchGetChannelMetadataResponse, Error>;
fn update_channel_metadata(
&self,
auth_: BearerToken,
request: UpdateChannelMetadataRequest,
) -> Result<ChannelMetadata, Error>;
fn batch_update_channel_metadata(
&self,
auth_: BearerToken,
request: BatchUpdateChannelMetadataRequest,
) -> Result<BatchUpdateChannelMetadataResponse, Error>;
}Expand description
Endpoints for retrieving and updating channel metadata.
Required Methods
Sourcefn get_channel_metadata(
&self,
auth_: BearerToken,
request: GetChannelMetadataRequest,
) -> Result<ChannelMetadata, Error>
fn get_channel_metadata( &self, auth_: BearerToken, request: GetChannelMetadataRequest, ) -> Result<ChannelMetadata, Error>
Get the metadata for a channel.
Sourcefn batch_get_channel_metadata(
&self,
auth_: BearerToken,
request: BatchGetChannelMetadataRequest,
) -> Result<BatchGetChannelMetadataResponse, Error>
fn batch_get_channel_metadata( &self, auth_: BearerToken, request: BatchGetChannelMetadataRequest, ) -> Result<BatchGetChannelMetadataResponse, Error>
Batch get the metadata for multiple channels. If some channels cannot be found or authorized, they will be omitted from the response.
Sourcefn update_channel_metadata(
&self,
auth_: BearerToken,
request: UpdateChannelMetadataRequest,
) -> Result<ChannelMetadata, Error>
fn update_channel_metadata( &self, auth_: BearerToken, request: UpdateChannelMetadataRequest, ) -> Result<ChannelMetadata, Error>
Update the metadata for a channel.
Sourcefn batch_update_channel_metadata(
&self,
auth_: BearerToken,
request: BatchUpdateChannelMetadataRequest,
) -> Result<BatchUpdateChannelMetadataResponse, Error>
fn batch_update_channel_metadata( &self, auth_: BearerToken, request: BatchUpdateChannelMetadataRequest, ) -> Result<BatchUpdateChannelMetadataResponse, Error>
Batch update the metadata for multiple channels. If some channels cannot be found or authorized, no metadata will be updated for any of the channels in the request.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".