InternalUserCreationService

Trait InternalUserCreationService 

pub trait InternalUserCreationService {
    // Required method
    fn ensure_database_user_exists(
        &self,
        auth_: BearerToken,
    ) -> Result<(), Error>;
}
Internal service responsible for handling creation of new users.

Required Methods

fn ensure_database_user_exists(&self, auth_: BearerToken) -> Result<(), Error>

Ensures that the user corresponding to the auth header provided exists in the database. Will do nothing if the user already exists.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors