Module api

Module api 

Modules

batch_granularity_mismatch
containerized_extractor_container_failed
containerized_extractor_not_found
containerized_extractors_not_found
dataset_file_not_found
dataset_not_found
empty_multipart_upload
failed_to_download_file
failed_to_download_file_user_error
frame_count_timestamps_mismatch
incompatible_connection_type_and_log_query
incompatible_file_for_dataset
incompatible_inputs
incorrect_size_bytes
ingest_job_not_compatible_for_rerun
ingest_job_not_found
invalid_bucket
invalid_container_image
invalid_custom_timestamp_format
invalid_default_tag
invalid_output_file_format
invalid_s3_path
invalid_url
missing_metadata_for_reingest
null_key
parallel_reingest_into_dataset_v1
recursive_reingest
reingest_too_many_files
run_bounds_inverted
s3_path_not_found
streaming_session_not_found
unsupported_ingest_source
unsupported_request_type_for_re_ingest

Structs

BatchGranularityMismatch
All dataset granularities must match.
ContainerizedExtractorContainerFailed
ContainerizedExtractorNotFound
ContainerizedExtractorsNotFound
DatasetFileNotFound
The target dataset file could not be found.
DatasetNotFound
The target dataset could not be found.
EmptyMultipartUpload
FailedToDownloadFile
FailedToDownloadFileUserError
FrameCountTimestampsMismatch
IncompatibleConnectionTypeAndLogQuery
IncompatibleFileForDataset
IncompatibleInputs
The inputs provided to the ingest job are incompatible with each other
IncorrectSizeBytes
IngestJobNotCompatibleForRerun
The ingest job exists but is not compatible to be re-run.
IngestJobNotFound
InvalidBucket
InvalidContainerImage
InvalidCustomTimestampFormat
InvalidDefaultTag
InvalidOutputFileFormat
InvalidS3Path
InvalidUrl
MissingMetadataForReingest
The timestamp metadata required to reingest the dataset is missing and must be provided in the request.
NullKey
ParallelReingestIntoDatasetV1
Cannot ingest multiple datasets in parallel into older datasets. It is recommended to reingest all source datasets and the target dataset into a new dataset destination.
RecursiveReingest
The target dataset is included in the source datasets.
ReingestTooManyFiles
The number of files to reingest is too large.
RunBoundsInverted
S3PathNotFound
StreamingSessionNotFound
The streaming session could not be found.
UnsupportedIngestSource
UnsupportedRequestTypeForReIngest