pub struct ContainerizedExtractorTimestampMetadataMissing { /* private fields */ }Expand description
Neither the containerized extractor (or its active container image) nor the ingest request provides timestamp metadata, so the extractor output cannot be indexed. Register the image with default timestamp metadata or supply it on the request.
Implementations
Sourceimpl ContainerizedExtractorTimestampMetadataMissing
impl ContainerizedExtractorTimestampMetadataMissing
Sourcepub fn builder() -> Builder<ExtractorRidStage>
pub fn builder() -> Builder<ExtractorRidStage>
Returns a new builder.
Sourceimpl ContainerizedExtractorTimestampMetadataMissing
impl ContainerizedExtractorTimestampMetadataMissing
Sourcepub fn new(
extractor_rid: ContainerizedExtractorRid,
) -> ContainerizedExtractorTimestampMetadataMissing
pub fn new( extractor_rid: ContainerizedExtractorRid, ) -> ContainerizedExtractorTimestampMetadataMissing
Constructs a new instance of the type.
pub fn extractor_rid(&self) -> &ContainerizedExtractorRid