pub struct IngestJobMissingDatasetForIdempotencyKey { /* private fields */ }Expand description
A prior ingest job already exists for this idempotency key but never produced a dataset (the original submit did not get far enough). The idempotency key deduplicates to that existing job and does not re-run ingestion; rerun the job identified by ingestJobRid to complete it.
Implementations
Sourceimpl IngestJobMissingDatasetForIdempotencyKey
impl IngestJobMissingDatasetForIdempotencyKey
Sourcepub fn builder() -> Builder<IngestJobRidStage>
pub fn builder() -> Builder<IngestJobRidStage>
Returns a new builder.
Sourceimpl IngestJobMissingDatasetForIdempotencyKey
impl IngestJobMissingDatasetForIdempotencyKey
Sourcepub fn new(
ingest_job_rid: IngestJobRid,
) -> IngestJobMissingDatasetForIdempotencyKey
pub fn new( ingest_job_rid: IngestJobRid, ) -> IngestJobMissingDatasetForIdempotencyKey
Constructs a new instance of the type.
pub fn ingest_job_rid(&self) -> &IngestJobRid