pub struct MissingMetadataForReingest { /* private fields */ }Expand description
The timestamp metadata required to reingest the dataset is missing and must be provided in the request.
Implementations
Sourceimpl MissingMetadataForReingest
impl MissingMetadataForReingest
Sourcepub fn new() -> MissingMetadataForReingest
pub fn new() -> MissingMetadataForReingest
Constructs a new instance of the type.
pub fn dataset_rids(&self) -> &BTreeSet<ResourceIdentifier>