pub struct ParallelReingestIntoDatasetV1 {}Expand description
Cannot ingest multiple datasets in parallel into older datasets. It is recommended to reingest all source datasets and the target dataset into a new dataset destination.
Implementations
Sourceimpl ParallelReingestIntoDatasetV1
impl ParallelReingestIntoDatasetV1
Sourcepub fn new() -> ParallelReingestIntoDatasetV1
pub fn new() -> ParallelReingestIntoDatasetV1
Constructs a new instance of the type.