Module upload_bucket_not_allowed

Module upload_bucket_not_allowed 

Structs

BucketStage
The bucket stage for Builder.
Builder
A builder for UploadBucketNotAllowed
Complete
The final stage for UploadBucketNotAllowed.
UploadBucketNotAllowed
A multipart-upload follow-up call specified a bucket this service does not recognize. It must be the value returned as bucket by initiateMultipartUpload, unchanged.