pub struct WorkspaceResourceMismatch { /* private fields */ }Expand description
Both workspace and resource were set on the upload request, but the workspace
derived from the resource does not match the explicitly-supplied workspace. Returned
as a defensive sanity check so callers don’t accidentally believe they’re uploading
to one workspace while the file is actually being routed to another.
Implementations
Sourceimpl WorkspaceResourceMismatch
impl WorkspaceResourceMismatch
Sourcepub fn builder() -> Builder<ResourceRidStage>
pub fn builder() -> Builder<ResourceRidStage>
Returns a new builder.
Sourceimpl WorkspaceResourceMismatch
impl WorkspaceResourceMismatch
Sourcepub fn new(
resource_rid: ResourceIdentifier,
requested_workspace: WorkspaceRid,
resolved_workspace: WorkspaceRid,
) -> Self
pub fn new( resource_rid: ResourceIdentifier, requested_workspace: WorkspaceRid, resolved_workspace: WorkspaceRid, ) -> Self
Constructs a new instance of the type.
pub fn resource_rid(&self) -> &ResourceIdentifier
pub fn requested_workspace(&self) -> &WorkspaceRid
pub fn resolved_workspace(&self) -> &WorkspaceRid