Module module

Module module 

Modules

cyclic_module_function_definitions
function_name_conflict
invalid_function_names
invalid_module_api_name
invalid_module_version_string
invalid_nested_function_references
invalid_parameter_names
module_name_conflict
module_rids_not_found
modules_not_found
parameter_name_conflict
undefined_module_function_reference
variable_name_conflict

Structs

CyclicModuleFunctionDefinitions
One or more functions contain cyclic references to each other.
FunctionNameConflict
One or more function names conflict with each other in the module definition.
InvalidFunctionNames
One or more function names are invalid. Function names must begin with a letter and can only contain letters, numbers, and underscores.
InvalidModuleApiName
The provided module API name is invalid. Module names must begin with a letter and can only contain letters, numbers, and underscores.
InvalidModuleVersionString
The provided module version string is invalid. Module version strings must be of the form “MAJOR”, where MAJOR is a non-negative integer.
InvalidNestedFunctionReferences
One or more functions contain invalid nested function references. Functions cannot reference other functions that are not defined in the same module.
InvalidParameterNames
One or more parameter names are invalid. Parameter names must begin with a letter and can only contain letters, numbers, and underscores.
ModuleNameConflict
A module with the given API name already exists in the current organization.
ModuleRidsNotFound
One or more modules were not found in the current workspace.
ModulesNotFound
One or more modules were not found in the current workspace.
ParameterNameConflict
One or more parameter names conflict with each other in the module definition.
UndefinedModuleFunctionReference
The following function reference is undefined in the module.
VariableNameConflict
One or more variable names conflict with each other in the module definition.