Module job_invalid_state

Module job_invalid_state 

Structs

Builder
A builder for JobInvalidState
Complete
The final stage for JobInvalidState.
JobInvalidState
The streaming compute job entered a terminal state unexpectedly. This can indicate a transient issue with the compute engine.