pub struct JobInvalidState {}Expand description
The streaming compute job entered a terminal state unexpectedly. This can indicate a transient issue with the compute engine.
Implementations
Sourceimpl JobInvalidState
impl JobInvalidState
Sourcepub fn new() -> JobInvalidState
pub fn new() -> JobInvalidState
Constructs a new instance of the type.