Module api

Module api 

Modules

asset_not_found
assets_not_found
duplicate_data_scope_names
type_already_exists
type_check_failed
type_not_found
type_referenced_by_assets

Structs

AssetNotFound
AssetsNotFound
DuplicateDataScopeNames
Multiple data scopes within the same asset share the same refname
TypeAlreadyExists
TypeCheckFailed
The type check failed for the following properties.
TypeNotFound
TypeReferencedByAssets
The type is referenced by one or more assets and cannot be deleted.