Module catalog

Module catalog 

Modules

cannot_add_file_to_derived_dataset
cannot_add_to_legacy_dataset
cannot_create_nested_derived_dataset
cannot_create_unsupported_derived_dataset
cannot_update_non_derived_dataset
channel_not_found
conflict_on_dataset_creation
conflict_on_dataset_file_create_or_update
conflict_on_series_creation
dataset_exists_in_other_workspace
dataset_file_not_found
dataset_not_found
datasets_not_found
derived_datasets_not_enabled
granularity_mismatch
iceberg_not_supported
invalid_state_for_adding_additional_file
run_not_found
video_file_not_found

Structs

CannotAddFileToDerivedDataset
Derived datasets are backed by other datasets and do not support file ingest.
CannotAddToLegacyDataset
The current dataset is legacy and does not support multiple files. Please re-ingest this dataset.
CannotCreateNestedDerivedDataset
Derived datasets cannot currently be backed by other derived datasets.
CannotCreateUnsupportedDerivedDataset
Derived datasets can currently only be backed by ordinary datasets.
CannotUpdateNonDerivedDataset
Dataset derived definitions can only be updated for datasets that are already derived.
ChannelNotFound
ConflictOnDatasetCreation
ConflictOnDatasetFileCreateOrUpdate
Dataset files must have globally unique S3 paths on creation. On update, the ingested_at timestamp must be unique.
ConflictOnSeriesCreation
DatasetExistsInOtherWorkspace
The dataset with the requested path already exists in another workspace.
DatasetFileNotFound
DatasetNotFound
DatasetsNotFound
DerivedDatasetsNotEnabled
Derived dataset creation is not enabled for this environment.
GranularityMismatch
Different time units are not allowed for the same dataset. Must be all nanoseconds.
IcebergNotSupported
Iceberg support currently not enabled for new datasets for this environment.
InvalidStateForAddingAdditionalFile
The current dataset is not in a valid state for uploading an additional file - it is either failed or still ingesting the previous file.
RunNotFound
VideoFileNotFound