Skip to main content Module api Copy item path Source cannot_aggregate_enum_plot cannot_compile_regexp channel_has_wrong_type concurrent_queries_exceeded converter_input_unit_not_found converter_output_unit_not_found curve_invalid_negative_inputs curve_unequal_input_length derived_series_has_wrong_type duplicate_timestamp empty_input empty_path empty_set exponential_curve_input_too_large external_database_bad_gateway external_database_gateway_timeout external_database_socket_timeout frequency_domain_not_enough_data frequency_domain_window_empty frequency_domain_window_too_large granularity_mismatch group_by_missing_tag group_by_tags_not_subset group_bys_not_supported_for_query invalid_bit_operation invalid_expression invalid_field_name invalid_literal_range invalid_numeric_aggregations invalid_numeric_output_fields invalid_plot_type invalid_range_node_start_after_view_range invalid_refprop_input_count invalid_series_locator invalid_tag_filter_configuration invalid_time_unit invalid_value_map max_query_size_exceeded memory_limit_exceeded misaligned_scatter_points missing_function_parameter missing_module_application missing_module_function missing_module_variable missing_variable non_positive_duration non_positive_resample_interval not_authorized not_enough_points_for_curve overlapping_literal_ranges picos_range_too_large query_range_too_large refprop_input_too_large refprop_output_property_is_input requested_rows_limit_exceeded resample_default_value_type_mismatches_series_type resolution_interval_too_small_for_range row_limit_exceeded signal_filter_invalid_cutoff_band signal_filter_invalid_cutoff_frequency signal_filter_invalid_order signal_filter_non_positive_cutoff_frequency signal_filter_not_enough_data timeout_exceeded too_few_inputs too_many_buckets too_many_categories too_many_events too_many_literals too_many_points too_many_ranges too_many_resample_points too_many_subrequests unexpected_timeout unit_conversion_invalid unsupported_refprop_property variable_has_wrong_type CannotAggregateEnumPlot CannotCompileRegexp The regular expression could not be compiled. ChannelHasWrongType ConcurrentQueriesExceeded There are too many concurrent queries running. ConverterInputUnitNotFound A unit could not be found for the input series, or it did not exist in the unit system. The conversion could
not be computed. ConverterOutputUnitNotFound The output unit symbol could not be found in the unit system. The conversion could not be computed. CurveInvalidNegativeInputs Some points in the input had negative (or zero) x-values. Power and logarithmic curve fits
do not allow negative (or zero) x-valued points. CurveUnequalInputLength The x and y inputs to fit a curve to do not have the same length. DerivedSeriesHasWrongType DuplicateTimestamp EmptyInput At least one input must be provided. EmptyPath Specified path cannot be empty. EmptySet The provided set must contain at least one element. ExponentialCurveInputTooLarge Due to limits in how numbers are represented by computers, exponential fits cannot be performed
on data with x-values that are too large (> 650). This includes timestamp data based on the Time Unit
parameter to the curve fit - e.g. 1 second at millisecond scale is too large, as it is 1000 milliseconds. ExternalDatabaseBadGateway A bad gateway result was encountered while trying to fetch data from the external database. ExternalDatabaseGatewayTimeout A gateway timeout was encountered while trying to fetch data from the external database. ExternalDatabaseSocketTimeout A socket timeout was encountered while trying to fetch data from the external database. FrequencyDomainNotEnoughData Not enough data points to estimate a sampling frequency for frequency-domain analysis.
Try again with a larger time range. FrequencyDomainWindowEmpty The selected window for the frequency domain is empty. Try again with a larger time range. FrequencyDomainWindowTooLarge The selected window for the frequency domain is too large. Try again with a smaller time range. GranularityMismatch Some operations that require matching granularity did not have matching granularity. GroupByMissingTag Attempted to group by a tag that does not exist. GroupByTagsNotSubset Group by tags must be equal, or one set must be a subset of the other. GroupBysNotSupportedForQuery Group by queries are not supported for the compute node supplied InvalidBitOperation The bit operation is invalid due to the index or operand being out of range. Valid range - [0, 63]. InvalidExpression InvalidFieldName Struct field names cannot contain ‘.’ InvalidLiteralRange The starting timestamp of a range cannot be greater than or equal to the end timestamp.
At least one of start and end timestamps must be present.
Only the first range when sorted may omit the start, and only the last may omit the end. InvalidNumericAggregations Numeric aggregations can only be specified on numeric series requests. InvalidNumericOutputFields Numeric output fields can only be specified on Arrow format numeric series requests.
At least one field must be specified. InvalidPlotType InvalidRangeNodeStartAfterViewRange The compute node was given a starting timestamp after the end of the view range window. InvalidRefpropInputCount REFPROP requires exactly two input series. InvalidSeriesLocator InvalidTagFilterConfiguration Invalid tag filter configuration was provided. InvalidTimeUnit The time unit associated with the series is incompatible with the current transform. InvalidValueMap Range end must be greater than range start. Range start may only be undefined if in the first range, or the prior end is defined and less.
Range end may only be undefined if in the last range, or the next start is defined and greater. Ranges must be in increasing order. MaxQuerySizeExceeded The maximum query size was exceeded. MemoryLimitExceeded The query exceeded the memory limit. Try querying a smaller time range or fewer series. MisalignedScatterPoints No scatter points could be aligned for plotting. This typically means the input series
do not have overlapping timestamps within the configured interpolation window. MissingFunctionParameter The requested module function could not be executed because a required parameter was not provided. MissingModuleApplication The requested module application could not be found.
This may be because the reference is incorrect or the application is unavailable in the current execution context. MissingModuleFunction The requested module function could not be found.
This may be because the reference is incorrect or the function is unavailable in the current execution context. MissingModuleVariable MissingVariable NonPositiveDuration Duration must be strictly positive. NonPositiveResampleInterval The resample interval must be strictly positive. NotAuthorized NotEnoughPointsForCurve There were not enough points to fit the curve requested. OverlappingLiteralRanges Ranges cannot overlap. Only the first range when sorted may omit the start,
and only the last may omit the end. PicosRangeTooLarge Time range is too large to fit in 64 bits for picosecond granularity data.
Try again with a smaller time range. QueryRangeTooLarge The requested time range is too large. Try again with a smaller time range. RefpropInputTooLarge The number of points in the REFPROP inputs is too large. RefpropOutputPropertyIsInput The output property cannot be one of the input properties for REFPROP. RequestedRowsLimitExceeded The maximum number of points that can be returned is 10,000. ResampleDefaultValueTypeMismatchesSeriesType The default value provided for resampling does not match the type of the series being resampled. ResolutionIntervalTooSmallForRange RowLimitExceeded The query exceeded that limit for number of rows returned. For the query to complete,
either zoom in or downsample. SignalFilterInvalidCutoffBand Lower band cutoff frequency must be less than or equal to upper band cutoff frequency. SignalFilterInvalidCutoffFrequency Cutoff frequency must be less than half the sampling frequency. SignalFilterInvalidOrder Order must be positive even numbers for bidirectional filters.
Bidirectional filters are applied once forwards and once backwards, effectively doubling order.
Doubled again for bandpass/bandstop filters, requiring a multiple of 4 for filter order. SignalFilterNonPositiveCutoffFrequency Cutoff frequency must be strictly positive. SignalFilterNotEnoughData Not enough data to apply the filter. Required data scales with filter order.
Try again with a larger time range. TimeoutExceeded The query timed out. Try querying a smaller time range or fewer series. TooFewInputs The operation requires more input series than were provided. TooManyBuckets The number of buckets returned is greater than the max allowed (1000). Try again by specifying a larger bucket width or
fewer bucket counts. TooManyCategories An enum series has more categories than the max allowed. TooManyEvents Number of events is greater than the max allowed (1000). TooManyLiterals Too many literals provided in a literal node. TooManyPoints The number of points returned is greater than the max allowed. Try again with a smaller time
range, or a larger resolution. TooManyRanges Ranges is greater than the max allowed (2000). TooManyResamplePoints The resample interval is too short and would produce more than the max points (10,000,000). Try again by specifying a larger interval. TooManySubrequests Number of parameterized subrequests is greater than the max allowed (300). UnexpectedTimeout An unexpected timeout occurred when executing a query. This indicates an internal error
where the query may have succeeded but the response did not reach the client. UnitConversionInvalid The unit conversion could not be computed because the input unit cannot be converted
to the output unit. UnsupportedRefpropProperty The specified REFPROP property is not supported or not available in the current configuration. VariableHasWrongType