pub struct MissingModuleApplication { /* private fields */ }Expand description
The requested module application could not be found. This may be because the reference is incorrect or the application is unavailable in the current execution context.
Implementations
Sourceimpl MissingModuleApplication
impl MissingModuleApplication
Sourcepub fn builder() -> Builder<ModuleApplicationRidStage>
pub fn builder() -> Builder<ModuleApplicationRidStage>
Returns a new builder.
Sourceimpl MissingModuleApplication
impl MissingModuleApplication
Sourcepub fn new(
module_application_rid: ModuleApplicationRid,
) -> MissingModuleApplication
pub fn new( module_application_rid: ModuleApplicationRid, ) -> MissingModuleApplication
Constructs a new instance of the type.
pub fn module_application_rid(&self) -> &ModuleApplicationRid