pub struct MissingModuleFunction { /* private fields */ }Expand description
The requested module function could not be found. This may be because the reference is incorrect or the function is unavailable in the current execution context.
Implementations
Sourceimpl MissingModuleFunction
impl MissingModuleFunction
Sourcepub fn builder() -> Builder<ModuleNameStage>
pub fn builder() -> Builder<ModuleNameStage>
Returns a new builder.
Sourceimpl MissingModuleFunction
impl MissingModuleFunction
Sourcepub fn new(
module_name: impl Into<String>,
module_version: impl Into<String>,
function_name: impl Into<String>,
) -> MissingModuleFunction
pub fn new( module_name: impl Into<String>, module_version: impl Into<String>, function_name: impl Into<String>, ) -> MissingModuleFunction
Constructs a new instance of the type.
pub fn module_name(&self) -> &str
pub fn module_version(&self) -> &str
pub fn function_name(&self) -> &str