Module series_storage_unavailable

Module series_storage_unavailable 

Structs

Builder
A builder for SeriesStorageUnavailable
Complete
The final stage for SeriesStorageUnavailable.
DataSourceRidStage
The data_source_rid stage for Builder.
RequestedStorageStage
The requested_storage stage for Builder.
SeriesStorageUnavailable
A series asked to be read from a storage engine that does not back its data source. Only a dataset written to both engines can be read from either one; omit storage to read the engine that does back it.