pub struct OverlappingLiteralRanges {}Expand description
Ranges cannot overlap. Only the first range when sorted may omit the start, and only the last may omit the end.
Implementations
Sourceimpl OverlappingLiteralRanges
impl OverlappingLiteralRanges
Sourcepub fn new() -> OverlappingLiteralRanges
pub fn new() -> OverlappingLiteralRanges
Constructs a new instance of the type.