pub struct TooManyBuckets {}Expand description
The number of buckets returned is greater than the max allowed (1000). Try again by specifying a larger bucket width or fewer bucket counts.
Implementations
Sourceimpl TooManyBuckets
impl TooManyBuckets
Sourcepub fn new() -> TooManyBuckets
pub fn new() -> TooManyBuckets
Constructs a new instance of the type.