pub struct UdfExecutionLimitExceeded { /* private fields */ }Expand description
A user-defined function exceeded its per-query execution limit while processing this query. Try querying a smaller time range, increasing the aggregation bucket size to reduce the number of UDF invocations, or simplifying the function’s per-row logic.
Implementations
Sourceimpl UdfExecutionLimitExceeded
impl UdfExecutionLimitExceeded
Sourcepub fn builder() -> Builder<QueryIdStage>
pub fn builder() -> Builder<QueryIdStage>
Returns a new builder.