Module api

Module api 

Modules

array_values_unsupported
arrow_requires_single_channel
channels_not_exportable
export_bucket_not_configured
export_data_too_big

Structs

ArrayValuesUnsupported
Array-valued channels cannot be exported in this format.
ArrowRequiresSingleChannel
Arrow export supports exactly one requested channel.
ChannelsNotExportable
One or more requested export columns could not be exported.
ExportBucketNotConfigured
The export bucket is not configured for this environment. Data export via presigned link is not available.
ExportDataTooBig