Module segment_conflict_v2

Module segment_conflict_v2 

Structs

Builder
A builder for SegmentConflictV2
Complete
The final stage for SegmentConflictV2.
Segment1BoundsStage
The segment1_bounds stage for Builder.
Segment2BoundsStage
The segment2_bounds stage for Builder.
SegmentConflictV2
Video segments have overlapping timestamps for a given channel. This occurs when multiple videos are tagged with the same channel variable tags. To resolve, apply different tags to each video or use the channel’s tag filter to select a specific video.
SeriesUuidStage
The series_uuid stage for Builder.