pub struct SegmentConflictV2 { /* private fields */ }Expand description
Video segments have overlapping timestamps for a given channel. This occurs when multiple videos are tagged with the same channel variable tags. To resolve, apply different tags to each video or use the channel’s tag filter to select a specific video.
Implementations
Sourceimpl SegmentConflictV2
impl SegmentConflictV2
Sourcepub fn builder() -> Builder<SeriesUuidStage>
pub fn builder() -> Builder<SeriesUuidStage>
Returns a new builder.
Sourceimpl SegmentConflictV2
impl SegmentConflictV2
Sourcepub fn new(
series_uuid: Uuid,
segment1_bounds: Bounds,
segment2_bounds: Bounds,
) -> SegmentConflictV2
pub fn new( series_uuid: Uuid, segment1_bounds: Bounds, segment2_bounds: Bounds, ) -> SegmentConflictV2
Constructs a new instance of the type.
pub fn series_uuid(&self) -> Uuid
pub fn segment1_bounds(&self) -> &Bounds
pub fn segment2_bounds(&self) -> &Bounds