Modules
- array_
too_ large - conflicting_
data_ types - invalid_
channel_ name - invalid_
data_ source - invalid_
struct - invalid_
telegraf_ timestamp - invalid_
timestamp - mismatched_
timestamps_ and_ values - points_
too_ large - streaming_
disabled_ on_ dataset
Structs
- Array
TooLarge - Array size exceeds maximum allowed length.
- Conflicting
Data Types - Found two different data types for the same series in the request.
- Invalid
Channel Name - The channel name is invalid.
- Invalid
Data Source - The nominal data source or dataset provided is invalid.
- Invalid
Struct - Ingested Struct is not a valid JSON struct
- Invalid
Telegraf Timestamp - Invalid
Timestamp - Mismatched
Timestamps AndValues - Columnar streaming request contains different numbers of timestamps and values
- Points
TooLarge - The size of the points being written exceeds the maximum allowed size.
- Streaming
Disabled OnDataset - Unsupported dataset for streaming.