pub struct DuplicateResolvedChannelName { /* private fields */ }Expand description
Multiple ingested columns resolve to the same channel name after applying channelPrefix and channelNameOverrides. Resolved channel names must be unique within a single ingest.
Implementations
Sourceimpl DuplicateResolvedChannelName
impl DuplicateResolvedChannelName
Sourcepub fn builder() -> Builder<ChannelStage>
pub fn builder() -> Builder<ChannelStage>
Returns a new builder.