Modules
- archived_
status - channel
- column_
name - data_
source_ ref_ name - data_
source_ type - deleted
- deletion_
in_ progress - empty
- error_
result - error_
type - granularity
- handle
- ids
- in_
progress_ details - in_
progress_ result - ingest_
status - ingest_
status_ v2 - ingesting
- label
- logical_
series_ rid - mcap_
channel_ id - mcap_
channel_ locator - mcap_
channel_ topic - numeric_
property_ predicate - parsing
- property
- property_
comparison_ operator - property_
name - property_
value - queued
- range
- ref_
name_ and_ type - rids
- s3_path
- serializable_
error - series_
archetype_ rid - series_
data_ type - series_
metadata_ rid - set_
operator - success_
result - tag_
name - tag_
value - theme_
aware_ image - time_
unit - timestamp
- token
- typed_
property_ value - unit
Structs
- Channel
- Column
Name - Data
Source RefName - Deleted
- Deletion
InProgress - Empty
- Error
Result - Error
Type - Should be of the format Namespace:ErrorType
- InProgress
Result - Ingesting
- Label
- Logical
Series Rid - Mcap
Channel Id - Mcap
Channel Topic - Numeric
Property Predicate - Matches resources that have a numeric value for the named property and whose value satisfies the operator. NEQ excludes resources that lack the property or store a string value under the same name.
- Parsing
- Property
- Property
Name - Property
Value - Queued
- Range
- RefName
AndType - S3Path
- Serializable
Error - A SerializableError is a representation of a ServiceException that exists to send error results to clients as part of a response object when directly throwing an exception is undesirable.
- Series
Archetype Rid - Series
Metadata Rid - Success
Result - TagName
- TagValue
- Theme
Aware Image - Timestamp
- Nanosecond precision timestamp type, represented by an epoch time in seconds and a nanosecond offset. The nanosecond offset is from the start of the epoch second, so must be less than 1 billion.
- Token
- Tokens are used with paginated requests to get the next “page” of results from an API, and typically are used as both part of the request and response schema of an endpoint to allow users to stream pages of results.
- Unit
Enums
- Archived
Status - Data
Source Type - Granularity
- Handle
- InProgress
Details - Ingest
Status - Ingest
Status V2 - Mcap
Channel Locator - Property
Comparison Operator - Series
Data Type - The data types that are available for querying.
- SetOperator
- Time
Unit - Typed
Property Value