Module numeric_property_predicate

Module numeric_property_predicate 

Structs

Builder
A builder for NumericPropertyPredicate
Complete
The final stage for NumericPropertyPredicate.
NameStage
The name stage for Builder.
NumericPropertyPredicate
Matches resources that have a numeric value for the named property and whose value satisfies the operator. NEQ excludes resources that lack the property or store a string value under the same name.
OperatorStage
The operator stage for Builder.
ValueStage
The value stage for Builder.