pub struct LocalResourceRid(pub ResourceIdentifier);Expand description
Unique resource identifier for a local resource in a Mesh link. This is any resource type that’s supported for mesh links and represents the local environment’s resource.
Tuple Fields
0: ResourceIdentifierMethods from Deref<Target = ResourceIdentifier>