pub struct NumericPropertyPredicate { /* private fields */ }Expand description
Matches resources that have a numeric value for the named property and whose value satisfies the operator. NEQ excludes resources that lack the property or store a string value under the same name.
Implementations
Sourceimpl NumericPropertyPredicate
impl NumericPropertyPredicate
Sourcepub fn new(
name: PropertyName,
value: f64,
operator: PropertyComparisonOperator,
) -> NumericPropertyPredicate
pub fn new( name: PropertyName, value: f64, operator: PropertyComparisonOperator, ) -> NumericPropertyPredicate
Constructs a new instance of the type.
pub fn name(&self) -> &PropertyName
pub fn value(&self) -> f64
pub fn operator(&self) -> &PropertyComparisonOperator