Module batch_preregister_users_response

Module batch_preregister_users_response 

Structs

BatchPreregisterUsersResponse
Response containing only the newly created users keyed by email. Emails that already had existing accounts are silently skipped.
Builder
A builder for BatchPreregisterUsersResponse
Complete
The final stage for BatchPreregisterUsersResponse.