Module sandbox_workspace

Module sandbox_workspace 

Structs

Unknown
An unknown variant of the SandboxWorkspace enum.

Enums

SandboxWorkspace
Which sandbox workspace to create a token for. Each has its own service user, so the two values are two user identities in the same sandbox org.