pub enum SandboxWorkspace {
Primary,
Secondary,
Unknown(Unknown),
}Expand description
Which sandbox workspace to create a token for. Each has its own service user, so the two values are two user identities in the same sandbox org.
Variants
Implementations