Module api

Module api 

Modules

batch_get_channel_prefix_tree_request
batch_get_channel_prefix_tree_response
batch_get_data_scope_bounds_request
batch_get_data_scope_bounds_response
batch_get_series_count_request
batch_get_series_count_response
channel_metadata
channel_or_prefix
channel_prefix_tree
channel_prefix_tree_node
channel_with_available_tags
channel_with_tag_filters
data_scope_filters
data_source_prefix_node
get_available_tag_keys_request
get_available_tag_keys_response
get_available_tag_values_request
get_available_tag_values_response
get_available_tags_for_channel_request
get_available_tags_for_channel_response
get_data_scope_bounds_request
get_data_scope_bounds_response
get_matching_channels_with_tags_request
get_matching_channels_with_tags_response
get_series_count_request
get_series_count_response
get_tag_values_for_data_source_request
index_channel_prefix_tree_request
matching_channel_with_tags
search_channels_request
search_channels_response
search_filtered_channels_request
search_filtered_channels_response
search_hierarchical_channels_request
search_hierarchical_channels_response
series_metadata_rid_or_logical_series_rid
tag_search_filters

Structs

BatchGetChannelPrefixTreeRequest
BatchGetChannelPrefixTreeResponse
If the tree for a data source has not been indexed, it will be omitted from the map.
BatchGetDataScopeBoundsRequest
BatchGetDataScopeBoundsResponse
BatchGetSeriesCountRequest
BatchGetSeriesCountResponse
ChannelMetadata
ChannelPrefixTree
ChannelPrefixTreeNode
ChannelWithAvailableTags
ChannelWithTagFilters
DataScopeFilters
DataSourcePrefixNode
GetAvailableTagKeysRequest
GetAvailableTagKeysResponse
GetAvailableTagValuesRequest
GetAvailableTagValuesResponse
GetAvailableTagsForChannelRequest
GetAvailableTagsForChannelResponse
GetDataScopeBoundsRequest
GetDataScopeBoundsResponse
GetMatchingChannelsWithTagsRequest
GetMatchingChannelsWithTagsResponse
GetSeriesCountRequest
GetSeriesCountResponse
GetTagValuesForDataSourceRequest
IndexChannelPrefixTreeRequest
MatchingChannelWithTags
Represents a channel identity by channel name and full tag map.
SearchChannelsRequest
SearchChannelsResponse
SearchFilteredChannelsRequest
SearchFilteredChannelsResponse
SearchHierarchicalChannelsRequest
SearchHierarchicalChannelsResponse
TagSearchFilters
Filters to use when searching for available tag names and values in paged endpoints. All filters are optional.

Enums

ChannelOrPrefix
SeriesMetadataRidOrLogicalSeriesRid