pub struct BatchGetChannelPrefixTreeResponse { /* private fields */ }Expand description
If the tree for a data source has not been indexed, it will be omitted from the map.
Implementations
Sourceimpl BatchGetChannelPrefixTreeResponse
impl BatchGetChannelPrefixTreeResponse
Sourcepub fn new() -> BatchGetChannelPrefixTreeResponse
pub fn new() -> BatchGetChannelPrefixTreeResponse
Constructs a new instance of the type.
pub fn channel_prefix_trees( &self, ) -> &BTreeMap<ResourceIdentifier, ChannelPrefixTree>