pub struct TimeSeriesChannelAssociation { /* private fields */ }Expand description
A singular time series to associate the event with.
Implementations
Sourceimpl TimeSeriesChannelAssociation
impl TimeSeriesChannelAssociation
Sourcepub fn builder() -> Builder<VariableNameStage>
pub fn builder() -> Builder<VariableNameStage>
Returns a new builder.
Sourceimpl TimeSeriesChannelAssociation
impl TimeSeriesChannelAssociation
Sourcepub fn new(variable_name: impl Into<String>) -> TimeSeriesChannelAssociation
pub fn new(variable_name: impl Into<String>) -> TimeSeriesChannelAssociation
Constructs a new instance of the type.
pub fn variable_name(&self) -> &str
If this variable is grouped, the tags within the groupings this event should associate with