Module exit_code_mapping

Module exit_code_mapping 

Structs

Builder
A builder for ExitCodeMapping
CodeStage
The code stage for Builder.
Complete
The final stage for ExitCodeMapping.
ExitCodeMapping
Maps a container exit code to a structured error, for extractors that cannot emit a structured /dev/termination-log document. Applied as a fallback error tier at ingest time.
ExitCodeStage
The exit_code stage for Builder.
MessageStage
The message stage for Builder.
RetryableStage
The retryable stage for Builder.