pub struct HeartbeatStreamingSessionRequest { /* private fields */ }Implementations
Sourceimpl HeartbeatStreamingSessionRequest
impl HeartbeatStreamingSessionRequest
Sourcepub fn builder() -> Builder<BoundsStage>
pub fn builder() -> Builder<BoundsStage>
Returns a new builder.
Sourceimpl HeartbeatStreamingSessionRequest
impl HeartbeatStreamingSessionRequest
Sourcepub fn bounds(&self) -> &Range
pub fn bounds(&self) -> &Range
The time range of data points ingested since the last heartbeat. The server atomically merges this with the session’s existing bounds using LEAST/GREATEST to track the full time range.
Sourcepub fn points_count(&self) -> i32
pub fn points_count(&self) -> i32
Number of data points ingested since the last heartbeat. The server atomically adds this to the session’s running total.