pub struct IngestMetadata { /* private fields */ }Implementations
Sourceimpl IngestMetadata
impl IngestMetadata
Sourcepub fn new() -> IngestMetadata
pub fn new() -> IngestMetadata
Constructs a new instance of the type.
Sourcepub fn timestamp_metadata(&self) -> Option<&TimestampMetadata>
pub fn timestamp_metadata(&self) -> Option<&TimestampMetadata>
The timestamp metadata will be recovered from the dataset files if possible. Older datasets may have unrecoverable timestamp metadata. If unrecoverable, reingestion will throw MissingMetadataForReingest if not provided in request.
Sourcepub fn channel_prefix(&self) -> Option<&str>
pub fn channel_prefix(&self) -> Option<&str>
Channel prefix to use when reingesting the dataset. Defaults to empty string. Not recoverable from prior ingests and must be provided in request if needed.
Sourcepub fn channel_name_overrides(&self) -> &BTreeMap<String, String>
pub fn channel_name_overrides(&self) -> &BTreeMap<String, String>
Renames individual columns to explicit channel names. Composes with channelPrefix:
final name = channelPrefix + channelNameOverrides.getOrDefault(column, column).
Defaults to empty map. Not recoverable from prior ingests and must be provided in request if needed.
At most 1000 entries may be provided. Resolved channel names must be unique across columns;
renaming a column onto another column’s name fails the ingest.
Sourcepub fn tag_columns(&self) -> Option<&BTreeMap<String, String>>
pub fn tag_columns(&self) -> Option<&BTreeMap<String, String>>
A map of tag names to column names to derive the tag values from. Not recoverable from prior ingests and must be provided in request if needed.
Additional tags to apply to all dataset files within the the given dataset. Not recoverable from prior ingests and must be provided in request if needed.