pub struct StreamingSource { /* private fields */ }Expand description
Aggregate view of the streaming sessions sharing a single (source, dataset) pair.
Implementations
Sourceimpl StreamingSource
impl StreamingSource
Sourcepub fn builder() -> Builder<DatasetRidStage>
pub fn builder() -> Builder<DatasetRidStage>
Returns a new builder.
Sourceimpl StreamingSource
impl StreamingSource
Sourcepub fn source(&self) -> Option<&StreamingSessionSource>
pub fn source(&self) -> Option<&StreamingSessionSource>
The source attribution shared by the aggregated sessions. Absent for unattributed sessions.
pub fn dataset_rid(&self) -> &DatasetRid
Sourcepub fn session_count(&self) -> SafeLong
pub fn session_count(&self) -> SafeLong
Number of sessions aggregated into this group.
Sourcepub fn total_points_count(&self) -> SafeLong
pub fn total_points_count(&self) -> SafeLong
Sum of the points counts across the aggregated sessions.
Sourcepub fn earliest_created_at(&self) -> &Timestamp
pub fn earliest_created_at(&self) -> &Timestamp
Creation time of the oldest aggregated session.
Sourcepub fn latest_last_seen_at(&self) -> &Timestamp
pub fn latest_last_seen_at(&self) -> &Timestamp
Most recent heartbeat time across the aggregated sessions.
Sourcepub fn merged_bounds(&self) -> Option<&Range>
pub fn merged_bounds(&self) -> Option<&Range>
Union of the data bounds across the aggregated sessions, if any session has bounds.
Sourcepub fn any_in_progress(&self) -> bool
pub fn any_in_progress(&self) -> bool
True if at least one aggregated session is in progress.