pub struct ContainerizedExtractor { /* private fields */ }Expand description
Represents a containerized extractor that processes input files using a container.
Implementations
Sourceimpl ContainerizedExtractor
impl ContainerizedExtractor
Sourcepub fn rid(&self) -> &ContainerizedExtractorRid
pub fn rid(&self) -> &ContainerizedExtractorRid
Unique resource identifier for the extractor.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
Optional description of the extractor.
Sourcepub fn image(&self) -> &DockerImageSource
👎Deprecated: Use containerImageRid for self-hosted images.
pub fn image(&self) -> &DockerImageSource
Use containerImageRid for self-hosted images.
Deprecated: use containerImageRid instead for self-hosted images. Container image used to run the extractor via an external registry. When containerImageRid is set, this field contains placeholder values and should be ignored.
Sourcepub fn container_image_rid(&self) -> Option<&ContainerImageRid>
pub fn container_image_rid(&self) -> Option<&ContainerImageRid>
RID of a self-hosted container image in the internal registry. When set, the extractor uses the internal registry; when absent, the legacy image field is used.
Sourcepub fn inputs(&self) -> &[FileExtractionInput]
pub fn inputs(&self) -> &[FileExtractionInput]
The input files that this extractor requires, mapped to environment variables that store the path to the file.
Sourcepub fn parameters(&self) -> &[FileExtractionParameter]
pub fn parameters(&self) -> &[FileExtractionParameter]
Describes the parameters of the extractor.
Sourcepub fn properties(&self) -> &BTreeMap<PropertyName, PropertyValue>
pub fn properties(&self) -> &BTreeMap<PropertyName, PropertyValue>
Additional properties associated with this extractor.
Sourcepub fn created_at(&self) -> DateTime<Utc>
pub fn created_at(&self) -> DateTime<Utc>
Timestamp when this extractor was created.
Sourcepub fn is_archived(&self) -> bool
pub fn is_archived(&self) -> bool
Whether this extractor is archived.
Sourcepub fn timestamp_metadata(&self) -> Option<&TimestampMetadata>
pub fn timestamp_metadata(&self) -> Option<&TimestampMetadata>
Metadata about the intermediate parquet this extractor will produce. If not set, timestamp metadata must be provided at ingest time.
Sourcepub fn output_file_format(&self) -> &FileOutputFormat
pub fn output_file_format(&self) -> &FileOutputFormat
The format of the output file. Currently only “parquet”, “csv”, “parquet.tar” are supported