pub struct DataflashOpts { /* private fields */ }Implementations
Sourceimpl DataflashOpts
impl DataflashOpts
Sourcepub fn builder() -> Builder<SourceStage>
pub fn builder() -> Builder<SourceStage>
Returns a new builder.
Sourceimpl DataflashOpts
impl DataflashOpts
Sourcepub fn new(source: IngestSource, target: DatasetIngestTarget) -> DataflashOpts
pub fn new(source: IngestSource, target: DatasetIngestTarget) -> DataflashOpts
Constructs a new instance of the type.
pub fn source(&self) -> &IngestSource
pub fn target(&self) -> &DatasetIngestTarget
Sourcepub fn ignore_invalid_timestamps(&self) -> Option<bool>
pub fn ignore_invalid_timestamps(&self) -> Option<bool>
If true, skips dataflash records whose timestamp cannot be represented (corrupted/out-of-range) instead of failing the entire ingest. If not provided, defaults to false.
Specifies a tag set to apply to all data in the file.