pub struct IngestJob { /* private fields */ }Expand description
Ingest job information
Implementations
Sourceimpl IngestJob
impl IngestJob
pub fn ingest_job_rid(&self) -> &ResourceIdentifier
pub fn status(&self) -> &IngestJobStatus
pub fn origin_files(&self) -> Option<&[String]>
pub fn created_by(&self) -> Uuid
👎Deprecated:
use createdByRid instead
pub fn created_by_rid(&self) -> Option<&UserRid>
pub fn org_uuid(&self) -> Uuid
pub fn ingest_type(&self) -> &IngestType
pub fn dataset_rid(&self) -> Option<&ResourceIdentifier>
pub fn created_at(&self) -> Option<DateTime<Utc>>
Sourcepub fn start_time(&self) -> Option<DateTime<Utc>>
pub fn start_time(&self) -> Option<DateTime<Utc>>
The time the job transitioned to IN_PROGRESS. Absent for jobs that have not started running yet (SUBMITTED, QUEUED).
pub fn end_time(&self) -> Option<DateTime<Utc>>
Sourcepub fn produced_file_count(&self) -> Option<i32>
pub fn produced_file_count(&self) -> Option<i32>
Count of dataset files produced by this ingest job.