pub struct NewDatasetIngestDestination { /* private fields */ }Implementations
Sourceimpl NewDatasetIngestDestination
impl NewDatasetIngestDestination
Sourcepub fn new() -> NewDatasetIngestDestination
pub fn new() -> NewDatasetIngestDestination
Constructs a new instance of the type.
pub fn dataset_name(&self) -> Option<&str>
pub fn dataset_description(&self) -> Option<&str>
pub fn properties(&self) -> &BTreeMap<String, String>
pub fn labels(&self) -> &BTreeSet<String>
pub fn channel_config(&self) -> Option<&ChannelConfig>
Sourcepub fn workspace(&self) -> Option<&ResourceIdentifier>
pub fn workspace(&self) -> Option<&ResourceIdentifier>
The workspace in which to create the dataset. If not provided, the dataset will be created in the default workspace for the user’s organization, if the default workspace for the organization is configured.
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created dataset. If not provided, the dataset will be visible to all users in the same workspace.