pub struct NewPointCloudIngestDestination { /* private fields */ }Implementations
Sourceimpl NewPointCloudIngestDestination
impl NewPointCloudIngestDestination
Sourcepub fn new() -> NewPointCloudIngestDestination
pub fn new() -> NewPointCloudIngestDestination
Constructs a new instance of the type.
pub fn description(&self) -> Option<&str>
pub fn properties(&self) -> &BTreeMap<String, String>
pub fn labels(&self) -> &BTreeSet<String>
Sourcepub fn workspace(&self) -> Option<&ResourceIdentifier>
pub fn workspace(&self) -> Option<&ResourceIdentifier>
The workspace in which to create the point cloud. If not provided, the point cloud will be created in the default workspace for the user’s organization, if the default workspace is configured.
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created point cloud.