pub struct NoTimestampManifest { /* private fields */ }Implementations
Sourceimpl NoTimestampManifest
impl NoTimestampManifest
Sourcepub fn builder() -> Builder<StartingTimestampStage>
pub fn builder() -> Builder<StartingTimestampStage>
Returns a new builder.
Sourceimpl NoTimestampManifest
impl NoTimestampManifest
Sourcepub fn new(starting_timestamp: UtcTimestamp) -> NoTimestampManifest
pub fn new(starting_timestamp: UtcTimestamp) -> NoTimestampManifest
Constructs a new instance of the type.
pub fn starting_timestamp(&self) -> &UtcTimestamp
Sourcepub fn scale_parameter(&self) -> Option<&ScaleParameter>
pub fn scale_parameter(&self) -> Option<&ScaleParameter>
A field that specifies that the frame rate of the video does not match the frame rate of the camera | i.e. a slowed down or sped up video. Can specify either the camera frame rate or the absolute end time.