Module manifest

Module manifest 

Modules

extractor_manifest
extractor_upload_metadata
manifest_epoch_time_unit
manifest_ingest_type
manifest_output
manifest_timestamp_metadata
upload_metadata

Structs

ExtractorManifest
Manifest file produced by containerized extractors to describe their outputs. This is written as manifest.json in the OUTPUT_DIR by the container.
ExtractorUploadMetadata
Metadata file created by yeeter after uploading extractor outputs to S3. This is uploaded to S3 by yeeter and read by the Temporal activity to orchestrate ingestion.
ManifestOutput
Describes a single output file from a containerized extractor. This is written by the container in manifest.json.
ManifestTimestampMetadata
Per-output timestamp metadata for a containerized extractor output.
UploadMetadata
Metadata about a single file uploaded to S3 by yeeter. Enriches the original manifest entry with S3 upload information.

Enums

ManifestEpochTimeUnit
Time unit for a numeric epoch timestamp in a manifest output.
ManifestIngestType
Supported ingest types for containerized extractor outputs.