pub struct ExtractorUploadMetadata { /* private fields */ }Expand description
Metadata file created by yeeter after uploading extractor outputs to S3. This is uploaded to S3 by yeeter and read by the Temporal activity to orchestrate ingestion.
Implementations
Sourceimpl ExtractorUploadMetadata
impl ExtractorUploadMetadata
Sourcepub fn new() -> ExtractorUploadMetadata
pub fn new() -> ExtractorUploadMetadata
Constructs a new instance of the type.
Sourcepub fn uploads(&self) -> &[UploadMetadata]
pub fn uploads(&self) -> &[UploadMetadata]
List of uploaded files with their S3 locations and manifest metadata