pub struct StreamingComputeNodeRequest { /* private fields */ }Expand description
A templatized version of ComputeNodeRequest where the end of the range will track the current time and
the start of the range tracks windowWidth time ago.
Implementations
Sourceimpl StreamingComputeNodeRequest
impl StreamingComputeNodeRequest
Sourcepub fn new(
node: ComputableNode,
window_width: Duration,
context: Context,
) -> StreamingComputeNodeRequest
pub fn new( node: ComputableNode, window_width: Duration, context: Context, ) -> StreamingComputeNodeRequest
Constructs a new instance of the type.
pub fn node(&self) -> &ComputableNode
pub fn window_width(&self) -> &Duration
pub fn context(&self) -> &Context
Sourcepub fn source_rid(&self) -> Option<&ResourceIdentifier>
pub fn source_rid(&self) -> Option<&ResourceIdentifier>
Optional RID identifying the resource that initiated this query (e.g. workbook/notebook RID, checklist RID). Used for observability only — trusted as-is, no permission checks are performed on this value.