Module api

Module api 

Modules

add_data_scopes_to_asset_request
asset
asset_sort_field
asset_sort_options
asset_type_data_scope_config
asset_types_filter
batch_edit_asset_metadata_request
batch_edit_asset_metadata_response
channel
channel_metadata
create_asset_data_scope
create_asset_request
create_type_request
data_scope
property_config
remove_type
search_asset_channels_request
search_asset_channels_response
search_assets_query
search_assets_request
search_assets_response
search_types_query
search_types_request
search_types_response
sort_key
sort_property
tag_config
type_
type_sort_field
type_sort_options
update_asset_ref_names_request
update_asset_request
update_attachments_request
update_or_remove_asset_type
update_type_request

Structs

AddDataScopesToAssetRequest
Asset
AssetSortOptions
AssetTypeDataScopeConfig
AssetTypesFilter
returns runs that match any of the provided assetTypes.
BatchEditAssetMetadataRequest
BatchEditAssetMetadataResponse
Channel
ChannelMetadata
CreateAssetDataScope
CreateAssetRequest
CreateTypeRequest
DataScope
PropertyConfig
RemoveType
The request to remove the type from the asset.
SearchAssetChannelsRequest
SearchAssetChannelsResponse
SearchAssetsRequest
SearchAssetsResponse
SearchTypesRequest
SearchTypesResponse
SortProperty
Type
TypeSortOptions
UpdateAssetRefNamesRequest
UpdateAssetRequest
UpdateAttachmentsRequest
UpdateTypeRequest
The request to update a type. The request will replace all existing properties with the properties specified in the request.

Enums

AssetSortField
SearchAssetsQuery
SearchTypesQuery
SortKey
TagConfig
TypeSortField
UpdateOrRemoveAssetType