pub struct BatchEditAssetMetadataRequest { /* private fields */ }Implementations
Sourceimpl BatchEditAssetMetadataRequest
impl BatchEditAssetMetadataRequest
Sourcepub fn builder() -> Builder<OperationStage>
pub fn builder() -> Builder<OperationStage>
Returns a new builder.
Sourceimpl BatchEditAssetMetadataRequest
impl BatchEditAssetMetadataRequest
Sourcepub fn new(operation: MetadataChange) -> Self
pub fn new(operation: MetadataChange) -> Self
Constructs a new instance of the type.
Sourcepub fn asset_search_query(&self) -> Option<&SearchAssetsQuery>
pub fn asset_search_query(&self) -> Option<&SearchAssetsQuery>
Additional search query to filter which assets are targeted by the edit. Source labels/properties from the metadata change are automatically included as filters.
pub fn operation(&self) -> &MetadataChange