pub struct BatchEditAssetMetadataResponse { /* private fields */ }Implementations
Sourceimpl BatchEditAssetMetadataResponse
impl BatchEditAssetMetadataResponse
Sourcepub fn new() -> BatchEditAssetMetadataResponse
pub fn new() -> BatchEditAssetMetadataResponse
Constructs a new instance of the type.
Sourcepub fn modified_asset_rids(&self) -> &[AssetRid]
pub fn modified_asset_rids(&self) -> &[AssetRid]
RIDs for assets that were modified by the batch edit.
Sourcepub fn conflicting_asset_rids(&self) -> &[AssetRid]
pub fn conflicting_asset_rids(&self) -> &[AssetRid]
RIDs for assets that matched the source filter but already had the target property key and were skipped (SkipOnConflict behavior). Empty for operations without conflict semantics or when using OverwriteOnConflict.