Module catalog

Module catalog 

Modules

absolute_timestamp
add_file_to_dataset
all_properties_and_labels_response
batch_get_dataset_files_request
bounds
channel
channel_config
channel_details
create_dataset
create_dataset_with_uuid_request
custom_timestamp
dataset
dataset_backing_type
dataset_file
dataset_file_metadata
dataset_file_sort_field
dataset_file_sort_options
dataset_file_uri
dataset_files_page
dataset_origin_metadata
enriched_dataset
epoch_timestamp
get_channels_for_datasets_request
get_datasets_request
get_details_for_channels_request
get_handles_for_datasets_request
handle
ingest_progress_v2
ingest_status
ingest_tag_metadata
iso8601_timestamp
mark_file_ingest_error
mark_file_ingest_successful
origin_file_uri
relative_timestamp
retention_policy
retention_policy_type
s3_handle
search_dataset_files_query
search_dataset_files_request
search_dataset_files_response
search_datasets_query
search_datasets_request
search_datasets_response
skip_rows_config
sort_field
sort_options
time_range_filter
timestamp_metadata
timestamp_type
unit_config
update_bounds_request
update_dataset_metadata
update_ingest_status
update_ingest_status_v2
update_retention_policy_request
uploaded_at_filter
utc_timestamp
video_file_uri
weak_timestamp_type

Structs

AddFileToDataset
AllPropertiesAndLabelsResponse
BatchGetDatasetFilesRequest
Request to batch get dataset files for a single dataset.
Bounds
Channel
ChannelConfig
ChannelDetails
CreateDataset
CreateDatasetWithUuidRequest
Request to create a dataset with a specific UUID. Used for migrations where the UUID must be controlled by the caller.
CustomTimestamp
Dataset
DatasetFile
DatasetFileSortOptions
DatasetFileUri
Pre-signed URI that can be used to download the original file directly. Expires if the download has not been initiated within 1 minute.
DatasetFilesPage
DatasetOriginMetadata
EnrichedDataset
EpochTimestamp
GetChannelsForDatasetsRequest
GetDatasetsRequest
GetDetailsForChannelsRequest
GetHandlesForDatasetsRequest
IngestProgressV2
IngestTagMetadata
The tags used when ingesting the dataset file.
Iso8601Timestamp
MarkFileIngestError
MarkFileIngestSuccessful
OriginFileUri
Pre-signed URI that can be used to download an origin file directly. Expires if the download has not been initiated within 1 minute.
RelativeTimestamp
RetentionPolicy
S3Handle
SearchDatasetFilesRequest
SearchDatasetFilesResponse
SearchDatasetsRequest
SearchDatasetsResponse
SkipRowsConfig
SortOptions
TimeRangeFilter
searches for files that intersect with the specified range.
TimestampMetadata
UnitConfig
UpdateBoundsRequest
UpdateDatasetMetadata
UpdateIngestStatus
UpdateIngestStatusV2
UpdateRetentionPolicyRequest
UploadedAtFilter
Searches for files whose uploadedAt falls within the specified range using half-open bounds [start, end). If start is omitted the range is unbounded below. If end is omitted the range is unbounded above.
UtcTimestamp
VideoFileUri
Pre-signed URI that can be used to download the original video file directly. Expires if the download has not been initiated within 1 minute.

Enums

AbsoluteTimestamp
DatasetBackingType
DatasetFileMetadata
DatasetFileSortField
Handle
IngestStatus
RetentionPolicyType
SearchDatasetFilesQuery
SearchDatasetsQuery
SortField
TimestampType
WeakTimestampType
If a CSV dataset is still being split, the timestamp type is not known.