pub struct CreateDataset { /* private fields */ }Implementations
Sourceimpl CreateDataset
impl CreateDataset
Sourcepub fn new(
name: impl Into<String>,
origin_metadata: DatasetOriginMetadata,
) -> Self
pub fn new( name: impl Into<String>, origin_metadata: DatasetOriginMetadata, ) -> Self
Constructs a new instance of the type.
pub fn name(&self) -> &str
pub fn handle(&self) -> Option<&Handle>
Handles should only be specified when adding files to datasets
pub fn metadata(&self) -> &BTreeMap<String, String>
Deprecated in favor of properties
pub fn origin_metadata(&self) -> &DatasetOriginMetadata
pub fn labels(&self) -> &BTreeSet<String>
pub fn properties(&self) -> &BTreeMap<String, String>
pub fn description(&self) -> Option<&str>
Sourcepub fn granularity(&self) -> Option<&Granularity>
pub fn granularity(&self) -> Option<&Granularity>
Granularity of dataset timestamps. Defaults to nanoseconds.
Sourcepub fn is_v2_dataset(&self) -> Option<bool>
👎Deprecated: Regardless of what value is specified, this flag is treated as true by the service.
pub fn is_v2_dataset(&self) -> Option<bool>
Regardless of what value is specified, this flag is treated as true by the service.
If true, the dataset should be ingested to the v2 tables and is compatible with streaming.
Sourcepub fn workspace(&self) -> Option<&ResourceIdentifier>
pub fn workspace(&self) -> Option<&ResourceIdentifier>
The workspace in which to create the dataset. If not provided, the dataset will be created in the default workspace for the user’s organization, if the default workspace for the organization is configured.
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created dataset. If not provided, the dataset will be visible to all users in the same workspace.
Sourcepub fn dataset_type(&self) -> Option<&DatasetBackingType>
pub fn dataset_type(&self) -> Option<&DatasetBackingType>
The backing dataset type. Defaults to LEGACY type.
Sourcepub fn derived_definition(&self) -> Option<&CreateDerivedDefinition>
pub fn derived_definition(&self) -> Option<&CreateDerivedDefinition>
Definition for a derived dataset. When present, the created dataset is virtual and does not ingest or persist dataset files.