Dataset

Struct Dataset 

pub struct Dataset { /* private fields */ }

Implementations

Source

impl Dataset

pub fn builder() -> Builder<RidStage>

Returns a new builder.

Source

impl Dataset

pub fn rid(&self) -> &ResourceIdentifier

pub fn name(&self) -> &str

pub fn handle(&self) -> Option<&Handle>

👎Deprecated:

Deprecated. Use DatasetFile#handle

pub fn description(&self) -> Option<&str>

pub fn origin_metadata(&self) -> &DatasetOriginMetadata

pub fn bounds(&self) -> Option<&Bounds>

pub fn properties(&self) -> &BTreeMap<String, String>

pub fn labels(&self) -> &BTreeSet<String>

pub fn timestamp_type(&self) -> &WeakTimestampType

pub fn allow_streaming(&self) -> bool

pub fn granularity(&self) -> &Granularity

pub fn is_archived(&self) -> bool

pub fn dataset_type(&self) -> Option<&DatasetBackingType>

pub fn derived_definition(&self) -> Option<&DerivedDefinition>

Definition for a derived dataset. When present, this dataset is virtual and backed by the referenced provided Dataset definition instead of persisted dataset files.