EnrichedDataset

Struct EnrichedDataset 

pub struct EnrichedDataset { /* private fields */ }

Implementations

Source

impl EnrichedDataset

pub fn builder() -> Builder<RidStage>

Returns a new builder.

Source

impl EnrichedDataset

pub fn rid(&self) -> &ResourceIdentifier

pub fn uuid(&self) -> Uuid

pub fn name(&self) -> &str

pub fn description(&self) -> Option<&str>

pub fn display_name(&self) -> &str

pub fn metadata(&self) -> Option<&BTreeMap<String, String>>

👎Deprecated:

Deprecated in favor of properties.

pub fn handle(&self) -> Option<&Handle>

👎Deprecated:

Deprecated. Use DatasetFile#handle

pub fn ingest_date(&self) -> DateTime<Utc>

pub fn ingest_status(&self) -> Option<&IngestStatus>

👎Deprecated:

Deprecated. Use lastIngestStatus.

pub fn origin_metadata(&self) -> &DatasetOriginMetadata

pub fn last_ingest_status(&self) -> &IngestStatusV2

pub fn retention_policy(&self) -> &RetentionPolicy

pub fn source(&self) -> Option<&str>

pub fn bounds(&self) -> Option<&Bounds>

pub fn timestamp_type(&self) -> &WeakTimestampType

pub fn labels(&self) -> &BTreeSet<String>

pub fn properties(&self) -> &BTreeMap<String, String>

pub fn granularity(&self) -> &Granularity

pub fn allow_streaming(&self) -> bool

pub fn is_archived(&self) -> bool

pub fn dataset_type(&self) -> Option<&DatasetBackingType>

pub fn external_connection_metadata( &self, ) -> Option<&ExternalConnectionMetadata>

pub fn derived_definition(&self) -> Option<&DerivedDefinition>

Definition for a derived dataset. When present, this dataset is virtual and backed by the referenced provided Dataset definition instead of persisted dataset files.