pub struct VideoFileUri { /* private fields */ }Expand description
Pre-signed URI that can be used to download the original video file directly. Expires if the download has not been initiated within 1 minute.
Implementations