pub struct BatchSearchChannelsRequest { /* private fields */ }Expand description
Batched form of searchChannels. The map key of requests can be an arbitrary string
identifier. It will be returned in the response as part of BatchedLocator.
Implementations
Sourceimpl BatchSearchChannelsRequest
impl BatchSearchChannelsRequest
Sourcepub fn builder() -> Builder<QueryStage>
pub fn builder() -> Builder<QueryStage>
Returns a new builder.
Sourceimpl BatchSearchChannelsRequest
impl BatchSearchChannelsRequest
Sourcepub fn new(query: ChannelSearchQuery, time_range: Range) -> Self
pub fn new(query: ChannelSearchQuery, time_range: Range) -> Self
Constructs a new instance of the type.
pub fn requests(&self) -> &BTreeMap<String, BatchSearchChannelsEntry>
pub fn query(&self) -> &ChannelSearchQuery
Sourcepub fn time_range(&self) -> &Range
pub fn time_range(&self) -> &Range
Time filter applied to the search. Only channels with data within this time range will be returned. A shorter time range will improve performance!
Sourcepub fn max_result_channels(&self) -> Option<i32>
pub fn max_result_channels(&self) -> Option<i32>
Global cap on the merged channel result list. Defaults to 1000. Capped at 1000.