Module batched_prefix_entry

Module batched_prefix_entry 

Structs

BatchedPrefixEntry
A prefix node collapsed across locators in the batch. presentAtLocators lists the locators where this prefix exists, each tagged with the set of entry ids whose scope expanded to that locator.
Builder
A builder for BatchedPrefixEntry
Complete
The final stage for BatchedPrefixEntry.
PartStage
The part stage for Builder.