Module channel_entry

Module channel_entry 

Structs

Builder
A builder for ChannelEntry
ChannelEntry
A channel (by name) found in one or more locators of the frame. locatorMetadata has one entry per locator the channel exists in; locators not represented here are ones where the channel does not exist.
Complete
The final stage for ChannelEntry.
NameStage
The name stage for Builder.