pub struct BatchGetLocatorDelimitersRequest { /* private fields */ }Expand description
Batched form of getLocatorDelimiters. The map key of requests can be an arbitrary string
identifier. It will be returned in the response as part of BatchedLocatorWithDelimiter.
Implementations
Sourceimpl BatchGetLocatorDelimitersRequest
impl BatchGetLocatorDelimitersRequest
Sourcepub fn builder() -> Builder<TimeRangeStage>
pub fn builder() -> Builder<TimeRangeStage>
Returns a new builder.
Sourceimpl BatchGetLocatorDelimitersRequest
impl BatchGetLocatorDelimitersRequest
Sourcepub fn new(time_range: Range) -> BatchGetLocatorDelimitersRequest
pub fn new(time_range: Range) -> BatchGetLocatorDelimitersRequest
Constructs a new instance of the type.
pub fn requests(&self) -> &BTreeMap<String, BatchGetLocatorDelimitersEntry>
pub fn time_range(&self) -> &Range