pub struct BatchListChannelChildrenRequest { /* private fields */ }Expand description
Batched form of listChannelChildren. The map key of requests can be an arbitrary string
identifier. It will be returned in the response as part of BatchedLocator.
Implementations
Sourceimpl BatchListChannelChildrenRequest
impl BatchListChannelChildrenRequest
Sourcepub fn builder() -> Builder<TimeRangeStage>
pub fn builder() -> Builder<TimeRangeStage>
Returns a new builder.
Sourceimpl BatchListChannelChildrenRequest
impl BatchListChannelChildrenRequest
pub fn requests(&self) -> &BTreeMap<String, BatchListChannelChildrenEntry>
Sourcepub fn parent(&self) -> &[String]
pub fn parent(&self) -> &[String]
Ancestor parts. Empty means top-level. Applied identically to every entry’s scope.
Sourcepub fn time_range(&self) -> &Range
pub fn time_range(&self) -> &Range
Time filter applied to the search. Only channels with data within this time range will be returned. A shorter time range will improve performance!