pub struct BatchListChannelChildrenResponse { /* private fields */ }Implementations
Sourceimpl BatchListChannelChildrenResponse
impl BatchListChannelChildrenResponse
Sourcepub fn all_expanded_locators(&self) -> &BTreeSet<BatchedLocator>
pub fn all_expanded_locators(&self) -> &BTreeSet<BatchedLocator>
All locators expanded from the union of entry scopes in the batch, independent of which channels exist within them.
Sourcepub fn entries(&self) -> &[BatchedChannelChildEntry]
pub fn entries(&self) -> &[BatchedChannelChildEntry]
Mix of channel leaves and prefix nodes, one entry per distinct (channel name | prefix part) collapsed across locators across all entries.