pub struct BatchedChannelEntry { /* private fields */ }Expand description
A channel (by name) found in one or more locators across the batch. locatorMetadata
has one entry per locator the channel exists in.
Implementations
Sourceimpl BatchedChannelEntry
impl BatchedChannelEntry
pub fn name(&self) -> &Channel
pub fn locator_metadata(&self) -> &BTreeSet<BatchedLocatorChannelMetadata>