pub struct NumericRawVisualisationV2 { /* private fields */ }Expand description
A raw numeric visualisation with optional coloring based on numeric thresholds.
Implementations
Sourceimpl NumericRawVisualisationV2
impl NumericRawVisualisationV2
Sourcepub fn new() -> NumericRawVisualisationV2
pub fn new() -> NumericRawVisualisationV2
Constructs a new instance of the type.
Sourcepub fn thresholds(&self) -> Option<&[Threshold]>
pub fn thresholds(&self) -> Option<&[Threshold]>
Modifies the visualisation based on the highest threshold value that the computed value surpasses.