pub struct ValueTableMultiCellConfig { /* private fields */ }Expand description
Configurations for each type of cell in a grouping of heterogenous cells, such as for a row, for a column, or for the entire grid.
Implementations
Sourceimpl ValueTableMultiCellConfig
impl ValueTableMultiCellConfig
Sourcepub fn new() -> ValueTableMultiCellConfig
pub fn new() -> ValueTableMultiCellConfig
Constructs a new instance of the type.
pub fn range(&self) -> Option<&RangeCellConfig>
pub fn enum_(&self) -> Option<&EnumCellConfig>
pub fn numeric(&self) -> Option<&NumericCellConfig>
pub fn staleness(&self) -> Option<&StalenessCellConfig>
pub fn numeric_array(&self) -> Option<&NumericArrayCellConfig>
pub fn enum_array(&self) -> Option<&EnumArrayCellConfig>
pub fn struct_(&self) -> Option<&StructCellConfig>