pub struct CommitChecklistRequest { /* private fields */ }Implementations
Sourceimpl CommitChecklistRequest
impl CommitChecklistRequest
Sourcepub fn builder() -> Builder<CommitMessageStage>
pub fn builder() -> Builder<CommitMessageStage>
Returns a new builder.
Sourceimpl CommitChecklistRequest
impl CommitChecklistRequest
Sourcepub fn new(commit_message: impl Into<String>) -> CommitChecklistRequest
pub fn new(commit_message: impl Into<String>) -> CommitChecklistRequest
Constructs a new instance of the type.
pub fn commit_message(&self) -> &str
pub fn checks(&self) -> &[UpdateChecklistEntryRequest]
Sourcepub fn checklist_variables(&self) -> &[UnresolvedChecklistVariable]
pub fn checklist_variables(&self) -> &[UnresolvedChecklistVariable]
Variables that can be used in checks. Variables are resolved in order of declaration.
If variable a depends on variable b, then b must be defined before a in the list.
Sourcepub fn latest_commit(&self) -> Option<&CommitId>
pub fn latest_commit(&self) -> Option<&CommitId>
If present, will validate that the latest commit matches this id, and otherwise throw CommitConflict.