pub struct BatchEditChecklistMetadataRequest { /* private fields */ }Implementations
Sourceimpl BatchEditChecklistMetadataRequest
impl BatchEditChecklistMetadataRequest
Sourcepub fn builder() -> Builder<OperationStage>
pub fn builder() -> Builder<OperationStage>
Returns a new builder.
Sourceimpl BatchEditChecklistMetadataRequest
impl BatchEditChecklistMetadataRequest
Sourcepub fn new(operation: MetadataChange) -> Self
pub fn new(operation: MetadataChange) -> Self
Constructs a new instance of the type.
Sourcepub fn checklist_search_query(&self) -> Option<&ChecklistSearchQuery>
pub fn checklist_search_query(&self) -> Option<&ChecklistSearchQuery>
Additional search query to filter which checklists are targeted by the edit. Source labels/properties from the operation are automatically included as filters.
pub fn operation(&self) -> &MetadataChange