pub struct BatchEditChecklistMetadataResponse { /* private fields */ }Implementations
Sourceimpl BatchEditChecklistMetadataResponse
impl BatchEditChecklistMetadataResponse
Sourcepub fn modified_checklist_rids(&self) -> &[ChecklistRid]
pub fn modified_checklist_rids(&self) -> &[ChecklistRid]
RIDs for checklists that were modified by the batch edit.
Sourcepub fn conflicting_checklist_rids(&self) -> &[ChecklistRid]
pub fn conflicting_checklist_rids(&self) -> &[ChecklistRid]
RIDs for checklists that matched the source filter but already had the target property key and were skipped (SkipOnConflict behavior). Empty for operations without conflict semantics or when using OverwriteOnConflict.