pub struct CreateCheckRequest { /* private fields */ }Implementations
Sourceimpl CreateCheckRequest
impl CreateCheckRequest
Sourcepub fn builder() -> Builder<TitleStage>
pub fn builder() -> Builder<TitleStage>
Returns a new builder.
Sourceimpl CreateCheckRequest
impl CreateCheckRequest
Sourcepub fn new(
title: impl Into<String>,
description: impl Into<String>,
priority: Priority,
) -> CreateCheckRequest
pub fn new( title: impl Into<String>, description: impl Into<String>, priority: Priority, ) -> CreateCheckRequest
Constructs a new instance of the type.
Sourcepub fn check_lineage_rid(&self) -> Option<Uuid>
pub fn check_lineage_rid(&self) -> Option<Uuid>
Identifies the lineage of checks this check belongs to. If not specified, a new lineage will be created. This is named checkLineageRid for historical reasons but is actually a UUID.
pub fn title(&self) -> &str
pub fn description(&self) -> &str
pub fn auto_generated_title(&self) -> Option<&str>
pub fn auto_generated_description(&self) -> Option<&str>
pub fn priority(&self) -> &Priority
Sourcepub fn generated_event_type(&self) -> Option<&EventType>
pub fn generated_event_type(&self) -> Option<&EventType>
The event type that will be used for events generated from an execution of this check. If the check is executed through a data review, the event will have this type. Defaults to ERROR.
pub fn generated_event_labels(&self) -> Option<&BTreeSet<String>>
Sourcepub fn condition(&self) -> Option<&UnresolvedCheckCondition>
pub fn condition(&self) -> Option<&UnresolvedCheckCondition>
This field should not be omitted.