pub struct ParameterizedNumRangesConditionV1 { /* private fields */ }Implementations
Sourceimpl ParameterizedNumRangesConditionV1
impl ParameterizedNumRangesConditionV1
Sourcepub fn builder() -> Builder<RangesStage>
pub fn builder() -> Builder<RangesStage>
Returns a new builder.
Sourceimpl ParameterizedNumRangesConditionV1
impl ParameterizedNumRangesConditionV1
Sourcepub fn new(ranges: RangeSeries) -> ParameterizedNumRangesConditionV1
pub fn new(ranges: RangeSeries) -> ParameterizedNumRangesConditionV1
Constructs a new instance of the type.
pub fn ranges(&self) -> &RangeSeries
Sourcepub fn implementations(&self) -> &[CheckContext]
pub fn implementations(&self) -> &[CheckContext]
Each permutation of check context in the list will be executed as a new a stand-alone check. Violations produced will be associated with the context of the index.