pub struct UnresolvedBooleanSeriesConditionV1 { /* private fields */ }Implementations
Sourceimpl UnresolvedBooleanSeriesConditionV1
impl UnresolvedBooleanSeriesConditionV1
Sourcepub fn builder() -> Builder<BooleanSeriesStage>
pub fn builder() -> Builder<BooleanSeriesStage>
Returns a new builder.
Sourceimpl UnresolvedBooleanSeriesConditionV1
impl UnresolvedBooleanSeriesConditionV1
Sourcepub fn new(boolean_series: BooleanSeries) -> Self
pub fn new(boolean_series: BooleanSeries) -> Self
Constructs a new instance of the type.
pub fn boolean_series(&self) -> &BooleanSeries
Sourcepub fn variables(&self) -> &BTreeMap<VariableName, UnresolvedVariableLocator>
pub fn variables(&self) -> &BTreeMap<VariableName, UnresolvedVariableLocator>
Default overrides for the variables used in the check condition. These variables can be overridden at checklist execution time.