pub struct UnresolvedNumRangesConditionV3 { /* private fields */ }Implementations
Sourceimpl UnresolvedNumRangesConditionV3
impl UnresolvedNumRangesConditionV3
Sourcepub fn builder() -> Builder<RangesStage>
pub fn builder() -> Builder<RangesStage>
Returns a new builder.
Sourceimpl UnresolvedNumRangesConditionV3
impl UnresolvedNumRangesConditionV3
pub fn ranges(&self) -> &RangeSeries
pub fn function_spec(&self) -> &Any
pub fn threshold(&self) -> i32
pub fn operator(&self) -> &ThresholdOperator
Sourcepub fn variables(&self) -> &BTreeMap<VariableName, UnresolvedVariableLocator>
pub fn variables(&self) -> &BTreeMap<VariableName, UnresolvedVariableLocator>
Default overrides for the variables used in the check condition. These variables can be overridden at checklist execution time.