pub struct VersionedChecklist { /* private fields */ }Implementations
Sourceimpl VersionedChecklist
impl VersionedChecklist
Sourcepub fn new(
rid: ChecklistRid,
metadata: ChecklistMetadata,
commit: Commit,
) -> VersionedChecklist
pub fn new( rid: ChecklistRid, metadata: ChecklistMetadata, commit: Commit, ) -> VersionedChecklist
Constructs a new instance of the type.
pub fn rid(&self) -> &ChecklistRid
pub fn metadata(&self) -> &ChecklistMetadata
pub fn commit(&self) -> &Commit
pub fn functions(&self) -> Option<&[Function]>
👎Deprecated:
The functions field is deprecated and will be removed in a future version.
pub fn checks(&self) -> &[ChecklistEntry]
Sourcepub fn checklist_variables(&self) -> &[ChecklistVariable]
pub fn checklist_variables(&self) -> &[ChecklistVariable]
Variables that can be used in checks. Variables are resolved in order of declaration.
If variable a depends on variable b, then b must be defined before a in the list.