pub struct RangeAggregationDefinition { /* private fields */ }Expand description
Every range aggregation must be defined by a data scope and set of conditions. This type should be used by every comparison workbook viz definition.
Implementations
Sourceimpl RangeAggregationDefinition
impl RangeAggregationDefinition
Sourcepub fn builder() -> Builder<DataScopeStage>
pub fn builder() -> Builder<DataScopeStage>
Returns a new builder.
Sourceimpl RangeAggregationDefinition
impl RangeAggregationDefinition
Sourcepub fn new(
data_scope: ComparisonWorkbookDataScope,
condition: ComputeNodeWithContext,
) -> RangeAggregationDefinition
pub fn new( data_scope: ComparisonWorkbookDataScope, condition: ComputeNodeWithContext, ) -> RangeAggregationDefinition
Constructs a new instance of the type.
pub fn data_scope(&self) -> &ComparisonWorkbookDataScope
pub fn condition(&self) -> &ComputeNodeWithContext
Sourcepub fn time_window(&self) -> Option<&TimeWindow>
pub fn time_window(&self) -> Option<&TimeWindow>
determines the window of data included in the visualization. Currently only applied on assets.