pub struct ArrowPlot { /* private fields */ }Expand description
A generic Arrow IPC plot response. Used for all Arrow-serialized plot types (numeric, bucketed numeric, enum, bucketed enum, struct, bucketed struct, full resolution, and bucketed multivariate).
Implementations
Sourceimpl ArrowPlot
impl ArrowPlot
Sourcepub fn arrow_binary(&self) -> &Bytes
pub fn arrow_binary(&self) -> &Bytes
The raw binary containing an Arrow IPC stream.
Sourcepub fn group_by_keys(&self) -> Option<&[String]>
pub fn group_by_keys(&self) -> Option<&[String]>
This field specifies the tags that the final output is grouped by. When you combine multiple channels, this list represents the superset of all group by keys used across every individual channel.