pub struct ArrowStructPlot { /* private fields */ }Implementations
Sourceimpl ArrowStructPlot
impl ArrowStructPlot
Sourcepub fn builder() -> Builder<ArrowBinaryStage>
pub fn builder() -> Builder<ArrowBinaryStage>
Returns a new builder.
Sourceimpl ArrowStructPlot
impl ArrowStructPlot
Sourcepub fn arrow_binary(&self) -> &Bytes
pub fn arrow_binary(&self) -> &Bytes
The raw binary containing Arrow IPC stream for struct plot
Sourcepub fn group_by_keys(&self) -> Option<&[String]>
pub fn group_by_keys(&self) -> Option<&[String]>
This field specifies the tags that the final output is grouped by. When you combine multiple channels, this list represents the superset of all group by keys used across every individual channel.