pub struct Asset { /* private fields */ }Expand description
Query the data backing an asset
Implementations
Sourceimpl Asset
impl Asset
Sourcepub fn new(rid: StringConstant, data_scope: StringConstant) -> Self
pub fn new(rid: StringConstant, data_scope: StringConstant) -> Self
Constructs a new instance of the type.
Sourcepub fn rid(&self) -> &StringConstant
pub fn rid(&self) -> &StringConstant
Resource identifier of an asset
Sourcepub fn data_scope(&self) -> &StringConstant
pub fn data_scope(&self) -> &StringConstant
A data scope is a special tag on an asset which further specifies the data to query. It is helpful for disambiguating duplicate channel names across sources.