Module combine_assets_frame

Module combine_assets_frame 

Structs

Builder
A builder for CombineAssetsFrame
CombineAssetsFrame
Combines explicit assets into one frame. Each asset expands to one tagged branch per data scope on that asset, with the same per-branch tags as asset-target SearchFrame (assetRid, dataScope).
Complete
The final stage for CombineAssetsFrame.