pub enum UnboundedRangeBehavior {
ClampToWindow(Empty),
Drop(Empty),
Unknown(Unknown),
}Variants
ClampToWindow(Empty)
Clamp a missing range start to the compute request window start and a missing range end to the compute request window end.
Drop(Empty)
Drop the range if it has a missing start or end.
Unknown(Unknown)
An unknown variant.