Module event_time_shift

Module event_time_shift 

Structs

Builder
A builder for EventTimeShift
Complete
The final stage for EventTimeShift.
EventTimeShift
Shift by the start timestamp of the event at the configured zero-based index from this query whose event time lies in the anchor window [start, end), or [start, +infinity) when the end is absent. The window is the tagging interval for tagByIntervals and the run bounds for a run anchor. The query may differ from the query that produced a tagging interval.
QueryStage
The query stage for Builder.