pub struct FirstPointMatchingCondition {}Expand description
The first point in the output range will be the first point where the condition evaluates to true.
Implementations
Sourceimpl FirstPointMatchingCondition
impl FirstPointMatchingCondition
Sourcepub fn new() -> FirstPointMatchingCondition
pub fn new() -> FirstPointMatchingCondition
Constructs a new instance of the type.