Module intersect_ranges

Module intersect_ranges 

Structs

Builder
A builder for IntersectRanges
Complete
The final stage for IntersectRanges.
IntersectRanges
Produces the intersection of the input ranges: the ranges of time covered by every input. For best performance, pass inputs in the order in which they should be evaluated, listing the ranges that are cheapest to compute first.