Structs
- Builder
- A builder for MaxSeries
- Complete
- The final stage for
MaxSeries. - MaxSeries
- For every timestamp specified in the input series, outputs a value that is the maximum for that timestamp across all input series. Only outputs timestamps where all input series have an entry for that timestamp, subject to interpolation.