Structs
- Builder
- A builder for MinSeries
- Complete
- The final stage for
MinSeries. - MinSeries
- For every timestamp specified in the input series, outputs a value that is the minimum for that timestamp across all input series. Only outputs timestamps where all input series have an entry for that timestamp, subject to interpolation.