Module numeric_aggregation

Module numeric_aggregation 

Structs

Builder
A builder for NumericAggregation
Complete
The final stage for NumericAggregation.
InputStage
The input stage for Builder.
NumericAggregation
Aggregates an input series using the given operator. The shape of the aggregation (rolling time window vs. group by) is selected via the AggregationBuilder union. The operator needs to be compatible with the input series, producing a numeric output (e.g., count works for any type of input series whereas SUM only works for numeric series).
OperatorStage
The operator stage for Builder.