Module numeric_aggregation_udf

Module numeric_aggregation_udf 

Structs

Builder
A builder for NumericAggregationUdf
Complete
The final stage for NumericAggregationUdf.
NumericAggregationUdf
A user-defined numeric aggregation. The aggregation builder controls grouping/windowing. Supported Rust entrypoints accept grouped value vectors, optionally with leading sample timestamps, and return either one numeric value or timestamped numeric point(s), e.g. fn rms(values: Vec<f64>) -> f64, fn energy(timestamp_ns: Vec<i64>, values: Vec<f64>) -> f64, fn first(timestamp_ns: Vec<i64>, values: Vec<f64>) -> (i64, f64), or fn passthrough(timestamp_ns: Vec<i64>, values: Vec<f64>) -> Vec<(i64, f64)>.
SourceStage
The source stage for Builder.