pub struct NumericConstantResampleInterpolationConfiguration { /* private fields */ }Expand description
Fills all empty resample intervals with a single constant value.
If a resampled time interval (bucket) contains no data points from the input, it will be assigned the specified ‘constant’ as a default value. This applies to gaps at the start of the series, between data points, and at the end.
Implementations
Sourceimpl NumericConstantResampleInterpolationConfiguration
impl NumericConstantResampleInterpolationConfiguration
Sourcepub fn builder() -> Builder<ConstantStage>
pub fn builder() -> Builder<ConstantStage>
Returns a new builder.
Sourceimpl NumericConstantResampleInterpolationConfiguration
impl NumericConstantResampleInterpolationConfiguration
Sourcepub fn new(
constant: DoubleConstant,
) -> NumericConstantResampleInterpolationConfiguration
pub fn new( constant: DoubleConstant, ) -> NumericConstantResampleInterpolationConfiguration
Constructs a new instance of the type.
pub fn constant(&self) -> &DoubleConstant