pub struct NumericResampleSeries { /* private fields */ }Expand description
Resamples the input series to a new resolution using interpolation. Outputs data for timestamps corresponding to the defined frequency. Based on interpolation strategy, determines range of timestamps to output data for and interpolates values where necessary.
Implementations
Sourceimpl NumericResampleSeries
impl NumericResampleSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl NumericResampleSeries
impl NumericResampleSeries
Sourcepub fn new(
input: NumericSeries,
resample_configuration: NumericResampleConfiguration,
) -> NumericResampleSeries
pub fn new( input: NumericSeries, resample_configuration: NumericResampleConfiguration, ) -> NumericResampleSeries
Constructs a new instance of the type.
pub fn input(&self) -> &NumericSeries
Sourcepub fn resample_configuration(&self) -> &NumericResampleConfiguration
pub fn resample_configuration(&self) -> &NumericResampleConfiguration
The interpolation strategy and interval at which to resample the series