Module numeric_union_operation

Module numeric_union_operation 

Structs

Unknown
An unknown variant of the NumericUnionOperation enum.

Enums

NumericUnionOperation
In the event of a duplicate timestamp, the operation is applied to the values at the duplicate timestamp.