Module numeric_union_series

Module numeric_union_series 

Structs

Builder
A builder for NumericUnionSeries
Complete
The final stage for NumericUnionSeries.
NumericUnionSeries
Combines multiple numeric series together and outputs a single series. By default, points from the inputs are concatenated (SQL {@code UNION ALL}) and duplicate timestamps across inputs are preserved. To aggregate values that share a timestamp, do a separate aggregation step next.