pub struct PaddedRanges { /* private fields */ }Expand description
Expands ranges durations by adding temporal padding to the start, end, or both sides. Note that if the input ranges contain a RangeValue, it will be dropped.
Implementations
Sourceimpl PaddedRanges
impl PaddedRanges
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl PaddedRanges
impl PaddedRanges
Sourcepub fn new(input: RangeSeries, padding: DurationConstant) -> PaddedRanges
pub fn new(input: RangeSeries, padding: DurationConstant) -> PaddedRanges
Constructs a new instance of the type.
pub fn input(&self) -> &RangeSeries
pub fn padding(&self) -> &DurationConstant
Sourcepub fn padding_configuration(&self) -> Option<&RangePaddingConfiguration>
pub fn padding_configuration(&self) -> Option<&RangePaddingConfiguration>
Configuration for how to apply padding to the ranges. Defaults to PAD_START_AND_END if not specified.