Module page_info

Module page_info 

Structs

Builder
A builder for PageInfo
Complete
The final stage for PageInfo.
PageInfo
Specification of a page for a series. Returns full resolution points beginning nearest to the given page token, advancing pageSize points in the time direction specified by the sign of the page size. Paging cursors are not guaranteed to distinguish exact duplicate non-log points with the same timestamp, tags, and value. If those duplicates straddle a page boundary, later duplicates may be skipped.
PageSizeStage
The page_size stage for Builder.