pub struct RangeSummary { /* private fields */ }Expand description
Summary of a set of ranges
Implementations
Sourceimpl RangeSummary
impl RangeSummary
Sourcepub fn builder() -> Builder<RangeStage>
pub fn builder() -> Builder<RangeStage>
Returns a new builder.
Sourceimpl RangeSummary
impl RangeSummary
Sourcepub fn new(range: Range, sub_range_count: i32) -> RangeSummary
pub fn new(range: Range, sub_range_count: i32) -> RangeSummary
Constructs a new instance of the type.
Sourcepub fn range(&self) -> &Range
pub fn range(&self) -> &Range
The range representing the minimum start and maximum end times of the ranges.
Sourcepub fn sub_range_count(&self) -> i32
pub fn sub_range_count(&self) -> i32
The number of ranges found within this time range.