pub struct RustUdfSource { /* private fields */ }Expand description
Rust source code defining the UDF entrypoint and any helper functions.
Implementations
Sourceimpl RustUdfSource
impl RustUdfSource
Sourcepub fn builder() -> Builder<SourceCodeStage>
pub fn builder() -> Builder<SourceCodeStage>
Returns a new builder.
Sourceimpl RustUdfSource
impl RustUdfSource
Sourcepub fn source_code(&self) -> &str
pub fn source_code(&self) -> &str
Rust source code to transpiled into WASM. The source may contain a single function as the entrypoint, or if several
functions appear at the top level, annotate the entrypoint with #[main]. Entrypoint must return a single f64 value.
Parameters must be typed as f64 for numeric inputes or String for categorical inputs.
Single function example:
ⓘ
fn run(a: f64, b: f64) -> f64 {
a + b
}
Main with helper function:
ⓘ
#[main]
fn run(sample: f64, band_size: f64) -> f64 {
excedance_count(sample, band_size)
}
fn excedance_count(value: f64, band_size: f64) -> f64 {
let mut excedances = 0.0;
for i in 1..=5 {
if value > band_size * i as f64 {
excedances += 1.0;
}
}
excedances
}Trait Implementations
Sourceimpl Clone for RustUdfSource
impl Clone for RustUdfSource
Sourcefn clone(&self) -> RustUdfSource
fn clone(&self) -> RustUdfSource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RustUdfSource
impl Debug for RustUdfSource
Sourceimpl<'de> Deserialize<'de> for RustUdfSource
impl<'de> Deserialize<'de> for RustUdfSource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<RustUdfSource> for Builder<Complete>
impl From<RustUdfSource> for Builder<Complete>
Sourcefn from(v: RustUdfSource) -> Self
fn from(v: RustUdfSource) -> Self
Converts to this type from the input type.
Sourceimpl Hash for RustUdfSource
impl Hash for RustUdfSource
Sourceimpl Ord for RustUdfSource
impl Ord for RustUdfSource
Sourcefn cmp(&self, other: &RustUdfSource) -> Ordering
fn cmp(&self, other: &RustUdfSource) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for RustUdfSource
impl PartialEq for RustUdfSource
Sourceimpl PartialOrd for RustUdfSource
impl PartialOrd for RustUdfSource
Sourceimpl Serialize for RustUdfSource
impl Serialize for RustUdfSource
impl Eq for RustUdfSource
impl StructuralPartialEq for RustUdfSource