Module select_series

Module select_series 

Structs

Builder
A builder for SelectSeries
Complete
The final stage for SelectSeries.
SelectSeries
Selects series from a dataset (might contain multiple tag groupings). When name is provided, selects that single channel. When name is omitted, selection starts from all channels in the dataset scope; callers narrow the selection with a filterByTag predicate on the reserved NOMINAL_CHANNEL tag key and preserve per-channel identity in the response with selectTags. Providing both name and a NOMINAL_CHANNEL filter is rejected as an invalid request. Raw and derived channels can both be selected through the reserved tag filter.