pub struct SelectSeries { /* private fields */ }Expand description
Selects a specific series from a time series frame (might contain multiple tag groupings).
Implementations
Sourceimpl SelectSeries
impl SelectSeries
Sourcepub fn builder() -> Builder<TimeSeriesFrameStage>
pub fn builder() -> Builder<TimeSeriesFrameStage>
Returns a new builder.
Sourceimpl SelectSeries
impl SelectSeries
Sourcepub fn new(time_series_frame: TimeSeriesFrame, name: StringConstant) -> Self
pub fn new(time_series_frame: TimeSeriesFrame, name: StringConstant) -> Self
Constructs a new instance of the type.
Sourcepub fn time_series_frame(&self) -> &TimeSeriesFrame
pub fn time_series_frame(&self) -> &TimeSeriesFrame
The time series frame providing the data to query
Sourcepub fn name(&self) -> &StringConstant
pub fn name(&self) -> &StringConstant
The identifying series name to query