Module series_variable

Module series_variable 

Structs

Builder
A builder for SeriesVariable
Complete
The final stage for SeriesVariable.
SelectStage
The select stage for Builder.
SeriesVariable
A series selected from a dataset, bound to a variable. The series type (numeric, enum, …) is decided lazily by the node consuming the variable, matching the behaviour of channel variables.