pub struct SinglePoint { /* private fields */ }Expand description
Return type representing a single point value.
Implementations
Sourceimpl SinglePoint
impl SinglePoint
Sourcepub fn builder() -> Builder<TimestampStage>
pub fn builder() -> Builder<TimestampStage>
Returns a new builder.
Sourceimpl SinglePoint
impl SinglePoint
Sourcepub fn new(
timestamp: Timestamp,
value: Value,
precision_loss: bool,
) -> SinglePoint
pub fn new( timestamp: Timestamp, value: Value, precision_loss: bool, ) -> SinglePoint
Constructs a new instance of the type.
pub fn timestamp(&self) -> &Timestamp
pub fn value(&self) -> &Value
Sourcepub fn precision_loss(&self) -> bool
pub fn precision_loss(&self) -> bool
Returns true if the result required downcasting to a type with less precision, for example if the input series was Int64 and the result is a Float64.