pub struct StabilityDetectionRanges { /* private fields */ }Expand description
Outputs a set of ranges where the input series is stable. For each point, the min and max are calculated over the specified lookback window, including the current point. A point is considered stable if its value does not deviate from the calculated min and the max by more than the threshold and the total number of points within the window is at least the specified amount. The threshold can be either fixed values or percentages of the value. The lookback window must be strictly positive. The minimum points threshold defaults to 2.
Implementations
Sourceimpl StabilityDetectionRanges
impl StabilityDetectionRanges
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl StabilityDetectionRanges
impl StabilityDetectionRanges
Sourcepub fn new(
input: NumericSeries,
window_configuration: StabilityWindowConfiguration,
threshold: Threshold,
) -> StabilityDetectionRanges
pub fn new( input: NumericSeries, window_configuration: StabilityWindowConfiguration, threshold: Threshold, ) -> StabilityDetectionRanges
Constructs a new instance of the type.
pub fn input(&self) -> &NumericSeries
pub fn window_configuration(&self) -> &StabilityWindowConfiguration
pub fn threshold(&self) -> &Threshold