pub struct AggregateEnumSeries { /* private fields */ }Expand description
Aggregates values with duplicate timestamps in the input series values into a single value using the specified aggregation function.
Implementations
Sourceimpl AggregateEnumSeries
impl AggregateEnumSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl AggregateEnumSeries
impl AggregateEnumSeries
Sourcepub fn new(
input: EnumSeries,
function: EnumAggregationFunction,
) -> AggregateEnumSeries
pub fn new( input: EnumSeries, function: EnumAggregationFunction, ) -> AggregateEnumSeries
Constructs a new instance of the type.
pub fn input(&self) -> &EnumSeries
pub fn function(&self) -> &EnumAggregationFunction