pub struct DataSourceChannel { /* private fields */ }Implementations
Sourceimpl DataSourceChannel
impl DataSourceChannel
Sourcepub fn builder() -> Builder<DataSourceRidStage>
pub fn builder() -> Builder<DataSourceRidStage>
Returns a new builder.
Sourceimpl DataSourceChannel
impl DataSourceChannel
Sourcepub fn new(
data_source_rid: StringConstant,
channel: StringConstant,
) -> DataSourceChannel
pub fn new( data_source_rid: StringConstant, channel: StringConstant, ) -> DataSourceChannel
Constructs a new instance of the type.
pub fn data_source_rid(&self) -> &StringConstant
pub fn channel(&self) -> &StringConstant
👎Deprecated:
Use tagFilters
Sourcepub fn tag_filters(&self) -> Option<&TagFilters>
pub fn tag_filters(&self) -> Option<&TagFilters>
Tags to filter the channel by. Only returns points from the channel where tag values match the provided expression. For log series, include arg filters here in addition to tag filters.
👎Deprecated:
Use groupByTags instead. Throws if both tagsToGroupBy and groupByTags are specified.
Tags that the channel should be grouped by. If this is non-empty a grouped result will be returned with an entry for each grouping. Only one of tagsToGroupBy and groupByTags should be specified.