pub struct EnumHistogramBucket { /* private fields */ }Expand description
A bucket in an enum histogram representing all the counts for a specific enumerated value, across all input series.
Implementations
Sourceimpl EnumHistogramBucket
impl EnumHistogramBucket
Sourcepub fn builder() -> Builder<ValueStage>
pub fn builder() -> Builder<ValueStage>
Returns a new builder.
Sourceimpl EnumHistogramBucket
impl EnumHistogramBucket
Sourcepub fn new(value: impl Into<String>) -> EnumHistogramBucket
pub fn new(value: impl Into<String>) -> EnumHistogramBucket
Constructs a new instance of the type.
pub fn counts_by_channel( &self, ) -> &BTreeMap<VariableName, HistogramChannelCount>