pub struct EventTimeShift { /* private fields */ }Expand description
Shift by the start timestamp of the first event (ascending) from this query whose event time lies in the tagging interval [start, end). Query may differ from tagging events.
Implementations
Sourceimpl EventTimeShift
impl EventTimeShift
Sourcepub fn builder() -> Builder<QueryStage>
pub fn builder() -> Builder<QueryStage>
Returns a new builder.
Sourceimpl EventTimeShift
impl EventTimeShift
Sourcepub fn new(query: ComputeEventQuery) -> Self
pub fn new(query: ComputeEventQuery) -> Self
Constructs a new instance of the type.
pub fn query(&self) -> &ComputeEventQuery