pub struct ExtractEnumFromStructSeries { /* private fields */ }Implementations
Sourceimpl ExtractEnumFromStructSeries
impl ExtractEnumFromStructSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl ExtractEnumFromStructSeries
impl ExtractEnumFromStructSeries
Sourcepub fn new(input: StructSeries) -> ExtractEnumFromStructSeries
pub fn new(input: StructSeries) -> ExtractEnumFromStructSeries
Constructs a new instance of the type.
pub fn input(&self) -> &StructSeries
Sourcepub fn field_path(&self) -> &[StringConstant]
pub fn field_path(&self) -> &[StringConstant]
Path segments that are joined to locate a nested enum field. Use dots to traverse
objects (e.g. a.b.c) and 0-based brackets to index into arrays (e.g. items[0].value).
A bare numeric name like 0 refers to an object key named “0”; use [0] to index
into an array. Rows where the path is invalid or resolves to a nested object rather
than a scalar are filtered out.