pub struct ExtractNumericFromStructSeries { /* private fields */ }Implementations
Sourceimpl ExtractNumericFromStructSeries
impl ExtractNumericFromStructSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl ExtractNumericFromStructSeries
impl ExtractNumericFromStructSeries
Sourcepub fn new(input: StructSeries) -> ExtractNumericFromStructSeries
pub fn new(input: StructSeries) -> ExtractNumericFromStructSeries
Constructs a new instance of the type.
pub fn input(&self) -> &StructSeries
Sourcepub fn field_path(&self) -> &[StringConstant]
pub fn field_path(&self) -> &[StringConstant]
Path segments that are joined to locate a nested numeric field. Use dots to traverse
objects (e.g. a.b.c) and 0-based brackets to index into arrays (e.g. items[0].value).
A bare numeric name like 0 refers to an object key named “0”; use [0] to index
into an array. Rows where the path is invalid or the value cannot be converted to the
specified type are filtered out.
Sourcepub fn data_type(&self) -> Option<&NumericDataType>
pub fn data_type(&self) -> Option<&NumericDataType>
The type the numeric data will be cast to, defaults to FLOAT64