pub struct ExtractStructFromStructSeries { /* private fields */ }Implementations
Sourceimpl ExtractStructFromStructSeries
impl ExtractStructFromStructSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl ExtractStructFromStructSeries
impl ExtractStructFromStructSeries
Sourcepub fn new(input: StructSeries) -> Self
pub fn new(input: StructSeries) -> Self
Constructs a new instance of the type.
pub fn input(&self) -> &StructSeries
Sourcepub fn field_path(&self) -> &[StringConstant]
pub fn field_path(&self) -> &[StringConstant]
Path segments that are joined to locate a nested struct field. Use dots to traverse
objects (e.g. a.b.c) and 0-based brackets to index into arrays (e.g. items[0].value).
A bare numeric name like 0 refers to an object key named “0”; use [0] to index
into an array. Returns an empty struct when the path does not resolve to a valid
JSON object.