pub struct ForwardFillResampleInterpolationConfiguration {}Expand description
Forward fill interpolation for resampling. Rounds the earliest and latest timestamp up to the nearest interval multiple and generates timestamps at the given interval between the new earliest and latest timestamps. For every timestamp in the resampled timestamps, takes the last known value before the timestamp as the value.
Implementations
Sourceimpl ForwardFillResampleInterpolationConfiguration
impl ForwardFillResampleInterpolationConfiguration
Sourcepub fn new() -> ForwardFillResampleInterpolationConfiguration
pub fn new() -> ForwardFillResampleInterpolationConfiguration
Constructs a new instance of the type.