pub struct LogUnionSeries { /* private fields */ }Expand description
Combines multiple log series together and outputs a single series. The strategy to merge input values with the same timestamp together is specified in the operation field.
Implementations
Sourceimpl LogUnionSeries
impl LogUnionSeries
Sourcepub fn builder() -> Builder<OperationStage>
pub fn builder() -> Builder<OperationStage>
Returns a new builder.
Sourceimpl LogUnionSeries
impl LogUnionSeries
Sourcepub fn new(operation: LogUnionOperation) -> LogUnionSeries
pub fn new(operation: LogUnionOperation) -> LogUnionSeries
Constructs a new instance of the type.
pub fn input(&self) -> &[LogSeries]
Sourcepub fn operation(&self) -> &LogUnionOperation
pub fn operation(&self) -> &LogUnionOperation
The strategy to merge points with duplicate timestamps.