pub struct MeanSeries { /* private fields */ }Expand description
For every timestamp specified in the input series, outputs a value that is the mean for that timestamp across all input series. Only outputs timestamps where all input series have an entry for that timestamp, subject to interpolation.
Implementations
Sourceimpl MeanSeries
impl MeanSeries
Sourcepub fn new() -> MeanSeries
pub fn new() -> MeanSeries
Constructs a new instance of the type.
Sourcepub fn inputs(&self) -> &[NumericSeries]
pub fn inputs(&self) -> &[NumericSeries]
Input series across which to take the pointwise mean
Sourcepub fn interpolation_configuration(&self) -> Option<&InterpolationConfiguration>
👎Deprecated: Setting interpolation on this node is deprecated.
pub fn interpolation_configuration(&self) -> Option<&InterpolationConfiguration>
Setting interpolation on this node is deprecated.
Defaults to forward fill interpolation with a 1s interpolation radius