pub struct NumericAggregationUdf { /* private fields */ }Expand description
A user-defined numeric aggregation. The aggregation builder controls grouping/windowing.
Supported Rust entrypoints accept grouped value vectors, optionally with leading sample timestamps,
and return either one numeric value or timestamped numeric point(s), e.g.
fn rms(values: Vec<f64>) -> f64,
fn energy(timestamp_ns: Vec<i64>, values: Vec<f64>) -> f64,
fn first(timestamp_ns: Vec<i64>, values: Vec<f64>) -> (i64, f64), or
fn passthrough(timestamp_ns: Vec<i64>, values: Vec<f64>) -> Vec<(i64, f64)>.
Implementations
Sourceimpl NumericAggregationUdf
impl NumericAggregationUdf
Sourcepub fn builder() -> Builder<SourceStage>
pub fn builder() -> Builder<SourceStage>
Returns a new builder.