NumericBucket

Struct NumericBucket 

pub struct NumericBucket { /* private fields */ }

Implementations

Source

impl NumericBucket

pub fn builder() -> Builder<Complete>

Returns a new builder.

Source

impl NumericBucket

pub fn new() -> NumericBucket

Constructs a new instance of the type.

pub fn min(&self) -> Option<f64>

pub fn max(&self) -> Option<f64>

pub fn mean(&self) -> Option<f64>

pub fn count(&self) -> Option<SafeLong>

pub fn variance(&self) -> Option<f64>

The population variance of the bucket. If the bucket has only one value, this will be 0.

pub fn first_point(&self) -> Option<&NumericPoint>

pub fn last_point(&self) -> Option<&NumericPoint>

Will be empty if the bucket only has a single point.

pub fn aggregations(&self) -> &BTreeMap<String, f64>

Additional per-bucket aggregations that have no dedicated field above, keyed by the output column name requested via numericAggregations or numericOutputFieldsV2 (e.g. sum, standardDeviation, rootMeanSquare, p50). Empty when no additional aggregations were requested.