pub struct NumericHistogramBucket { /* private fields */ }Expand description
A bucket in a numeric histogram representing a range of values, and the counts of values in that range across all input series.
Implementations
Sourceimpl NumericHistogramBucket
impl NumericHistogramBucket
Sourcepub fn builder() -> Builder<LowerBoundStage>
pub fn builder() -> Builder<LowerBoundStage>
Returns a new builder.
Sourceimpl NumericHistogramBucket
impl NumericHistogramBucket
Sourcepub fn new(lower_bound: f64, upper_bound: f64) -> NumericHistogramBucket
pub fn new(lower_bound: f64, upper_bound: f64) -> NumericHistogramBucket
Constructs a new instance of the type.
Sourcepub fn lower_bound(&self) -> f64
pub fn lower_bound(&self) -> f64
The lower bound of the bucket, inclusive
Sourcepub fn upper_bound(&self) -> f64
pub fn upper_bound(&self) -> f64
The upper bound of the bucket, exclusive
pub fn counts_by_channel( &self, ) -> &BTreeMap<VariableName, HistogramChannelCount>
pub fn buckets(&self) -> &BTreeMap<VariableName, HistogramChannelCount>
👎Deprecated:
Use countsByChannel instead