pub struct NumericPlot { /* private fields */ }Implementations
Sourceimpl NumericPlot
impl NumericPlot
pub fn timestamps(&self) -> &[Timestamp]
pub fn values(&self) -> &[f64]
Sourcepub fn next_page_token(&self) -> Option<&PageToken>
pub fn next_page_token(&self) -> Option<&PageToken>
Continuation token for this paged result. Can only be returned if paging was requested.
To retrieve the next page, repeat the same request with this
value as pageToken and keep the pageSize sign unchanged. Returned only when this response
contains exactly abs(pageSize) points; the next response may still be empty if this page ended exactly at
the result-set boundary. Empty means this response was short and there are no further points in the
requested direction.