pub struct NumericUnionSeries { /* private fields */ }Expand description
Combines multiple numeric series together and outputs a single series. By default, points from the inputs are concatenated (SQL {@code UNION ALL}) and duplicate timestamps across inputs are preserved. To aggregate values that share a timestamp, do a separate aggregation step next.
Implementations
Sourceimpl NumericUnionSeries
impl NumericUnionSeries
Sourcepub fn input(&self) -> &[NumericSeries]
pub fn input(&self) -> &[NumericSeries]
Input series to union
Sourcepub fn operation(&self) -> Option<&NumericUnionOperation>
👎Deprecated: Apply aggregations as a separate step over the unioned output.
pub fn operation(&self) -> Option<&NumericUnionOperation>
Apply aggregations as a separate step over the unioned output.
The strategy to merge points with duplicate timestamps.