pub struct OnChangeSeries { /* private fields */ }Expand description
Outputs a boolean series that is true at each point where the series value differs from the preceding point, and false otherwise. The first point always outputs false.
Implementations
Sourceimpl OnChangeSeries
impl OnChangeSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.