pub struct PeakRanges { /* private fields */ }Expand description
Produces a list of ranges for each point that is greater than its neighbors. Peaks at edges are discarded, and continuous, multivalue, flat peaks will return all values.
Implementations
Sourceimpl PeakRanges
impl PeakRanges
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl PeakRanges
impl PeakRanges
Sourcepub fn new(input: NumericSeries) -> PeakRanges
pub fn new(input: NumericSeries) -> PeakRanges
Constructs a new instance of the type.
pub fn input(&self) -> &NumericSeries
Sourcepub fn returns_peaks(&self) -> Option<bool>
👎Deprecated: No longer used, use returnType instead
pub fn returns_peaks(&self) -> Option<bool>
No longer used, use returnType instead
True if returning peaks, else troughs.
Sourcepub fn return_type(&self) -> Option<&PeakType>
pub fn return_type(&self) -> Option<&PeakType>
Optional for backcompatibility.
Sourcepub fn minimum_prominence(&self) -> Option<&DoubleConstant>
pub fn minimum_prominence(&self) -> Option<&DoubleConstant>
The minimum topographic prominence for an extrema to be returned. Prominence is the minimum vertical distance needed to travel from an extrema to one of greater magnitude.