pub struct RangesSummary { /* private fields */ }Expand description
A summary of the ranges returned from a SummarizeRanges request. Returned when the number of ranges found is above a threshold.
Implementations
Sourceimpl RangesSummary
impl RangesSummary
Sourcepub fn new() -> RangesSummary
pub fn new() -> RangesSummary
Constructs a new instance of the type.
pub fn ranges_summary(&self) -> &[RangeSummary]