pub struct ScalarUdfSeries { /* private fields */ }Expand description
Executes user-provided scalar UDF code over aligned inputs. The function must return one output for each aligned input row, with the return type matching the series type that contains this node.
Implementations
Sourceimpl ScalarUdfSeries
impl ScalarUdfSeries
Sourcepub fn builder() -> Builder<SourceStage>
pub fn builder() -> Builder<SourceStage>
Returns a new builder.