pub struct Scatter { /* private fields */ }Expand description
A scatter plot comprised of the values from one input series on the x-axis and values from another input series on the y-axis, for all points within a requested time range.
Implementations
Sourceimpl Scatter
impl Scatter
Sourcepub fn new(x: NumericSeries, y: NumericSeries) -> Scatter
pub fn new(x: NumericSeries, y: NumericSeries) -> Scatter
Constructs a new instance of the type.
pub fn x(&self) -> &NumericSeries
pub fn y(&self) -> &NumericSeries