pub struct SelectIndexFrom1dEnumArraySeries { /* private fields */ }Expand description
For each timestamp, selects a single enum value from the 1D enum array at the specified index. If the index is out of bounds for an array at a given timestamp, it is omitted.
Implementations
Sourceimpl SelectIndexFrom1dEnumArraySeries
impl SelectIndexFrom1dEnumArraySeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl SelectIndexFrom1dEnumArraySeries
impl SelectIndexFrom1dEnumArraySeries
Sourcepub fn new(
input: Enum1dArraySeries,
index: IntegerConstant,
) -> SelectIndexFrom1dEnumArraySeries
pub fn new( input: Enum1dArraySeries, index: IntegerConstant, ) -> SelectIndexFrom1dEnumArraySeries
Constructs a new instance of the type.
pub fn input(&self) -> &Enum1dArraySeries
pub fn index(&self) -> &IntegerConstant