pub struct SelectIndexFrom1dNumericArraySeries { /* private fields */ }Expand description
For each timestamp, selects a single numeric value from the 1D numeric array at the specified index. If the index is out of bounds for an array at a given timestamp, it is omitted.
Implementations
Sourceimpl SelectIndexFrom1dNumericArraySeries
impl SelectIndexFrom1dNumericArraySeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl SelectIndexFrom1dNumericArraySeries
impl SelectIndexFrom1dNumericArraySeries
Sourcepub fn new(
input: Numeric1dArraySeries,
index: IntegerConstant,
) -> SelectIndexFrom1dNumericArraySeries
pub fn new( input: Numeric1dArraySeries, index: IntegerConstant, ) -> SelectIndexFrom1dNumericArraySeries
Constructs a new instance of the type.
pub fn input(&self) -> &Numeric1dArraySeries
pub fn index(&self) -> &IntegerConstant