pub struct SelectNewestPointsSeries { /* private fields */ }Expand description
Select the most recent N points from the input series by timestamp.
Implementations
Sourceimpl SelectNewestPointsSeries
impl SelectNewestPointsSeries
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl SelectNewestPointsSeries
impl SelectNewestPointsSeries
Sourcepub fn new(
input: NumericSeries,
num_points: IntegerConstant,
) -> SelectNewestPointsSeries
pub fn new( input: NumericSeries, num_points: IntegerConstant, ) -> SelectNewestPointsSeries
Constructs a new instance of the type.
Sourcepub fn input(&self) -> &NumericSeries
pub fn input(&self) -> &NumericSeries
The input series to select the newest points from.
Sourcepub fn num_points(&self) -> &IntegerConstant
pub fn num_points(&self) -> &IntegerConstant
The number of points to select.