pub struct SeriesVariable { /* private fields */ }Expand description
A series selected from a dataset, bound to a variable. The series type (numeric, enum, …) is decided lazily by the node consuming the variable, matching the behaviour of channel variables.
Implementations
Sourceimpl SeriesVariable
impl SeriesVariable
Sourcepub fn builder() -> Builder<SelectStage>
pub fn builder() -> Builder<SelectStage>
Returns a new builder.
Sourceimpl SeriesVariable
impl SeriesVariable
Sourcepub fn new(select: SelectSeries) -> SeriesVariable
pub fn new(select: SelectSeries) -> SeriesVariable
Constructs a new instance of the type.
pub fn select(&self) -> &SelectSeries
Tags that the series should be grouped by. If this is non-empty a grouped result will be returned with an entry for each grouping; otherwise all matching series are merged.