pub struct SpatialDecimateStrategy {}Expand description
Decimate by spatial trees. Creates buckets by bisecting on each dimension, creating quadrants for 2d scatter and octants for 3d scatter. Continues subdividing by prioritizing larger undivided buckets until reaching the max amount of buckets.
Implementations
Sourceimpl SpatialDecimateStrategy
impl SpatialDecimateStrategy
Sourcepub fn new() -> SpatialDecimateStrategy
pub fn new() -> SpatialDecimateStrategy
Constructs a new instance of the type.