SummarizeSeries

Struct SummarizeSeries 

pub struct SummarizeSeries { /* private fields */ }
Summarizes the output of a series node. The output can be a numeric, enum, log, or cartesian series. Summarization strategy should be specified.

Implementations

Source

impl SummarizeSeries

pub fn builder() -> Builder<InputStage>

Returns a new builder.

Source

impl SummarizeSeries

pub fn new(input: Series) -> SummarizeSeries

Constructs a new instance of the type.

pub fn input(&self) -> &Series

pub fn output_format(&self) -> Option<&OutputFormat>

The output format of the response. Defaults to LEGACY.

pub fn numeric_output_fields(&self) -> Option<&BTreeSet<NumericOutputField>>

👎Deprecated:

Use numericOutputFieldsV2 instead.

The fields to output from the summarization. Applies only to Arrow format numeric series.

pub fn numeric_aggregations( &self, ) -> &BTreeMap<String, NumericAggregationOperator>

Additional numeric aggregations per decimation bucket (e.g. percentiles). Map key is the name of the column in the result.

pub fn numeric_output_fields_v2(&self) -> Option<&[NumericOutputFieldV2]>

Numeric bucket output fields to return. Applies only to Arrow format numeric series. Defaults to MEAN when no numeric output selector is specified. Mutually exclusive with numericOutputFields and numericAggregations.

pub fn resolution(&self) -> Option<SafeLong>

👎Deprecated:

Use summarizationStrategy instead.

Resolution of the output series specifying time interval between decimated points, in nanoseconds.

pub fn buckets(&self) -> Option<i32>

👎Deprecated:

Use summarizationStrategy instead.

Number of points to generate in the output series.

pub fn summarization_strategy(&self) -> Option<&SummarizationStrategy>

The strategy to use when summarizing the series.