pub struct WithEnumSeriesDataset { /* private fields */ }Expand description
Adds a derived enum series to the base dataset. If a series with the same name already exists, then it will be replaced.
Implementations
Sourceimpl WithEnumSeriesDataset
impl WithEnumSeriesDataset
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl WithEnumSeriesDataset
impl WithEnumSeriesDataset
Sourcepub fn new(input: Dataset, name: StringConstant, definition: EnumSeries) -> Self
pub fn new(input: Dataset, name: StringConstant, definition: EnumSeries) -> Self
Constructs a new instance of the type.
Sourcepub fn name(&self) -> &StringConstant
pub fn name(&self) -> &StringConstant
Name of the new derived series.
Sourcepub fn definition(&self) -> &EnumSeries
pub fn definition(&self) -> &EnumSeries
Compute expression defining the series values.