pub struct WithNumericSeriesDataset { /* private fields */ }Expand description
Adds a derived numeric series to the base dataset. If a series with the same name already exists, then it will be replaced.
Implementations
Sourceimpl WithNumericSeriesDataset
impl WithNumericSeriesDataset
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl WithNumericSeriesDataset
impl WithNumericSeriesDataset
Sourcepub fn new(
input: Dataset,
name: StringConstant,
definition: NumericSeries,
) -> Self
pub fn new( input: Dataset, name: StringConstant, definition: NumericSeries, ) -> Self
Constructs a new instance of the type.
Sourcepub fn name(&self) -> &StringConstant
pub fn name(&self) -> &StringConstant
Name of the new derived series.
Sourcepub fn definition(&self) -> &NumericSeries
pub fn definition(&self) -> &NumericSeries
Compute expression defining the series values.