Module with_enum_series_dataset

Module with_enum_series_dataset 

Structs

Builder
A builder for WithEnumSeriesDataset
Complete
The final stage for WithEnumSeriesDataset.
DefinitionStage
The definition stage for Builder.
InputStage
The input stage for Builder.
NameStage
The name stage for Builder.
WithEnumSeriesDataset
Adds a derived enum series to the base dataset. If a series with the same name already exists, then it will be replaced.