Module with_enum_series_frame

Module with_enum_series_frame 

Structs

Builder
A builder for WithEnumSeriesFrame
Complete
The final stage for WithEnumSeriesFrame.
DefinitionStage
The definition stage for Builder.
InputStage
The input stage for Builder.
NameStage
The name stage for Builder.
WithEnumSeriesFrame
Adds a derived enum series to the base frame. If a series with the same name already exists, then it will be replaced.