Module with_numeric_series_dataset

Module with_numeric_series_dataset 

Structs

Builder
A builder for WithNumericSeriesDataset
Complete
The final stage for WithNumericSeriesDataset.
DefinitionStage
The definition stage for Builder.
InputStage
The input stage for Builder.
NameStage
The name stage for Builder.
WithNumericSeriesDataset
Adds a derived numeric series to the base dataset. If a series with the same name already exists, then it will be replaced.