pub struct WithNumericSeriesFrame { /* private fields */ }Expand description
Adds a derived numeric series to the base frame. If a series with the same name already exists, then it will be replaced.
Implementations
Sourceimpl WithNumericSeriesFrame
impl WithNumericSeriesFrame
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl WithNumericSeriesFrame
impl WithNumericSeriesFrame
Sourcepub fn new(
input: TimeSeriesFrame,
name: StringConstant,
definition: NumericSeries,
) -> Self
pub fn new( input: TimeSeriesFrame, name: StringConstant, definition: NumericSeries, ) -> Self
Constructs a new instance of the type.
Sourcepub fn input(&self) -> &TimeSeriesFrame
pub fn input(&self) -> &TimeSeriesFrame
The base frame to which the new series will be added.
Sourcepub fn name(&self) -> &StringConstant
pub fn name(&self) -> &StringConstant
Name of the new derived series.
Sourcepub fn definition(&self) -> &NumericSeries
pub fn definition(&self) -> &NumericSeries
Compute expression defining the series values.