Module combined_source_read_node

Module combined_source_read_node 

Structs

Builder
A builder for CombinedSourceReadNode
ChannelStage
The channel stage for Builder.
CombinedSourceReadNode
A single raw read over multiple Nominal storage sources (e.g., assets/runs). More efficient than unionAll of per-source raw reads. The fields that every source shares are hoisted here.
Complete
The final stage for CombinedSourceReadNode.
DatasetBackingTypeStage
The dataset_backing_type stage for Builder.
OrgRidStage
The org_rid stage for Builder.
TypeStage
The type_ stage for Builder.