pub struct PhaseUnwrapSeriesNode { /* private fields */ }Expand description
Removes discontinuities from a wrapping signal by adding whole multiples of period
whenever the step between consecutive samples exceeds half the period.
Implementations
Sourceimpl PhaseUnwrapSeriesNode
impl PhaseUnwrapSeriesNode
Sourcepub fn builder() -> Builder<InputStage>
pub fn builder() -> Builder<InputStage>
Returns a new builder.
Sourceimpl PhaseUnwrapSeriesNode
impl PhaseUnwrapSeriesNode
Sourcepub fn new(input: NumericSeriesNode, period: f64) -> PhaseUnwrapSeriesNode
pub fn new(input: NumericSeriesNode, period: f64) -> PhaseUnwrapSeriesNode
Constructs a new instance of the type.
pub fn input(&self) -> &NumericSeriesNode
pub fn period(&self) -> f64