pub struct AllTimestampsForwardFillStrategy { /* private fields */ }Expand description
All timestamps will be kept. The value of a channel at a timestamp will be its latest value, within the provided look back period.
Implementations
Sourceimpl AllTimestampsForwardFillStrategy
impl AllTimestampsForwardFillStrategy
Sourcepub fn builder() -> Builder<LookBackPeriodStage>
pub fn builder() -> Builder<LookBackPeriodStage>
Returns a new builder.
Sourceimpl AllTimestampsForwardFillStrategy
impl AllTimestampsForwardFillStrategy
Sourcepub fn new(look_back_period: Duration) -> AllTimestampsForwardFillStrategy
pub fn new(look_back_period: Duration) -> AllTimestampsForwardFillStrategy
Constructs a new instance of the type.
pub fn look_back_period(&self) -> &Duration