pub struct ExportChannelFailure { /* private fields */ }Expand description
Describes one requested export column that could not be exported.
Implementations
Sourceimpl ExportChannelFailure
impl ExportChannelFailure
Sourcepub fn builder() -> Builder<ColumnNameStage>
pub fn builder() -> Builder<ColumnNameStage>
Returns a new builder.
Sourceimpl ExportChannelFailure
impl ExportChannelFailure
Sourcepub fn new(column_name: impl Into<String>, error: SerializableError) -> Self
pub fn new(column_name: impl Into<String>, error: SerializableError) -> Self
Constructs a new instance of the type.
Sourcepub fn column_name(&self) -> &str
pub fn column_name(&self) -> &str
User-visible export column name from the request.
Sourcepub fn error(&self) -> &SerializableError
pub fn error(&self) -> &SerializableError
Error explaining why this export column could not be exported.