pub struct NoneStrategy {}Expand description
Do nothing. The value of a channel will be empty at timestamps not present in its original time series.
Implementations
Sourceimpl NoneStrategy
impl NoneStrategy
Sourcepub fn new() -> NoneStrategy
pub fn new() -> NoneStrategy
Constructs a new instance of the type.