Module api

Module api 

Modules

batch_data_frame_metadata
batch_data_source_streaming_support
batch_get_data_frame_metadata_request
batch_streaming_support
data_frame_metadata
data_source_streaming_support
get_data_frame_metadata_request
streaming_not_supported_reason
streaming_support

Structs

BatchDataFrameMetadata
Metadata about a data frame.
BatchDataSourceStreamingSupport
Diagnostic details for a data source within a batched metadata request that does not support streaming.
BatchGetDataFrameMetadataRequest
Batched form of getDataFrameMetadata. The map key of requests can be an arbitrary string identifier and is returned in diagnostic requestIds.
BatchStreamingSupport
Whether the data frame supports live streaming, plus unsupported data source diagnostics.
DataFrameMetadata
Metadata about a data frame.
DataSourceStreamingSupport
Diagnostic details for a data source within the data frame that does not support streaming.
GetDataFrameMetadataRequest
Data frame metadata request.
StreamingSupport
Whether the data frame supports live streaming, plus unsupported data source diagnostics.

Enums

StreamingNotSupportedReason
Why a particular data source within the dataframedoes not support streaming.