pub struct BatchStreamingSupport { /* private fields */ }Expand description
Whether the data frame supports live streaming, plus unsupported data source diagnostics.
Implementations
Sourceimpl BatchStreamingSupport
impl BatchStreamingSupport
Sourcepub fn builder() -> Builder<SupportsStreamingStage>
pub fn builder() -> Builder<SupportsStreamingStage>
Returns a new builder.
Sourceimpl BatchStreamingSupport
impl BatchStreamingSupport
Sourcepub fn supports_streaming(&self) -> bool
pub fn supports_streaming(&self) -> bool
True iff unsupportedDataSources is empty.
Sourcepub fn unsupported_data_sources(&self) -> &[BatchDataSourceStreamingSupport]
pub fn unsupported_data_sources(&self) -> &[BatchDataSourceStreamingSupport]
Diagnostic entries for data sources reachable from the data frame that do not support live streaming. A data source may appear multiple times if multiple checks fail.