pub struct DataSourceStreamingSupport { /* private fields */ }Expand description
Diagnostic details for a data source within the data frame that does not support streaming.
Implementations
Sourceimpl DataSourceStreamingSupport
impl DataSourceStreamingSupport
Sourcepub fn builder() -> Builder<DataSourceStage>
pub fn builder() -> Builder<DataSourceStage>
Returns a new builder.
Sourceimpl DataSourceStreamingSupport
impl DataSourceStreamingSupport
Sourcepub fn new(
data_source: DataSource,
unsupported_reason: StreamingNotSupportedReason,
) -> Self
pub fn new( data_source: DataSource, unsupported_reason: StreamingNotSupportedReason, ) -> Self
Constructs a new instance of the type.
pub fn data_source(&self) -> &DataSource
Sourcepub fn unsupported_reason(&self) -> &StreamingNotSupportedReason
pub fn unsupported_reason(&self) -> &StreamingNotSupportedReason
Why this data source does not support live streaming.