pub struct StreamingSupport { /* private fields */ }Expand description
Whether the data frame supports live streaming, plus unsupported data source diagnostics.
Implementations
Sourceimpl StreamingSupport
impl StreamingSupport
Sourcepub fn builder() -> Builder<SupportsStreamingStage>
pub fn builder() -> Builder<SupportsStreamingStage>
Returns a new builder.
Sourceimpl StreamingSupport
impl StreamingSupport
Sourcepub fn supports_streaming(&self) -> bool
pub fn supports_streaming(&self) -> bool
True iff unsupportedDataSources is empty.
Sourcepub fn unsupported_data_sources(&self) -> &[DataSourceStreamingSupport]
pub fn unsupported_data_sources(&self) -> &[DataSourceStreamingSupport]
Diagnostic entries for data sources reachable from the data frame that do not support live streaming. A data source may appear multiple times if multiple checks fail.