Skip to main content Module api Copy item path Source archive_data_review automatic_check_evaluation automatic_check_evaluation_action automatic_check_evaluation_action_log automatic_check_evaluation_action_log_entry automatic_check_evaluation_review_action automatic_check_evaluation_review_action_log automatic_check_evaluation_review_action_log_entry automatic_check_evaluation_state automatic_check_execution_failed_to_run automatic_check_execution_finished automatic_check_execution_started batch_automatic_check_evaluation_action_request batch_automatic_check_evaluation_action_response batch_check_alert_action_request batch_check_alert_action_response batch_initiate_data_review_request batch_initiate_data_review_response batch_manual_check_evaluation_action_request check_alert check_alert_action check_alert_action_log check_alert_action_log_entry check_alert_status check_alerts_histogram_buckets check_alerts_histogram_request check_alerts_histogram_response check_alerts_priority_histogram check_alerts_status_histogram check_alerts_unstacked_histogram check_evaluation checklist_evaluation close_action close_all_linked_alerts close_and_detach_from_notebook close_and_duplicate_previously_linked_notebook close_and_link_to_notebook close_strategy close_with_further_action close_with_ignore_alert closed_with_further_action_state create_data_review_request data_review data_review_check_metrics_scope data_review_page duplicate_and_link_notebook executing_state execution_retriggered failed_to_execute_state find_data_reviews_request generated_alerts_state get_data_review_check_metrics_request get_data_review_check_metrics_response histogram_bucket histogram_distribution_variable histogram_end_time_variable histogram_priority_bucket histogram_priority_variable histogram_start_time_variable histogram_status_bucket histogram_status_variable histogram_sub_group_variable link_notebook link_notebook_strategy manual_check_alert_action manual_check_evaluation manual_check_evaluation_action_log manual_check_evaluation_action_log_entry manual_check_evaluation_rid manual_check_evaluation_state pass pass_state passing_execution_state pending_execution_state pending_review_state reassign reopen reopen_all_linked_alerts reopen_and_detach_from_notebook reopen_and_duplicate_previously_linked_notebook reopen_and_link_to_notebook reopen_strategy rerun_failed_automatic_checks_request search_check_alerts_request search_check_alerts_response search_check_alerts_sort_field search_check_alerts_sort_options status too_many_alerts_state unarchive_data_review unlink_notebook update_notes ArchiveDataReview Archive the data review which created this check alert. Only performable via the archive data review endpoint;
not supported by Perform Check Alert Action. AutomaticCheckEvaluation AutomaticCheckEvaluationActionLog AutomaticCheckEvaluationActionLogEntry AutomaticCheckEvaluationReviewActionLog AutomaticCheckEvaluationReviewActionLogEntry AutomaticCheckExecutionFailedToRun AutomaticCheckExecutionFinished AutomaticCheckExecutionStarted BatchAutomaticCheckEvaluationActionRequest BatchAutomaticCheckEvaluationActionResponse BatchCheckAlertActionRequest BatchCheckAlertActionResponse BatchInitiateDataReviewRequest BatchInitiateDataReviewResponse Responses are returned in the same order as the requests. BatchManualCheckEvaluationActionRequest CheckAlert CheckAlertActionLog CheckAlertActionLogEntry CheckAlertsHistogramRequest CheckAlertsHistogramResponse CheckAlertsPriorityHistogram CheckAlertsStatusHistogram CheckAlertsUnstackedHistogram ChecklistEvaluation CloseAllLinkedAlerts Close all alerts associated with the same notebook with the same comment. CloseAndDetachFromNotebook Close the alert and detach it from the notebook. If the alert is linked to the same notebook as other
alerts, those alerts will maintain the reference to the notebook and the notebook will remain unlocked. CloseAndDuplicatePreviouslyLinkedNotebook Close the alert and detach it from the notebook. If the alert is linked to the same notebook as other
alerts, the notebook will be duplicated and the alert will be linked to the new notebook. The new notebook
will be locked. CloseAndLinkToNotebook Close the alert and link to notebook. Throws if the associated notebook has open alerts. CloseWithFurtherAction Close the alert with further action. If the alert is linked to the same notebook as other alerts, the other
alerts will also be closed with further action. This will also lock the associated notebook. CloseWithIgnoreAlert Close the alert with ignore. If the alert is linked to the same notebook as other alerts, the other
alerts will also be closed with ignore. This will also lock the associated notebook. ClosedWithFurtherActionState CreateDataReviewRequest If commit not is provided, the latest commit on main will be used.
Asset RID is required only for multi-asset runs. DataReview DataReviewPage DuplicateAndLinkNotebook Duplicate the notebook and link the alert to it. ExecutingState ExecutionRetriggered FailedToExecuteState FindDataReviewsRequest If both sets are empty, an empty page is returned.
If one set is empty, that field is not considered for filtering (like a wildcard).
If commitId is omitted from a ChecklistRef, it will match all commits. GeneratedAlertsState GetDataReviewCheckMetricsRequest GetDataReviewCheckMetricsResponse HistogramBucket HistogramEndTimeVariable HistogramPriorityBucket HistogramPriorityVariable HistogramStartTimeVariable HistogramStatusBucket HistogramStatusVariable LinkNotebook ManualCheckEvaluation ManualCheckEvaluationActionLog ManualCheckEvaluationActionLogEntry ManualCheckEvaluationRid Pass PassState PassingExecutionState PendingExecutionState PendingReviewState Reassign Reopen ReopenAllLinkedAlerts Reopen all alerts associated with the same notebook and unlock the notebook. ReopenAndDetachFromNotebook Reopen the alert and detach it from the notebook. If the alert is linked to the same notebook as other
alerts, those alerts will maintain the reference to the notebook and the notebook will remain locked. ReopenAndDuplicatePreviouslyLinkedNotebook Reopen the alert and detach it from the notebook. If the alert is linked to the same notebook as other
alerts, the notebook will be duplicated and the alert will be linked to the new notebook. The new notebook
will be unlocked. ReopenAndLinkToNotebook Reopen the alert and link to notebook. Throws if the associated notebook has closed alerts. RerunFailedAutomaticChecksRequest SearchCheckAlertsRequest SearchCheckAlertsResponse SearchCheckAlertsSortOptions TooManyAlertsState The number of generated alerts is greater than the maximum. The check is likely misconfigured. UnarchiveDataReview Unarchive the data review which created this check alert. Only performable via the unarchive data review
endpoint; not supported by Perform Check Alert Action. UnlinkNotebook UpdateNotes AutomaticCheckEvaluationAction AutomaticCheckEvaluationReviewAction AutomaticCheckEvaluationState CheckAlertAction CheckAlertStatus CheckAlertsHistogramBuckets CheckEvaluation CloseAction CloseStrategy DataReviewCheckMetricsScope HistogramDistributionVariable HistogramSubGroupVariable LinkNotebookStrategy ManualCheckAlertAction ManualCheckEvaluationState ReopenStrategy SearchCheckAlertsSortField Status