pub struct ReopenAndDuplicatePreviouslyLinkedNotebook {}Expand description
Reopen the alert and detach it from the notebook. If the alert is linked to the same notebook as other alerts, the notebook will be duplicated and the alert will be linked to the new notebook. The new notebook will be unlocked.
Implementations
Sourceimpl ReopenAndDuplicatePreviouslyLinkedNotebook
impl ReopenAndDuplicatePreviouslyLinkedNotebook
Sourcepub fn new() -> ReopenAndDuplicatePreviouslyLinkedNotebook
pub fn new() -> ReopenAndDuplicatePreviouslyLinkedNotebook
Constructs a new instance of the type.