Modules
- batch_
data_ source_ streaming_ support - batch_
dataset_ metadata - batch_
get_ dataset_ metadata_ request - batch_
streaming_ support - data_
source_ streaming_ support - dataset_
metadata - get_
dataset_ metadata_ request - streaming_
not_ supported_ reason - streaming_
support
Structs
- Batch
Data Source Streaming Support - Diagnostic details for a data source within a batched metadata request that does not support streaming.
- Batch
Dataset Metadata - Metadata about a dataset.
- Batch
GetDataset Metadata Request - Batched form of
getDatasetMetadata. The map key ofrequestscan be an arbitrary string identifier and is returned in diagnosticrequestIds. - Batch
Streaming Support - Whether the dataset supports live streaming, plus unsupported data source diagnostics.
- Data
Source Streaming Support - Diagnostic details for a data source within the dataset that does not support streaming.
- Dataset
Metadata - Metadata about a dataset.
- GetDataset
Metadata Request - Dataset metadata request.
- Streaming
Support - Whether the dataset supports live streaming, plus unsupported data source diagnostics.
Enums
- Streaming
NotSupported Reason - Why a particular data source within the dataset does not support streaming.