pub struct BatchDataSourceStreamingSupport { /* private fields */ }Expand description
Diagnostic details for a data source within a batched metadata request that does not support streaming.
Implementations
Sourceimpl BatchDataSourceStreamingSupport
impl BatchDataSourceStreamingSupport
Sourcepub fn builder() -> Builder<DataSourceStage>
pub fn builder() -> Builder<DataSourceStage>
Returns a new builder.
Sourceimpl BatchDataSourceStreamingSupport
impl BatchDataSourceStreamingSupport
Sourcepub fn new(
data_source: DataSource,
unsupported_reason: StreamingNotSupportedReason,
) -> BatchDataSourceStreamingSupport
pub fn new( data_source: DataSource, unsupported_reason: StreamingNotSupportedReason, ) -> BatchDataSourceStreamingSupport
Constructs a new instance of the type.
pub fn data_source(&self) -> &DataSource
Sourcepub fn unsupported_reason(&self) -> &StreamingNotSupportedReason
pub fn unsupported_reason(&self) -> &StreamingNotSupportedReason
Why this data source does not support live streaming.
Sourcepub fn request_ids(&self) -> &BTreeSet<String>
pub fn request_ids(&self) -> &BTreeSet<String>
Request ids of the datasets that included this data source.