pub struct BigQueryChannelNameComponent { /* private fields */ }Implementations
Sourceimpl BigQueryChannelNameComponent
impl BigQueryChannelNameComponent
Sourcepub fn builder() -> Builder<IncludeProjectStage>
pub fn builder() -> Builder<IncludeProjectStage>
Returns a new builder.
Sourceimpl BigQueryChannelNameComponent
impl BigQueryChannelNameComponent
Sourcepub fn new(
include_project: bool,
include_dataset: bool,
include_table: bool,
) -> BigQueryChannelNameComponent
pub fn new( include_project: bool, include_dataset: bool, include_table: bool, ) -> BigQueryChannelNameComponent
Constructs a new instance of the type.
Sourcepub fn include_project(&self) -> bool
pub fn include_project(&self) -> bool
Whether to include the project name in the channel name.
Sourcepub fn include_dataset(&self) -> bool
pub fn include_dataset(&self) -> bool
Whether to include the dataset name in the channel name.
Sourcepub fn include_table(&self) -> bool
pub fn include_table(&self) -> bool
Whether to include the table name in the channel name.