pub struct ConnectionPlottingConfiguration { /* private fields */ }Implementations
Sourceimpl ConnectionPlottingConfiguration
impl ConnectionPlottingConfiguration
Sourcepub fn new() -> ConnectionPlottingConfiguration
pub fn new() -> ConnectionPlottingConfiguration
Constructs a new instance of the type.
Sourcepub fn max_undecimated_points_per_page(&self) -> Option<i32>
pub fn max_undecimated_points_per_page(&self) -> Option<i32>
The maximum number of points to return per page for undecimated queries
Sourcepub fn max_unbounded_range(&self) -> Option<SafeLong>
pub fn max_unbounded_range(&self) -> Option<SafeLong>
The maximum range (in nanoseconds) for unbounded queries
Sourcepub fn max_undecimated_page_reads_per_second(&self) -> Option<f64>
pub fn max_undecimated_page_reads_per_second(&self) -> Option<f64>
The maximum number of page reads per second for undecimated queries
Sourcepub fn max_permits_per_second(&self) -> Option<f64>
pub fn max_permits_per_second(&self) -> Option<f64>
The maximum number of permits per second for queries
Sourcepub fn max_connections(&self) -> Option<i32>
pub fn max_connections(&self) -> Option<i32>
The maximum number of connections to the database