pub struct RegisterExternalConnectionConfigRequest { /* private fields */ }Expand description
Internal compatibility request that attaches external connection configuration to an existing dataset. The dataset remains the public resource; the returned connection is a legacy compatibility view.
Implementations
Sourceimpl RegisterExternalConnectionConfigRequest
impl RegisterExternalConnectionConfigRequest
Sourcepub fn builder() -> Builder<DatasetRidStage>
pub fn builder() -> Builder<DatasetRidStage>
Returns a new builder.
Sourceimpl RegisterExternalConnectionConfigRequest
impl RegisterExternalConnectionConfigRequest
Sourcepub fn new(
dataset_rid: DatasetRid,
connection_details: ConnectionDetails,
should_scrape: bool,
) -> Self
pub fn new( dataset_rid: DatasetRid, connection_details: ConnectionDetails, should_scrape: bool, ) -> Self
Constructs a new instance of the type.
pub fn dataset_rid(&self) -> &DatasetRid
pub fn connection_details(&self) -> &ConnectionDetails
Sourcepub fn metadata(&self) -> &BTreeMap<String, String>
pub fn metadata(&self) -> &BTreeMap<String, String>
Metadata information about the external connection configuration.
Sourcepub fn required_tag_names(&self) -> &BTreeSet<TagName>
pub fn required_tag_names(&self) -> &BTreeSet<TagName>
Additional tag names that are required to construct a fully qualified series.
Sourcepub fn available_tag_values(
&self,
) -> Option<&BTreeMap<TagName, BTreeSet<TagValue>>>
pub fn available_tag_values( &self, ) -> Option<&BTreeMap<TagName, BTreeSet<TagValue>>>
Optional externally supplied tag values. In most cases these are indexed by scraping.
pub fn scraping(&self) -> Option<&ScrapingConfig>
pub fn should_scrape(&self) -> bool
pub fn limits(&self) -> Option<&LimitsConfig>