Module metadata

Module metadata 

Modules

conflict_behavior
created_at_query
find_similar_label_matches_request
find_similar_label_matches_response
find_similar_property_key_matches_request
find_similar_property_key_matches_response
get_metadata_usage_count_request
get_metadata_usage_count_response
label_with_count
list_properties_and_labels_request
list_properties_and_labels_response
match_count
merge_property_values_for_key
metadata_change
metadata_sort_field
metadata_usage_query
overwrite_on_conflict
property_key_with_count
property_value_with_count
rename_label
rename_property_key
resource_type
search_labels_response
search_metadata_request
search_property_keys_response
search_property_values_request
search_property_values_response
skip_on_conflict
string_array_length_query

Structs

CreatedAtQuery
FindSimilarLabelMatchesRequest
FindSimilarLabelMatchesResponse
FindSimilarPropertyKeyMatchesRequest
FindSimilarPropertyKeyMatchesResponse
GetMetadataUsageCountRequest
GetMetadataUsageCountResponse
LabelWithCount
ListPropertiesAndLabelsRequest
ListPropertiesAndLabelsResponse
MatchCount
MergePropertyValuesForKey
Merge one or more values of a property key into a single target value.
OverwriteOnConflict
Documents that already have the target property key are included in the rename. The priority list determines which value wins via ordered precedence. Must contain exactly the source keys + target key.
PropertyKeyWithCount
PropertyValueWithCount
RenameLabel
Rename or merge one or more source labels into a single target label.
RenamePropertyKey
Rename one or more source property keys to a single target key. Existing values are preserved under the new key. The rename should be skipped in the service for resources w/ conflicting keys.
SearchLabelsResponse
SearchMetadataRequest
SearchPropertyKeysResponse
SearchPropertyValuesRequest
SearchPropertyValuesResponse
SkipOnConflict
Documents are skipped when:
StringArrayLengthQuery

Enums

ConflictBehavior
MetadataChange
MetadataSortField
MetadataUsageQuery
ResourceType