pub struct OverwriteOnConflict { /* private fields */ }Expand description
Documents that already have the target property key are included in the rename. The priority list determines which value wins via ordered precedence. Must contain exactly the source keys + target key.
Implementations
Sourceimpl OverwriteOnConflict
impl OverwriteOnConflict
pub fn priority(&self) -> &[PropertyName]