pub struct RenamePropertyKey { /* private fields */ }Expand description
Rename one or more source property keys to a single target key. Existing values are preserved under the new key. The rename should be skipped in the service for resources w/ conflicting keys.
Implementations
Sourceimpl RenamePropertyKey
impl RenamePropertyKey
Sourcepub fn builder() -> Builder<TargetStage>
pub fn builder() -> Builder<TargetStage>
Returns a new builder.
Sourceimpl RenamePropertyKey
impl RenamePropertyKey
Sourcepub fn new(target: PropertyName, on_conflict: ConflictBehavior) -> Self
pub fn new(target: PropertyName, on_conflict: ConflictBehavior) -> Self
Constructs a new instance of the type.
pub fn source(&self) -> &BTreeSet<PropertyName>
pub fn target(&self) -> &PropertyName
pub fn on_conflict(&self) -> &ConflictBehavior