pub struct SkipOnConflict {}Expand description
Documents are skipped when:
- The target property key already exists on the document, or
- Multiple source property keys exist on the document (ambiguous merge). Conflicting document RIDs are returned in the response.
Implementations