pub struct BatchEditNotebookMetadataRequest { /* private fields */ }Implementations
Sourceimpl BatchEditNotebookMetadataRequest
impl BatchEditNotebookMetadataRequest
Sourcepub fn builder() -> Builder<OperationStage>
pub fn builder() -> Builder<OperationStage>
Returns a new builder.
Sourceimpl BatchEditNotebookMetadataRequest
impl BatchEditNotebookMetadataRequest
Sourcepub fn new(operation: MetadataChange) -> Self
pub fn new(operation: MetadataChange) -> Self
Constructs a new instance of the type.
Sourcepub fn notebook_search_query(&self) -> Option<&SearchNotebooksQuery>
pub fn notebook_search_query(&self) -> Option<&SearchNotebooksQuery>
Additional search query to filter which workbooks are targeted by the edit. Source labels/properties from the operation are automatically included as filters.
pub fn operation(&self) -> &MetadataChange