pub struct BatchEditNotebookMetadataResponse { /* private fields */ }Implementations
Sourceimpl BatchEditNotebookMetadataResponse
impl BatchEditNotebookMetadataResponse
Sourcepub fn modified_notebook_rids(&self) -> &[NotebookRid]
pub fn modified_notebook_rids(&self) -> &[NotebookRid]
RIDs for workbooks that were modified by the batch edit.
Sourcepub fn conflicting_notebook_rids(&self) -> &[NotebookRid]
pub fn conflicting_notebook_rids(&self) -> &[NotebookRid]
RIDs for workbooks that matched the source filter but already had the target property key and were skipped (SkipOnConflict behavior). Empty for operations without conflict semantics or when using OverwriteOnConflict.