pub struct CreateNotebookRequest { /* private fields */ }Implementations
Sourceimpl CreateNotebookRequest
impl CreateNotebookRequest
Sourcepub fn builder() -> Builder<TitleStage>
pub fn builder() -> Builder<TitleStage>
Returns a new builder.
Sourceimpl CreateNotebookRequest
impl CreateNotebookRequest
pub fn title(&self) -> &str
pub fn description(&self) -> &str
Sourcepub fn notebook_type(&self) -> Option<&NotebookType>
pub fn notebook_type(&self) -> Option<&NotebookType>
Optional for backcompatibility. Default is a normal workbook.
pub fn is_draft(&self) -> bool
pub fn state_as_json(&self) -> &str
pub fn charts(&self) -> Option<&[ChartWithOverlays]>
charts are now stored in contentV2
Sourcepub fn data_scope(&self) -> Option<&NotebookDataScope>
pub fn data_scope(&self) -> Option<&NotebookDataScope>
Optional for back-compatibility.
pub fn layout(&self) -> &WorkbookLayout
pub fn content(&self) -> Option<&WorkbookContent>
use contentV2 instead
Sourcepub fn content_v2(&self) -> Option<&UnifiedWorkbookContent>
pub fn content_v2(&self) -> Option<&UnifiedWorkbookContent>
Optional for backcompatibility
Sourcepub fn event_refs(&self) -> &BTreeSet<EventReference>
pub fn event_refs(&self) -> &BTreeSet<EventReference>
Field to pin events to a workbook on creation.
Sourcepub fn check_alert_refs(&self) -> Option<&BTreeSet<CheckAlertReference>>
👎Deprecated: CheckAlerts are no longer supported and will be removed in the future.
Use eventRefs to pin events to workbooks instead.
pub fn check_alert_refs(&self) -> Option<&BTreeSet<CheckAlertReference>>
CheckAlerts are no longer supported and will be removed in the future. Use eventRefs to pin events to workbooks instead.
Field to pin check alerts to a workbook on creation. Any specified CheckAlertReference will be added to the workbook along with it’s corresponding EventReference.
Sourcepub fn workspace(&self) -> Option<&WorkspaceRid>
pub fn workspace(&self) -> Option<&WorkspaceRid>
The workspace in which to create the workbook. If not provided, the workbook will be created in the default workspace for the user’s organization, if the default workspace for the organization is configured.
Sourcepub fn preview_image(&self) -> Option<&ThemeAwareImage>
pub fn preview_image(&self) -> Option<&ThemeAwareImage>
Theme-aware preview image for the workbook. Falls back to a default illustration if not provided.