Modules
- all_
runs_ properties_ and_ labels_ response - archive_
runs_ request - assets_
filter - batch_
edit_ run_ metadata_ request - batch_
edit_ run_ metadata_ response - channel_
metadata - check_
alert_ states_ filter - connection_
rid - create_
or_ update_ run_ request - create_
run_ data_ source - create_
run_ request - custom_
timeframe_ filter - data_
review_ alert_ metrics - data_
review_ check_ metrics - data_
review_ metrics - data_
scopes - data_
source - data_
source_ series_ tag - data_
source_ type - duration
- get_
run_ by_ id_ request - get_
runs_ by_ asset_ request - get_
runs_ by_ asset_ response - link
- log_
set_ rid - preset_
timeframe_ duration - preset_
timeframe_ filter - ref_
name_ and_ type - run
- run_
data_ review_ evaluation_ status - run_
data_ review_ summary - run_
data_ source - run_rid
- run_
with_ data_ review_ metrics - run_
with_ data_ review_ summary - search_
query - search_
run_ channels_ request - search_
run_ channels_ response - search_
runs_ request - search_
runs_ response - search_
runs_ with_ data_ review_ metrics_ response - search_
runs_ with_ data_ review_ summary_ response - sort_
field - sort_
key - sort_
options - sort_
property - time_
range_ filter - timeframe_
filter - unarchive_
runs_ request - unit
- update_
attachments_ request - update_
run_ request - utc_
timestamp - weak_
timestamp_ type
Structs
- AllRuns
Properties AndLabels Response - Archive
Runs Request - Assets
Filter - returns runs that match any of the provided assets.
- Batch
Edit RunMetadata Request - Batch
Edit RunMetadata Response - Channel
Metadata - Check
Alert States Filter - Connection
Rid - Create
OrUpdate RunRequest - Create
RunData Source - For write requests, we want to allow for optional fields
- Create
RunRequest - Custom
Timeframe Filter - Data
Review Alert Metrics - Data
Review Check Metrics - Data
Review Metrics - Data
Scopes - Data
Source Series Tag - Duration
- GetRun
ById Request - GetRuns
ByAsset Request - GetRuns
ByAsset Response - Link
- LogSet
Rid - Preset
Timeframe Filter - RefName
AndType - Scoped to the org-level, intended to help the frontend
prevent users from submitting invalid ref names, ex.
using a
datasetref name for aconnectiondata source - Run
- RunData
Review Summary - RunData
Source - For read requests, we want to require all fields
- RunRid
- RunWith
Data Review Metrics - RunWith
Data Review Summary - Search
RunChannels Request - Search
RunChannels Response - Search
Runs Request - Search
Runs Response - Search
Runs With Data Review Metrics Response - Search
Runs With Data Review Summary Response - Sort
Options - Sort
Property - Time
Range Filter - searches for runs that have at least some intersection with the specified range.
- Unarchive
Runs Request - Unit
- Update
Attachments Request - Update
RunRequest - UtcTimestamp
Enums
- Data
Source - Data
Source Type - Preset
Timeframe Duration - RunData
Review Evaluation Status - Search
Query - Sort
Field - SortKey
- Timeframe
Filter - Weak
Timestamp Type - If a CSV data source is still being split, the timestamp type is not known.