pub struct BatchEditRunMetadataResponse { /* private fields */ }Implementations
Sourceimpl BatchEditRunMetadataResponse
impl BatchEditRunMetadataResponse
Sourcepub fn modified_run_rids(&self) -> &[RunRid]
pub fn modified_run_rids(&self) -> &[RunRid]
RIDs for runs that were modified by the batch edit.
Sourcepub fn conflicting_run_rids(&self) -> &[RunRid]
pub fn conflicting_run_rids(&self) -> &[RunRid]
RIDs for runs that matched the source filter but already had the target property key and were skipped (SkipOnConflict behavior). Empty for operations without conflict semantics or when using OverwriteOnConflict.