Modules
- create_
spatial_ request - get_
spatials_ request - get_
spatials_ response - import_
file_ request - import_
file_ response - point_
cloud_ metadata - scan_
pattern - search_
spatials_ query - search_
spatials_ request - search_
spatials_ response - sort_
field - sort_
options - spatial
- spatial_
ingest_ status - spatial_
type - spatial_
type_ metadata - update_
spatial_ metadata_ request
Structs
- Create
Spatial Request - GetSpatials
Request - GetSpatials
Response - Import
File Request - Request to import a spatial data file (e.g. LAS, LAZ, PLY, PCD, E57, PCAP).
- Import
File Response - Point
Cloud Metadata - Metadata about the sensor that captured a point cloud.
- Search
Spatials Request - Search
Spatials Response - Sort
Options - Spatial
- A spatial asset representing 3D or geospatial data (e.g. point clouds).
- Update
Spatial Metadata Request
Enums
- Scan
Pattern - Search
Spatials Query - Sort
Field - Spatial
Ingest Status - Spatial
Type - The type of spatial data stored in a spatial asset.
- Spatial
Type Metadata