pub struct ImportFileRequest { /* private fields */ }Expand description
Request to import a spatial data file (e.g. LAS, LAZ, PLY, PCD, E57, PCAP).
Implementations
Sourceimpl ImportFileRequest
impl ImportFileRequest
Sourcepub fn builder() -> Builder<SourceStage>
pub fn builder() -> Builder<SourceStage>
Returns a new builder.
Sourceimpl ImportFileRequest
impl ImportFileRequest
Sourcepub fn new(source: Handle, type_metadata: SpatialTypeMetadata) -> Self
pub fn new(source: Handle, type_metadata: SpatialTypeMetadata) -> Self
Constructs a new instance of the type.
pub fn title(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
pub fn labels(&self) -> &BTreeSet<Label>
pub fn properties(&self) -> &BTreeMap<PropertyName, PropertyValue>
pub fn type_metadata(&self) -> &SpatialTypeMetadata
Sourcepub fn workspace(&self) -> Option<&WorkspaceRid>
pub fn workspace(&self) -> Option<&WorkspaceRid>
The workspace in which to create the spatial asset. If not provided, the asset will be created in the default workspace for the user’s organization.
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created spatial asset.