pub struct CreateSpatialRequest { /* private fields */ }Implementations
Sourceimpl CreateSpatialRequest
impl CreateSpatialRequest
Sourcepub fn builder() -> Builder<TitleStage>
pub fn builder() -> Builder<TitleStage>
Returns a new builder.
Sourceimpl CreateSpatialRequest
impl CreateSpatialRequest
Sourcepub fn new(
title: impl Into<String>,
dagger_uuid: Uuid,
type_metadata: SpatialTypeMetadata,
) -> Self
pub fn new( title: impl Into<String>, dagger_uuid: Uuid, type_metadata: SpatialTypeMetadata, ) -> Self
Constructs a new instance of the type.
pub fn title(&self) -> &str
Sourcepub fn dagger_uuid(&self) -> Uuid
pub fn dagger_uuid(&self) -> Uuid
UUID of the Dagger model that backs this spatial asset. Callers must create the model in Dagger before calling create.
pub fn type_metadata(&self) -> &SpatialTypeMetadata
pub fn labels(&self) -> &BTreeSet<Label>
pub fn properties(&self) -> &BTreeMap<PropertyName, PropertyValue>
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created spatial asset. If not provided, the asset will be visible to all users in the same workspace.
pub fn description(&self) -> Option<&str>
Sourcepub fn start_timestamp(&self) -> Option<&Timestamp>
pub fn start_timestamp(&self) -> Option<&Timestamp>
Start of the time range covered by this spatial asset.
Sourcepub fn end_timestamp(&self) -> Option<&Timestamp>
pub fn end_timestamp(&self) -> Option<&Timestamp>
End of the time range covered by this spatial asset.
Sourcepub fn source_handle(&self) -> Option<&Handle>
pub fn source_handle(&self) -> Option<&Handle>
Optional reference to the original source data (e.g., S3 path) for provenance tracking.
Sourcepub fn workspace(&self) -> Option<&WorkspaceRid>
pub fn workspace(&self) -> Option<&WorkspaceRid>
The workspace in which to create the spatial asset. If not provided, the asset will be created in the default workspace for the user’s organization, if the default workspace is configured.