pub struct Unit { /* private fields */ }Implementations
Sourceimpl Unit
impl Unit
Sourcepub fn new(symbol: UnitSymbol, system: UnitSystem) -> Unit
pub fn new(symbol: UnitSymbol, system: UnitSystem) -> Unit
Constructs a new instance of the type.
pub fn name(&self) -> Option<&UnitName>
pub fn symbol(&self) -> &UnitSymbol
Sourcepub fn property(&self) -> Option<&UnitProperty>
pub fn property(&self) -> Option<&UnitProperty>
Empty if no property is available. If two units measure different properties, it is not possible to convert between them.
Sourcepub fn dimension(&self) -> Option<&UnitDimension>
pub fn dimension(&self) -> Option<&UnitDimension>
The physical dimensions in terms of the base units of the system. It is only possible to convert units if they have the same dimension. Empty if the unit is a base unit.
pub fn system(&self) -> &UnitSystem