Module batch_update_video_files_request

Module batch_update_video_files_request 

Structs

BatchUpdateVideoFilesRequest
Request to update metadata for multiple files within a single video. All files must belong to the provided video, and the batch may include at most 100 files.
Builder
A builder for BatchUpdateVideoFilesRequest
Complete
The final stage for BatchUpdateVideoFilesRequest.
VideoRidStage
The video_rid stage for Builder.