pub struct GetSegmentAtOrAfterTimestampV2Request { /* private fields */ }Expand description
Request to get a segment containing the given timestamp, or the closest segment starting after it, for a video channel series (identified by channel + tags).
Implementations
Sourceimpl GetSegmentAtOrAfterTimestampV2Request
impl GetSegmentAtOrAfterTimestampV2Request
Sourcepub fn builder() -> Builder<ChannelSeriesStage>
pub fn builder() -> Builder<ChannelSeriesStage>
Returns a new builder.
Sourceimpl GetSegmentAtOrAfterTimestampV2Request
impl GetSegmentAtOrAfterTimestampV2Request
Sourcepub fn new(channel_series: VideoChannelSeries, timestamp: Timestamp) -> Self
pub fn new(channel_series: VideoChannelSeries, timestamp: Timestamp) -> Self
Constructs a new instance of the type.
pub fn channel_series(&self) -> &VideoChannelSeries
pub fn timestamp(&self) -> &Timestamp