pub struct TimestampMappings { /* private fields */ }Expand description
contains 2 equal-length lists, which contain the video media time and user-provided absolute time for the frame at each index. Enables frame-mapping on the front-end.
Implementations
Sourceimpl TimestampMappings
impl TimestampMappings
Sourcepub fn new() -> TimestampMappings
pub fn new() -> TimestampMappings
Constructs a new instance of the type.
pub fn media_timestamps(&self) -> &[f64]
pub fn absolute_timestamps(&self) -> &[Timestamp]