pub struct UpdateVideoFileRequest { /* private fields */ }Expand description
Request to update metadata for a given video file.
Implementations
Sourceimpl UpdateVideoFileRequest
impl UpdateVideoFileRequest
Sourcepub fn new() -> UpdateVideoFileRequest
pub fn new() -> UpdateVideoFileRequest
Constructs a new instance of the type.
pub fn title(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
pub fn starting_timestamp(&self) -> Option<&Timestamp>
pub fn scale_parameter(&self) -> Option<&ScaleParameter>
Sourcepub fn segmented_files_size(&self) -> Option<SafeLong>
pub fn segmented_files_size(&self) -> Option<SafeLong>
The total size of all the post-processed segments corresponding to this video file in bytes.