pub struct VideoChannelDatasetFile { /* private fields */ }Expand description
A dataset file backing a video channel, with the min and max absolute timestamps of the segments it contributes to the channel.
Implementations
Sourceimpl VideoChannelDatasetFile
impl VideoChannelDatasetFile
Sourcepub fn builder() -> Builder<DatasetFileIdStage>
pub fn builder() -> Builder<DatasetFileIdStage>
Returns a new builder.