Module api

Module api 

Modules

asset_data_scope_input_value
asset_list_data_scope_input_value
asset_offset
asset_query_data_scope_input_value
asset_settings
check_alert_reference
data_scope_input_value
event_align_to
event_alignment
event_reference
input_offset
input_type
offset
run_align_to
run_alignment
run_data_scope_input_value
run_list_data_scope_input_value
run_offset
run_query_data_scope_input_value
run_settings
tag
tag_string
tag_string_literal
time_range
unified_workbook_content
workbook_content
workbook_data_scope_input
workbook_data_scope_input_id
workbook_data_scope_input_name
workbook_data_scope_inputs
workbook_data_scope_inputs_v1
workbook_input
workbook_inputs
workbook_inputs_v1
workbook_offsets
workbook_offsets_v1
workbook_settings
workbook_time_range_type
workbook_time_settings
workbook_time_settings_v1

Structs

AssetDataScopeInputValue
An asset data scope input value.
AssetListDataScopeInputValue
A data scope input value resolving to an explicit list of assets.
AssetOffset
An offset that can be applied to an asset.
AssetQueryDataScopeInputValue
A data scope input value resolving to the assets matching a search query.
AssetSettings
CheckAlertReference
EventAlignment
An offset that is defined relative to the first target event found by query.
EventReference
InputOffset
RunAlignment
An offset that is defined relative to a target run.
RunDataScopeInputValue
A run data scope input value.
RunListDataScopeInputValue
A data scope input value resolving to an explicit list of runs.
RunOffset
An offset that can be applied to a run.
RunQueryDataScopeInputValue
A data scope input value resolving to the runs matching a search query.
RunSettings
Tag
A tag input contains tag key and tag value information that can apply to a channel’s compute tree. Applies the tag to both the tag filter and tag group by fields of the series node in the compute tree.
TagStringLiteral
A literal string value
TimeRange
WorkbookContent
WorkbookDataScopeInput
A data scope input that binds a variable name to an asset or run RID. The variable name is the map key.
WorkbookDataScopeInputId
Unique identifier. Needs to be string for back-compatibility but this will usually be a uuid.
WorkbookDataScopeInputName
WorkbookDataScopeInputsV1
A map of data scope input variable name to its definition.
WorkbookInput
A workbook input is a value managed at the workbook level that can be applied to multiple elements.
WorkbookInputsV1
A list of workbook inputs.
WorkbookOffsetsV1
WorkbookSettings
WorkbookTimeSettingsV1
Time range configuration for workbooks

Enums

DataScopeInputValue
EventAlignTo
The align to value for an event offset. If the queried event is a moment, the offset will be the moment timestamp regardless of the align to value.
InputType
Offset
RunAlignTo
The align to value for a run offset.
TagString
UnifiedWorkbookContent
WorkbookDataScopeInputs
WorkbookInputs
WorkbookOffsets
WorkbookTimeRangeType
WorkbookTimeSettings