pub struct AnchorAlignment { /* private fields */ }Expand description
An offset that aligns each anchored portion of a dataset so the selected anchor becomes timestamp zero.
Implementations
Sourceimpl AnchorAlignment
impl AnchorAlignment
Sourcepub fn builder() -> Builder<AnchorStage>
pub fn builder() -> Builder<AnchorStage>
Returns a new builder.
Sourceimpl AnchorAlignment
impl AnchorAlignment
Sourcepub fn new(anchor: DatasetAnchor) -> AnchorAlignment
pub fn new(anchor: DatasetAnchor) -> AnchorAlignment
Constructs a new instance of the type.
pub fn anchor(&self) -> &DatasetAnchor