pub struct Workspace { /* private fields */ }Implementations
Sourceimpl Workspace
impl Workspace
Sourcepub fn id(&self) -> &WorkspaceId
pub fn id(&self) -> &WorkspaceId
A unique identifier for the workspace within the organization. The workspace ID must be lower case alphanumeric characters, optionally separated by hyphens.
pub fn rid(&self) -> &WorkspaceRid
pub fn org(&self) -> &OrgRid
pub fn display_name(&self) -> Option<&str>
pub fn symbol(&self) -> Option<&WorkspaceSymbol>
pub fn settings(&self) -> &WorkspaceSettings