pub struct ColumnBatch { /* private fields */ }Expand description
Batch of data to stream for a single channel with their associated timestamps.
Implementations
Sourceimpl ColumnBatch
impl ColumnBatch
Sourcepub fn builder() -> Builder<ChannelStage>
pub fn builder() -> Builder<ChannelStage>
Returns a new builder.
Sourceimpl ColumnBatch
impl ColumnBatch
Sourcepub fn new(channel: Channel, values: ColumnValues) -> ColumnBatch
pub fn new(channel: Channel, values: ColumnValues) -> ColumnBatch
Constructs a new instance of the type.
Mapping of key-value pairs to provide as tags to all points within the batch
Sourcepub fn timestamps(&self) -> &[Timestamp]
pub fn timestamps(&self) -> &[Timestamp]
List of timestamp values that correspond to the provided list of column values. The number of timestamps provided MUST match the number of columnar values provided, otherwise a 400 error will be returned.
Sourcepub fn values(&self) -> &ColumnValues
pub fn values(&self) -> &ColumnValues
List of time series values that should be ingested to a single channel. The number of columnar values provided MUST match the number of timestamps provided, otherwise a 400 error will be returned.