Module api

Modules

client_message
full_result
milliseconds
permission_denied
server_message
streaming_compute_node_request
streaming_compute_node_subscription
streaming_not_enabled_for_data_source
subscription_error
subscription_id
subscription_options
subscription_update
window_too_large

Structs

FullResult
Milliseconds
PermissionDenied
StreamingComputeNodeRequest
A templatized version of ComputeNodeRequest where the end of the range will track the current time and the start of the range tracks windowWidth time ago.
StreamingComputeNodeSubscription
StreamingNotEnabledForDataSource
SubscriptionError
This will be sent if there is an error while creating or updating a subscription. Note: This won’t automatically cancel the subscription. The client will have to call ClientMessage::unsubscribe to do that if warranted.
SubscriptionId
SubscriptionOptions
WindowTooLarge

Enums

ClientMessage
ServerMessage
SubscriptionUpdate