pub struct BadFlinkStatus {}Expand description
Flink is required for this subscription but is currently not available. This can be because Flink is disabled or because of a temporary issue with the Flink cluster.
Implementations