Module value_difference_series

Module value_difference_series 

Structs

Builder
A builder for ValueDifferenceSeries
Complete
The final stage for ValueDifferenceSeries.
InputStage
The input stage for Builder.
ValueDifferenceSeries
Calculates the first discrete difference of the input series. For each point, computes the difference between the current value and the previous value (current - previous). The first point in the input series is omitted from the output since it has no previous point to compare against.