pub struct DataReviewServiceClient<T>(/* private fields */);Expand description
The data review service manages the evaluation, disposition, and historical record of checks alerts.
Implementations
Sourceimpl<T> DataReviewServiceClient<T>where
T: Client,
impl<T> DataReviewServiceClient<T>where
T: Client,
Sourcepub fn batch_initiate(
&self,
auth_: &BearerToken,
request: &BatchInitiateDataReviewRequest,
) -> Result<BatchInitiateDataReviewResponse, Error>
pub fn batch_initiate( &self, auth_: &BearerToken, request: &BatchInitiateDataReviewRequest, ) -> Result<BatchInitiateDataReviewResponse, Error>
For each request, initiates data review for the requested run and checklist and executes the automatic checks against the run.
Sourcepub fn rerun_failed_automatic_checks(
&self,
auth_: &BearerToken,
request: &RerunFailedAutomaticChecksRequest,
) -> Result<(), Error>
pub fn rerun_failed_automatic_checks( &self, auth_: &BearerToken, request: &RerunFailedAutomaticChecksRequest, ) -> Result<(), Error>
Re-executes the most recent failed automatic checks for the data review.
Sourcepub fn find_data_reviews(
&self,
auth_: &BearerToken,
request: &FindDataReviewsRequest,
) -> Result<DataReviewPage, Error>
pub fn find_data_reviews( &self, auth_: &BearerToken, request: &FindDataReviewsRequest, ) -> Result<DataReviewPage, Error>
Returns the data reviews under the provided search parameters.
Sourcepub fn get(
&self,
auth_: &BearerToken,
data_review_rid: &DataReviewRid,
) -> Result<DataReview, Error>
pub fn get( &self, auth_: &BearerToken, data_review_rid: &DataReviewRid, ) -> Result<DataReview, Error>
Throws if not found.
Sourcepub fn get_check_alert(
&self,
auth_: &BearerToken,
check_alert_rid: &CheckAlertRid,
) -> Result<CheckAlert, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn get_check_alert( &self, auth_: &BearerToken, check_alert_rid: &CheckAlertRid, ) -> Result<CheckAlert, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Throws if not found.
Sourcepub fn get_check_alerts_for_data_review(
&self,
auth_: &BearerToken,
data_review_rid: &DataReviewRid,
) -> Result<BTreeSet<CheckAlert>, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn get_check_alerts_for_data_review( &self, auth_: &BearerToken, data_review_rid: &DataReviewRid, ) -> Result<BTreeSet<CheckAlert>, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Gets all check alerts from the provided data review.
Sourcepub fn get_check_alerts_histogram(
&self,
auth_: &BearerToken,
request: &CheckAlertsHistogramRequest,
) -> Result<CheckAlertsHistogramResponse, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn get_check_alerts_histogram( &self, auth_: &BearerToken, request: &CheckAlertsHistogramRequest, ) -> Result<CheckAlertsHistogramResponse, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Returns a histogram of alerts that occur across the provided runs or assets. At least one run or asset must be specified.
Sourcepub fn search_check_alerts(
&self,
auth_: &BearerToken,
request: &SearchCheckAlertsRequest,
) -> Result<SearchCheckAlertsResponse, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn search_check_alerts( &self, auth_: &BearerToken, request: &SearchCheckAlertsRequest, ) -> Result<SearchCheckAlertsResponse, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Returns the check alerts under the provided search parameters. At least one run or asset must be specified.
Sourcepub fn get_check_alert_action_log(
&self,
auth_: &BearerToken,
check_alert_rid: &CheckAlertRid,
) -> Result<CheckAlertActionLog, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn get_check_alert_action_log( &self, auth_: &BearerToken, check_alert_rid: &CheckAlertRid, ) -> Result<CheckAlertActionLog, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Returns a record of the historical actions taken on the provided check alert.
Sourcepub fn get_check_alert_counts_for_notebooks(
&self,
auth_: &BearerToken,
rids: &BTreeSet<NotebookRid>,
) -> Result<BTreeMap<NotebookRid, i32>, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn get_check_alert_counts_for_notebooks( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> Result<BTreeMap<NotebookRid, i32>, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Returns the number of alerts attached to each provided notebook.
Sourcepub fn get_check_alert_status_for_notebooks(
&self,
auth_: &BearerToken,
rids: &BTreeSet<NotebookRid>,
) -> Result<BTreeMap<NotebookRid, Option<CheckAlertStatus>>, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn get_check_alert_status_for_notebooks( &self, auth_: &BearerToken, rids: &BTreeSet<NotebookRid>, ) -> Result<BTreeMap<NotebookRid, Option<CheckAlertStatus>>, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Returns the check alert status of any linked violations for the provided notebooks. If none exist, an empty optional is returned.
Sourcepub fn perform_check_alert_action(
&self,
auth_: &BearerToken,
check_alert_rid: &CheckAlertRid,
request: &CheckAlertAction,
) -> Result<CheckAlert, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn perform_check_alert_action( &self, auth_: &BearerToken, check_alert_rid: &CheckAlertRid, request: &CheckAlertAction, ) -> Result<CheckAlert, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Applies a check alert action to the specified check alert RID.
Sourcepub fn batch_perform_check_alert_action(
&self,
auth_: &BearerToken,
request: &BatchCheckAlertActionRequest,
) -> Result<BatchCheckAlertActionResponse, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn batch_perform_check_alert_action( &self, auth_: &BearerToken, request: &BatchCheckAlertActionRequest, ) -> Result<BatchCheckAlertActionResponse, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Applies a check alert action to the specified check alert RIDs. If any of the check actions fail, then none of the check actions will be applied.
Sourcepub fn batch_perform_automatic_check_evaluation_review_action(
&self,
auth_: &BearerToken,
request: &BatchAutomaticCheckEvaluationActionRequest,
) -> Result<BatchAutomaticCheckEvaluationActionResponse, Error>
👎Deprecated: CheckAlerts have been replaced by Events.
Please use the EventService instead.
pub fn batch_perform_automatic_check_evaluation_review_action( &self, auth_: &BearerToken, request: &BatchAutomaticCheckEvaluationActionRequest, ) -> Result<BatchAutomaticCheckEvaluationActionResponse, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Applies an action to the specified check evaluation RIDs. If any of the check actions fail, then none of the actions will be applied.
pub fn get_automatic_check_evaluation_action_log( &self, auth_: &BearerToken, rid: &AutomaticCheckEvaluationRid, ) -> Result<AutomaticCheckEvaluationActionLog, Error>
CheckAlerts have been replaced by Events. Please use the EventService instead.
Sourcepub fn batch_perform_manual_check_alert_action(
&self,
auth_: &BearerToken,
request: &BatchManualCheckEvaluationActionRequest,
) -> Result<(), Error>
👎Deprecated: No longer in use
pub fn batch_perform_manual_check_alert_action( &self, auth_: &BearerToken, request: &BatchManualCheckEvaluationActionRequest, ) -> Result<(), Error>
No longer in use
Applies an action to the specified check evaluation RIDs. If any of the check actions fail, then none of the actions will be applied.
Sourcepub fn get_manual_check_evaluation_action_log(
&self,
auth_: &BearerToken,
rid: &ManualCheckEvaluationRid,
) -> Result<ManualCheckEvaluationActionLog, Error>
👎Deprecated: No longer in use
pub fn get_manual_check_evaluation_action_log( &self, auth_: &BearerToken, rid: &ManualCheckEvaluationRid, ) -> Result<ManualCheckEvaluationActionLog, Error>
No longer in use
Returns a record of the historical manual actions taken on the provided check evaluation.
Sourcepub fn archive_data_review(
&self,
auth_: &BearerToken,
data_review_rid: &DataReviewRid,
) -> Result<bool, Error>
pub fn archive_data_review( &self, auth_: &BearerToken, data_review_rid: &DataReviewRid, ) -> Result<bool, Error>
Archives the data review with the given rid.
Sourcepub fn batch_archive_data_review(
&self,
auth_: &BearerToken,
rids: &BTreeSet<DataReviewRid>,
) -> Result<(), Error>
pub fn batch_archive_data_review( &self, auth_: &BearerToken, rids: &BTreeSet<DataReviewRid>, ) -> Result<(), Error>
Batch archives the data reviews with the given rids.
Sourcepub fn unarchive_data_review(
&self,
auth_: &BearerToken,
data_review_rid: &DataReviewRid,
) -> Result<(), Error>
pub fn unarchive_data_review( &self, auth_: &BearerToken, data_review_rid: &DataReviewRid, ) -> Result<(), Error>
Unarchives the data review with the given rid.
pub fn get_data_review_check_metrics( &self, auth_: &BearerToken, request: &GetDataReviewCheckMetricsRequest, ) -> Result<GetDataReviewCheckMetricsResponse, Error>