Struct VideoServiceClient

pub struct VideoServiceClient<T>(/* private fields */);
The video service manages videos and video metadata.

Implementations

Source

impl<T> VideoServiceClient<T>
where T: Client,

pub fn get( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<Video, Error>

Returns video metadata associated with a video rid.

pub fn batch_get( &self, auth_: &BearerToken, request: &GetVideosRequest, ) -> Result<GetVideosResponse, Error>

Returns video metadata about each video given a set of video rids.

pub fn search( &self, auth_: &BearerToken, request: &SearchVideosRequest, ) -> Result<SearchVideosResponse, Error>

Returns metadata about videos that match a given query.

pub fn create( &self, auth_: &BearerToken, request: &CreateVideoRequest, ) -> Result<Video, Error>

Creates and persists a video entity with the given metadata.

pub fn update_metadata( &self, auth_: &BearerToken, video_rid: &VideoRid, request: &UpdateVideoMetadataRequest, ) -> Result<Video, Error>

Updates the metadata for a video associated with the given video rid.

pub fn update_ingest_status( &self, auth_: &BearerToken, video_rid: &VideoRid, request: &UpdateIngestStatus, ) -> Result<(), Error>

pub fn get_ingest_status( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<DetailedIngestStatus, Error>

pub fn batch_get_ingest_status( &self, auth_: &BearerToken, video_rids: &BTreeSet<VideoRid>, ) -> Result<BTreeMap<VideoRid, DetailedIngestStatus>, Error>

pub fn archive( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<(), Error>

Archives a video, which excludes it from search and hides it from being publicly visible, but does not permanently delete it. Archived videos can be unarchived.

pub fn unarchive( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<(), Error>

Unarchives a previously archived video.

pub fn get_playlist( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<T::ResponseBody, Error>

Generates an HLS playlist for a video with the given video rid to enable playback. The HLS playlist will contain links to all of the segments in the video in sequential order.

pub fn get_segment_summaries( &self, auth_: &BearerToken, video_rid: &VideoRid, ) -> Result<Vec<SegmentSummary>, Error>

Returns the min and max absolute and media timestamps for each segment in a video. To be used during frame-timestamp mapping.