Struct NominalSeriesServiceAsyncClient

pub struct NominalSeriesServiceAsyncClient<T>(/* private fields */);
Create and fetch series stored by Nominal. This service is deprecated.

Implementations

Source

impl<T> NominalSeriesServiceAsyncClient<T>
where T: AsyncClient,

pub async fn get( &self, auth_: &BearerToken, rid: &NominalSeriesRid, ) -> Result<NominalSeries, Error>

👎Deprecated: Deprecated with no replacement.

Retrieves a series for the given series RID.

pub async fn batch_get( &self, auth_: &BearerToken, rids: &BTreeSet<NominalSeriesRid>, ) -> Result<BTreeSet<NominalSeries>, Error>

👎Deprecated: Deprecated with no replacement.

Retrieves series for the given series RIDs. Excludes series that do not exist or are unauthorized. A maximum of 1000 rids can be requested.

pub async fn batch_get_by_channel_and_tags( &self, auth_: &BearerToken, request: &BTreeSet<GetSeriesByChannelAndTagsRequest>, ) -> Result<BTreeSet<NominalSeries>, Error>

👎Deprecated: Deprecated with no replacement.

Retrieves series that match the requested data source, channel name and tags exactly. Omits series that do not exist or are unauthorized. A maximum of 1000 rids can be requested.

pub async fn create_or_get( &self, auth_: &BearerToken, request: &CreateSeriesRequest, ) -> Result<NominalSeries, Error>

👎Deprecated: Deprecated with no replacement.

Creates a new series if it doesn’t already exist.

A series exists if there is already a series with the same channel name and tag values in the data source. Returns the series that was created or the existing series.

pub async fn batch_create_or_get( &self, auth_: &BearerToken, request: &[CreateSeriesRequest], ) -> Result<Vec<NominalSeries>, Error>

👎Deprecated: use batchCreateOrGetV2
pub async fn batch_create_or_get_v2( &self, auth_: &BearerToken, request: &[CreateSeriesRequest], ) -> Result<BatchCreateOrGetResponse, Error>

👎Deprecated: Deprecated with no replacement.

Creates new series if they don’t already exist.

A series exists if there is already a series with the same channel name and tag values in the data source. Returns series that were created and any existing series.

pub async fn update_last_touched_at( &self, auth_: &BearerToken, request: &BatchUpdateLastTouchedAtRequest, ) -> Result<(), Error>

👎Deprecated: Deprecated with no replacement.

Updates the last touched at time for series. The last touched at time represents the last time a series had data written to it.

pub async fn search( &self, auth_: &BearerToken, request: &SearchSeriesRequest, ) -> Result<SearchSeriesResponse, Error>

👎Deprecated: Deprecated with no replacement.

Retrieves series that match the search query.