WellKnown

Enum WellKnown 

pub enum WellKnown {
Show 21 variants Email(bool), Hostname(bool), Ip(bool), Ipv4(bool), Ipv6(bool), Uri(bool), UriRef(bool), Address(bool), Uuid(bool), Tuuid(bool), IpWithPrefixlen(bool), Ipv4WithPrefixlen(bool), Ipv6WithPrefixlen(bool), IpPrefix(bool), Ipv4Prefix(bool), Ipv6Prefix(bool), HostAndPort(bool), Ulid(bool), ProtobufFqn(bool), ProtobufDotFqn(bool), WellKnownRegex(i32),
}

Variants



Email(bool)



Hostname(bool)



Ip(bool)



Ipv4(bool)



Ipv6(bool)



Uri(bool)



UriRef(bool)



Address(bool)



Uuid(bool)



Tuuid(bool)



IpWithPrefixlen(bool)



Ipv4WithPrefixlen(bool)



Ipv6WithPrefixlen(bool)



IpPrefix(bool)



Ipv4Prefix(bool)



Ipv6Prefix(bool)



HostAndPort(bool)



Ulid(bool)



ProtobufFqn(bool)



ProtobufDotFqn(bool)



WellKnownRegex(i32)

Implementations

Source

impl WellKnown

pub fn encode(&self, buf: &mut impl BufMut)

Encodes the message to a buffer.

pub fn merge( field: &mut Option<WellKnown>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>

Decodes an instance of the message from a buffer, and merges it into self.

pub fn encoded_len(&self) -> usize

Returns the encoded length of the message without a length delimiter.