pub struct FieldPathElement {
pub field_number: Option<i32>,
pub field_name: Option<String>,
pub field_type: Option<i32>,
pub key_type: Option<i32>,
pub value_type: Option<i32>,
pub subscript: Option<Subscript>,
}Fields
field_number: Option<i32>field_name: Option<String>field_type: Option<i32>key_type: Option<i32>value_type: Option<i32>subscript: Option<Subscript>Implementations
Sourceimpl FieldPathElement
impl FieldPathElement
Sourcepub fn field_number(&self) -> i32
pub fn field_number(&self) -> i32
Returns the value of field_number, or the default value if field_number is unset.
Sourcepub fn field_name(&self) -> &str
pub fn field_name(&self) -> &str
Returns the value of field_name, or the default value if field_name is unset.
Sourcepub fn field_type(&self) -> Type
pub fn field_type(&self) -> Type
Returns the enum value of field_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_field_type(&mut self, value: Type)
pub fn set_field_type(&mut self, value: Type)
Sets field_type to the provided enum value.
Sourcepub fn key_type(&self) -> Type
pub fn key_type(&self) -> Type
Returns the enum value of key_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_key_type(&mut self, value: Type)
pub fn set_key_type(&mut self, value: Type)
Sets key_type to the provided enum value.
Sourcepub fn value_type(&self) -> Type
pub fn value_type(&self) -> Type
Returns the enum value of value_type, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_value_type(&mut self, value: Type)
pub fn set_value_type(&mut self, value: Type)
Sets value_type to the provided enum value.