pub struct FieldRules {
pub cel_expression: Vec<String>,
pub cel: Vec<Rule>,
pub required: Option<bool>,
pub ignore: Option<i32>,
pub type: Option<Type>,
}Fields
cel_expression: Vec<String>cel: Vec<Rule>required: Option<bool>ignore: Option<i32>type: Option<Type>Implementations
Sourceimpl FieldRules
impl FieldRules
Sourcepub fn required(&self) -> bool
pub fn required(&self) -> bool
Returns the value of required, or the default value if required is unset.
Sourcepub fn ignore(&self) -> Ignore
pub fn ignore(&self) -> Ignore
Returns the enum value of ignore, or the default if the field is unset or set to an invalid enum value.
Sourcepub fn set_ignore(&mut self, value: Ignore)
pub fn set_ignore(&mut self, value: Ignore)
Sets ignore to the provided enum value.