pub struct ChecklistContext {
pub checklist_rid: String,
pub branch_name: String,
pub reference_rid: Option<ReferenceRid>,
}Expand description
ChecklistContext for use when the agent is being messaged in the context of a checklist currently being edited
Fields
checklist_rid: StringRID of the checklist being edited
branch_name: StringName of the branch that this edit is being done on This is equivalent to the ‘draft name’ for a check being edited in the UI
reference_rid: Option<ReferenceRid>A checklist opened in edit mode will always have some resource by which it is referencing for viewing. It can either be an asset or a run