UpdateContainerizedExtractorRequest

Struct UpdateContainerizedExtractorRequest 

pub struct UpdateContainerizedExtractorRequest {
    pub rid: String,
    pub workspace_rid: String,
    pub name: Option<String>,
    pub description: Option<String>,
    pub is_archived: Option<bool>,
    pub active_container_image_rid: Option<String>,
}
Partial update. Only fields explicitly set on the request are modified; unset fields are left unchanged on the existing extractor. Archive / unarchive are expressed through this request by setting is_archived. The active container image is selected by setting active_container_image_rid.

Fields

rid: Stringworkspace_rid: Stringname: Option<String>description: Option<String>is_archived: Option<bool>

Set to true to archive, false to unarchive. Leave unset to leave archive state unchanged.

active_container_image_rid: Option<String>

RID of the container image to set as the active one for this extractor. Must reference a ContainerImage that is owned by the same workspace, was built for this extractor, and has reached READY status. Leave unset to leave the active image unchanged.

Implementations

Source

impl UpdateContainerizedExtractorRequest

pub fn name(&self) -> &str

Returns the value of name, or the default value if name is unset.

pub fn description(&self) -> &str

Returns the value of description, or the default value if description is unset.

pub fn is_archived(&self) -> bool

Returns the value of is_archived, or the default value if is_archived is unset.

pub fn active_container_image_rid(&self) -> &str

Returns the value of active_container_image_rid, or the default value if active_container_image_rid is unset.