pub struct UpdateRemoteConnectionStatusRequest {
pub remote_connection_rid: String,
pub status: i32,
}Fields
remote_connection_rid: Stringstatus: i32Implementations
Sourceimpl UpdateRemoteConnectionStatusRequest
impl UpdateRemoteConnectionStatusRequest
Sourcepub fn status(&self) -> RemoteConnectionStatus
pub fn status(&self) -> RemoteConnectionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: RemoteConnectionStatus)
pub fn set_status(&mut self, value: RemoteConnectionStatus)
Sets status to the provided enum value.