pub struct UpdateStepCompletionActionStatusRequest {
pub procedure_execution_rid: String,
pub step_id: String,
pub completion_action_statuses: Vec<CompletionActionStatus>,
}Fields
procedure_execution_rid: Stringstep_id: StringThe unique identifier of the execution step to update.
completion_action_statuses: Vec<CompletionActionStatus>The updated list of completion action statuses for the step. The backend replaces the step’s completion_action_statuses with this list.