pub struct UpdateRunConfig {
pub runs: Option<MultiRunReference>,
pub name: Option<StringReference>,
pub description: Option<StringReference>,
pub time_range: Option<TimeRangeReference>,
pub labels: Option<MultiStringReference>,
pub properties: Vec<PropertyReference>,
pub strict_overwrite: Option<bool>,
}Expand description
An action to update an existing run when a step is completed (e.g. set end time to previous step end time).
option (buf.validate.message).cel = { id: “update_run_config.at_least_one_update” message: “At least one update field (name, description, time_range, labels, or properties) must be set” expression: “has(this.name) || has(this.description) || has(this.time_range) || has(this.labels) || this.properties.size() > 0” };
Fields
runs: Option<MultiRunReference>The run(s) to update. Typically but not limited to a reference to a run created earlier in the procedure
name: Option<StringReference>Optional PATCH-style updates. Only set fields that should change. If unset, the run will not be updated.
description: Option<StringReference>time_range: Option<TimeRangeReference>labels: Option<MultiStringReference>TODO(ryanyost): support patch-behavior for labels
properties: Vec<PropertyReference>TODO(ryanyost): support patch-behavior for properties
strict_overwrite: Option<bool>When true, time fields overwrite existing values. When false, start only moves earlier, end only moves later (aligns with runs API strictOverwrite).
Implementations
Sourceimpl UpdateRunConfig
impl UpdateRunConfig
Sourcepub fn strict_overwrite(&self) -> bool
pub fn strict_overwrite(&self) -> bool
Returns the value of strict_overwrite, or the default value if strict_overwrite is unset.