#[repr(i32)]pub enum FileOutputFormat {
Unspecified = 0,
Parquet = 1,
Csv = 2,
ParquetTar = 3,
AvroStream = 4,
JsonL = 5,
Manifest = 6,
}Expand description
Output file format emitted by the extractor. Currently PARQUET, CSV, and PARQUET_TAR are the primary supported formats.
Variants
Implementations
Sourceimpl FileOutputFormat
impl FileOutputFormat
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.