pub struct FileExtractionInput {
pub environment_variable: String,
pub name: String,
pub description: Option<String>,
pub file_filters: Vec<FileFilter>,
pub required: Option<bool>,
}Expand description
Defines an input file to be provided to the extractor.
Fields
environment_variable: StringThe environment variable that stores the path to the input file.
name: StringName of the input file which users will be prompted with.
description: Option<String>Description of the input file which users will be prompted with.
file_filters: Vec<FileFilter>Optionally filter files for file selection.
required: Option<bool>Whether the input file is required for the extractor to run.
Implementations