pub struct FileExtractionParameter {
pub environment_variable: String,
pub name: String,
pub description: Option<String>,
pub required: Option<bool>,
}Expand description
Defines an input parameter to be provided to the extractor.
Fields
environment_variable: StringThe environment variable that stores the argument.
name: StringName of the parameter which users will be prompted with.
description: Option<String>Description of the parameter which users will be prompted with.
required: Option<bool>Whether the parameter is required for the extractor to run.
Implementations