pub struct DatasetRetentionExemption {
pub dataset_rid: String,
pub source_id: String,
pub bounds: Option<Range>,
pub description: Option<String>,
}Expand description
A retention exemption for a dataset, representing a time range that should be preserved regardless of the dataset’s retention policy.
Fields
dataset_rid: StringThe dataset this exemption applies to.
source_id: StringIdentifier for the source of this exemption (e.g. run RID).
bounds: Option<Range>Inclusive time range to exempt from retention.
description: Option<String>Implementations
Sourceimpl DatasetRetentionExemption
impl DatasetRetentionExemption
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Returns the value of description, or the default value if description is unset.