pub struct ResourceOpenedEvent {
pub resource_type: i32,
pub rid: String,
pub is_creator: bool,
}Expand description
A resource-opened event.
Fields
resource_type: i32The type of resource that was opened.
rid: StringThe RID of the resource that was opened.
is_creator: boolWhether the current user is the creator of the resource.
Implementations
Sourceimpl ResourceOpenedEvent
impl ResourceOpenedEvent
Sourcepub fn resource_type(&self) -> ResourceType
pub fn resource_type(&self) -> ResourceType
Returns the enum value of resource_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_resource_type(&mut self, value: ResourceType)
pub fn set_resource_type(&mut self, value: ResourceType)
Sets resource_type to the provided enum value.