LocalAsyncAuthenticationServiceV2

Trait LocalAsyncAuthenticationServiceV2 

pub trait LocalAsyncAuthenticationServiceV2<I: Stream<Item = Result<Bytes, Error>>> {
Show 15 methods // Required methods fn get_my_profile( &self, auth_: &BearerToken, ) -> impl Future<Output = Result<UserV2, Error>>; fn update_my_profile( &self, auth_: &BearerToken, update_my_profile_request: &UpdateMyProfileRequest, ) -> impl Future<Output = Result<UserV2, Error>>; fn get_my_settings( &self, auth_: &BearerToken, ) -> impl Future<Output = Result<UserSettings, Error>>; fn update_my_settings( &self, auth_: &BearerToken, user_settings: &UserSettings, ) -> impl Future<Output = Result<UserSettings, Error>>; fn get_my_org_settings( &self, auth_: &BearerToken, ) -> impl Future<Output = Result<OrgSettings, Error>>; fn update_my_org_settings( &self, auth_: &BearerToken, org_settings: &OrgSettings, ) -> impl Future<Output = Result<OrgSettings, Error>>; fn search_users_v2( &self, auth_: &BearerToken, request: &SearchUsersRequest, ) -> impl Future<Output = Result<SearchUsersResponseV2, Error>>; fn get_users( &self, auth_: &BearerToken, user_rids: &BTreeSet<UserRid>, ) -> impl Future<Output = Result<BTreeSet<UserV2>, Error>>; fn get_user( &self, auth_: &BearerToken, user_rid: &UserRid, ) -> impl Future<Output = Result<UserV2, Error>>; fn get_jwks(&self) -> impl Future<Output = Result<Jwks, Error>>; fn generate_media_mtx_token( &self, auth_: &BearerToken, request: &GenerateMediaMtxTokenRequest, ) -> impl Future<Output = Result<GenerateMediaMtxTokenResponse, Error>>; fn get_my_coachmark_dismissals( &self, auth_: &BearerToken, request: &GetCoachmarkDismissalsRequest, ) -> impl Future<Output = Result<GetCoachmarkDismissalsResponse, Error>>; fn dismiss_my_coachmark( &self, auth_: &BearerToken, request: &DismissCoachmarkRequest, ) -> impl Future<Output = Result<CoachmarkDismissal, Error>>; fn is_my_coachmark_dismissed( &self, auth_: &BearerToken, coachmark_id: &str, ) -> impl Future<Output = Result<bool, Error>>; fn reset_my_coachmark_dismissal( &self, auth_: &BearerToken, coachmark_id: &str, ) -> impl Future<Output = Result<(), Error>>;
}
This service provides operations for managing user and org profiles/settings. Its name is a bit of a misnomer.

Required Methods

fn get_my_profile( &self, auth_: &BearerToken, ) -> impl Future<Output = Result<UserV2, Error>>

Gets the profile of the authenticated user.

fn update_my_profile( &self, auth_: &BearerToken, update_my_profile_request: &UpdateMyProfileRequest, ) -> impl Future<Output = Result<UserV2, Error>>

Updates the profile of the authenticated user.

fn get_my_settings( &self, auth_: &BearerToken, ) -> impl Future<Output = Result<UserSettings, Error>>

Gets the settings of the authenticated user.

fn update_my_settings( &self, auth_: &BearerToken, user_settings: &UserSettings, ) -> impl Future<Output = Result<UserSettings, Error>>

Updates the settings of the authenticated user.

fn get_my_org_settings( &self, auth_: &BearerToken, ) -> impl Future<Output = Result<OrgSettings, Error>>

Gets the settings of the org of the authenticated user.

fn update_my_org_settings( &self, auth_: &BearerToken, org_settings: &OrgSettings, ) -> impl Future<Output = Result<OrgSettings, Error>>

Updates the settings of the org of the authenticated user.

fn search_users_v2( &self, auth_: &BearerToken, request: &SearchUsersRequest, ) -> impl Future<Output = Result<SearchUsersResponseV2, Error>>

Searches for users by email and displayName.

fn get_users( &self, auth_: &BearerToken, user_rids: &BTreeSet<UserRid>, ) -> impl Future<Output = Result<BTreeSet<UserV2>, Error>>

Get users by RID.

fn get_user( &self, auth_: &BearerToken, user_rid: &UserRid, ) -> impl Future<Output = Result<UserV2, Error>>

Gets a user by RID.

fn get_jwks(&self) -> impl Future<Output = Result<Jwks, Error>>

Returns JWKS (JSON Web Key Set) for MediaMTX JWT verification. Only available if MediaMTX integration is enabled.

fn generate_media_mtx_token( &self, auth_: &BearerToken, request: &GenerateMediaMtxTokenRequest, ) -> impl Future<Output = Result<GenerateMediaMtxTokenResponse, Error>>

Generates a JWT token for MediaMTX authentication with a 2-hour expiration. The token is signed with the MediaMTX private key and contains the specified permissions. Requires authentication with Nominal. This endpoint is intended for internal use only.

fn get_my_coachmark_dismissals( &self, auth_: &BearerToken, request: &GetCoachmarkDismissalsRequest, ) -> impl Future<Output = Result<GetCoachmarkDismissalsResponse, Error>>

Gets coachmark dismissals for the authenticated user. Optionally filter by specific coachmark IDs.

fn dismiss_my_coachmark( &self, auth_: &BearerToken, request: &DismissCoachmarkRequest, ) -> impl Future<Output = Result<CoachmarkDismissal, Error>>

Dismisses a coachmark for the authenticated user. Records the dismissal timestamp and app version.

fn is_my_coachmark_dismissed( &self, auth_: &BearerToken, coachmark_id: &str, ) -> impl Future<Output = Result<bool, Error>>

Checks if a specific coachmark has been dismissed by the authenticated user.

fn reset_my_coachmark_dismissal( &self, auth_: &BearerToken, coachmark_id: &str, ) -> impl Future<Output = Result<(), Error>>

Resets a coachmark dismissal for the authenticated user. This allows the coachmark to be shown again. Primarily intended for testing and debugging.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors