pub struct ComputeServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C: Clone> Clone for ComputeServiceClient<C>
impl<C: Clone> Clone for ComputeServiceClient<C>
Sourcefn clone(&self) -> ComputeServiceClient<C>
fn clone(&self) -> ComputeServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<I: Iterator<Item = Result<Bytes, Error>>, __C> ComputeService<I> for ComputeServiceClient<__C>where
__C: Client<ResponseBody = I>,
impl<I: Iterator<Item = Result<Bytes, Error>>, __C> ComputeService<I> for ComputeServiceClient<__C>where
__C: Client<ResponseBody = I>,
Sourcefn compute(
&self,
auth_: &BearerToken,
request: &ComputeNodeRequest,
) -> Result<ComputeNodeResponse, Error>
fn compute( &self, auth_: &BearerToken, request: &ComputeNodeRequest, ) -> Result<ComputeNodeResponse, Error>
Computes the output of the compute graph specified by a ComputeNodeRequest.
Sourcefn parameterized_compute(
&self,
auth_: &BearerToken,
request: &ParameterizedComputeNodeRequest,
) -> Result<ParameterizedComputeNodeResponse, Error>
fn parameterized_compute( &self, auth_: &BearerToken, request: &ParameterizedComputeNodeRequest, ) -> Result<ParameterizedComputeNodeResponse, Error>
Computes the output of the compute graph specified by a ParameterizedComputeNodeRequest. A parameterized
compute request supports multiple values for a single variable, supplied by the ParameterizedContext.
Results are returned in the same order of the request.
Sourcefn compute_units(
&self,
auth_: &BearerToken,
request: &ComputeUnitsRequest,
) -> Result<ComputeUnitResult, Error>
fn compute_units( &self, auth_: &BearerToken, request: &ComputeUnitsRequest, ) -> Result<ComputeUnitResult, Error>
Returns the resulting unit for the output of a compute graph. If the resulting unit is equivalent to exactly
one existing unit in the system, it will be returned (for example, a series in Coulombs divided by a series
in Volts will return an output of Farads). If the output does not have units (for example, a range output,)
the unit result will return noUnitAvailable, and if the computation was not successful, corresponding errors
are returned.
Sourcefn batch_compute_with_units(
&self,
auth_: &BearerToken,
request: &BatchComputeWithUnitsRequest,
) -> Result<BatchComputeWithUnitsResponse, Error>
fn batch_compute_with_units( &self, auth_: &BearerToken, request: &BatchComputeWithUnitsRequest, ) -> Result<BatchComputeWithUnitsResponse, Error>
Computes the output of compute graphs specified by BatchComputeNodeRequest. Results are returned in the same
order as the request.
Sourcefn batch_compute_units(
&self,
auth_: &BearerToken,
request: &BatchComputeUnitsRequest,
) -> Result<BatchComputeUnitResult, Error>
fn batch_compute_units( &self, auth_: &BearerToken, request: &BatchComputeUnitsRequest, ) -> Result<BatchComputeUnitResult, Error>
Same as computeUnits, however this endpoint functions on a batch of requests for wire efficiency purposes. An
extra note is that this method will serialize underlying conjure errors into the BatchComputeUnitResult type,
meaning callers are required to check for errors explicitly (rather than relying on exceptions being thrown).
Sourcefn compute_with_units(
&self,
auth_: &BearerToken,
request: &ComputeWithUnitsRequest,
) -> Result<ComputeWithUnitsResponse, Error>
fn compute_with_units( &self, auth_: &BearerToken, request: &ComputeWithUnitsRequest, ) -> Result<ComputeWithUnitsResponse, Error>
Computes the output of the compute graph specified by a ComputeNodeRequest, as well as providing the resulting
unit for the output of a compute graph. If the resulting unit is equivalent to exactly one existing unit in the
system, it will be returned (for example, a series in Coulombs divided by a series in Volts will return an
output of Farads). If the output does not have units (for example, a range output,) the unit result will return
noUnitAvailable, and if the computation was not successful, corresponding errors are returned.
Sourceimpl<C: Debug> Debug for ComputeServiceClient<C>
impl<C: Debug> Debug for ComputeServiceClient<C>
Sourceimpl<C> Service<C> for ComputeServiceClient<C>
impl<C> Service<C> for ComputeServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an HTTP client.