pub trait SandboxWorkspaceService<I: Iterator<Item = Result<Bytes, Error>>> {
// Required methods
fn get_demo_workbooks(
&self,
auth_: &BearerToken,
workspace_rid: &WorkspaceRid,
) -> Result<GetDemoWorkbooksResponse, Error>;
fn set_demo_workbooks(
&self,
auth_: &BearerToken,
workspace_rid: &WorkspaceRid,
request: &SetDemoWorkbooksRequest,
) -> Result<(), Error>;
}Expand description
Service for managing demo workbooks in sandbox workspaces. All endpoints validate that the provided workspace has the human-readable ID “sandbox”.
Required Methods
Sourcefn get_demo_workbooks(
&self,
auth_: &BearerToken,
workspace_rid: &WorkspaceRid,
) -> Result<GetDemoWorkbooksResponse, Error>
fn get_demo_workbooks( &self, auth_: &BearerToken, workspace_rid: &WorkspaceRid, ) -> Result<GetDemoWorkbooksResponse, Error>
Returns the list of demo workbook RIDs for the given sandbox workspace.
Sourcefn set_demo_workbooks(
&self,
auth_: &BearerToken,
workspace_rid: &WorkspaceRid,
request: &SetDemoWorkbooksRequest,
) -> Result<(), Error>
fn set_demo_workbooks( &self, auth_: &BearerToken, workspace_rid: &WorkspaceRid, request: &SetDemoWorkbooksRequest, ) -> Result<(), Error>
Sets the list of demo workbook RIDs for the given sandbox workspace, replacing any existing entries.