pub trait LocalAsyncSpatialService<I: Stream<Item = Result<Bytes, Error>>> {
// Required methods
fn get(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<Spatial, Error>>;
fn batch_get(
&self,
auth_: &BearerToken,
request: &GetSpatialsRequest,
) -> impl Future<Output = Result<GetSpatialsResponse, Error>>;
fn search(
&self,
auth_: &BearerToken,
request: &SearchSpatialsRequest,
) -> impl Future<Output = Result<SearchSpatialsResponse, Error>>;
fn create(
&self,
auth_: &BearerToken,
request: &CreateSpatialRequest,
) -> impl Future<Output = Result<Spatial, Error>>;
fn update_metadata(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
request: &UpdateSpatialMetadataRequest,
) -> impl Future<Output = Result<Spatial, Error>>;
fn get_ingest_status(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<SpatialIngestStatus, Error>>;
fn batch_get_ingest_status(
&self,
auth_: &BearerToken,
spatial_rids: &BTreeSet<SpatialRid>,
) -> impl Future<Output = Result<BTreeMap<SpatialRid, SpatialIngestStatus>, Error>>;
fn archive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<(), Error>>;
fn unarchive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<(), Error>>;
fn import_file(
&self,
auth_: &BearerToken,
request: &ImportFileRequest,
) -> impl Future<Output = Result<ImportFileResponse, Error>>;
}Expand description
The spatial asset service manages spatial assets (point clouds, etc.) and their metadata. Spatial asset data is stored in Dagger; Scout tracks metadata and references.
Required Methods
Sourcefn get(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<Spatial, Error>>
fn get( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> impl Future<Output = Result<Spatial, Error>>
Returns spatial asset metadata associated with a spatial asset rid.
Sourcefn batch_get(
&self,
auth_: &BearerToken,
request: &GetSpatialsRequest,
) -> impl Future<Output = Result<GetSpatialsResponse, Error>>
fn batch_get( &self, auth_: &BearerToken, request: &GetSpatialsRequest, ) -> impl Future<Output = Result<GetSpatialsResponse, Error>>
Returns spatial asset metadata for each given spatial asset rid.
Sourcefn search(
&self,
auth_: &BearerToken,
request: &SearchSpatialsRequest,
) -> impl Future<Output = Result<SearchSpatialsResponse, Error>>
fn search( &self, auth_: &BearerToken, request: &SearchSpatialsRequest, ) -> impl Future<Output = Result<SearchSpatialsResponse, Error>>
Returns metadata about spatial assets that match a given query.
Sourcefn create(
&self,
auth_: &BearerToken,
request: &CreateSpatialRequest,
) -> impl Future<Output = Result<Spatial, Error>>
fn create( &self, auth_: &BearerToken, request: &CreateSpatialRequest, ) -> impl Future<Output = Result<Spatial, Error>>
Creates and persists a spatial asset entity with the given metadata.
Sourcefn update_metadata(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
request: &UpdateSpatialMetadataRequest,
) -> impl Future<Output = Result<Spatial, Error>>
fn update_metadata( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, request: &UpdateSpatialMetadataRequest, ) -> impl Future<Output = Result<Spatial, Error>>
Updates the metadata for a spatial asset associated with the given rid.
fn get_ingest_status( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> impl Future<Output = Result<SpatialIngestStatus, Error>>
fn batch_get_ingest_status( &self, auth_: &BearerToken, spatial_rids: &BTreeSet<SpatialRid>, ) -> impl Future<Output = Result<BTreeMap<SpatialRid, SpatialIngestStatus>, Error>>
Sourcefn archive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<(), Error>>
fn archive( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> impl Future<Output = Result<(), Error>>
Archives a spatial asset, excluding it from search. Can be unarchived.
Sourcefn unarchive(
&self,
auth_: &BearerToken,
spatial_rid: &SpatialRid,
) -> impl Future<Output = Result<(), Error>>
fn unarchive( &self, auth_: &BearerToken, spatial_rid: &SpatialRid, ) -> impl Future<Output = Result<(), Error>>
Unarchives a previously archived spatial asset.
Sourcefn import_file(
&self,
auth_: &BearerToken,
request: &ImportFileRequest,
) -> impl Future<Output = Result<ImportFileResponse, Error>>
fn import_file( &self, auth_: &BearerToken, request: &ImportFileRequest, ) -> impl Future<Output = Result<ImportFileResponse, Error>>
Imports a spatial data file (e.g. LAS, LAZ, PLY, PCAP). Creates a new spatial asset, processes the file, and uploads the extracted data to Dagger.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.