pub trait InternalSecretService<I: Iterator<Item = Result<Bytes, Error>>> {
// Required method
fn get_decrypted(
&self,
auth_: &BearerToken,
rid: &SecretRid,
) -> Result<DecryptedSecret, Error>;
}Expand description
The internal secrets service provides functionality for retrieving customer secrets where the “user” is a service.
Required Methods
Sourcefn get_decrypted(
&self,
auth_: &BearerToken,
rid: &SecretRid,
) -> Result<DecryptedSecret, Error>
fn get_decrypted( &self, auth_: &BearerToken, rid: &SecretRid, ) -> Result<DecryptedSecret, Error>
Get decrypted secret by rid. This is a privileged operation that is restricted to services only. This endpoint must be a conjure endpoint in order to support TLS.