pub struct LocalAsyncUploadServiceClient<C> { /* private fields */ }Trait Implementations
Sourceimpl<C> AsyncService<C> for LocalAsyncUploadServiceClient<C>
impl<C> AsyncService<C> for LocalAsyncUploadServiceClient<C>
Sourcefn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
fn new(client: C, runtime: &Arc<ConjureRuntime>) -> Self
Creates a new service wrapping an async HTTP client.
Sourceimpl<C: Clone> Clone for LocalAsyncUploadServiceClient<C>
impl<C: Clone> Clone for LocalAsyncUploadServiceClient<C>
Sourcefn clone(&self) -> LocalAsyncUploadServiceClient<C>
fn clone(&self) -> LocalAsyncUploadServiceClient<C>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<C: Debug> Debug for LocalAsyncUploadServiceClient<C>
impl<C: Debug> Debug for LocalAsyncUploadServiceClient<C>
Sourceimpl<O, I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncUploadService<O, I> for LocalAsyncUploadServiceClient<__C>where
__C: LocalAsyncClient<BodyWriter = O, ResponseBody = I>,
impl<O, I: Stream<Item = Result<Bytes, Error>>, __C> LocalAsyncUploadService<O, I> for LocalAsyncUploadServiceClient<__C>where
__C: LocalAsyncClient<BodyWriter = O, ResponseBody = I>,
Sourceasync fn initiate_multipart_upload(
&self,
auth_: &BearerToken,
upload_request: &InitiateMultipartUploadRequest,
) -> Result<InitiateMultipartUploadResponse, Error>
async fn initiate_multipart_upload( &self, auth_: &BearerToken, upload_request: &InitiateMultipartUploadRequest, ) -> Result<InitiateMultipartUploadResponse, Error>
Initiates a multipart upload to object storage.
Returns an uploadId that should be used with listParts, signPart, and completeMultipartUpload.
Sourceasync fn list_parts(
&self,
auth_: &BearerToken,
upload_id: &str,
key: &str,
) -> Result<Vec<PartWithSize>, Error>
async fn list_parts( &self, auth_: &BearerToken, upload_id: &str, key: &str, ) -> Result<Vec<PartWithSize>, Error>
Lists the parts that have been uploaded for a given uploadId.
Sourceasync fn sign_part(
&self,
auth_: &BearerToken,
upload_id: &str,
key: &str,
part_number: i32,
) -> Result<SignPartResponse, Error>
async fn sign_part( &self, auth_: &BearerToken, upload_id: &str, key: &str, part_number: i32, ) -> Result<SignPartResponse, Error>
Signs an upload request for a single part.
Returns a URL that will execute the upload without further authentication.
Sourceasync fn complete_multipart_upload(
&self,
auth_: &BearerToken,
upload_id: &str,
key: &str,
parts: &[Part],
) -> Result<CompleteMultipartUploadResponse, Error>
async fn complete_multipart_upload( &self, auth_: &BearerToken, upload_id: &str, key: &str, parts: &[Part], ) -> Result<CompleteMultipartUploadResponse, Error>
Completes a multipart upload to object storage.
This should be called after all parts have been uploaded.
Will throw EmptyMultipartUpload if there are 0 parts.
Sourceasync fn abort_multipart_upload(
&self,
auth_: &BearerToken,
upload_id: &str,
key: &str,
) -> Result<(), Error>
async fn abort_multipart_upload( &self, auth_: &BearerToken, upload_id: &str, key: &str, ) -> Result<(), Error>
Aborts a multipart upload to S3.
Frees storage used by previously uploaded parts and prevents further uploads to the same uploadId.
Sourceasync fn upload_file(
&self,
auth_: &BearerToken,
file_name: &str,
size_bytes: Option<SafeLong>,
workspace: Option<&WorkspaceRid>,
body: impl LocalAsyncWriteBody<O>,
) -> Result<S3Path, Error>
async fn upload_file( &self, auth_: &BearerToken, file_name: &str, size_bytes: Option<SafeLong>, workspace: Option<&WorkspaceRid>, body: impl LocalAsyncWriteBody<O>, ) -> Result<S3Path, Error>
Uploads a file to S3. Intended for smaller files.