pub trait AsyncIngestJobService {
// Required methods
fn get_ingest_job(
&self,
auth_: BearerToken,
ingest_job_rid: ResourceIdentifier,
) -> impl Future<Output = Result<IngestJob, Error>> + Send;
fn search_ingest_jobs(
&self,
auth_: BearerToken,
request: SearchIngestJobsRequest,
) -> impl Future<Output = Result<SearchIngestJobsResponse, Error>> + Send;
fn cancel_ingest_job(
&self,
auth_: BearerToken,
ingest_job_rid: ResourceIdentifier,
) -> impl Future<Output = Result<IngestJob, Error>> + Send;
}Expand description
Public API for querying ingest jobs.
Required Methods
Sourcefn get_ingest_job(
&self,
auth_: BearerToken,
ingest_job_rid: ResourceIdentifier,
) -> impl Future<Output = Result<IngestJob, Error>> + Send
fn get_ingest_job( &self, auth_: BearerToken, ingest_job_rid: ResourceIdentifier, ) -> impl Future<Output = Result<IngestJob, Error>> + Send
Returns a single ingest job by RID. Does not include the full ingest request details.
Sourcefn search_ingest_jobs(
&self,
auth_: BearerToken,
request: SearchIngestJobsRequest,
) -> impl Future<Output = Result<SearchIngestJobsResponse, Error>> + Send
fn search_ingest_jobs( &self, auth_: BearerToken, request: SearchIngestJobsRequest, ) -> impl Future<Output = Result<SearchIngestJobsResponse, Error>> + Send
Returns a paginated list of ingest jobs, optionally filtered by dataset.
Sourcefn cancel_ingest_job(
&self,
auth_: BearerToken,
ingest_job_rid: ResourceIdentifier,
) -> impl Future<Output = Result<IngestJob, Error>> + Send
fn cancel_ingest_job( &self, auth_: BearerToken, ingest_job_rid: ResourceIdentifier, ) -> impl Future<Output = Result<IngestJob, Error>> + Send
Cancels an ingest job. Jobs that have not yet started running (SUBMITTED, QUEUED) are transitioned directly to CANCELLED. Jobs that are IN_PROGRESS have their underlying Temporal workflow cancelled; the workflow is responsible for transitioning the job to CANCELLED and tearing down in-flight work. Cancelling a job that is already in a terminal state (COMPLETED, FAILED, CANCELLED) throws IngestJobNotCancellable.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".