DataExportService

Trait DataExportService 

pub trait DataExportService<O> {
    type ExportChannelDataBody: WriteBody<O> + 'static;

    // Required methods
    fn export_channel_data(
        &self,
        auth_: BearerToken,
        request: ExportDataRequest,
    ) -> Result<Self::ExportChannelDataBody, Error>;
    fn generate_export_channel_data_presigned_link(
        &self,
        auth_: BearerToken,
        request: ExportDataRequest,
    ) -> Result<GeneratePresignedLinkResponse, Error>;
}
Provides functionality for exporting data from Scout.

Required Associated Types

type ExportChannelDataBody: WriteBody<O> + 'static

The body type returned by the export_channel_data method.

Required Methods

fn export_channel_data( &self, auth_: BearerToken, request: ExportDataRequest, ) -> Result<Self::ExportChannelDataBody, Error>

Required permissions matches those required to compute the channels via the compute API.

Required permissions matches those required to compute the channels via the compute API.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors