pub trait AsyncResourceMetadataService {
// Required methods
fn list_properties_and_labels(
&self,
auth_: BearerToken,
request: ListPropertiesAndLabelsRequest,
) -> impl Future<Output = Result<ListPropertiesAndLabelsResponse, Error>> + Send;
fn get_metadata_usage_count(
&self,
auth_: BearerToken,
request: GetMetadataUsageCountRequest,
) -> impl Future<Output = Result<GetMetadataUsageCountResponse, Error>> + Send;
fn find_similar_label_matches(
&self,
auth_: BearerToken,
request: FindSimilarLabelMatchesRequest,
) -> impl Future<Output = Result<FindSimilarLabelMatchesResponse, Error>> + Send;
fn find_similar_property_key_matches(
&self,
auth_: BearerToken,
request: FindSimilarPropertyKeyMatchesRequest,
) -> impl Future<Output = Result<FindSimilarPropertyKeyMatchesResponse, Error>> + Send;
fn search_labels(
&self,
auth_: BearerToken,
request: SearchMetadataRequest,
) -> impl Future<Output = Result<SearchLabelsResponse, Error>> + Send;
fn search_property_keys(
&self,
auth_: BearerToken,
request: SearchMetadataRequest,
) -> impl Future<Output = Result<SearchPropertyKeysResponse, Error>> + Send;
fn search_property_values(
&self,
auth_: BearerToken,
request: SearchPropertyValuesRequest,
) -> impl Future<Output = Result<SearchPropertyValuesResponse, Error>> + Send;
}Expand description
The Resource Metadata Service provides common metadata about resources.
Required Methods
Sourcefn list_properties_and_labels(
&self,
auth_: BearerToken,
request: ListPropertiesAndLabelsRequest,
) -> impl Future<Output = Result<ListPropertiesAndLabelsResponse, Error>> + Send
fn list_properties_and_labels( &self, auth_: BearerToken, request: ListPropertiesAndLabelsRequest, ) -> impl Future<Output = Result<ListPropertiesAndLabelsResponse, Error>> + Send
Returns all existing properties (key value pairs) and labels, which can be used to organize resources such as runs and videos.
Sourcefn get_metadata_usage_count(
&self,
auth_: BearerToken,
request: GetMetadataUsageCountRequest,
) -> impl Future<Output = Result<GetMetadataUsageCountResponse, Error>> + Send
fn get_metadata_usage_count( &self, auth_: BearerToken, request: GetMetadataUsageCountRequest, ) -> impl Future<Output = Result<GetMetadataUsageCountResponse, Error>> + Send
Returns the count of resources that use a given label or property. The query can match by label, property name (key only), or a full property key+value pair. Counts are scoped to the caller’s accessible workspaces unless specific workspaces are provided.
Sourcefn find_similar_label_matches(
&self,
auth_: BearerToken,
request: FindSimilarLabelMatchesRequest,
) -> impl Future<Output = Result<FindSimilarLabelMatchesResponse, Error>> + Send
fn find_similar_label_matches( &self, auth_: BearerToken, request: FindSimilarLabelMatchesRequest, ) -> impl Future<Output = Result<FindSimilarLabelMatchesResponse, Error>> + Send
Given a set of labels, finds similar labels across the specified workspaces and resource types. Includes document count. Useful for detecting unintentional duplicate labels.
Sourcefn find_similar_property_key_matches(
&self,
auth_: BearerToken,
request: FindSimilarPropertyKeyMatchesRequest,
) -> impl Future<Output = Result<FindSimilarPropertyKeyMatchesResponse, Error>> + Send
fn find_similar_property_key_matches( &self, auth_: BearerToken, request: FindSimilarPropertyKeyMatchesRequest, ) -> impl Future<Output = Result<FindSimilarPropertyKeyMatchesResponse, Error>> + Send
Given a set of property keys, finds similar property keys across the specified workspaces and resource types. Includes document count. Useful for detecting unintentional duplicate property keys.
Sourcefn search_labels(
&self,
auth_: BearerToken,
request: SearchMetadataRequest,
) -> impl Future<Output = Result<SearchLabelsResponse, Error>> + Send
fn search_labels( &self, auth_: BearerToken, request: SearchMetadataRequest, ) -> impl Future<Output = Result<SearchLabelsResponse, Error>> + Send
Returns a paginated list of labels with document usage counts, filterable by resource type, workspace, and search text.
Sourcefn search_property_keys(
&self,
auth_: BearerToken,
request: SearchMetadataRequest,
) -> impl Future<Output = Result<SearchPropertyKeysResponse, Error>> + Send
fn search_property_keys( &self, auth_: BearerToken, request: SearchMetadataRequest, ) -> impl Future<Output = Result<SearchPropertyKeysResponse, Error>> + Send
Returns a paginated list of property keys with document usage counts, filterable by resource type, workspace, and search text.
Sourcefn search_property_values(
&self,
auth_: BearerToken,
request: SearchPropertyValuesRequest,
) -> impl Future<Output = Result<SearchPropertyValuesResponse, Error>> + Send
fn search_property_values( &self, auth_: BearerToken, request: SearchPropertyValuesRequest, ) -> impl Future<Output = Result<SearchPropertyValuesResponse, Error>> + Send
Returns a paginated list of property values for a given property key with document usage counts, filterable by resource type, workspace, and search text.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.