AsyncResourceMetadataService

Trait AsyncResourceMetadataService 

pub trait AsyncResourceMetadataService {
    // Required methods
    fn list_properties_and_labels(
        &self,
        auth_: BearerToken,
        request: ListPropertiesAndLabelsRequest,
    ) -> impl Future<Output = Result<ListPropertiesAndLabelsResponse, Error>> + Send;
    fn get_metadata_usage_count(
        &self,
        auth_: BearerToken,
        request: GetMetadataUsageCountRequest,
    ) -> impl Future<Output = Result<GetMetadataUsageCountResponse, Error>> + Send;
}
The Resource Metadata Service provides common metadata about resources.

Required Methods

fn list_properties_and_labels( &self, auth_: BearerToken, request: ListPropertiesAndLabelsRequest, ) -> impl Future<Output = Result<ListPropertiesAndLabelsResponse, Error>> + Send

Returns all existing properties (key value pairs) and labels, which can be used to organize resources such as runs and videos.

fn get_metadata_usage_count( &self, auth_: BearerToken, request: GetMetadataUsageCountRequest, ) -> impl Future<Output = Result<GetMetadataUsageCountResponse, Error>> + Send

Returns the count of resources that use a given label or property. The query can match by label, property name (key only), or a full property key+value pair. Counts are scoped to the caller’s accessible workspaces unless specific workspaces are provided.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors