AsyncSandboxWorkspaceService

Trait AsyncSandboxWorkspaceService 

pub trait AsyncSandboxWorkspaceService {
    // Required methods
    fn get_demo_workbooks(
        &self,
        auth_: BearerToken,
        workspace_rid: WorkspaceRid,
    ) -> impl Future<Output = Result<GetDemoWorkbooksResponse, Error>> + Send;
    fn set_demo_workbooks(
        &self,
        auth_: BearerToken,
        workspace_rid: WorkspaceRid,
        request: SetDemoWorkbooksRequest,
    ) -> impl Future<Output = Result<(), Error>> + Send;
}
Service for managing demo workbooks in sandbox workspaces. All endpoints validate that the provided workspace has the human-readable ID “sandbox”.

Required Methods

fn get_demo_workbooks( &self, auth_: BearerToken, workspace_rid: WorkspaceRid, ) -> impl Future<Output = Result<GetDemoWorkbooksResponse, Error>> + Send

Returns the list of demo workbook RIDs for the given sandbox workspace.

fn set_demo_workbooks( &self, auth_: BearerToken, workspace_rid: WorkspaceRid, request: SetDemoWorkbooksRequest, ) -> impl Future<Output = Result<(), Error>> + Send

Sets the list of demo workbook RIDs for the given sandbox workspace, replacing any existing entries.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors