SandboxWorkspaceService

Trait SandboxWorkspaceService 

pub trait SandboxWorkspaceService {
    // Required methods
    fn get_demo_workbooks(
        &self,
        auth_: BearerToken,
        workspace_rid: WorkspaceRid,
    ) -> Result<GetDemoWorkbooksResponse, Error>;
    fn set_demo_workbooks(
        &self,
        auth_: BearerToken,
        workspace_rid: WorkspaceRid,
        request: SetDemoWorkbooksRequest,
    ) -> Result<(), Error>;
}
Service for managing demo workbooks in sandbox workspaces. All endpoints validate that the provided workspace has the human-readable ID “sandbox”.

Required Methods

fn get_demo_workbooks( &self, auth_: BearerToken, workspace_rid: WorkspaceRid, ) -> Result<GetDemoWorkbooksResponse, Error>

Returns the list of demo workbook RIDs for the given sandbox workspace.

fn set_demo_workbooks( &self, auth_: BearerToken, workspace_rid: WorkspaceRid, request: SetDemoWorkbooksRequest, ) -> Result<(), Error>

Sets the list of demo workbook RIDs for the given sandbox workspace, replacing any existing entries.

Implementors