pub trait AsyncSpatialService {
// Required methods
fn get(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<Spatial, Error>> + Send;
fn batch_get(
&self,
auth_: BearerToken,
request: GetSpatialsRequest,
) -> impl Future<Output = Result<GetSpatialsResponse, Error>> + Send;
fn search(
&self,
auth_: BearerToken,
request: SearchSpatialsRequest,
) -> impl Future<Output = Result<SearchSpatialsResponse, Error>> + Send;
fn create(
&self,
auth_: BearerToken,
request: CreateSpatialRequest,
) -> impl Future<Output = Result<Spatial, Error>> + Send;
fn update_metadata(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
request: UpdateSpatialMetadataRequest,
) -> impl Future<Output = Result<Spatial, Error>> + Send;
fn get_ingest_status(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<SpatialIngestStatus, Error>> + Send;
fn batch_get_ingest_status(
&self,
auth_: BearerToken,
spatial_rids: BTreeSet<SpatialRid>,
) -> impl Future<Output = Result<BTreeMap<SpatialRid, SpatialIngestStatus>, Error>> + Send;
fn archive(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<(), Error>> + Send;
fn unarchive(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<(), Error>> + Send;
fn import_file(
&self,
auth_: BearerToken,
request: ImportFileRequest,
) -> impl Future<Output = Result<ImportFileResponse, Error>> + Send;
}Expand description
The spatial asset service manages spatial assets (point clouds, etc.) and their metadata. Spatial asset data is stored in Dagger; Scout tracks metadata and references.
Required Methods
Sourcefn get(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<Spatial, Error>> + Send
fn get( &self, auth_: BearerToken, spatial_rid: SpatialRid, ) -> impl Future<Output = Result<Spatial, Error>> + Send
Returns spatial asset metadata associated with a spatial asset rid.
Sourcefn batch_get(
&self,
auth_: BearerToken,
request: GetSpatialsRequest,
) -> impl Future<Output = Result<GetSpatialsResponse, Error>> + Send
fn batch_get( &self, auth_: BearerToken, request: GetSpatialsRequest, ) -> impl Future<Output = Result<GetSpatialsResponse, Error>> + Send
Returns spatial asset metadata for each given spatial asset rid.
Sourcefn search(
&self,
auth_: BearerToken,
request: SearchSpatialsRequest,
) -> impl Future<Output = Result<SearchSpatialsResponse, Error>> + Send
fn search( &self, auth_: BearerToken, request: SearchSpatialsRequest, ) -> impl Future<Output = Result<SearchSpatialsResponse, Error>> + Send
Returns metadata about spatial assets that match a given query.
Sourcefn create(
&self,
auth_: BearerToken,
request: CreateSpatialRequest,
) -> impl Future<Output = Result<Spatial, Error>> + Send
fn create( &self, auth_: BearerToken, request: CreateSpatialRequest, ) -> impl Future<Output = Result<Spatial, Error>> + Send
Creates and persists a spatial asset entity with the given metadata.
Sourcefn update_metadata(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
request: UpdateSpatialMetadataRequest,
) -> impl Future<Output = Result<Spatial, Error>> + Send
fn update_metadata( &self, auth_: BearerToken, spatial_rid: SpatialRid, request: UpdateSpatialMetadataRequest, ) -> impl Future<Output = Result<Spatial, Error>> + Send
Updates the metadata for a spatial asset associated with the given rid.
fn get_ingest_status( &self, auth_: BearerToken, spatial_rid: SpatialRid, ) -> impl Future<Output = Result<SpatialIngestStatus, Error>> + Send
fn batch_get_ingest_status( &self, auth_: BearerToken, spatial_rids: BTreeSet<SpatialRid>, ) -> impl Future<Output = Result<BTreeMap<SpatialRid, SpatialIngestStatus>, Error>> + Send
Sourcefn archive(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<(), Error>> + Send
fn archive( &self, auth_: BearerToken, spatial_rid: SpatialRid, ) -> impl Future<Output = Result<(), Error>> + Send
Archives a spatial asset, excluding it from search. Can be unarchived.
Sourcefn unarchive(
&self,
auth_: BearerToken,
spatial_rid: SpatialRid,
) -> impl Future<Output = Result<(), Error>> + Send
fn unarchive( &self, auth_: BearerToken, spatial_rid: SpatialRid, ) -> impl Future<Output = Result<(), Error>> + Send
Unarchives a previously archived spatial asset.
Sourcefn import_file(
&self,
auth_: BearerToken,
request: ImportFileRequest,
) -> impl Future<Output = Result<ImportFileResponse, Error>> + Send
fn import_file( &self, auth_: BearerToken, request: ImportFileRequest, ) -> impl Future<Output = Result<ImportFileResponse, Error>> + Send
Imports a spatial data file (e.g. LAS, LAZ, PLY, PCAP). Creates a new spatial asset, processes the file, and uploads the extracted data to Dagger.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.