Modules
- batch_
granularity_ mismatch - containerized_
extractor_ container_ failed - containerized_
extractor_ not_ found - containerized_
extractors_ not_ found - dataset_
file_ not_ found - dataset_
not_ found - empty_
multipart_ upload - failed_
to_ download_ file - failed_
to_ download_ file_ user_ error - frame_
count_ timestamps_ mismatch - incompatible_
connection_ type_ and_ log_ query - incompatible_
file_ for_ dataset - incompatible_
inputs - incorrect_
size_ bytes - ingest_
job_ not_ compatible_ for_ rerun - ingest_
job_ not_ found - invalid_
bucket - invalid_
container_ image - invalid_
custom_ timestamp_ format - invalid_
default_ tag - invalid_
output_ file_ format - invalid_
s3_ path - invalid_
url - missing_
metadata_ for_ reingest - null_
key - parallel_
reingest_ into_ dataset_ v1 - recursive_
reingest - reingest_
too_ many_ files - run_
bounds_ inverted - s3_
path_ not_ found - streaming_
session_ not_ found - unsupported_
ingest_ source - unsupported_
request_ type_ for_ re_ ingest
Structs
- Batch
Granularity Mismatch - All dataset granularities must match.
- Containerized
Extractor Container Failed - Containerized
Extractor NotFound - Containerized
Extractors NotFound - Dataset
File NotFound - The target dataset file could not be found.
- Dataset
NotFound - The target dataset could not be found.
- Empty
Multipart Upload - Failed
ToDownload File - Failed
ToDownload File User Error - Frame
Count Timestamps Mismatch - Incompatible
Connection Type AndLog Query - Incompatible
File ForDataset - Incompatible
Inputs - The inputs provided to the ingest job are incompatible with each other
- Incorrect
Size Bytes - Ingest
JobNot Compatible ForRerun - The ingest job exists but is not compatible to be re-run.
- Ingest
JobNot Found - Invalid
Bucket - Invalid
Container Image - Invalid
Custom Timestamp Format - Invalid
Default Tag - Invalid
Output File Format - Invalid
S3Path - Invalid
Url - Missing
Metadata ForReingest - The timestamp metadata required to reingest the dataset is missing and must be provided in the request.
- NullKey
- Parallel
Reingest Into Dataset V1 - Cannot ingest multiple datasets in parallel into older datasets. It is recommended to reingest all source datasets and the target dataset into a new dataset destination.
- Recursive
Reingest - The target dataset is included in the source datasets.
- Reingest
TooMany Files - The number of files to reingest is too large.
- RunBounds
Inverted - S3Path
NotFound - Streaming
Session NotFound - The streaming session could not be found.
- Unsupported
Ingest Source - Unsupported
Request Type ForRe Ingest