Modules
- cyclic_
module_ function_ definitions - function_
name_ conflict - invalid_
function_ names - invalid_
module_ api_ name - invalid_
module_ version_ string - invalid_
nested_ function_ references - invalid_
parameter_ names - module_
name_ conflict - module_
rids_ not_ found - modules_
not_ found - parameter_
name_ conflict - undefined_
module_ function_ reference - variable_
name_ conflict
Structs
- Cyclic
Module Function Definitions - One or more functions contain cyclic references to each other.
- Function
Name Conflict - One or more function names conflict with each other in the module definition.
- Invalid
Function Names - One or more function names are invalid. Function names must begin with a letter and can only contain letters, numbers, and underscores.
- Invalid
Module ApiName - The provided module API name is invalid. Module names must begin with a letter and can only contain letters, numbers, and underscores.
- Invalid
Module Version String - The provided module version string is invalid. Module version strings must be of the form “MAJOR”, where MAJOR is a non-negative integer.
- Invalid
Nested Function References - One or more functions contain invalid nested function references. Functions cannot reference other functions that are not defined in the same module.
- Invalid
Parameter Names - One or more parameter names are invalid. Parameter names must begin with a letter and can only contain letters, numbers, and underscores.
- Module
Name Conflict - A module with the given API name already exists in the current organization.
- Module
Rids NotFound - One or more modules were not found in the current workspace.
- Modules
NotFound - One or more modules were not found in the current workspace.
- Parameter
Name Conflict - One or more parameter names conflict with each other in the module definition.
- Undefined
Module Function Reference - The following function reference is undefined in the module.
- Variable
Name Conflict - One or more variable names conflict with each other in the module definition.