Module api

Module api 

Modules

bad_flink_status
invalid_client_message
invalid_computation
non_nominal_storage_locator
permission_denied
polling_only_computation
too_many_points
too_many_points_for_single_series
unavailable_result_configuration
unsupported_granularity
window_negative
window_too_large
window_with_look_back_too_large

Structs

BadFlinkStatus
Flink is required for this subscription but is currently not available. This can be because Flink is disabled or because of a temporary issue with the Flink cluster.
InvalidClientMessage
Could not parse client message.
InvalidComputation
NonNominalStorageLocator
PermissionDenied
PollingOnlyComputation
The requested compute contains nodes that support streaming but only via polling (not WebSocket). The frontend should use polling mode (HTTP requests) instead of WebSocket streaming for this query.
TooManyPoints
The subscription is operating on too many points.
TooManyPointsForSingleSeries
The subscription is operating on a series that has too many points.
UnavailableResultConfiguration
ResultConfiguration is incompatible with the requested compute.
UnsupportedGranularity
WindowNegative
WindowTooLarge
WindowWithLookBackTooLarge