Modules
- bad_
flink_ status - invalid_
client_ message - invalid_
computation - non_
nominal_ storage_ locator - permission_
denied - polling_
only_ computation - too_
many_ points - too_
many_ points_ for_ single_ series - unavailable_
result_ configuration - unsupported_
granularity - window_
negative - window_
too_ large - window_
with_ look_ back_ too_ large
Structs
- BadFlink
Status - Flink is required for this subscription but is currently not available. This can be because Flink is disabled or because of a temporary issue with the Flink cluster.
- Invalid
Client Message - Could not parse client message.
- Invalid
Computation - NonNominal
Storage Locator - Permission
Denied - Polling
Only Computation - The requested compute contains nodes that support streaming but only via polling (not WebSocket). The frontend should use polling mode (HTTP requests) instead of WebSocket streaming for this query.
- TooMany
Points - The subscription is operating on too many points.
- TooMany
Points ForSingle Series - The subscription is operating on a series that has too many points.
- Unavailable
Result Configuration - ResultConfiguration is incompatible with the requested compute.
- Unsupported
Granularity - Window
Negative - Window
TooLarge - Window
With Look Back TooLarge