Modules
- asset_
not_ found - assets_
not_ found - duplicate_
data_ scope_ names - type_
already_ exists - type_
check_ failed - type_
not_ found - type_
referenced_ by_ assets
Structs
- Asset
NotFound - Assets
NotFound - Duplicate
Data Scope Names - Multiple data scopes within the same asset share the same refname
- Type
Already Exists - Type
Check Failed - The type check failed for the following properties.
- Type
NotFound - Type
Referenced ByAssets - The type is referenced by one or more assets and cannot be deleted.