Module catalog

Module catalog 

Modules

cannot_add_to_legacy_dataset
channel_not_found
conflict_on_dataset_creation
conflict_on_dataset_file_create_or_update
conflict_on_series_creation
dataset_exists_in_other_workspace
dataset_file_not_found
dataset_not_found
datasets_not_found
granularity_mismatch
iceberg_not_supported
invalid_state_for_adding_additional_file
run_not_found
video_file_not_found

Structs

CannotAddToLegacyDataset
The current dataset is legacy and does not support multiple files. Please re-ingest this dataset.
ChannelNotFound
ConflictOnDatasetCreation
ConflictOnDatasetFileCreateOrUpdate
Dataset files must have globally unique S3 paths on creation. On update, the ingested_at timestamp must be unique.
ConflictOnSeriesCreation
DatasetExistsInOtherWorkspace
The dataset with the requested path already exists in another workspace.
DatasetFileNotFound
DatasetNotFound
DatasetsNotFound
GranularityMismatch
Different time units are not allowed for the same dataset. Must be either all nanoseconds or all picoseconds.
IcebergNotSupported
Iceberg support currently not enabled for new datasets for this environment.
InvalidStateForAddingAdditionalFile
The current dataset is not in a valid state for uploading an additional file - it is either failed or still ingesting the previous file.
RunNotFound
VideoFileNotFound