Modules
- cannot_
add_ to_ legacy_ dataset - channel_
not_ found - conflict_
on_ dataset_ creation - conflict_
on_ dataset_ file_ create_ or_ update - conflict_
on_ series_ creation - dataset_
exists_ in_ other_ workspace - dataset_
file_ not_ found - dataset_
not_ found - datasets_
not_ found - granularity_
mismatch - iceberg_
not_ supported - invalid_
state_ for_ adding_ additional_ file - run_
not_ found - video_
file_ not_ found
Structs
- Cannot
AddTo Legacy Dataset - The current dataset is legacy and does not support multiple files. Please re-ingest this dataset.
- Channel
NotFound - Conflict
OnDataset Creation - Conflict
OnDataset File Create OrUpdate - Dataset files must have globally unique S3 paths on creation. On update, the ingested_at timestamp must be unique.
- Conflict
OnSeries Creation - Dataset
Exists InOther Workspace - The dataset with the requested path already exists in another workspace.
- Dataset
File NotFound - Dataset
NotFound - Datasets
NotFound - Granularity
Mismatch - Different time units are not allowed for the same dataset. Must be either all nanoseconds or all picoseconds.
- Iceberg
NotSupported - Iceberg support currently not enabled for new datasets for this environment.
- Invalid
State ForAdding Additional File - The current dataset is not in a valid state for uploading an additional file - it is either failed or still ingesting the previous file.
- RunNot
Found - Video
File NotFound