Module api

Module api 

Modules

invalid_channel_specification
invalid_file_shift_scale_request
invalid_shift_scale_request
invalid_source_video
invalid_tags
invalid_timestamp
missing_timestamp_bound_pair
no_segments_in_bounds
not_authorized
segment_conflict
segment_conflict_v2
segment_not_found
video_file_ingest_not_complete
video_file_not_found
video_ingest_not_complete
video_not_found

Structs

InvalidChannelSpecification
Invalid channel specification (e.g., mutually exclusive parameters provided)
InvalidFileShiftScaleRequest
Attempting to shift or scale the timestamps of a video with a timestamp manifest.
InvalidShiftScaleRequest
Attempting to shift or scale the timestamps of a video file with a timestamp manifest, or scale a multi-file video.
InvalidSourceVideo
Attempting to segment a file that does not contain any video streams.
InvalidTags
The provided tags parameter is not valid JSON
InvalidTimestamp
The provided timestamp string is not in valid ISO-8601 format
MissingTimestampBoundPair
Both start and end timestamp bounds must be provided together, or neither. Either provide both bounds or neither.
NoSegmentsInBounds
The requested time bounds do not overlap with any video segments.
NotAuthorized
User is not authorized to read data from the requested datasources.
SegmentConflict
Attempting to create multiple segments with overlapping timestamps
SegmentConflictV2
Attempting to create multiple segments with overlapping timestamps for a given series
SegmentNotFound
unable to find segment at the requested timestamp.
VideoFileIngestNotComplete
Attempting to access per-file segment information before video segmentation has finished.
VideoFileNotFound
Accessing a video file by RID that does not exist or that you do not have permission to access.
VideoIngestNotComplete
Video has no segments available. The video may still be processing or ingest has not started.
VideoNotFound