Modules
- invalid_
channel_ specification - invalid_
file_ shift_ scale_ request - invalid_
shift_ scale_ request - invalid_
source_ video - invalid_
tags - invalid_
timestamp - missing_
timestamp_ bound_ pair - no_
segments_ in_ bounds - not_
authorized - segment_
conflict - segment_
conflict_ v2 - segment_
not_ found - video_
file_ ingest_ not_ complete - video_
file_ not_ found - video_
ingest_ not_ complete - video_
not_ found
Structs
- Invalid
Channel Specification - Invalid channel specification (e.g., mutually exclusive parameters provided)
- Invalid
File Shift Scale Request - Attempting to shift or scale the timestamps of a video with a timestamp manifest.
- Invalid
Shift Scale Request - Attempting to shift or scale the timestamps of a video file with a timestamp manifest, or scale a multi-file video.
- Invalid
Source Video - Attempting to segment a file that does not contain any video streams.
- Invalid
Tags - The provided tags parameter is not valid JSON
- Invalid
Timestamp - The provided timestamp string is not in valid ISO-8601 format
- Missing
Timestamp Bound Pair - Both start and end timestamp bounds must be provided together, or neither. Either provide both bounds or neither.
- NoSegments
InBounds - The requested time bounds do not overlap with any video segments.
- NotAuthorized
- User is not authorized to read data from the requested datasources.
- Segment
Conflict - Attempting to create multiple segments with overlapping timestamps
- Segment
Conflict V2 - Attempting to create multiple segments with overlapping timestamps for a given series
- Segment
NotFound - unable to find segment at the requested timestamp.
- Video
File Ingest NotComplete - Attempting to access per-file segment information before video segmentation has finished.
- Video
File NotFound - Accessing a video file by RID that does not exist or that you do not have permission to access.
- Video
Ingest NotComplete - Video has no segments available. The video may still be processing or ingest has not started.
- Video
NotFound