Module api

Module api 

Modules

array_too_large
conflicting_data_types
invalid_channel_name
invalid_data_source
invalid_struct
invalid_telegraf_timestamp
invalid_timestamp
mismatched_timestamps_and_values
points_too_large
streaming_disabled_on_dataset

Structs

ArrayTooLarge
Array size exceeds maximum allowed length.
ConflictingDataTypes
Found two different data types for the same series in the request.
InvalidChannelName
The channel name is invalid.
InvalidDataSource
The nominal data source or dataset provided is invalid.
InvalidStruct
Ingested Struct is not a valid JSON struct
InvalidTelegrafTimestamp
InvalidTimestamp
MismatchedTimestampsAndValues
Columnar streaming request contains different numbers of timestamps and values
PointsTooLarge
The size of the points being written exceeds the maximum allowed size.
StreamingDisabledOnDataset
Unsupported dataset for streaming.