Module api

Module api 

Modules

archived_status
data_source_type
deleted
deletion_in_progress
empty
error_result
granularity
handle
in_progress_result
ingest_status
ingest_status_v2
ingesting
mcap_channel_locator
parsing
property
queued
range
ref_name_and_type
serializable_error
series_data_type
set_operator
success_result
theme_aware_image
time_unit
timestamp

Structs

Deleted
DeletionInProgress
Empty
ErrorResult
InProgressResult
Ingesting
Parsing
Property
Queued
Range
RefNameAndType
SerializableError
A SerializableError is a representation of a ServiceException that exists to send error results to clients as part of a response object when directly throwing an exception is undesirable.
SuccessResult
ThemeAwareImage
Timestamp
Nanosecond precision timestamp type, represented by an epoch time in seconds and a nanosecond offset. The nanosecond offset is from the start of the epoch second, so must be less than 1 billion.

Enums

ArchivedStatus
DataSourceType
Granularity
Handle
IngestStatus
IngestStatusV2
McapChannelLocator
SeriesDataType
The data types that are available for querying.
SetOperator
TimeUnit