Modules
- archived_
status - data_
source_ type - deleted
- deletion_
in_ progress - empty
- error_
result - granularity
- handle
- in_
progress_ result - ingest_
status - ingest_
status_ v2 - ingesting
- mcap_
channel_ locator - parsing
- property
- queued
- range
- ref_
name_ and_ type - serializable_
error - series_
data_ type - set_
operator - success_
result - theme_
aware_ image - time_
unit - timestamp
Structs
- Deleted
- Deletion
InProgress - Empty
- Error
Result - InProgress
Result - Ingesting
- Parsing
- Property
- Queued
- Range
- RefName
AndType - Serializable
Error - A SerializableError is a representation of a ServiceException that exists to send error results to clients as part of a response object when directly throwing an exception is undesirable.
- Success
Result - Theme
Aware Image - Timestamp
- Nanosecond precision timestamp type, represented by an epoch time in seconds and a nanosecond offset. The nanosecond offset is from the start of the epoch second, so must be less than 1 billion.
Enums
- Archived
Status - Data
Source Type - Granularity
- Handle
- Ingest
Status - Ingest
Status V2 - Mcap
Channel Locator - Series
Data Type - The data types that are available for querying.
- SetOperator
- Time
Unit