Modules
- appearance_
setting - chart_
tooltip_ mode_ setting - coachmark_
dismissal - default_
number_ format_ configurations - default_
time_ range_ type_ setting - dismiss_
coachmark_ request - generate_
media_ mtx_ token_ request - generate_
media_ mtx_ token_ response - get_
coachmark_ dismissals_ request - get_
coachmark_ dismissals_ response - jwk
- jwks
- media_
mtx_ permission - org_rid
- org_
settings - search_
users_ query - search_
users_ request - search_
users_ response_ v2 - sort_by
- sort_
by_ field - timezone_
setting - update_
my_ profile_ request - user_
rid - user_
settings - user_v2
Structs
- Coachmark
Dismissal - A record of a coachmark dismissal, including when it was dismissed and on which app version.
- Default
Number Format Configurations - Dismiss
Coachmark Request - Request to dismiss a coachmark
- Generate
Media MtxToken Request - Request to generate a MediaMTX authentication token
- Generate
Media MtxToken Response - Response containing the generated MediaMTX token
- GetCoachmark
Dismissals Request - Request to get coachmark dismissals
- GetCoachmark
Dismissals Response - Response containing coachmark dismissals
- Jwk
- A JSON Web Key (JWK) representation for RSA public keys
- Jwks
- A JSON Web Key Set (JWKS) containing one or more keys
- Media
MtxPermission - A permission definition for MediaMTX authentication
- OrgRid
- Unique resource identifier for an Organization.
- OrgSettings
- Search
Users Request - Search
Users Response V2 - SortBy
- Update
MyProfile Request - UserRid
- User
Settings - UserV2
Enums
- Appearance
Setting - Chart
Tooltip Mode Setting - Tooltip modes which affect the data displayed in chart tooltips, primarily for time series charts. VERBOSE: Shows all the chart’s plotted series in the hover tooltip. CONCISE: Shows only the plotted series within the row currently being hovered. MULTI_ROW_CONCISE: Show separate tooltips for each row, where each shows the series plotted in that row. SINGLE: Shows only the plotted series closest to/under the cursor. NONE: Hides the tooltip entirely (also affects tooltips for other chart types).
- Default
Time Range Type Setting - Search
Users Query - Sort
ByField - Timezone
Setting