Module authorization

Module authorization 

Modules

api_key
api_key_rid
authorization_request
claim
create_api_key_request
create_api_key_response
get_access_token_from_api_key_request
get_access_token_request
get_access_token_response
get_user_orgs_request
get_user_orgs_response
is_email_allowed_request
is_email_allowed_response
list_api_key_request
list_api_key_response
okta_registration_event_data
okta_registration_request
okta_registration_response
okta_registration_status
okta_registration_user_profile
okta_update_action_command
okta_update_action_value
refresh_access_token_request
refresh_access_token_response
register_in_workspace_request

Structs

ApiKey
ApiKeyRid
AuthorizationRequest
CreateApiKeyRequest
CreateApiKeyResponse
GetAccessTokenFromApiKeyRequest
GetAccessTokenRequest
We accept an OIDC ID token issued by a trusted identity provider as proof of authentication. The ID token is validated and exchanged for a Nominal access token. This ID token should generally be short lived since it is fungible with a Nominal access token via this endpoint. An access token, if provider, is used to get user information from the OIDC userinfo endpoint. An org rid should be provided if the user is a member of multiple orgs.
GetAccessTokenResponse
GetUserOrgsRequest
We use the claims in the id token to determine which orgs the user belongs to.
GetUserOrgsResponse
IsEmailAllowedRequest
IsEmailAllowedResponse
ListApiKeyRequest
ListApiKeyResponse
OktaRegistrationEventData
OktaRegistrationRequest
OktaRegistrationResponse
OktaRegistrationUserProfile
OktaUpdateActionCommand
OktaUpdateActionValue
RefreshAccessTokenRequest
We accept an OIDC access token issued by a trusted identity provider to refresh a Nominal access token. The access token is validated and exchanged for a Nominal access token. To be used in this endpoint, the OIDC access token must contain an email claim. The org rid from the expiring session should be provided to deconflict if the user is a member of multiple orgs.
RefreshAccessTokenResponse
RegisterInWorkspaceRequest

Enums

Claim
OktaRegistrationStatus