Skip to main content Module api Copy item path Source absolute_timestamp async_handle authentication avro_stream_opts channel_config channel_prefix complete_multipart_upload_response containerized_extractor containerized_extractor_rid containerized_opts create_ingest_job_request csv_opts custom_timestamp data_source_ref_name dataflash_opts dataset_ingest_target dataset_spec deprecated_new_csv deprecated_new_data_source docker_image_source environment_variable epoch_timestamp existing_dataset_ingest_destination existing_video_ingest_destination file_extraction_input file_extraction_parameter file_filter file_output_format file_suffix gcs_ingest_source get_containerized_extractors_request get_containerized_extractors_response ingest_data_source ingest_dataset_file_details ingest_destination ingest_details ingest_job ingest_job_request ingest_job_rid ingest_job_status ingest_mcap_request ingest_mcap_response ingest_metadata ingest_options ingest_progress_v2 ingest_request ingest_response ingest_run_data_source ingest_run_request ingest_run_response ingest_source ingest_source_metadata ingest_status ingest_type ingest_video_file_details ingest_video_request ingest_video_response initiate_multipart_upload_request initiate_multipart_upload_response internal_ingest_job iso8601_timestamp journal_json_opts journal_timestamp_metadata log_time mcap_channel_config mcap_channel_config_type mcap_channels mcap_destination mcap_ingestion_output mcap_protobuf_timeseries_opts mcap_source mcap_timestamp_type mcap_video_channel_config new_data_source new_dataset_ingest_destination new_video_ingest_destination no_timestamp_manifest parquet_opts part part_with_size presigned_file_ingest_source public_authentication register_containerized_extractor_request register_containerized_extractor_response reingest_datasets_request reingest_datasets_response reingest_files_mapping relative_timestamp rerun_ingest_request resolve_streaming_session_request resolve_streaming_session_response s3_ingest_source scale_parameter search_containerized_extractors_query search_containerized_extractors_request sign_part_response streaming_session_rid streaming_session_status tag_details time_offset_spec timestamp_manifest timestamp_metadata timestamp_type update_containerized_extractor_request user_and_password_authentication utc_timestamp video_file_ingest_details video_ingest_target video_opts video_opts_v2 video_timestamp_manifest AsyncHandle AvroStreamOpts Options for ingesting Avro data with the following schema. This is a “stream-like” file format to support
use cases where a columnar/tabular format does not make sense. This closely matches Nominal’s streaming
API, making it useful for use cases where network connection drops during streaming and a backup file needs
to be created. ChannelConfig ChannelPrefix A string to prefix before every channel name in this file. Defaults to no prefix. CompleteMultipartUploadResponse ContainerizedExtractor Represents a containerized extractor that processes input files using a container. ContainerizedExtractorRid ContainerizedOpts CreateIngestJobRequest Request to create a new ingest job. CsvOpts Options for ingesting csv files. Supported file formats include .csv, .csv.gz CustomTimestamp DataSourceRefName DataflashOpts DatasetSpec DeprecatedNewCsv DockerImageSource Docker container image source definition. EnvironmentVariable Name of an environment variable to be passed to the container during extraction. EpochTimestamp ExistingDatasetIngestDestination ExistingVideoIngestDestination FileExtractionInput Defines an input file to be provided to the extractor. FileExtractionParameter Defines an input parameter to be provided to the extractor. FileSuffix The expected suffix of the file. For example, “parquet”, “json”, “csv”, etc. GcsIngestSource GetContainerizedExtractorsRequest GetContainerizedExtractorsResponse IngestDatasetFileDetails IngestJob Ingest job information IngestJobRid Unique resource identifier for an Ingest Job. IngestMcapRequest IngestMcapResponse Returns references to the data ingested from an MCAP file. IngestMetadata IngestProgressV2 IngestRequest IngestResponse IngestRunDataSource IngestRunRequest IngestRunResponse IngestSourceMetadata IngestVideoFileDetails IngestVideoRequest IngestVideoResponse InitiateMultipartUploadRequest InitiateMultipartUploadResponse InternalIngestJob Internal ingest job information including the full ingest request details. Iso8601Timestamp JournalJsonOpts JournalTimestampMetadata LogTime McapChannelConfig McapIngestionOutput McapProtobufTimeseriesOpts McapVideoChannelConfig Ingest a channel as video. This requires: NewDataSource NewDatasetIngestDestination NewVideoIngestDestination NoTimestampManifest ParquetOpts Options for ingesting parquet files.
Supported file formats include .parquet, .parquet.gz
and archives such as .tar, .tar.gz, and .zip (must set the isArchive flag). Part PartWithSize PresignedFileIngestSource PublicAuthentication RegisterContainerizedExtractorRequest RegisterContainerizedExtractorResponse ReingestDatasetsRequest ReingestDatasetsResponse The response to a reingest request.
Maps the source dataset RID and file ID to the destination dataset RID and file ID. ReingestFilesMapping Maps the source dataset file ID to the destination dataset and file ID. RelativeTimestamp RerunIngestRequest ResolveStreamingSessionRequest ResolveStreamingSessionResponse S3IngestSource SearchContainerizedExtractorsRequest SignPartResponse StreamingSessionRid Unique resource identifier for a Streaming Session. TagDetails TimestampManifest The timestamp manifest files will contain a list of absolute timestamps, in nanoseconds, that correspond to
each frame in a video. Each file should be of type JSON and store a single list, the length of which equals
the number of frames in its corresponding video. TimestampMetadata UpdateContainerizedExtractorRequest UserAndPasswordAuthentication Username and password authentication. UtcTimestamp VideoFileIngestDetails VideoOpts VideoOptsV2 AbsoluteTimestamp Authentication DatasetIngestTarget DeprecatedNewDataSource FileFilter FileOutputFormat IngestDataSource IngestDestination IngestDetails IngestJobRequest IngestJobStatus IngestOptions IngestSource IngestStatus IngestType McapChannelConfigType McapChannels McapDestination McapSource McapTimestampType ScaleParameter SearchContainerizedExtractorsQuery StreamingSessionStatus TimeOffsetSpec TimestampType VideoIngestTarget VideoTimestampManifest