pub struct NewPointCloudIngestDestination { /* private fields */ }Implementations
Sourceimpl NewPointCloudIngestDestination
impl NewPointCloudIngestDestination
pub fn description(&self) -> Option<&str>
pub fn properties(&self) -> &BTreeMap<PropertyName, PropertyValue>
pub fn labels(&self) -> &BTreeSet<Label>
Sourcepub fn workspace(&self) -> Option<&WorkspaceRid>
pub fn workspace(&self) -> Option<&WorkspaceRid>
The workspace in which to create the point cloud. If not provided, the point cloud will be created in the default workspace for the user’s organization, if the default workspace is configured.
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created point cloud.