Modules
- extractor_
manifest - extractor_
upload_ metadata - manifest_
epoch_ time_ unit - manifest_
ingest_ type - manifest_
output - manifest_
timestamp_ metadata - upload_
metadata
Structs
- Extractor
Manifest - Manifest file produced by containerized extractors to describe their outputs. This is written as manifest.json in the OUTPUT_DIR by the container.
- Extractor
Upload Metadata - Metadata file created by yeeter after uploading extractor outputs to S3. This is uploaded to S3 by yeeter and read by the Temporal activity to orchestrate ingestion.
- Manifest
Output - Describes a single output file from a containerized extractor. This is written by the container in manifest.json.
- Manifest
Timestamp Metadata - Per-output timestamp metadata for a containerized extractor output.
- Upload
Metadata - Metadata about a single file uploaded to S3 by yeeter. Enriches the original manifest entry with S3 upload information.
Enums
- Manifest
Epoch Time Unit - Time unit for a numeric epoch timestamp in a manifest output.
- Manifest
Ingest Type - Supported ingest types for containerized extractor outputs.