BatchEditAssetMetadataResponse

Struct BatchEditAssetMetadataResponse 

pub struct BatchEditAssetMetadataResponse { /* private fields */ }

Implementations

Source

impl BatchEditAssetMetadataResponse

pub fn builder() -> Builder<Complete>

Returns a new builder.

Source

impl BatchEditAssetMetadataResponse

pub fn new() -> Self

Constructs a new instance of the type.

pub fn modified_asset_rids(&self) -> &[AssetRid]

RIDs for assets that were modified by the batch edit.

pub fn conflicting_asset_rids(&self) -> &[AssetRid]

RIDs for assets that matched the source filter but already had the target property key and were skipped (SkipOnConflict behavior). Empty for operations without conflict semantics or when using OverwriteOnConflict.