Modules
- absolute_
timestamp - add_
file_ to_ dataset - all_
properties_ and_ labels_ response - batch_
get_ dataset_ files_ request - bounds
- channel
- channel_
config - channel_
details - create_
dataset - create_
dataset_ with_ uuid_ request - custom_
timestamp - dataset
- dataset_
backing_ type - dataset_
file - dataset_
file_ metadata - dataset_
file_ sort_ field - dataset_
file_ sort_ options - dataset_
file_ uri - dataset_
files_ page - dataset_
origin_ metadata - enriched_
dataset - epoch_
timestamp - get_
channels_ for_ datasets_ request - get_
datasets_ request - get_
details_ for_ channels_ request - get_
handles_ for_ datasets_ request - handle
- ingest_
progress_ v2 - ingest_
status - ingest_
tag_ metadata - iso8601_
timestamp - mark_
file_ ingest_ error - mark_
file_ ingest_ successful - origin_
file_ uri - relative_
timestamp - retention_
policy - retention_
policy_ type - s3_
handle - search_
dataset_ files_ query - search_
dataset_ files_ request - search_
dataset_ files_ response - search_
datasets_ query - search_
datasets_ request - search_
datasets_ response - skip_
rows_ config - sort_
field - sort_
options - time_
range_ filter - timestamp_
metadata - timestamp_
type - unit_
config - update_
bounds_ request - update_
dataset_ metadata - update_
ingest_ status - update_
ingest_ status_ v2 - update_
retention_ policy_ request - utc_
timestamp - video_
file_ uri - weak_
timestamp_ type
Structs
- AddFile
ToDataset - AllProperties
AndLabels Response - Batch
GetDataset Files Request - Request to batch get dataset files for a single dataset.
- Bounds
- Channel
- Channel
Config - Channel
Details - Create
Dataset - Create
Dataset With Uuid Request - Request to create a dataset with a specific UUID. Used for migrations where the UUID must be controlled by the caller.
- Custom
Timestamp - Dataset
- Dataset
File - Dataset
File Sort Options - Dataset
File Uri - Pre-signed URI that can be used to download the original file directly. Expires if the download has not been initiated within 1 minute.
- Dataset
Files Page - Dataset
Origin Metadata - Enriched
Dataset - Epoch
Timestamp - GetChannels
ForDatasets Request - GetDatasets
Request - GetDetails
ForChannels Request - GetHandles
ForDatasets Request - Ingest
Progress V2 - Ingest
TagMetadata - The tags used when ingesting the dataset file.
- Iso8601
Timestamp - Mark
File Ingest Error - Mark
File Ingest Successful - Origin
File Uri - Pre-signed URI that can be used to download an origin file directly. Expires if the download has not been initiated within 1 minute.
- Relative
Timestamp - Retention
Policy - S3Handle
- Search
Dataset Files Request - Search
Dataset Files Response - Search
Datasets Request - Search
Datasets Response - Skip
Rows Config - Sort
Options - Time
Range Filter - searches for files that intersect with the specified range.
- Timestamp
Metadata - Unit
Config - Update
Bounds Request - Update
Dataset Metadata - Update
Ingest Status - Update
Ingest Status V2 - Update
Retention Policy Request - UtcTimestamp
- Video
File Uri - Pre-signed URI that can be used to download the original video file directly. Expires if the download has not been initiated within 1 minute.
Enums
- Absolute
Timestamp - Dataset
Backing Type - Dataset
File Metadata - Dataset
File Sort Field - Handle
- Ingest
Status - Retention
Policy Type - Search
Dataset Files Query - Search
Datasets Query - Sort
Field - Timestamp
Type - Weak
Timestamp Type - If a CSV dataset is still being split, the timestamp type is not known.