pub struct BatchGetLocatorDelimitersRequest { /* private fields */ }Expand description
Batched form of getLocatorDelimiters. The map key of requests can be an arbitrary string
identifier. It will be returned in the response as part of BatchedLocatorWithDelimiter.
Implementations
Sourceimpl BatchGetLocatorDelimitersRequest
impl BatchGetLocatorDelimitersRequest
Sourcepub fn builder() -> Builder<TimeRangeStage>
pub fn builder() -> Builder<TimeRangeStage>
Returns a new builder.