pub struct LocatorChannelMetadata { /* private fields */ }Expand description
Metadata for a channel as it appears at one specific locator. Channels can have different metadata (seriesId, dataType, unit) across locators, so callers should treat each entry independently.
Implementations
Sourceimpl LocatorChannelMetadata
impl LocatorChannelMetadata
Sourcepub fn builder() -> Builder<LocatorStage>
pub fn builder() -> Builder<LocatorStage>
Returns a new builder.
Sourceimpl LocatorChannelMetadata
impl LocatorChannelMetadata
Sourcepub fn new(
locator: Locator,
series_id: SeriesMetadataRidOrLogicalSeriesRid,
) -> Self
pub fn new( locator: Locator, series_id: SeriesMetadataRidOrLogicalSeriesRid, ) -> Self
Constructs a new instance of the type.
pub fn locator(&self) -> &Locator
pub fn unit(&self) -> Option<&Unit>
pub fn description(&self) -> Option<&str>
pub fn data_type(&self) -> Option<&SeriesDataType>
pub fn series_id(&self) -> &SeriesMetadataRidOrLogicalSeriesRid