Module combined_frame

Module combined_frame 

Structs

Builder
A builder for CombinedFrame
CombinedFrame
Combines multiple frames into a single frame, merging duplicate timestamps for the same series using the specified operation.
Complete
The final stage for CombinedFrame.
NumericMergeOperationStage
The numeric_merge_operation stage for Builder.