Module event_time_shift

Module event_time_shift 

Structs

Builder
A builder for EventTimeShift
Complete
The final stage for EventTimeShift.
EventTimeShift
Shift by the start timestamp of the first event (ascending) from this query whose event time lies in the tagging interval [start, end). Query may differ from tagging events.
QueryStage
The query stage for Builder.