pub struct CombinedFrame { /* private fields */ }Expand description
Combines multiple frames into a single frame, merging duplicate timestamps for the same series using the specified operation.
Implementations
Sourceimpl CombinedFrame
impl CombinedFrame
Sourcepub fn builder() -> Builder<NumericMergeOperationStage>
pub fn builder() -> Builder<NumericMergeOperationStage>
Returns a new builder.
Sourceimpl CombinedFrame
impl CombinedFrame
Sourcepub fn new(numeric_merge_operation: NumericUnionOperation) -> Self
pub fn new(numeric_merge_operation: NumericUnionOperation) -> Self
Constructs a new instance of the type.
Sourcepub fn inputs(&self) -> &[TimeSeriesFrame]
pub fn inputs(&self) -> &[TimeSeriesFrame]
The frames to combine.
Sourcepub fn numeric_merge_operation(&self) -> &NumericUnionOperation
pub fn numeric_merge_operation(&self) -> &NumericUnionOperation
Strategy for resolving duplicate timestamps in numeric channels.