Module api

Module api 

Modules

batch_data_source_streaming_support
batch_dataset_metadata
batch_get_dataset_metadata_request
batch_streaming_support
data_source_streaming_support
dataset_metadata
get_dataset_metadata_request
streaming_not_supported_reason
streaming_support

Structs

BatchDataSourceStreamingSupport
Diagnostic details for a data source within a batched metadata request that does not support streaming.
BatchDatasetMetadata
Metadata about a dataset.
BatchGetDatasetMetadataRequest
Batched form of getDatasetMetadata. The map key of requests can be an arbitrary string identifier and is returned in diagnostic requestIds.
BatchStreamingSupport
Whether the dataset supports live streaming, plus unsupported data source diagnostics.
DataSourceStreamingSupport
Diagnostic details for a data source within the dataset that does not support streaming.
DatasetMetadata
Metadata about a dataset.
GetDatasetMetadataRequest
Dataset metadata request.
StreamingSupport
Whether the dataset supports live streaming, plus unsupported data source diagnostics.

Enums

StreamingNotSupportedReason
Why a particular data source within the dataset does not support streaming.