pub struct CreateSpatialRequest { /* private fields */ }Implementations
Sourceimpl CreateSpatialRequest
impl CreateSpatialRequest
Sourcepub fn builder() -> Builder<TitleStage>
pub fn builder() -> Builder<TitleStage>
Returns a new builder.
Sourceimpl CreateSpatialRequest
impl CreateSpatialRequest
Sourcepub fn new(title: impl Into<String>, type_metadata: SpatialTypeMetadata) -> Self
pub fn new(title: impl Into<String>, type_metadata: SpatialTypeMetadata) -> Self
Constructs a new instance of the type.
pub fn title(&self) -> &str
pub fn description(&self) -> Option<&str>
pub fn labels(&self) -> &BTreeSet<Label>
pub fn properties(&self) -> &BTreeMap<PropertyName, PropertyValue>
pub fn type_metadata(&self) -> &SpatialTypeMetadata
Sourcepub fn workspace(&self) -> Option<&WorkspaceRid>
pub fn workspace(&self) -> Option<&WorkspaceRid>
The workspace in which to create the spatial asset. If not provided, the asset will be created in the default workspace for the user’s organization, if the default workspace is configured.
Sourcepub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
pub fn marking_rids(&self) -> &BTreeSet<MarkingRid>
The markings to apply to the created spatial asset. If not provided, the asset will be visible to all users in the same workspace.