Module api

Module api 

Modules

bounds
create_segment
create_segments_request
create_segments_response
create_segments_v2_request
create_segments_v2_response
create_video_file_request
create_video_request
detailed_ingest_status
end_stream_response
enriched_video_ingest_status
error_ingest_status
error_type
file_summary
generate_whep_stream_response
generate_whip_stream_response
get_enriched_video_ingest_status_request
get_file_summaries_request
get_file_summaries_response
get_ingest_status_response
get_playlist_in_bounds_for_channel_request
get_playlist_in_bounds_request
get_segment_at_or_after_timestamp_request
get_segment_by_timestamp_request
get_segment_by_timestamp_v2_request
get_segment_metadata_for_channel_request
get_segment_summaries_in_bounds_for_channel_request
get_segment_summaries_in_bounds_request
get_streams_in_bounds_request
get_streams_in_bounds_response
get_videos_request
get_videos_response
ice_server
ingest_error
list_files_in_video_request
list_files_in_video_response
mcap_timestamp_manifest
no_timestamp_manifest
scale_parameter
search_videos_query
search_videos_request
search_videos_response
segment
segment_summary
segment_summary_v2
segment_timestamps
segment_v2
sort_field
sort_options
success_ingest_status
timestamp_mappings
update_ingest_status
update_ingest_status_request
update_video_file_request
update_video_metadata_request
video
video_all_segments_metadata
video_asset_channel
video_channel_segments_metadata
video_channel_series
video_data_source_channel
video_file
video_file_ingest_status
video_file_origin_metadata
video_file_segments_metadata
video_file_timestamp_manifest
video_ingest_status
video_origin_metadata
video_stream
video_timestamp_manifest

Structs

Bounds
CreateSegment
CreateSegmentsRequest
CreateSegmentsResponse
CreateSegmentsV2Request
Request to create video segments for channel-based ingestion. Internal use only.
CreateSegmentsV2Response
Response for creating V2 segments. Internal use only.
CreateVideoFileRequest
Request to create and persist a video file
CreateVideoRequest
EndStreamResponse
Response payload for ending an active stream session.
EnrichedVideoIngestStatus
ErrorIngestStatus
ErrorType
FileSummary
GenerateWhepStreamResponse
Response with WHEP URL, ICE servers, and token for playback
GenerateWhipStreamResponse
Response with WHIP URL and ICE servers for publishing
GetEnrichedVideoIngestStatusRequest
GetFileSummariesRequest
GetFileSummariesResponse
GetIngestStatusResponse
GetPlaylistInBoundsForChannelRequest
Request to get playlist for a video channel series. Uses channel + tags to resolve to video series metadata within the specified video.
GetPlaylistInBoundsRequest
GetSegmentAtOrAfterTimestampRequest
Request to get a segment containing the given timestamp, or the closest segment starting after it.
GetSegmentByTimestampRequest
GetSegmentByTimestampV2Request
Request to get a segment by timestamp for a video series.
GetSegmentMetadataForChannelRequest
Request to get aggregated segment metadata for a video channel series. Uses channel + tags to resolve to video series metadata. Optionally filter by time bounds.
GetSegmentSummariesInBoundsForChannelRequest
Request to get segment summaries for a video channel series. Uses channel + tags to resolve to video series metadata within the specified bounds.
GetSegmentSummariesInBoundsRequest
GetStreamsInBoundsRequest
GetStreamsInBoundsResponse
GetVideosRequest
GetVideosResponse
IceServer
WebRTC ICE server configuration
IngestError
ListFilesInVideoRequest
ListFilesInVideoResponse
McapTimestampManifest
Timestamps are derived from the mcap file containing the video frames.
NoTimestampManifest
these values will not be updated after ingest time, to allow for resetting. The updated values are stored implicitly through the segment timestamps.
SearchVideosRequest
SearchVideosResponse
Segment
SegmentSummary
Bounding timestamps for the frames within a segment. For non-frame-mapped videos, the min and max media timestamps will be empty.
SegmentSummaryV2
Bounding timestamps for the frames within a segment. Includes datasetFileId for V2 channel-based API.
SegmentV2
Segment for V2 channel-based video API (without videoRid).
SortOptions
SuccessIngestStatus
TimestampMappings
contains 2 equal-length lists, which contain the video media time and user-provided absolute time for the frame at each index. Enables frame-mapping on the front-end.
UpdateIngestStatusRequest
UpdateVideoFileRequest
Request to update metadata for a given video file.
UpdateVideoMetadataRequest
Video
VideoAllSegmentsMetadata
VideoAssetChannel
Reference a video channel via an Asset’s data scope
VideoChannelSegmentsMetadata
Aggregated segment metadata for a video channel series
VideoDataSourceChannel
Reference a video channel directly from a datasource/dataset
VideoFile
Representation of a single user-provided video file.
VideoFileOriginMetadata
Metadata about the origin of the video file. This includes the original source of the video file and additional timestamp metadata used to time-sync the video file.
VideoFileSegmentsMetadata
High-level metadata about the segments comprising a video file post-segmentation.
VideoOriginMetadata
VideoStream
Metadata for a single video stream session.

Enums

DetailedIngestStatus
ScaleParameter
SearchVideosQuery
SegmentTimestamps
SortField
UpdateIngestStatus
VideoChannelSeries
VideoFileIngestStatus
VideoFileTimestampManifest
VideoIngestStatus
VideoTimestampManifest