pub struct NominalSeriesServiceAsyncClient<T>(/* private fields */);Expand description
Create and fetch series stored by Nominal. This service is deprecated.
Implementations
Sourceimpl<T> NominalSeriesServiceAsyncClient<T>where
T: AsyncClient,
impl<T> NominalSeriesServiceAsyncClient<T>where
T: AsyncClient,
Sourcepub async fn get(
&self,
auth_: &BearerToken,
rid: &NominalSeriesRid,
) -> Result<NominalSeries, Error>
👎Deprecated: Deprecated with no replacement.
pub async fn get( &self, auth_: &BearerToken, rid: &NominalSeriesRid, ) -> Result<NominalSeries, Error>
Retrieves a series for the given series RID.
Sourcepub async fn batch_get(
&self,
auth_: &BearerToken,
rids: &BTreeSet<NominalSeriesRid>,
) -> Result<BTreeSet<NominalSeries>, Error>
👎Deprecated: Deprecated with no replacement.
pub async fn batch_get( &self, auth_: &BearerToken, rids: &BTreeSet<NominalSeriesRid>, ) -> Result<BTreeSet<NominalSeries>, Error>
Retrieves series for the given series RIDs. Excludes series that do not exist or are unauthorized. A maximum of 1000 rids can be requested.
👎Deprecated: Deprecated with no replacement.
Retrieves series that match the requested data source, channel name and tags exactly. Omits series that do not exist or are unauthorized. A maximum of 1000 rids can be requested.
Sourcepub async fn create_or_get(
&self,
auth_: &BearerToken,
request: &CreateSeriesRequest,
) -> Result<NominalSeries, Error>
👎Deprecated: Deprecated with no replacement.
pub async fn create_or_get( &self, auth_: &BearerToken, request: &CreateSeriesRequest, ) -> Result<NominalSeries, Error>
Creates a new series if it doesn’t already exist.
A series exists if there is already a series with the same channel name and tag values in the data source. Returns the series that was created or the existing series.
pub async fn batch_create_or_get( &self, auth_: &BearerToken, request: &[CreateSeriesRequest], ) -> Result<Vec<NominalSeries>, Error>
Sourcepub async fn batch_create_or_get_v2(
&self,
auth_: &BearerToken,
request: &[CreateSeriesRequest],
) -> Result<BatchCreateOrGetResponse, Error>
👎Deprecated: Deprecated with no replacement.
pub async fn batch_create_or_get_v2( &self, auth_: &BearerToken, request: &[CreateSeriesRequest], ) -> Result<BatchCreateOrGetResponse, Error>
Creates new series if they don’t already exist.
A series exists if there is already a series with the same channel name and tag values in the data source. Returns series that were created and any existing series.
Sourcepub async fn update_last_touched_at(
&self,
auth_: &BearerToken,
request: &BatchUpdateLastTouchedAtRequest,
) -> Result<(), Error>
👎Deprecated: Deprecated with no replacement.
pub async fn update_last_touched_at( &self, auth_: &BearerToken, request: &BatchUpdateLastTouchedAtRequest, ) -> Result<(), Error>
Updates the last touched at time for series. The last touched at time represents the last time a series had data written to it.
Sourcepub async fn search(
&self,
auth_: &BearerToken,
request: &SearchSeriesRequest,
) -> Result<SearchSeriesResponse, Error>
👎Deprecated: Deprecated with no replacement.
pub async fn search( &self, auth_: &BearerToken, request: &SearchSeriesRequest, ) -> Result<SearchSeriesResponse, Error>
Retrieves series that match the search query.